from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Graphics.DirectDraw
import win32more.Windows.Win32.Graphics.Gdi
import win32more.Windows.Win32.System.Com
class ACCESSRECTLIST(Structure):
    lpLink: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.ACCESSRECTLIST)
    rDest: win32more.Windows.Win32.Foundation.RECT
    lpOwner: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    lpSurfaceData: VoidPtr
    dwFlags: UInt32
    lpHeapAliasInfo: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.HEAPALIASINFO)
class ATTACHLIST(Structure):
    dwFlags: UInt32
    lpLink: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.ATTACHLIST)
    lpAttached: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_LCL)
    lpIAttached: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_INT)
DIRECTDRAW_VERSION: UInt32 = 1792
_FACDD: UInt32 = 2166
CLSID_DirectDraw: Guid = Guid('{d7b70ee0-4340-11cf-b063-0020afc2cd35}')
CLSID_DirectDraw7: Guid = Guid('{3c305196-50db-11d3-9cfe-00c04fd930c5}')
CLSID_DirectDrawClipper: Guid = Guid('{593817a0-7db3-11cf-a2de-00aa00b93356}')
DDENUM_ATTACHEDSECONDARYDEVICES: Int32 = 1
DDENUM_DETACHEDSECONDARYDEVICES: Int32 = 2
DDENUM_NONDISPLAYDEVICES: Int32 = 4
REGSTR_KEY_DDHW_DESCRIPTION: String = 'Description'
REGSTR_KEY_DDHW_DRIVERNAME: String = 'DriverName'
REGSTR_PATH_DDHW: String = 'Hardware\\DirectDrawDrivers'
DDCREATE_HARDWAREONLY: Int32 = 1
DDCREATE_EMULATIONONLY: Int32 = 2
MAX_DDDEVICEID_STRING: UInt32 = 512
DDGDI_GETHOSTIDENTIFIER: Int32 = 1
DDSD_CAPS: Int32 = 1
DDSD_HEIGHT: Int32 = 2
DDSD_WIDTH: Int32 = 4
DDSD_PITCH: Int32 = 8
DDSD_BACKBUFFERCOUNT: Int32 = 32
DDSD_ZBUFFERBITDEPTH: Int32 = 64
DDSD_ALPHABITDEPTH: Int32 = 128
DDSD_LPSURFACE: Int32 = 2048
DDSD_PIXELFORMAT: Int32 = 4096
DDSD_CKDESTOVERLAY: Int32 = 8192
DDSD_CKDESTBLT: Int32 = 16384
DDSD_CKSRCOVERLAY: Int32 = 32768
DDSD_CKSRCBLT: Int32 = 65536
DDSD_MIPMAPCOUNT: Int32 = 131072
DDSD_REFRESHRATE: Int32 = 262144
DDSD_LINEARSIZE: Int32 = 524288
DDSD_TEXTURESTAGE: Int32 = 1048576
DDSD_FVF: Int32 = 2097152
DDSD_SRCVBHANDLE: Int32 = 4194304
DDSD_DEPTH: Int32 = 8388608
DDSD_ALL: Int32 = 16775662
DDOSD_GUID: Int32 = 1
DDOSD_COMPRESSION_RATIO: Int32 = 2
DDOSD_SCAPS: Int32 = 4
DDOSD_OSCAPS: Int32 = 8
DDOSD_ALL: Int32 = 15
DDOSDCAPS_OPTCOMPRESSED: Int32 = 1
DDOSDCAPS_OPTREORDERED: Int32 = 2
DDOSDCAPS_MONOLITHICMIPMAP: Int32 = 4
DDOSDCAPS_VALIDSCAPS: Int32 = 805324800
DDOSDCAPS_VALIDOSCAPS: Int32 = 7
DDCOLOR_BRIGHTNESS: Int32 = 1
DDCOLOR_CONTRAST: Int32 = 2
DDCOLOR_HUE: Int32 = 4
DDCOLOR_SATURATION: Int32 = 8
DDCOLOR_SHARPNESS: Int32 = 16
DDCOLOR_GAMMA: Int32 = 32
DDCOLOR_COLORENABLE: Int32 = 64
DDSCAPS_RESERVED1: Int32 = 1
DDSCAPS_ALPHA: Int32 = 2
DDSCAPS_BACKBUFFER: Int32 = 4
DDSCAPS_COMPLEX: Int32 = 8
DDSCAPS_FLIP: Int32 = 16
DDSCAPS_FRONTBUFFER: Int32 = 32
DDSCAPS_OFFSCREENPLAIN: Int32 = 64
DDSCAPS_OVERLAY: Int32 = 128
DDSCAPS_PALETTE: Int32 = 256
DDSCAPS_PRIMARYSURFACE: Int32 = 512
DDSCAPS_RESERVED3: Int32 = 1024
DDSCAPS_PRIMARYSURFACELEFT: Int32 = 0
DDSCAPS_SYSTEMMEMORY: Int32 = 2048
DDSCAPS_TEXTURE: Int32 = 4096
DDSCAPS_3DDEVICE: Int32 = 8192
DDSCAPS_VIDEOMEMORY: Int32 = 16384
DDSCAPS_VISIBLE: Int32 = 32768
DDSCAPS_WRITEONLY: Int32 = 65536
DDSCAPS_ZBUFFER: Int32 = 131072
DDSCAPS_OWNDC: Int32 = 262144
DDSCAPS_LIVEVIDEO: Int32 = 524288
DDSCAPS_HWCODEC: Int32 = 1048576
DDSCAPS_MODEX: Int32 = 2097152
DDSCAPS_MIPMAP: Int32 = 4194304
DDSCAPS_RESERVED2: Int32 = 8388608
DDSCAPS_ALLOCONLOAD: Int32 = 67108864
DDSCAPS_VIDEOPORT: Int32 = 134217728
DDSCAPS_LOCALVIDMEM: Int32 = 268435456
DDSCAPS_NONLOCALVIDMEM: Int32 = 536870912
DDSCAPS_STANDARDVGAMODE: Int32 = 1073741824
DDSCAPS_OPTIMIZED: Int32 = -2147483648
DDSCAPS2_RESERVED4: Int32 = 2
DDSCAPS2_HARDWAREDEINTERLACE: Int32 = 0
DDSCAPS2_HINTDYNAMIC: Int32 = 4
DDSCAPS2_HINTSTATIC: Int32 = 8
DDSCAPS2_TEXTUREMANAGE: Int32 = 16
DDSCAPS2_RESERVED1: Int32 = 32
DDSCAPS2_RESERVED2: Int32 = 64
DDSCAPS2_OPAQUE: Int32 = 128
DDSCAPS2_HINTANTIALIASING: Int32 = 256
DDSCAPS2_CUBEMAP: Int32 = 512
DDSCAPS2_CUBEMAP_POSITIVEX: Int32 = 1024
DDSCAPS2_CUBEMAP_NEGATIVEX: Int32 = 2048
DDSCAPS2_CUBEMAP_POSITIVEY: Int32 = 4096
DDSCAPS2_CUBEMAP_NEGATIVEY: Int32 = 8192
DDSCAPS2_CUBEMAP_POSITIVEZ: Int32 = 16384
DDSCAPS2_CUBEMAP_NEGATIVEZ: Int32 = 32768
DDSCAPS2_MIPMAPSUBLEVEL: Int32 = 65536
DDSCAPS2_D3DTEXTUREMANAGE: Int32 = 131072
DDSCAPS2_DONOTPERSIST: Int32 = 262144
DDSCAPS2_STEREOSURFACELEFT: Int32 = 524288
DDSCAPS2_VOLUME: Int32 = 2097152
DDSCAPS2_NOTUSERLOCKABLE: Int32 = 4194304
DDSCAPS2_POINTS: Int32 = 8388608
DDSCAPS2_RTPATCHES: Int32 = 16777216
DDSCAPS2_NPATCHES: Int32 = 33554432
DDSCAPS2_RESERVED3: Int32 = 67108864
DDSCAPS2_DISCARDBACKBUFFER: Int32 = 268435456
DDSCAPS2_ENABLEALPHACHANNEL: Int32 = 536870912
DDSCAPS2_EXTENDEDFORMATPRIMARY: Int32 = 1073741824
DDSCAPS2_ADDITIONALPRIMARY: Int32 = -2147483648
DDSCAPS3_MULTISAMPLE_MASK: Int32 = 31
DDSCAPS3_MULTISAMPLE_QUALITY_MASK: Int32 = 224
DDSCAPS3_MULTISAMPLE_QUALITY_SHIFT: UInt32 = 5
DDSCAPS3_RESERVED1: Int32 = 256
DDSCAPS3_RESERVED2: Int32 = 512
DDSCAPS3_LIGHTWEIGHTMIPMAP: Int32 = 1024
DDSCAPS3_AUTOGENMIPMAP: Int32 = 2048
DDSCAPS3_DMAP: Int32 = 4096
DDSCAPS3_CREATESHAREDRESOURCE: Int32 = 8192
DDSCAPS3_READONLYRESOURCE: Int32 = 16384
DDSCAPS3_OPENSHAREDRESOURCE: Int32 = 32768
DDCAPS_3D: Int32 = 1
DDCAPS_ALIGNBOUNDARYDEST: Int32 = 2
DDCAPS_ALIGNSIZEDEST: Int32 = 4
DDCAPS_ALIGNBOUNDARYSRC: Int32 = 8
DDCAPS_ALIGNSIZESRC: Int32 = 16
DDCAPS_ALIGNSTRIDE: Int32 = 32
DDCAPS_BLT: Int32 = 64
DDCAPS_BLTQUEUE: Int32 = 128
DDCAPS_BLTFOURCC: Int32 = 256
DDCAPS_BLTSTRETCH: Int32 = 512
DDCAPS_GDI: Int32 = 1024
DDCAPS_OVERLAY: Int32 = 2048
DDCAPS_OVERLAYCANTCLIP: Int32 = 4096
DDCAPS_OVERLAYFOURCC: Int32 = 8192
DDCAPS_OVERLAYSTRETCH: Int32 = 16384
DDCAPS_PALETTE: Int32 = 32768
DDCAPS_PALETTEVSYNC: Int32 = 65536
DDCAPS_READSCANLINE: Int32 = 131072
DDCAPS_RESERVED1: Int32 = 262144
DDCAPS_VBI: Int32 = 524288
DDCAPS_ZBLTS: Int32 = 1048576
DDCAPS_ZOVERLAYS: Int32 = 2097152
DDCAPS_COLORKEY: Int32 = 4194304
DDCAPS_ALPHA: Int32 = 8388608
DDCAPS_COLORKEYHWASSIST: Int32 = 16777216
DDCAPS_NOHARDWARE: Int32 = 33554432
DDCAPS_BLTCOLORFILL: Int32 = 67108864
DDCAPS_BANKSWITCHED: Int32 = 134217728
DDCAPS_BLTDEPTHFILL: Int32 = 268435456
DDCAPS_CANCLIP: Int32 = 536870912
DDCAPS_CANCLIPSTRETCHED: Int32 = 1073741824
DDCAPS_CANBLTSYSMEM: Int32 = -2147483648
DDCAPS2_CERTIFIED: Int32 = 1
DDCAPS2_NO2DDURING3DSCENE: Int32 = 2
DDCAPS2_VIDEOPORT: Int32 = 4
DDCAPS2_AUTOFLIPOVERLAY: Int32 = 8
DDCAPS2_CANBOBINTERLEAVED: Int32 = 16
DDCAPS2_CANBOBNONINTERLEAVED: Int32 = 32
DDCAPS2_COLORCONTROLOVERLAY: Int32 = 64
DDCAPS2_COLORCONTROLPRIMARY: Int32 = 128
DDCAPS2_CANDROPZ16BIT: Int32 = 256
DDCAPS2_NONLOCALVIDMEM: Int32 = 512
DDCAPS2_NONLOCALVIDMEMCAPS: Int32 = 1024
DDCAPS2_NOPAGELOCKREQUIRED: Int32 = 2048
DDCAPS2_WIDESURFACES: Int32 = 4096
DDCAPS2_CANFLIPODDEVEN: Int32 = 8192
DDCAPS2_CANBOBHARDWARE: Int32 = 16384
DDCAPS2_COPYFOURCC: Int32 = 32768
DDCAPS2_PRIMARYGAMMA: Int32 = 131072
DDCAPS2_CANRENDERWINDOWED: Int32 = 524288
DDCAPS2_CANCALIBRATEGAMMA: Int32 = 1048576
DDCAPS2_FLIPINTERVAL: Int32 = 2097152
DDCAPS2_FLIPNOVSYNC: Int32 = 4194304
DDCAPS2_CANMANAGETEXTURE: Int32 = 8388608
DDCAPS2_TEXMANINNONLOCALVIDMEM: Int32 = 16777216
DDCAPS2_STEREO: Int32 = 33554432
DDCAPS2_SYSTONONLOCAL_AS_SYSTOLOCAL: Int32 = 67108864
DDCAPS2_RESERVED1: Int32 = 134217728
DDCAPS2_CANMANAGERESOURCE: Int32 = 268435456
DDCAPS2_DYNAMICTEXTURES: Int32 = 536870912
DDCAPS2_CANAUTOGENMIPMAP: Int32 = 1073741824
DDCAPS2_CANSHARERESOURCE: Int32 = -2147483648
DDFXALPHACAPS_BLTALPHAEDGEBLEND: Int32 = 1
DDFXALPHACAPS_BLTALPHAPIXELS: Int32 = 2
DDFXALPHACAPS_BLTALPHAPIXELSNEG: Int32 = 4
DDFXALPHACAPS_BLTALPHASURFACES: Int32 = 8
DDFXALPHACAPS_BLTALPHASURFACESNEG: Int32 = 16
DDFXALPHACAPS_OVERLAYALPHAEDGEBLEND: Int32 = 32
DDFXALPHACAPS_OVERLAYALPHAPIXELS: Int32 = 64
DDFXALPHACAPS_OVERLAYALPHAPIXELSNEG: Int32 = 128
DDFXALPHACAPS_OVERLAYALPHASURFACES: Int32 = 256
DDFXALPHACAPS_OVERLAYALPHASURFACESNEG: Int32 = 512
DDFXCAPS_BLTARITHSTRETCHY: Int32 = 32
DDFXCAPS_BLTARITHSTRETCHYN: Int32 = 16
DDFXCAPS_BLTMIRRORLEFTRIGHT: Int32 = 64
DDFXCAPS_BLTMIRRORUPDOWN: Int32 = 128
DDFXCAPS_BLTROTATION: Int32 = 256
DDFXCAPS_BLTROTATION90: Int32 = 512
DDFXCAPS_BLTSHRINKX: Int32 = 1024
DDFXCAPS_BLTSHRINKXN: Int32 = 2048
DDFXCAPS_BLTSHRINKY: Int32 = 4096
DDFXCAPS_BLTSHRINKYN: Int32 = 8192
DDFXCAPS_BLTSTRETCHX: Int32 = 16384
DDFXCAPS_BLTSTRETCHXN: Int32 = 32768
DDFXCAPS_BLTSTRETCHY: Int32 = 65536
DDFXCAPS_BLTSTRETCHYN: Int32 = 131072
DDFXCAPS_OVERLAYARITHSTRETCHY: Int32 = 262144
DDFXCAPS_OVERLAYARITHSTRETCHYN: Int32 = 8
DDFXCAPS_OVERLAYSHRINKX: Int32 = 524288
DDFXCAPS_OVERLAYSHRINKXN: Int32 = 1048576
DDFXCAPS_OVERLAYSHRINKY: Int32 = 2097152
DDFXCAPS_OVERLAYSHRINKYN: Int32 = 4194304
DDFXCAPS_OVERLAYSTRETCHX: Int32 = 8388608
DDFXCAPS_OVERLAYSTRETCHXN: Int32 = 16777216
DDFXCAPS_OVERLAYSTRETCHY: Int32 = 33554432
DDFXCAPS_OVERLAYSTRETCHYN: Int32 = 67108864
DDFXCAPS_OVERLAYMIRRORLEFTRIGHT: Int32 = 134217728
DDFXCAPS_OVERLAYMIRRORUPDOWN: Int32 = 268435456
DDFXCAPS_OVERLAYDEINTERLACE: Int32 = 536870912
DDFXCAPS_BLTALPHA: Int32 = 1
DDFXCAPS_BLTFILTER: Int32 = 32
DDFXCAPS_OVERLAYALPHA: Int32 = 4
DDFXCAPS_OVERLAYFILTER: Int32 = 262144
DDSVCAPS_RESERVED1: Int32 = 1
DDSVCAPS_RESERVED2: Int32 = 2
DDSVCAPS_RESERVED3: Int32 = 4
DDSVCAPS_RESERVED4: Int32 = 8
DDSVCAPS_STEREOSEQUENTIAL: Int32 = 16
DDPCAPS_4BIT: Int32 = 1
DDPCAPS_8BITENTRIES: Int32 = 2
DDPCAPS_8BIT: Int32 = 4
DDPCAPS_INITIALIZE: Int32 = 0
DDPCAPS_PRIMARYSURFACE: Int32 = 16
DDPCAPS_PRIMARYSURFACELEFT: Int32 = 32
DDPCAPS_ALLOW256: Int32 = 64
DDPCAPS_VSYNC: Int32 = 128
DDPCAPS_1BIT: Int32 = 256
DDPCAPS_2BIT: Int32 = 512
DDPCAPS_ALPHA: Int32 = 1024
DDSPD_IUNKNOWNPOINTER: Int32 = 1
DDSPD_VOLATILE: Int32 = 2
DDBD_1: Int32 = 16384
DDBD_2: Int32 = 8192
DDBD_4: Int32 = 4096
DDBD_8: Int32 = 2048
DDBD_16: Int32 = 1024
DDBD_24: Int32 = 512
DDBD_32: Int32 = 256
DDCKEY_COLORSPACE: Int32 = 1
DDCKEY_DESTBLT: Int32 = 2
DDCKEY_DESTOVERLAY: Int32 = 4
DDCKEY_SRCBLT: Int32 = 8
DDCKEY_SRCOVERLAY: Int32 = 16
DDCKEYCAPS_DESTBLT: Int32 = 1
DDCKEYCAPS_DESTBLTCLRSPACE: Int32 = 2
DDCKEYCAPS_DESTBLTCLRSPACEYUV: Int32 = 4
DDCKEYCAPS_DESTBLTYUV: Int32 = 8
DDCKEYCAPS_DESTOVERLAY: Int32 = 16
DDCKEYCAPS_DESTOVERLAYCLRSPACE: Int32 = 32
DDCKEYCAPS_DESTOVERLAYCLRSPACEYUV: Int32 = 64
DDCKEYCAPS_DESTOVERLAYONEACTIVE: Int32 = 128
DDCKEYCAPS_DESTOVERLAYYUV: Int32 = 256
DDCKEYCAPS_SRCBLT: Int32 = 512
DDCKEYCAPS_SRCBLTCLRSPACE: Int32 = 1024
DDCKEYCAPS_SRCBLTCLRSPACEYUV: Int32 = 2048
DDCKEYCAPS_SRCBLTYUV: Int32 = 4096
DDCKEYCAPS_SRCOVERLAY: Int32 = 8192
DDCKEYCAPS_SRCOVERLAYCLRSPACE: Int32 = 16384
DDCKEYCAPS_SRCOVERLAYCLRSPACEYUV: Int32 = 32768
DDCKEYCAPS_SRCOVERLAYONEACTIVE: Int32 = 65536
DDCKEYCAPS_SRCOVERLAYYUV: Int32 = 131072
DDCKEYCAPS_NOCOSTOVERLAY: Int32 = 262144
DDPF_ALPHAPIXELS: Int32 = 1
DDPF_ALPHA: Int32 = 2
DDPF_FOURCC: Int32 = 4
DDPF_PALETTEINDEXED4: Int32 = 8
DDPF_PALETTEINDEXEDTO8: Int32 = 16
DDPF_PALETTEINDEXED8: Int32 = 32
DDPF_RGB: Int32 = 64
DDPF_COMPRESSED: Int32 = 128
DDPF_RGBTOYUV: Int32 = 256
DDPF_YUV: Int32 = 512
DDPF_ZBUFFER: Int32 = 1024
DDPF_PALETTEINDEXED1: Int32 = 2048
DDPF_PALETTEINDEXED2: Int32 = 4096
DDPF_ZPIXELS: Int32 = 8192
DDPF_STENCILBUFFER: Int32 = 16384
DDPF_ALPHAPREMULT: Int32 = 32768
DDPF_LUMINANCE: Int32 = 131072
DDPF_BUMPLUMINANCE: Int32 = 262144
DDPF_BUMPDUDV: Int32 = 524288
DDENUMSURFACES_ALL: Int32 = 1
DDENUMSURFACES_MATCH: Int32 = 2
DDENUMSURFACES_NOMATCH: Int32 = 4
DDENUMSURFACES_CANBECREATED: Int32 = 8
DDENUMSURFACES_DOESEXIST: Int32 = 16
DDSDM_STANDARDVGAMODE: Int32 = 1
DDEDM_REFRESHRATES: Int32 = 1
DDEDM_STANDARDVGAMODES: Int32 = 2
DDSCL_FULLSCREEN: Int32 = 1
DDSCL_ALLOWREBOOT: Int32 = 2
DDSCL_NOWINDOWCHANGES: Int32 = 4
DDSCL_NORMAL: Int32 = 8
DDSCL_EXCLUSIVE: Int32 = 16
DDSCL_ALLOWMODEX: Int32 = 64
DDSCL_SETFOCUSWINDOW: Int32 = 128
DDSCL_SETDEVICEWINDOW: Int32 = 256
DDSCL_CREATEDEVICEWINDOW: Int32 = 512
DDSCL_MULTITHREADED: Int32 = 1024
DDSCL_FPUSETUP: Int32 = 2048
DDSCL_FPUPRESERVE: Int32 = 4096
DDBLT_ALPHADEST: Int32 = 1
DDBLT_ALPHADESTCONSTOVERRIDE: Int32 = 2
DDBLT_ALPHADESTNEG: Int32 = 4
DDBLT_ALPHADESTSURFACEOVERRIDE: Int32 = 8
DDBLT_ALPHAEDGEBLEND: Int32 = 16
DDBLT_ALPHASRC: Int32 = 32
DDBLT_ALPHASRCCONSTOVERRIDE: Int32 = 64
DDBLT_ALPHASRCNEG: Int32 = 128
DDBLT_ALPHASRCSURFACEOVERRIDE: Int32 = 256
DDBLT_ASYNC: Int32 = 512
DDBLT_COLORFILL: Int32 = 1024
DDBLT_DDFX: Int32 = 2048
DDBLT_DDROPS: Int32 = 4096
DDBLT_KEYDEST: Int32 = 8192
DDBLT_KEYDESTOVERRIDE: Int32 = 16384
DDBLT_KEYSRC: Int32 = 32768
DDBLT_KEYSRCOVERRIDE: Int32 = 65536
DDBLT_ROP: Int32 = 131072
DDBLT_ROTATIONANGLE: Int32 = 262144
DDBLT_ZBUFFER: Int32 = 524288
DDBLT_ZBUFFERDESTCONSTOVERRIDE: Int32 = 1048576
DDBLT_ZBUFFERDESTOVERRIDE: Int32 = 2097152
DDBLT_ZBUFFERSRCCONSTOVERRIDE: Int32 = 4194304
DDBLT_ZBUFFERSRCOVERRIDE: Int32 = 8388608
DDBLT_WAIT: Int32 = 16777216
DDBLT_DEPTHFILL: Int32 = 33554432
DDBLT_DONOTWAIT: Int32 = 134217728
DDBLT_PRESENTATION: Int32 = 268435456
DDBLT_LAST_PRESENTATION: Int32 = 536870912
DDBLT_EXTENDED_FLAGS: Int32 = 1073741824
DDBLT_EXTENDED_LINEAR_CONTENT: Int32 = 4
DDBLTFAST_NOCOLORKEY: UInt32 = 0
DDBLTFAST_SRCCOLORKEY: UInt32 = 1
DDBLTFAST_DESTCOLORKEY: UInt32 = 2
DDBLTFAST_WAIT: UInt32 = 16
DDBLTFAST_DONOTWAIT: UInt32 = 32
DDFLIP_WAIT: Int32 = 1
DDFLIP_EVEN: Int32 = 2
DDFLIP_ODD: Int32 = 4
DDFLIP_NOVSYNC: Int32 = 8
DDFLIP_INTERVAL2: Int32 = 33554432
DDFLIP_INTERVAL3: Int32 = 50331648
DDFLIP_INTERVAL4: Int32 = 67108864
DDFLIP_STEREO: Int32 = 16
DDFLIP_DONOTWAIT: Int32 = 32
DDOVER_ALPHADEST: Int32 = 1
DDOVER_ALPHADESTCONSTOVERRIDE: Int32 = 2
DDOVER_ALPHADESTNEG: Int32 = 4
DDOVER_ALPHADESTSURFACEOVERRIDE: Int32 = 8
DDOVER_ALPHAEDGEBLEND: Int32 = 16
DDOVER_ALPHASRC: Int32 = 32
DDOVER_ALPHASRCCONSTOVERRIDE: Int32 = 64
DDOVER_ALPHASRCNEG: Int32 = 128
DDOVER_ALPHASRCSURFACEOVERRIDE: Int32 = 256
DDOVER_HIDE: Int32 = 512
DDOVER_KEYDEST: Int32 = 1024
DDOVER_KEYDESTOVERRIDE: Int32 = 2048
DDOVER_KEYSRC: Int32 = 4096
DDOVER_KEYSRCOVERRIDE: Int32 = 8192
DDOVER_SHOW: Int32 = 16384
DDOVER_ADDDIRTYRECT: Int32 = 32768
DDOVER_REFRESHDIRTYRECTS: Int32 = 65536
DDOVER_REFRESHALL: Int32 = 131072
DDOVER_DDFX: Int32 = 524288
DDOVER_AUTOFLIP: Int32 = 1048576
DDOVER_BOB: Int32 = 2097152
DDOVER_OVERRIDEBOBWEAVE: Int32 = 4194304
DDOVER_INTERLEAVED: Int32 = 8388608
DDOVER_BOBHARDWARE: Int32 = 16777216
DDOVER_ARGBSCALEFACTORS: Int32 = 33554432
DDOVER_DEGRADEARGBSCALING: Int32 = 67108864
DDSETSURFACEDESC_RECREATEDC: Int32 = 0
DDSETSURFACEDESC_PRESERVEDC: Int32 = 1
DDLOCK_SURFACEMEMORYPTR: Int32 = 0
DDLOCK_WAIT: Int32 = 1
DDLOCK_EVENT: Int32 = 2
DDLOCK_READONLY: Int32 = 16
DDLOCK_WRITEONLY: Int32 = 32
DDLOCK_NOSYSLOCK: Int32 = 2048
DDLOCK_NOOVERWRITE: Int32 = 4096
DDLOCK_DISCARDCONTENTS: Int32 = 8192
DDLOCK_OKTOSWAP: Int32 = 8192
DDLOCK_DONOTWAIT: Int32 = 16384
DDLOCK_HASVOLUMETEXTUREBOXRECT: Int32 = 32768
DDLOCK_NODIRTYUPDATE: Int32 = 65536
DDBLTFX_ARITHSTRETCHY: Int32 = 1
DDBLTFX_MIRRORLEFTRIGHT: Int32 = 2
DDBLTFX_MIRRORUPDOWN: Int32 = 4
DDBLTFX_NOTEARING: Int32 = 8
DDBLTFX_ROTATE180: Int32 = 16
DDBLTFX_ROTATE270: Int32 = 32
DDBLTFX_ROTATE90: Int32 = 64
DDBLTFX_ZBUFFERRANGE: Int32 = 128
DDBLTFX_ZBUFFERBASEDEST: Int32 = 256
DDOVERFX_ARITHSTRETCHY: Int32 = 1
DDOVERFX_MIRRORLEFTRIGHT: Int32 = 2
DDOVERFX_MIRRORUPDOWN: Int32 = 4
DDOVERFX_DEINTERLACE: Int32 = 8
DDWAITVB_BLOCKBEGIN: Int32 = 1
DDWAITVB_BLOCKBEGINEVENT: Int32 = 2
DDWAITVB_BLOCKEND: Int32 = 4
DDGFS_CANFLIP: Int32 = 1
DDGFS_ISFLIPDONE: Int32 = 2
DDGBS_CANBLT: Int32 = 1
DDGBS_ISBLTDONE: Int32 = 2
DDENUMOVERLAYZ_BACKTOFRONT: Int32 = 0
DDENUMOVERLAYZ_FRONTTOBACK: Int32 = 1
DDOVERZ_SENDTOFRONT: Int32 = 0
DDOVERZ_SENDTOBACK: Int32 = 1
DDOVERZ_MOVEFORWARD: Int32 = 2
DDOVERZ_MOVEBACKWARD: Int32 = 3
DDOVERZ_INSERTINFRONTOF: Int32 = 4
DDOVERZ_INSERTINBACKOF: Int32 = 5
DDSGR_CALIBRATE: Int32 = 1
DDSMT_ISTESTREQUIRED: Int32 = 1
DDEM_MODEPASSED: Int32 = 1
DDEM_MODEFAILED: Int32 = 2
DDENUMRET_CANCEL: UInt32 = 0
DDENUMRET_OK: UInt32 = 1
DDERR_NOTINITIALIZED: Int32 = -2147221008
OBJECT_ISROOT: Int32 = -2147483648
DDUNSUPPORTEDMODE: UInt32 = 4294967295
GUID_MiscellaneousCallbacks: Guid = Guid('{efd60cc0-49e7-11d0-889d-00aa00bbb76a}')
GUID_VideoPortCallbacks: Guid = Guid('{efd60cc1-49e7-11d0-889d-00aa00bbb76a}')
GUID_ColorControlCallbacks: Guid = Guid('{efd60cc2-49e7-11d0-889d-00aa00bbb76a}')
GUID_VideoPortCaps: Guid = Guid('{efd60cc3-49e7-11d0-889d-00aa00bbb76a}')
GUID_D3DCallbacks2: Guid = Guid('{0ba584e1-70b6-11d0-889d-00aa00bbb76a}')
GUID_D3DCallbacks3: Guid = Guid('{ddf41230-ec0a-11d0-a9b6-00aa00c0993e}')
GUID_NonLocalVidMemCaps: Guid = Guid('{86c4fa80-8d84-11d0-94e8-00c04fc34137}')
GUID_KernelCallbacks: Guid = Guid('{80863800-6b06-11d0-9b06-00a0c903a3b8}')
GUID_KernelCaps: Guid = Guid('{ffaa7540-7aa8-11d0-9b06-00a0c903a3b8}')
GUID_D3DExtendedCaps: Guid = Guid('{7de41f80-9d93-11d0-89ab-00a0c9054129}')
GUID_ZPixelFormats: Guid = Guid('{93869880-36cf-11d1-9b1b-00aa00bbb8ae}')
GUID_DDMoreSurfaceCaps: Guid = Guid('{3b8a0466-f269-11d1-880b-00c04fd930c5}')
GUID_DDStereoMode: Guid = Guid('{f828169c-a8e8-11d2-a1f2-00a0c983eaf6}')
GUID_OptSurfaceKmodeInfo: Guid = Guid('{e05c8472-51d4-11d1-8cce-00a0c90629a8}')
GUID_OptSurfaceUmodeInfo: Guid = Guid('{9d792804-5fa8-11d1-8cd0-00a0c90629a8}')
GUID_UserModeDriverInfo: Guid = Guid('{f0b0e8e2-5f97-11d1-8cd0-00a0c90629a8}')
GUID_UserModeDriverPassword: Guid = Guid('{97f861b6-60a1-11d1-8cd0-00a0c90629a8}')
GUID_D3DParseUnknownCommandCallback: Guid = Guid('{2e04ffa0-98e4-11d1-8ce1-00a0c90629a8}')
GUID_MotionCompCallbacks: Guid = Guid('{b1122b40-5da5-11d1-8fcf-00c04fc29b4e}')
GUID_Miscellaneous2Callbacks: Guid = Guid('{406b2f00-3e5a-11d1-b640-00aa00a1f96a}')
DDPF_NOVEL_TEXTURE_FORMAT: Int32 = 1048576
DDPF_D3DFORMAT: Int32 = 2097152
D3DFORMAT_OP_TEXTURE: Int32 = 1
D3DFORMAT_OP_VOLUMETEXTURE: Int32 = 2
D3DFORMAT_OP_CUBETEXTURE: Int32 = 4
D3DFORMAT_OP_OFFSCREEN_RENDERTARGET: Int32 = 8
D3DFORMAT_OP_SAME_FORMAT_RENDERTARGET: Int32 = 16
D3DFORMAT_OP_ZSTENCIL: Int32 = 64
D3DFORMAT_OP_ZSTENCIL_WITH_ARBITRARY_COLOR_DEPTH: Int32 = 128
D3DFORMAT_OP_SAME_FORMAT_UP_TO_ALPHA_RENDERTARGET: Int32 = 256
D3DFORMAT_OP_DISPLAYMODE: Int32 = 1024
D3DFORMAT_OP_3DACCELERATION: Int32 = 2048
D3DFORMAT_OP_PIXELSIZE: Int32 = 4096
D3DFORMAT_OP_CONVERT_TO_ARGB: Int32 = 8192
D3DFORMAT_OP_OFFSCREENPLAIN: Int32 = 16384
D3DFORMAT_OP_SRGBREAD: Int32 = 32768
D3DFORMAT_OP_BUMPMAP: Int32 = 65536
D3DFORMAT_OP_DMAP: Int32 = 131072
D3DFORMAT_OP_NOFILTER: Int32 = 262144
D3DFORMAT_MEMBEROFGROUP_ARGB: Int32 = 524288
D3DFORMAT_OP_SRGBWRITE: Int32 = 1048576
D3DFORMAT_OP_NOALPHABLEND: Int32 = 2097152
D3DFORMAT_OP_AUTOGENMIPMAP: Int32 = 4194304
D3DFORMAT_OP_VERTEXTEXTURE: Int32 = 8388608
D3DFORMAT_OP_NOTEXCOORDWRAPNORMIP: Int32 = 16777216
DELETED_OK: UInt32 = 0
DELETED_LASTONE: UInt32 = 1
DELETED_NOTFOUND: UInt32 = 2
DCICOMMAND: UInt32 = 3075
DD_VERSION: Int32 = 512
DD_RUNTIME_VERSION: Int32 = 2306
DD_HAL_VERSION: UInt32 = 256
DDCREATEDRIVEROBJECT: UInt32 = 10
DDGET32BITDRIVERNAME: UInt32 = 11
DDNEWCALLBACKFNS: UInt32 = 12
DDVERSIONINFO: UInt32 = 13
DDHAL_DRIVER_DLLNAME: String = 'DDRAW16.DLL'
DDHAL_APP_DLLNAME: String = 'DDRAW.DLL'
CCHDEVICENAME: UInt32 = 32
MAX_DRIVER_NAME: UInt32 = 32
MAX_PALETTE_SIZE: UInt32 = 256
MAX_AUTOFLIP_BUFFERS: UInt32 = 10
DDSCAPS_EXECUTEBUFFER: Int32 = 8388608
DDSCAPS2_VERTEXBUFFER: Int32 = 32
DDSCAPS2_COMMANDBUFFER: Int32 = 64
DDSCAPS2_INDEXBUFFER: Int32 = 67108864
DDSCAPS3_VIDEO: Int32 = 512
D3DFMT_INTERNAL_D32: UInt32 = 71
D3DFMT_INTERNAL_S1D15: UInt32 = 72
D3DFMT_INTERNAL_D15S1: UInt32 = 73
D3DFMT_INTERNAL_S8D24: UInt32 = 74
D3DFMT_INTERNAL_D24S8: UInt32 = 75
D3DFMT_INTERNAL_X8D24: UInt32 = 76
D3DFMT_INTERNAL_D24X8: UInt32 = 77
DDHAL_PLEASEALLOC_BLOCKSIZE: Int32 = 2
DDHAL_PLEASEALLOC_LINEARSIZE: Int32 = 3
VIDMEM_ISLINEAR: Int32 = 1
VIDMEM_ISRECTANGULAR: Int32 = 2
VIDMEM_ISHEAP: Int32 = 4
VIDMEM_ISNONLOCAL: Int32 = 8
VIDMEM_ISWC: Int32 = 16
VIDMEM_HEAPDISABLED: Int32 = 32
HEAPALIASINFO_MAPPEDREAL: Int32 = 1
HEAPALIASINFO_MAPPEDDUMMY: Int32 = 2
DDHAL_CB32_DESTROYDRIVER: Int32 = 1
DDHAL_CB32_CREATESURFACE: Int32 = 2
DDHAL_CB32_SETCOLORKEY: Int32 = 4
DDHAL_CB32_SETMODE: Int32 = 8
DDHAL_CB32_WAITFORVERTICALBLANK: Int32 = 16
DDHAL_CB32_CANCREATESURFACE: Int32 = 32
DDHAL_CB32_CREATEPALETTE: Int32 = 64
DDHAL_CB32_GETSCANLINE: Int32 = 128
DDHAL_CB32_SETEXCLUSIVEMODE: Int32 = 256
DDHAL_CB32_FLIPTOGDISURFACE: Int32 = 512
DDHAL_PALCB32_DESTROYPALETTE: Int32 = 1
DDHAL_PALCB32_SETENTRIES: Int32 = 2
DDHAL_SURFCB32_DESTROYSURFACE: Int32 = 1
DDHAL_SURFCB32_FLIP: Int32 = 2
DDHAL_SURFCB32_SETCLIPLIST: Int32 = 4
DDHAL_SURFCB32_LOCK: Int32 = 8
DDHAL_SURFCB32_UNLOCK: Int32 = 16
DDHAL_SURFCB32_BLT: Int32 = 32
DDHAL_SURFCB32_SETCOLORKEY: Int32 = 64
DDHAL_SURFCB32_ADDATTACHEDSURFACE: Int32 = 128
DDHAL_SURFCB32_GETBLTSTATUS: Int32 = 256
DDHAL_SURFCB32_GETFLIPSTATUS: Int32 = 512
DDHAL_SURFCB32_UPDATEOVERLAY: Int32 = 1024
DDHAL_SURFCB32_SETOVERLAYPOSITION: Int32 = 2048
DDHAL_SURFCB32_RESERVED4: Int32 = 4096
DDHAL_SURFCB32_SETPALETTE: Int32 = 8192
DDHAL_MISCCB32_GETAVAILDRIVERMEMORY: Int32 = 1
DDHAL_MISCCB32_UPDATENONLOCALHEAP: Int32 = 2
DDHAL_MISCCB32_GETHEAPALIGNMENT: Int32 = 4
DDHAL_MISCCB32_GETSYSMEMBLTSTATUS: Int32 = 8
DDHAL_MISC2CB32_CREATESURFACEEX: Int32 = 2
DDHAL_MISC2CB32_GETDRIVERSTATE: Int32 = 4
DDHAL_MISC2CB32_DESTROYDDLOCAL: Int32 = 8
DDHAL_EXEBUFCB32_CANCREATEEXEBUF: Int32 = 1
DDHAL_EXEBUFCB32_CREATEEXEBUF: Int32 = 2
DDHAL_EXEBUFCB32_DESTROYEXEBUF: Int32 = 4
DDHAL_EXEBUFCB32_LOCKEXEBUF: Int32 = 8
DDHAL_EXEBUFCB32_UNLOCKEXEBUF: Int32 = 16
DDHAL_VPORT32_CANCREATEVIDEOPORT: Int32 = 1
DDHAL_VPORT32_CREATEVIDEOPORT: Int32 = 2
DDHAL_VPORT32_FLIP: Int32 = 4
DDHAL_VPORT32_GETBANDWIDTH: Int32 = 8
DDHAL_VPORT32_GETINPUTFORMATS: Int32 = 16
DDHAL_VPORT32_GETOUTPUTFORMATS: Int32 = 32
DDHAL_VPORT32_GETFIELD: Int32 = 128
DDHAL_VPORT32_GETLINE: Int32 = 256
DDHAL_VPORT32_GETCONNECT: Int32 = 512
DDHAL_VPORT32_DESTROY: Int32 = 1024
DDHAL_VPORT32_GETFLIPSTATUS: Int32 = 2048
DDHAL_VPORT32_UPDATE: Int32 = 4096
DDHAL_VPORT32_WAITFORSYNC: Int32 = 8192
DDHAL_VPORT32_GETSIGNALSTATUS: Int32 = 16384
DDHAL_VPORT32_COLORCONTROL: Int32 = 32768
DDHAL_COLOR_COLORCONTROL: Int32 = 1
DDHAL_KERNEL_SYNCSURFACEDATA: Int32 = 1
DDHAL_KERNEL_SYNCVIDEOPORTDATA: Int32 = 2
DDHAL_MOCOMP32_GETGUIDS: UInt32 = 1
DDHAL_MOCOMP32_GETFORMATS: UInt32 = 2
DDHAL_MOCOMP32_CREATE: UInt32 = 4
DDHAL_MOCOMP32_GETCOMPBUFFINFO: UInt32 = 8
DDHAL_MOCOMP32_GETINTERNALINFO: UInt32 = 16
DDHAL_MOCOMP32_BEGINFRAME: UInt32 = 32
DDHAL_MOCOMP32_ENDFRAME: UInt32 = 64
DDHAL_MOCOMP32_RENDER: UInt32 = 128
DDHAL_MOCOMP32_QUERYSTATUS: UInt32 = 256
DDHAL_MOCOMP32_DESTROY: UInt32 = 512
DDHAL_DRIVER_NOTHANDLED: Int32 = 0
DDHAL_DRIVER_HANDLED: Int32 = 1
DDHAL_DRIVER_NOCKEYHW: Int32 = 2
DDRAWIPAL_256: Int32 = 1
DDRAWIPAL_16: Int32 = 2
DDRAWIPAL_GDI: Int32 = 4
DDRAWIPAL_STORED_8: Int32 = 8
DDRAWIPAL_STORED_16: Int32 = 16
DDRAWIPAL_STORED_24: Int32 = 32
DDRAWIPAL_EXCLUSIVE: Int32 = 64
DDRAWIPAL_INHEL: Int32 = 128
DDRAWIPAL_DIRTY: Int32 = 256
DDRAWIPAL_ALLOW256: Int32 = 512
DDRAWIPAL_4: Int32 = 1024
DDRAWIPAL_2: Int32 = 2048
DDRAWIPAL_STORED_8INDEX: Int32 = 4096
DDRAWIPAL_ALPHA: Int32 = 8192
DDRAWICLIP_WATCHWINDOW: Int32 = 1
DDRAWICLIP_ISINITIALIZED: Int32 = 2
DDRAWICLIP_INMASTERSPRITELIST: Int32 = 4
DDAL_IMPLICIT: Int32 = 1
ACCESSRECT_VRAMSTYLE: Int32 = 1
ACCESSRECT_NOTHOLDINGWIN16LOCK: Int32 = 2
ACCESSRECT_BROKEN: Int32 = 4
PFINDEX_UNINITIALIZED: UInt32 = 0
DDRAWISURFGBL_MEMFREE: Int32 = 1
DDRAWISURFGBL_SYSMEMREQUESTED: Int32 = 2
DDRAWISURFGBL_ISGDISURFACE: Int32 = 4
DDRAWISURFGBL_SOFTWAREAUTOFLIP: Int32 = 8
DDRAWISURFGBL_LOCKNOTHOLDINGWIN16LOCK: Int32 = 16
DDRAWISURFGBL_LOCKVRAMSTYLE: Int32 = 32
DDRAWISURFGBL_LOCKBROKEN: Int32 = 64
DDRAWISURFGBL_IMPLICITHANDLE: Int32 = 128
DDRAWISURFGBL_ISCLIENTMEM: Int32 = 256
DDRAWISURFGBL_HARDWAREOPSOURCE: Int32 = 512
DDRAWISURFGBL_HARDWAREOPDEST: Int32 = 1024
DDRAWISURFGBL_VPORTINTERLEAVED: Int32 = 2048
DDRAWISURFGBL_VPORTDATA: Int32 = 4096
DDRAWISURFGBL_LATEALLOCATELINEAR: Int32 = 8192
DDRAWISURFGBL_SYSMEMEXECUTEBUFFER: Int32 = 16384
DDRAWISURFGBL_FASTLOCKHELD: Int32 = 32768
DDRAWISURFGBL_READONLYLOCKHELD: Int32 = 65536
DDRAWISURFGBL_DX8SURFACE: Int32 = 524288
DDRAWISURFGBL_DDHELDONTFREE: Int32 = 1048576
DDRAWISURFGBL_NOTIFYWHENUNLOCKED: Int32 = 2097152
DDRAWISURFGBL_RESERVED0: Int32 = -2147483648
DDRAWISURF_ATTACHED: Int32 = 1
DDRAWISURF_IMPLICITCREATE: Int32 = 2
DDRAWISURF_ISFREE: Int32 = 4
DDRAWISURF_ATTACHED_FROM: Int32 = 8
DDRAWISURF_IMPLICITROOT: Int32 = 16
DDRAWISURF_PARTOFPRIMARYCHAIN: Int32 = 32
DDRAWISURF_DATAISALIASED: Int32 = 64
DDRAWISURF_HASDC: Int32 = 128
DDRAWISURF_HASCKEYDESTOVERLAY: Int32 = 256
DDRAWISURF_HASCKEYDESTBLT: Int32 = 512
DDRAWISURF_HASCKEYSRCOVERLAY: Int32 = 1024
DDRAWISURF_HASCKEYSRCBLT: Int32 = 2048
DDRAWISURF_LOCKEXCLUDEDCURSOR: Int32 = 4096
DDRAWISURF_HASPIXELFORMAT: Int32 = 8192
DDRAWISURF_HASOVERLAYDATA: Int32 = 16384
DDRAWISURF_SETGAMMA: Int32 = 32768
DDRAWISURF_SW_CKEYDESTOVERLAY: Int32 = 65536
DDRAWISURF_SW_CKEYDESTBLT: Int32 = 131072
DDRAWISURF_SW_CKEYSRCOVERLAY: Int32 = 262144
DDRAWISURF_SW_CKEYSRCBLT: Int32 = 524288
DDRAWISURF_HW_CKEYDESTOVERLAY: Int32 = 1048576
DDRAWISURF_HW_CKEYDESTBLT: Int32 = 2097152
DDRAWISURF_HW_CKEYSRCOVERLAY: Int32 = 4194304
DDRAWISURF_HW_CKEYSRCBLT: Int32 = 8388608
DDRAWISURF_INMASTERSPRITELIST: Int32 = 16777216
DDRAWISURF_HELCB: Int32 = 33554432
DDRAWISURF_FRONTBUFFER: Int32 = 67108864
DDRAWISURF_BACKBUFFER: Int32 = 134217728
DDRAWISURF_INVALID: Int32 = 268435456
DDRAWISURF_DCIBUSY: Int32 = 536870912
DDRAWISURF_GETDCNULL: Int32 = 1073741824
DDRAWISURF_STEREOSURFACELEFT: Int32 = 536870912
DDRAWISURF_DRIVERMANAGED: Int32 = 1073741824
DDRAWISURF_DCILOCK: Int32 = -2147483648
ROP_HAS_SOURCE: Int32 = 1
ROP_HAS_PATTERN: Int32 = 2
DDMODEINFO_PALETTIZED: UInt32 = 1
DDMODEINFO_MODEX: UInt32 = 2
DDMODEINFO_UNSUPPORTED: UInt32 = 4
DDMODEINFO_STANDARDVGA: UInt32 = 8
DDMODEINFO_MAXREFRESH: UInt32 = 16
DDMODEINFO_STEREO: UInt32 = 32
DDRAWILCL_HASEXCLUSIVEMODE: Int32 = 1
DDRAWILCL_ISFULLSCREEN: Int32 = 2
DDRAWILCL_SETCOOPCALLED: Int32 = 4
DDRAWILCL_ACTIVEYES: Int32 = 8
DDRAWILCL_ACTIVENO: Int32 = 16
DDRAWILCL_HOOKEDHWND: Int32 = 32
DDRAWILCL_ALLOWMODEX: Int32 = 64
DDRAWILCL_V1SCLBEHAVIOUR: Int32 = 128
DDRAWILCL_MODEHASBEENCHANGED: Int32 = 256
DDRAWILCL_CREATEDWINDOW: Int32 = 512
DDRAWILCL_DIRTYDC: Int32 = 1024
DDRAWILCL_DISABLEINACTIVATE: Int32 = 2048
DDRAWILCL_CURSORCLIPPED: Int32 = 4096
DDRAWILCL_EXPLICITMONITOR: Int32 = 8192
DDRAWILCL_MULTITHREADED: Int32 = 16384
DDRAWILCL_FPUSETUP: Int32 = 32768
DDRAWILCL_POWEREDDOWN: Int32 = 65536
DDRAWILCL_DIRECTDRAW7: Int32 = 131072
DDRAWILCL_ATTEMPTEDD3DCONTEXT: Int32 = 262144
DDRAWILCL_FPUPRESERVE: Int32 = 524288
DDRAWILCL_DX8DRIVER: Int32 = 1048576
DDRAWILCL_DIRECTDRAW8: Int32 = 2097152
DDRAWI_xxxxxxxxx1: Int32 = 1
DDRAWI_xxxxxxxxx2: Int32 = 2
DDRAWI_VIRTUALDESKTOP: Int32 = 8
DDRAWI_MODEX: Int32 = 16
DDRAWI_DISPLAYDRV: Int32 = 32
DDRAWI_FULLSCREEN: Int32 = 64
DDRAWI_MODECHANGED: Int32 = 128
DDRAWI_NOHARDWARE: Int32 = 256
DDRAWI_PALETTEINIT: Int32 = 512
DDRAWI_NOEMULATION: Int32 = 1024
DDRAWI_HASCKEYDESTOVERLAY: Int32 = 2048
DDRAWI_HASCKEYSRCOVERLAY: Int32 = 4096
DDRAWI_HASGDIPALETTE: Int32 = 8192
DDRAWI_EMULATIONINITIALIZED: Int32 = 16384
DDRAWI_HASGDIPALETTE_EXCLUSIVE: Int32 = 32768
DDRAWI_MODEXILLEGAL: Int32 = 65536
DDRAWI_FLIPPEDTOGDI: Int32 = 131072
DDRAWI_NEEDSWIN16FORVRAMLOCK: Int32 = 262144
DDRAWI_PDEVICEVRAMBITCLEARED: Int32 = 524288
DDRAWI_STANDARDVGA: Int32 = 1048576
DDRAWI_EXTENDEDALIGNMENT: Int32 = 2097152
DDRAWI_CHANGINGMODE: Int32 = 4194304
DDRAWI_GDIDRV: Int32 = 8388608
DDRAWI_ATTACHEDTODESKTOP: Int32 = 16777216
DDRAWI_UMODELOADED: Int32 = 33554432
DDRAWI_DDRAWDATANOTFETCHED: Int32 = 67108864
DDRAWI_SECONDARYDRIVERLOADED: Int32 = 134217728
DDRAWI_TESTINGMODES: Int32 = 268435456
DDRAWI_DRIVERINFO2: Int32 = 536870912
DDRAWI_BADPDEV: Int32 = 1073741824
DDRAWIVPORT_ON: UInt32 = 1
DDRAWIVPORT_SOFTWARE_AUTOFLIP: UInt32 = 2
DDRAWIVPORT_COLORKEYANDINTERP: UInt32 = 4
DDRAWIVPORT_NOKERNELHANDLES: UInt32 = 8
DDRAWIVPORT_SOFTWARE_BOB: UInt32 = 16
DDRAWIVPORT_VBION: UInt32 = 32
DDRAWIVPORT_VIDEOON: UInt32 = 64
DDHALINFO_ISPRIMARYDISPLAY: Int32 = 1
DDHALINFO_MODEXILLEGAL: Int32 = 2
DDHALINFO_GETDRIVERINFOSET: Int32 = 4
DDHALINFO_GETDRIVERINFO2: Int32 = 8
DDWAITVB_I_TESTVB: Int32 = -2147483642
DDRAWI_VPORTSTART: UInt32 = 1
DDRAWI_VPORTSTOP: UInt32 = 2
DDRAWI_VPORTUPDATE: UInt32 = 3
DDRAWI_VPORTGETCOLOR: UInt32 = 1
DDRAWI_VPORTSETCOLOR: UInt32 = 2
DDRAWI_GETCOLOR: UInt32 = 1
DDRAWI_SETCOLOR: UInt32 = 2
DDMCQUERY_READ: UInt32 = 1
GUID_D3DCaps: Guid = Guid('{7bf06991-8794-11d0-9139-080036d2ef02}')
GUID_D3DCallbacks: Guid = Guid('{7bf06990-8794-11d0-9139-080036d2ef02}')
GUID_DDMoreCaps: Guid = Guid('{880baf30-b030-11d0-8ea7-00609797ea5b}')
GUID_NTCallbacks: Guid = Guid('{6fe9ecde-df89-11d1-9db0-0060082771ba}')
GUID_GetHeapAlignment: Guid = Guid('{42e02f16-7b41-11d2-8bff-00a0c983eaf6}')
GUID_UpdateNonLocalHeap: Guid = Guid('{42e02f17-7b41-11d2-8bff-00a0c983eaf6}')
GUID_NTPrivateDriverCaps: Guid = Guid('{fad16a23-7b66-11d2-83d7-00c04f7ce58c}')
GUID_VPE2Callbacks: Guid = Guid('{52882147-2d47-469a-a0d1-03455890f6c8}')
DDSCAPS_COMMANDBUFFER: Int32 = 1024
DDHAL_PLEASEALLOC_USERMEM: Int32 = 4
DDHAL_CB32_MAPMEMORY: Int32 = -2147483648
DDHAL_MISC2CB32_ALPHABLT: Int32 = 1
DDHAL_CREATESURFACEEX_SWAPHANDLES: Int32 = 1
DDHAL_NTCB32_FREEDRIVERMEMORY: Int32 = 1
DDHAL_NTCB32_SETEXCLUSIVEMODE: Int32 = 2
DDHAL_NTCB32_FLIPTOGDISURFACE: Int32 = 4
DDHAL_VPORT32_GETAUTOFLIPSURF: Int32 = 64
DDHAL_D3DBUFCB32_CANCREATED3DBUF: Int32 = 1
DDHAL_D3DBUFCB32_CREATED3DBUF: Int32 = 2
DDHAL_D3DBUFCB32_DESTROYD3DBUF: Int32 = 4
DDHAL_D3DBUFCB32_LOCKD3DBUF: Int32 = 8
DDHAL_D3DBUFCB32_UNLOCKD3DBUF: Int32 = 16
DDHAL_PRIVATECAP_ATOMICSURFACECREATION: Int32 = 1
DDHAL_PRIVATECAP_NOTIFYPRIMARYCREATION: Int32 = 2
DDHAL_PRIVATECAP_RESERVED1: Int32 = 4
DDBLT_AFLAGS: Int32 = -2147483648
DDABLT_SRCOVERDEST: Int32 = 1
DDKERNELCAPS_SKIPFIELDS: Int32 = 1
DDKERNELCAPS_AUTOFLIP: Int32 = 2
DDKERNELCAPS_SETSTATE: Int32 = 4
DDKERNELCAPS_LOCK: Int32 = 8
DDKERNELCAPS_FLIPVIDEOPORT: Int32 = 16
DDKERNELCAPS_FLIPOVERLAY: Int32 = 32
DDKERNELCAPS_CAPTURE_SYSMEM: Int32 = 64
DDKERNELCAPS_CAPTURE_NONLOCALVIDMEM: Int32 = 128
DDKERNELCAPS_FIELDPOLARITY: Int32 = 256
DDKERNELCAPS_CAPTURE_INVERTED: Int32 = 512
DDIRQ_DISPLAY_VSYNC: Int32 = 1
DDIRQ_RESERVED1: Int32 = 2
DDIRQ_VPORT0_VSYNC: Int32 = 4
DDIRQ_VPORT0_LINE: Int32 = 8
DDIRQ_VPORT1_VSYNC: Int32 = 16
DDIRQ_VPORT1_LINE: Int32 = 32
DDIRQ_VPORT2_VSYNC: Int32 = 64
DDIRQ_VPORT2_LINE: Int32 = 128
DDIRQ_VPORT3_VSYNC: Int32 = 256
DDIRQ_VPORT3_LINE: Int32 = 512
DDIRQ_VPORT4_VSYNC: Int32 = 1024
DDIRQ_VPORT4_LINE: Int32 = 2048
DDIRQ_VPORT5_VSYNC: Int32 = 4096
DDIRQ_VPORT5_LINE: Int32 = 8192
DDIRQ_VPORT6_VSYNC: Int32 = 16384
DDIRQ_VPORT6_LINE: Int32 = 32768
DDIRQ_VPORT7_VSYNC: Int32 = 65536
DDIRQ_VPORT7_LINE: Int32 = 131072
DDIRQ_VPORT8_VSYNC: Int32 = 262144
DDIRQ_VPORT8_LINE: Int32 = 524288
DDIRQ_VPORT9_VSYNC: Int32 = 65536
DDIRQ_VPORT9_LINE: Int32 = 131072
SURFACEALIGN_DISCARDABLE: Int32 = 1
VMEMHEAP_LINEAR: Int32 = 1
VMEMHEAP_RECTANGULAR: Int32 = 2
VMEMHEAP_ALIGNMENT: Int32 = 4
DDVPTYPE_E_HREFH_VREFH: Guid = Guid('{54f39980-da60-11cf-9b06-00a0c903a3b8}')
DDVPTYPE_E_HREFH_VREFL: Guid = Guid('{92783220-da60-11cf-9b06-00a0c903a3b8}')
DDVPTYPE_E_HREFL_VREFH: Guid = Guid('{a07a02e0-da60-11cf-9b06-00a0c903a3b8}')
DDVPTYPE_E_HREFL_VREFL: Guid = Guid('{e09c77e0-da60-11cf-9b06-00a0c903a3b8}')
DDVPTYPE_CCIR656: Guid = Guid('{fca326a0-da60-11cf-9b06-00a0c903a3b8}')
DDVPTYPE_BROOKTREE: Guid = Guid('{1352a560-da61-11cf-9b06-00a0c903a3b8}')
DDVPTYPE_PHILIPS: Guid = Guid('{332cf160-da61-11cf-9b06-00a0c903a3b8}')
DDVPD_WIDTH: Int32 = 1
DDVPD_HEIGHT: Int32 = 2
DDVPD_ID: Int32 = 4
DDVPD_CAPS: Int32 = 8
DDVPD_FX: Int32 = 16
DDVPD_AUTOFLIP: Int32 = 32
DDVPD_ALIGN: Int32 = 64
DDVPD_PREFERREDAUTOFLIP: Int32 = 128
DDVPD_FILTERQUALITY: Int32 = 256
DDVPCONNECT_DOUBLECLOCK: Int32 = 1
DDVPCONNECT_VACT: Int32 = 2
DDVPCONNECT_INVERTPOLARITY: Int32 = 4
DDVPCONNECT_DISCARDSVREFDATA: Int32 = 8
DDVPCONNECT_HALFLINE: Int32 = 16
DDVPCONNECT_INTERLACED: Int32 = 32
DDVPCONNECT_SHAREEVEN: Int32 = 64
DDVPCONNECT_SHAREODD: Int32 = 128
DDVPCAPS_AUTOFLIP: Int32 = 1
DDVPCAPS_INTERLACED: Int32 = 2
DDVPCAPS_NONINTERLACED: Int32 = 4
DDVPCAPS_READBACKFIELD: Int32 = 8
DDVPCAPS_READBACKLINE: Int32 = 16
DDVPCAPS_SHAREABLE: Int32 = 32
DDVPCAPS_SKIPEVENFIELDS: Int32 = 64
DDVPCAPS_SKIPODDFIELDS: Int32 = 128
DDVPCAPS_SYNCMASTER: Int32 = 256
DDVPCAPS_VBISURFACE: Int32 = 512
DDVPCAPS_COLORCONTROL: Int32 = 1024
DDVPCAPS_OVERSAMPLEDVBI: Int32 = 2048
DDVPCAPS_SYSTEMMEMORY: Int32 = 4096
DDVPCAPS_VBIANDVIDEOINDEPENDENT: Int32 = 8192
DDVPCAPS_HARDWAREDEINTERLACE: Int32 = 16384
DDVPFX_CROPTOPDATA: Int32 = 1
DDVPFX_CROPX: Int32 = 2
DDVPFX_CROPY: Int32 = 4
DDVPFX_INTERLEAVE: Int32 = 8
DDVPFX_MIRRORLEFTRIGHT: Int32 = 16
DDVPFX_MIRRORUPDOWN: Int32 = 32
DDVPFX_PRESHRINKX: Int32 = 64
DDVPFX_PRESHRINKY: Int32 = 128
DDVPFX_PRESHRINKXB: Int32 = 256
DDVPFX_PRESHRINKYB: Int32 = 512
DDVPFX_PRESHRINKXS: Int32 = 1024
DDVPFX_PRESHRINKYS: Int32 = 2048
DDVPFX_PRESTRETCHX: Int32 = 4096
DDVPFX_PRESTRETCHY: Int32 = 8192
DDVPFX_PRESTRETCHXN: Int32 = 16384
DDVPFX_PRESTRETCHYN: Int32 = 32768
DDVPFX_VBICONVERT: Int32 = 65536
DDVPFX_VBINOSCALE: Int32 = 131072
DDVPFX_IGNOREVBIXCROP: Int32 = 262144
DDVPFX_VBINOINTERLEAVE: Int32 = 524288
DDVP_AUTOFLIP: Int32 = 1
DDVP_CONVERT: Int32 = 2
DDVP_CROP: Int32 = 4
DDVP_INTERLEAVE: Int32 = 8
DDVP_MIRRORLEFTRIGHT: Int32 = 16
DDVP_MIRRORUPDOWN: Int32 = 32
DDVP_PRESCALE: Int32 = 64
DDVP_SKIPEVENFIELDS: Int32 = 128
DDVP_SKIPODDFIELDS: Int32 = 256
DDVP_SYNCMASTER: Int32 = 512
DDVP_VBICONVERT: Int32 = 1024
DDVP_VBINOSCALE: Int32 = 2048
DDVP_OVERRIDEBOBWEAVE: Int32 = 4096
DDVP_IGNOREVBIXCROP: Int32 = 8192
DDVP_VBINOINTERLEAVE: Int32 = 16384
DDVP_HARDWAREDEINTERLACE: Int32 = 32768
DDVPFORMAT_VIDEO: Int32 = 1
DDVPFORMAT_VBI: Int32 = 2
DDVPTARGET_VIDEO: Int32 = 1
DDVPTARGET_VBI: Int32 = 2
DDVPWAIT_BEGIN: Int32 = 1
DDVPWAIT_END: Int32 = 2
DDVPWAIT_LINE: Int32 = 3
DDVPFLIP_VIDEO: Int32 = 1
DDVPFLIP_VBI: Int32 = 2
DDVPSQ_NOSIGNAL: Int32 = 1
DDVPSQ_SIGNALOK: Int32 = 2
DDVPB_VIDEOPORT: Int32 = 1
DDVPB_OVERLAY: Int32 = 2
DDVPB_TYPE: Int32 = 4
DDVPBCAPS_SOURCE: Int32 = 1
DDVPBCAPS_DESTINATION: Int32 = 2
DDVPCREATE_VBIONLY: Int32 = 1
DDVPCREATE_VIDEOONLY: Int32 = 2
DDVPSTATUS_VBIONLY: Int32 = 1
DDVPSTATUS_VIDEOONLY: Int32 = 2
GUID_DxApi: Guid = Guid('{8a79bef0-b915-11d0-9144-080036d2ef02}')
MDL_MAPPED_TO_SYSTEM_VA: UInt32 = 1
MDL_PAGES_LOCKED: UInt32 = 2
MDL_SOURCE_IS_NONPAGED_POOL: UInt32 = 4
MDL_ALLOCATED_FIXED_SIZE: UInt32 = 8
MDL_PARTIAL: UInt32 = 16
MDL_PARTIAL_HAS_BEEN_MAPPED: UInt32 = 32
MDL_IO_PAGE_READ: UInt32 = 64
MDL_WRITE_OPERATION: UInt32 = 128
MDL_PARENT_MAPPED_SYSTEM_VA: UInt32 = 256
MDL_LOCK_HELD: UInt32 = 512
MDL_SCATTER_GATHER_VA: UInt32 = 1024
MDL_IO_SPACE: UInt32 = 2048
MDL_NETWORK_HEADER: UInt32 = 4096
MDL_MAPPING_CAN_FAIL: UInt32 = 8192
MDL_ALLOCATED_MUST_SUCCEED: UInt32 = 16384
MDL_64_BIT_VA: UInt32 = 32768
DX_OK: UInt32 = 0
DXERR_UNSUPPORTED: UInt32 = 2147500033
DXERR_GENERIC: UInt32 = 2147500037
DXERR_OUTOFCAPS: UInt32 = 2289434984
DDIRQ_BUSMASTER: Int32 = 2
IRQINFO_HANDLED: UInt32 = 1
IRQINFO_NOTHANDLED: UInt32 = 2
DDSKIP_SKIPNEXT: UInt32 = 1
DDSKIP_ENABLENEXT: UInt32 = 2
DDTRANSFER_SYSTEMMEMORY: UInt32 = 1
DDTRANSFER_NONLOCALVIDMEM: UInt32 = 2
DDTRANSFER_INVERT: UInt32 = 4
DDTRANSFER_CANCEL: UInt32 = 128
DDTRANSFER_HALFLINES: UInt32 = 256
DXAPI_HALVERSION: UInt32 = 1
@winfunctype('DDRAW.dll')
def DirectDrawEnumerateW(lpCallback: win32more.Windows.Win32.Graphics.DirectDraw.LPDDENUMCALLBACKW, lpContext: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
DirectDrawEnumerate = UnicodeAlias('DirectDrawEnumerateW')
@winfunctype('DDRAW.dll')
def DirectDrawEnumerateA(lpCallback: win32more.Windows.Win32.Graphics.DirectDraw.LPDDENUMCALLBACKA, lpContext: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('DDRAW.dll')
def DirectDrawEnumerateExW(lpCallback: win32more.Windows.Win32.Graphics.DirectDraw.LPDDENUMCALLBACKEXW, lpContext: VoidPtr, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
DirectDrawEnumerateEx = UnicodeAlias('DirectDrawEnumerateExW')
@winfunctype('DDRAW.dll')
def DirectDrawEnumerateExA(lpCallback: win32more.Windows.Win32.Graphics.DirectDraw.LPDDENUMCALLBACKEXA, lpContext: VoidPtr, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('DDRAW.dll')
def DirectDrawCreate(lpGUID: POINTER(Guid), lplpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDraw), pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('DDRAW.dll')
def DirectDrawCreateEx(lpGuid: POINTER(Guid), lplpDD: POINTER(VoidPtr), iid: POINTER(Guid), pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('DDRAW.dll')
def DirectDrawCreateClipper(dwFlags: UInt32, lplpDDClipper: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawClipper), pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class DBLNODE(Structure):
    next: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DBLNODE)
    prev: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DBLNODE)
    object: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_LCL)
    object_int: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_INT)
class DD32BITDRIVERDATA(Structure):
    szName: win32more.Windows.Win32.Foundation.CHAR * 260
    szEntryPoint: win32more.Windows.Win32.Foundation.CHAR * 64
    dwContext: UInt32
class DDARGB(Structure):
    blue: Byte
    green: Byte
    red: Byte
    alpha: Byte
class DDBLTBATCH(Structure):
    lprDest: POINTER(win32more.Windows.Win32.Foundation.RECT)
    lpDDSSrc: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface
    lprSrc: POINTER(win32more.Windows.Win32.Foundation.RECT)
    dwFlags: UInt32
    lpDDBltFx: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDBLTFX)
class DDBLTFX(Structure):
    dwSize: UInt32
    dwDDFX: UInt32
    dwROP: UInt32
    dwDDROP: UInt32
    dwRotationAngle: UInt32
    dwZBufferOpCode: UInt32
    dwZBufferLow: UInt32
    dwZBufferHigh: UInt32
    dwZBufferBaseDest: UInt32
    dwZDestConstBitDepth: UInt32
    Anonymous1: _Anonymous1_e__Union
    dwZSrcConstBitDepth: UInt32
    Anonymous2: _Anonymous2_e__Union
    dwAlphaEdgeBlendBitDepth: UInt32
    dwAlphaEdgeBlend: UInt32
    dwReserved: UInt32
    dwAlphaDestConstBitDepth: UInt32
    Anonymous3: _Anonymous3_e__Union
    dwAlphaSrcConstBitDepth: UInt32
    Anonymous4: _Anonymous4_e__Union
    Anonymous5: _Anonymous5_e__Union
    ddckDestColorkey: win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORKEY
    ddckSrcColorkey: win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORKEY
    class _Anonymous1_e__Union(Union):
        dwZDestConst: UInt32
        lpDDSZBufferDest: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface
    class _Anonymous2_e__Union(Union):
        dwZSrcConst: UInt32
        lpDDSZBufferSrc: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface
    class _Anonymous3_e__Union(Union):
        dwAlphaDestConst: UInt32
        lpDDSAlphaDest: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface
    class _Anonymous4_e__Union(Union):
        dwAlphaSrcConst: UInt32
        lpDDSAlphaSrc: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface
    class _Anonymous5_e__Union(Union):
        dwFillColor: UInt32
        dwFillDepth: UInt32
        dwFillPixel: UInt32
        lpDDSPattern: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface
class DDBOBNEXTFIELDINFO(Structure):
    lpSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDATA)
class DDCAPS_DX1(Structure):
    dwSize: UInt32
    dwCaps: UInt32
    dwCaps2: UInt32
    dwCKeyCaps: UInt32
    dwFXCaps: UInt32
    dwFXAlphaCaps: UInt32
    dwPalCaps: UInt32
    dwSVCaps: UInt32
    dwAlphaBltConstBitDepths: UInt32
    dwAlphaBltPixelBitDepths: UInt32
    dwAlphaBltSurfaceBitDepths: UInt32
    dwAlphaOverlayConstBitDepths: UInt32
    dwAlphaOverlayPixelBitDepths: UInt32
    dwAlphaOverlaySurfaceBitDepths: UInt32
    dwZBufferBitDepths: UInt32
    dwVidMemTotal: UInt32
    dwVidMemFree: UInt32
    dwMaxVisibleOverlays: UInt32
    dwCurrVisibleOverlays: UInt32
    dwNumFourCCCodes: UInt32
    dwAlignBoundarySrc: UInt32
    dwAlignSizeSrc: UInt32
    dwAlignBoundaryDest: UInt32
    dwAlignSizeDest: UInt32
    dwAlignStrideAlign: UInt32
    dwRops: UInt32 * 8
    ddsCaps: win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPS
    dwMinOverlayStretch: UInt32
    dwMaxOverlayStretch: UInt32
    dwMinLiveVideoStretch: UInt32
    dwMaxLiveVideoStretch: UInt32
    dwMinHwCodecStretch: UInt32
    dwMaxHwCodecStretch: UInt32
    dwReserved1: UInt32
    dwReserved2: UInt32
    dwReserved3: UInt32
class DDCAPS_DX3(Structure):
    dwSize: UInt32
    dwCaps: UInt32
    dwCaps2: UInt32
    dwCKeyCaps: UInt32
    dwFXCaps: UInt32
    dwFXAlphaCaps: UInt32
    dwPalCaps: UInt32
    dwSVCaps: UInt32
    dwAlphaBltConstBitDepths: UInt32
    dwAlphaBltPixelBitDepths: UInt32
    dwAlphaBltSurfaceBitDepths: UInt32
    dwAlphaOverlayConstBitDepths: UInt32
    dwAlphaOverlayPixelBitDepths: UInt32
    dwAlphaOverlaySurfaceBitDepths: UInt32
    dwZBufferBitDepths: UInt32
    dwVidMemTotal: UInt32
    dwVidMemFree: UInt32
    dwMaxVisibleOverlays: UInt32
    dwCurrVisibleOverlays: UInt32
    dwNumFourCCCodes: UInt32
    dwAlignBoundarySrc: UInt32
    dwAlignSizeSrc: UInt32
    dwAlignBoundaryDest: UInt32
    dwAlignSizeDest: UInt32
    dwAlignStrideAlign: UInt32
    dwRops: UInt32 * 8
    ddsCaps: win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPS
    dwMinOverlayStretch: UInt32
    dwMaxOverlayStretch: UInt32
    dwMinLiveVideoStretch: UInt32
    dwMaxLiveVideoStretch: UInt32
    dwMinHwCodecStretch: UInt32
    dwMaxHwCodecStretch: UInt32
    dwReserved1: UInt32
    dwReserved2: UInt32
    dwReserved3: UInt32
    dwSVBCaps: UInt32
    dwSVBCKeyCaps: UInt32
    dwSVBFXCaps: UInt32
    dwSVBRops: UInt32 * 8
    dwVSBCaps: UInt32
    dwVSBCKeyCaps: UInt32
    dwVSBFXCaps: UInt32
    dwVSBRops: UInt32 * 8
    dwSSBCaps: UInt32
    dwSSBCKeyCaps: UInt32
    dwSSBFXCaps: UInt32
    dwSSBRops: UInt32 * 8
    dwReserved4: UInt32
    dwReserved5: UInt32
    dwReserved6: UInt32
class DDCAPS_DX5(Structure):
    dwSize: UInt32
    dwCaps: UInt32
    dwCaps2: UInt32
    dwCKeyCaps: UInt32
    dwFXCaps: UInt32
    dwFXAlphaCaps: UInt32
    dwPalCaps: UInt32
    dwSVCaps: UInt32
    dwAlphaBltConstBitDepths: UInt32
    dwAlphaBltPixelBitDepths: UInt32
    dwAlphaBltSurfaceBitDepths: UInt32
    dwAlphaOverlayConstBitDepths: UInt32
    dwAlphaOverlayPixelBitDepths: UInt32
    dwAlphaOverlaySurfaceBitDepths: UInt32
    dwZBufferBitDepths: UInt32
    dwVidMemTotal: UInt32
    dwVidMemFree: UInt32
    dwMaxVisibleOverlays: UInt32
    dwCurrVisibleOverlays: UInt32
    dwNumFourCCCodes: UInt32
    dwAlignBoundarySrc: UInt32
    dwAlignSizeSrc: UInt32
    dwAlignBoundaryDest: UInt32
    dwAlignSizeDest: UInt32
    dwAlignStrideAlign: UInt32
    dwRops: UInt32 * 8
    ddsCaps: win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPS
    dwMinOverlayStretch: UInt32
    dwMaxOverlayStretch: UInt32
    dwMinLiveVideoStretch: UInt32
    dwMaxLiveVideoStretch: UInt32
    dwMinHwCodecStretch: UInt32
    dwMaxHwCodecStretch: UInt32
    dwReserved1: UInt32
    dwReserved2: UInt32
    dwReserved3: UInt32
    dwSVBCaps: UInt32
    dwSVBCKeyCaps: UInt32
    dwSVBFXCaps: UInt32
    dwSVBRops: UInt32 * 8
    dwVSBCaps: UInt32
    dwVSBCKeyCaps: UInt32
    dwVSBFXCaps: UInt32
    dwVSBRops: UInt32 * 8
    dwSSBCaps: UInt32
    dwSSBCKeyCaps: UInt32
    dwSSBFXCaps: UInt32
    dwSSBRops: UInt32 * 8
    dwMaxVideoPorts: UInt32
    dwCurrVideoPorts: UInt32
    dwSVBCaps2: UInt32
    dwNLVBCaps: UInt32
    dwNLVBCaps2: UInt32
    dwNLVBCKeyCaps: UInt32
    dwNLVBFXCaps: UInt32
    dwNLVBRops: UInt32 * 8
class DDCAPS_DX6(Structure):
    dwSize: UInt32
    dwCaps: UInt32
    dwCaps2: UInt32
    dwCKeyCaps: UInt32
    dwFXCaps: UInt32
    dwFXAlphaCaps: UInt32
    dwPalCaps: UInt32
    dwSVCaps: UInt32
    dwAlphaBltConstBitDepths: UInt32
    dwAlphaBltPixelBitDepths: UInt32
    dwAlphaBltSurfaceBitDepths: UInt32
    dwAlphaOverlayConstBitDepths: UInt32
    dwAlphaOverlayPixelBitDepths: UInt32
    dwAlphaOverlaySurfaceBitDepths: UInt32
    dwZBufferBitDepths: UInt32
    dwVidMemTotal: UInt32
    dwVidMemFree: UInt32
    dwMaxVisibleOverlays: UInt32
    dwCurrVisibleOverlays: UInt32
    dwNumFourCCCodes: UInt32
    dwAlignBoundarySrc: UInt32
    dwAlignSizeSrc: UInt32
    dwAlignBoundaryDest: UInt32
    dwAlignSizeDest: UInt32
    dwAlignStrideAlign: UInt32
    dwRops: UInt32 * 8
    ddsOldCaps: win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPS
    dwMinOverlayStretch: UInt32
    dwMaxOverlayStretch: UInt32
    dwMinLiveVideoStretch: UInt32
    dwMaxLiveVideoStretch: UInt32
    dwMinHwCodecStretch: UInt32
    dwMaxHwCodecStretch: UInt32
    dwReserved1: UInt32
    dwReserved2: UInt32
    dwReserved3: UInt32
    dwSVBCaps: UInt32
    dwSVBCKeyCaps: UInt32
    dwSVBFXCaps: UInt32
    dwSVBRops: UInt32 * 8
    dwVSBCaps: UInt32
    dwVSBCKeyCaps: UInt32
    dwVSBFXCaps: UInt32
    dwVSBRops: UInt32 * 8
    dwSSBCaps: UInt32
    dwSSBCKeyCaps: UInt32
    dwSSBFXCaps: UInt32
    dwSSBRops: UInt32 * 8
    dwMaxVideoPorts: UInt32
    dwCurrVideoPorts: UInt32
    dwSVBCaps2: UInt32
    dwNLVBCaps: UInt32
    dwNLVBCaps2: UInt32
    dwNLVBCKeyCaps: UInt32
    dwNLVBFXCaps: UInt32
    dwNLVBRops: UInt32 * 8
    ddsCaps: win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPS2
class DDCAPS_DX7(Structure):
    dwSize: UInt32
    dwCaps: UInt32
    dwCaps2: UInt32
    dwCKeyCaps: UInt32
    dwFXCaps: UInt32
    dwFXAlphaCaps: UInt32
    dwPalCaps: UInt32
    dwSVCaps: UInt32
    dwAlphaBltConstBitDepths: UInt32
    dwAlphaBltPixelBitDepths: UInt32
    dwAlphaBltSurfaceBitDepths: UInt32
    dwAlphaOverlayConstBitDepths: UInt32
    dwAlphaOverlayPixelBitDepths: UInt32
    dwAlphaOverlaySurfaceBitDepths: UInt32
    dwZBufferBitDepths: UInt32
    dwVidMemTotal: UInt32
    dwVidMemFree: UInt32
    dwMaxVisibleOverlays: UInt32
    dwCurrVisibleOverlays: UInt32
    dwNumFourCCCodes: UInt32
    dwAlignBoundarySrc: UInt32
    dwAlignSizeSrc: UInt32
    dwAlignBoundaryDest: UInt32
    dwAlignSizeDest: UInt32
    dwAlignStrideAlign: UInt32
    dwRops: UInt32 * 8
    ddsOldCaps: win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPS
    dwMinOverlayStretch: UInt32
    dwMaxOverlayStretch: UInt32
    dwMinLiveVideoStretch: UInt32
    dwMaxLiveVideoStretch: UInt32
    dwMinHwCodecStretch: UInt32
    dwMaxHwCodecStretch: UInt32
    dwReserved1: UInt32
    dwReserved2: UInt32
    dwReserved3: UInt32
    dwSVBCaps: UInt32
    dwSVBCKeyCaps: UInt32
    dwSVBFXCaps: UInt32
    dwSVBRops: UInt32 * 8
    dwVSBCaps: UInt32
    dwVSBCKeyCaps: UInt32
    dwVSBFXCaps: UInt32
    dwVSBRops: UInt32 * 8
    dwSSBCaps: UInt32
    dwSSBCKeyCaps: UInt32
    dwSSBFXCaps: UInt32
    dwSSBRops: UInt32 * 8
    dwMaxVideoPorts: UInt32
    dwCurrVideoPorts: UInt32
    dwSVBCaps2: UInt32
    dwNLVBCaps: UInt32
    dwNLVBCaps2: UInt32
    dwNLVBCKeyCaps: UInt32
    dwNLVBFXCaps: UInt32
    dwNLVBRops: UInt32 * 8
    ddsCaps: win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPS2
class DDCOLORCONTROL(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    lBrightness: Int32
    lContrast: Int32
    lHue: Int32
    lSaturation: Int32
    lSharpness: Int32
    lGamma: Int32
    lColorEnable: Int32
    dwReserved1: UInt32
class DDCOLORKEY(Structure):
    dwColorSpaceLowValue: UInt32
    dwColorSpaceHighValue: UInt32
class DDCOMPBUFFERINFO(Structure):
    dwSize: UInt32
    dwNumCompBuffers: UInt32
    dwWidthToCreate: UInt32
    dwHeightToCreate: UInt32
    dwBytesToAllocate: UInt32
    ddCompCaps: win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPS2
    ddPixelFormat: win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT
class DDCORECAPS(Structure):
    dwSize: UInt32
    dwCaps: UInt32
    dwCaps2: UInt32
    dwCKeyCaps: UInt32
    dwFXCaps: UInt32
    dwFXAlphaCaps: UInt32
    dwPalCaps: UInt32
    dwSVCaps: UInt32
    dwAlphaBltConstBitDepths: UInt32
    dwAlphaBltPixelBitDepths: UInt32
    dwAlphaBltSurfaceBitDepths: UInt32
    dwAlphaOverlayConstBitDepths: UInt32
    dwAlphaOverlayPixelBitDepths: UInt32
    dwAlphaOverlaySurfaceBitDepths: UInt32
    dwZBufferBitDepths: UInt32
    dwVidMemTotal: UInt32
    dwVidMemFree: UInt32
    dwMaxVisibleOverlays: UInt32
    dwCurrVisibleOverlays: UInt32
    dwNumFourCCCodes: UInt32
    dwAlignBoundarySrc: UInt32
    dwAlignSizeSrc: UInt32
    dwAlignBoundaryDest: UInt32
    dwAlignSizeDest: UInt32
    dwAlignStrideAlign: UInt32
    dwRops: UInt32 * 8
    ddsCaps: win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPS
    dwMinOverlayStretch: UInt32
    dwMaxOverlayStretch: UInt32
    dwMinLiveVideoStretch: UInt32
    dwMaxLiveVideoStretch: UInt32
    dwMinHwCodecStretch: UInt32
    dwMaxHwCodecStretch: UInt32
    dwReserved1: UInt32
    dwReserved2: UInt32
    dwReserved3: UInt32
    dwSVBCaps: UInt32
    dwSVBCKeyCaps: UInt32
    dwSVBFXCaps: UInt32
    dwSVBRops: UInt32 * 8
    dwVSBCaps: UInt32
    dwVSBCKeyCaps: UInt32
    dwVSBFXCaps: UInt32
    dwVSBRops: UInt32 * 8
    dwSSBCaps: UInt32
    dwSSBCKeyCaps: UInt32
    dwSSBFXCaps: UInt32
    dwSSBRops: UInt32 * 8
    dwMaxVideoPorts: UInt32
    dwCurrVideoPorts: UInt32
    dwSVBCaps2: UInt32
class DDDEVICEIDENTIFIER(Structure):
    szDriver: win32more.Windows.Win32.Foundation.CHAR * 512
    szDescription: win32more.Windows.Win32.Foundation.CHAR * 512
    liDriverVersion: Int64
    dwVendorId: UInt32
    dwDeviceId: UInt32
    dwSubSysId: UInt32
    dwRevision: UInt32
    guidDeviceIdentifier: Guid
class DDDEVICEIDENTIFIER2(Structure):
    szDriver: win32more.Windows.Win32.Foundation.CHAR * 512
    szDescription: win32more.Windows.Win32.Foundation.CHAR * 512
    liDriverVersion: Int64
    dwVendorId: UInt32
    dwDeviceId: UInt32
    dwSubSysId: UInt32
    dwRevision: UInt32
    guidDeviceIdentifier: Guid
    dwWHQLLevel: UInt32
class DDENABLEIRQINFO(Structure):
    dwIRQSources: UInt32
    dwLine: UInt32
    IRQCallback: win32more.Windows.Win32.Graphics.DirectDraw.PDX_IRQCALLBACK
    lpIRQData: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DX_IRQDATA)
class DDFLIPOVERLAYINFO(Structure):
    lpCurrentSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDATA)
    lpTargetSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDATA)
    dwFlags: UInt32
class DDFLIPVIDEOPORTINFO(Structure):
    lpVideoPortData: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDVIDEOPORTDATA)
    lpCurrentSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDATA)
    lpTargetSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDATA)
    dwFlipVPFlags: UInt32
class DDGAMMARAMP(Structure):
    red: UInt16 * 256
    green: UInt16 * 256
    blue: UInt16 * 256
class DDGETCURRENTAUTOFLIPININFO(Structure):
    lpVideoPortData: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDVIDEOPORTDATA)
class DDGETCURRENTAUTOFLIPOUTINFO(Structure):
    dwSurfaceIndex: UInt32
    dwVBISurfaceIndex: UInt32
class DDGETIRQINFO(Structure):
    dwFlags: UInt32
class DDGETPOLARITYININFO(Structure):
    lpVideoPortData: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDVIDEOPORTDATA)
class DDGETPOLARITYOUTINFO(Structure):
    bPolarity: UInt32
class DDGETPREVIOUSAUTOFLIPININFO(Structure):
    lpVideoPortData: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDVIDEOPORTDATA)
class DDGETPREVIOUSAUTOFLIPOUTINFO(Structure):
    dwSurfaceIndex: UInt32
    dwVBISurfaceIndex: UInt32
class DDGETTRANSFERSTATUSOUTINFO(Structure):
    dwTransferID: UIntPtr
class DDHALDDRAWFNS(Structure):
    dwSize: UInt32
    lpSetInfo: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHAL_SETINFO
    lpVidMemAlloc: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHAL_VIDMEMALLOC
    lpVidMemFree: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHAL_VIDMEMFREE
class DDHALINFO(Structure):
    dwSize: UInt32
    lpDDCallbacks: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_DDCALLBACKS)
    lpDDSurfaceCallbacks: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_DDSURFACECALLBACKS)
    lpDDPaletteCallbacks: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_DDPALETTECALLBACKS)
    vmiData: win32more.Windows.Win32.Graphics.DirectDraw.VIDMEMINFO
    ddCaps: win32more.Windows.Win32.Graphics.DirectDraw.DDCORECAPS
    dwMonitorFrequency: UInt32
    GetDriverInfo: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHAL_GETDRIVERINFO
    dwModeIndex: UInt32
    lpdwFourCC: POINTER(UInt32)
    dwNumModes: UInt32
    lpModeInfo: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHALMODEINFO)
    dwFlags: UInt32
    lpPDevice: VoidPtr
    hInstance: UInt32
    lpD3DGlobalDriverData: UIntPtr
    lpD3DHALCallbacks: UIntPtr
    lpDDExeBufCallbacks: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_DDEXEBUFCALLBACKS)
class DDHALMODEINFO(Structure):
    dwWidth: UInt32
    dwHeight: UInt32
    lPitch: Int32
    dwBPP: UInt32
    wFlags: UInt16
    wRefreshRate: UInt16
    dwRBitMask: UInt32
    dwGBitMask: UInt32
    dwBBitMask: UInt32
    dwAlphaBitMask: UInt32
class DDHAL_ADDATTACHEDSURFACEDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_GBL)
    lpDDSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_LCL)
    lpSurfAttached: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_LCL)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    AddAttachedSurface: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALSURFCB_ADDATTACHEDSURFACE
class DDHAL_BEGINMOCOMPFRAMEDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    lpMoComp: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDMOTIONCOMP_LCL)
    lpDestSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_LCL)
    dwInputDataSize: UInt32
    lpInputData: VoidPtr
    dwOutputDataSize: UInt32
    lpOutputData: VoidPtr
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    BeginMoCompFrame: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALMOCOMPCB_BEGINFRAME
class DDHAL_BLTDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_GBL)
    lpDDDestSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_LCL)
    rDest: win32more.Windows.Win32.Foundation.RECTL
    lpDDSrcSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_LCL)
    rSrc: win32more.Windows.Win32.Foundation.RECTL
    dwFlags: UInt32
    dwROPFlags: UInt32
    bltFX: win32more.Windows.Win32.Graphics.DirectDraw.DDBLTFX
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    Blt: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALSURFCB_BLT
    IsClipped: win32more.Windows.Win32.Foundation.BOOL
    rOrigDest: win32more.Windows.Win32.Foundation.RECTL
    rOrigSrc: win32more.Windows.Win32.Foundation.RECTL
    dwRectCnt: UInt32
    prDestRects: POINTER(win32more.Windows.Win32.Foundation.RECT)
class DDHAL_CALLBACKS(Structure):
    cbDDCallbacks: win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_DDCALLBACKS
    cbDDSurfaceCallbacks: win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_DDSURFACECALLBACKS
    cbDDPaletteCallbacks: win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_DDPALETTECALLBACKS
    HALDD: win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_DDCALLBACKS
    HALDDSurface: win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_DDSURFACECALLBACKS
    HALDDPalette: win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_DDPALETTECALLBACKS
    HELDD: win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_DDCALLBACKS
    HELDDSurface: win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_DDSURFACECALLBACKS
    HELDDPalette: win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_DDPALETTECALLBACKS
    cbDDExeBufCallbacks: win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_DDEXEBUFCALLBACKS
    HALDDExeBuf: win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_DDEXEBUFCALLBACKS
    HELDDExeBuf: win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_DDEXEBUFCALLBACKS
    cbDDVideoPortCallbacks: win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_DDVIDEOPORTCALLBACKS
    HALDDVideoPort: win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_DDVIDEOPORTCALLBACKS
    cbDDColorControlCallbacks: win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_DDCOLORCONTROLCALLBACKS
    HALDDColorControl: win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_DDCOLORCONTROLCALLBACKS
    cbDDMiscellaneousCallbacks: win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_DDMISCELLANEOUSCALLBACKS
    HALDDMiscellaneous: win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_DDMISCELLANEOUSCALLBACKS
    cbDDKernelCallbacks: win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_DDKERNELCALLBACKS
    HALDDKernel: win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_DDKERNELCALLBACKS
    cbDDMotionCompCallbacks: win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_DDMOTIONCOMPCALLBACKS
    HALDDMotionComp: win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_DDMOTIONCOMPCALLBACKS
class DDHAL_CANCREATESURFACEDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_GBL)
    lpDDSurfaceDesc: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC)
    bIsDifferentPixelFormat: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    CanCreateSurface: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHAL_CANCREATESURFACE
class DDHAL_CANCREATEVPORTDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    lpDDVideoPortDesc: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDVIDEOPORTDESC)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    CanCreateVideoPort: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALVPORTCB_CANCREATEVIDEOPORT
class DDHAL_COLORCONTROLDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_GBL)
    lpDDSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_LCL)
    lpColorData: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORCONTROL)
    dwFlags: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    ColorControl: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALCOLORCB_COLORCONTROL
class DDHAL_CREATEMOCOMPDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    lpMoComp: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDMOTIONCOMP_LCL)
    lpGuid: POINTER(Guid)
    dwUncompWidth: UInt32
    dwUncompHeight: UInt32
    ddUncompPixelFormat: win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT
    lpData: VoidPtr
    dwDataSize: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    CreateMoComp: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALMOCOMPCB_CREATE
class DDHAL_CREATEPALETTEDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_GBL)
    lpDDPalette: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWPALETTE_GBL)
    lpColorTable: POINTER(win32more.Windows.Win32.Graphics.Gdi.PALETTEENTRY)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    CreatePalette: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHAL_CREATEPALETTE
    is_excl: win32more.Windows.Win32.Foundation.BOOL
class DDHAL_CREATESURFACEDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_GBL)
    lpDDSurfaceDesc: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC)
    lplpSList: POINTER(POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_LCL))
    dwSCnt: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    CreateSurface: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHAL_CREATESURFACE
class DDHAL_CREATESURFACEEXDATA(Structure):
    dwFlags: UInt32
    lpDDLcl: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    lpDDSLcl: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_LCL)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
class DDHAL_CREATEVPORTDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    lpDDVideoPortDesc: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDVIDEOPORTDESC)
    lpVideoPort: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDVIDEOPORT_LCL)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    CreateVideoPort: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALVPORTCB_CREATEVIDEOPORT
class DDHAL_DDCALLBACKS(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    DestroyDriver: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHAL_DESTROYDRIVER
    CreateSurface: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHAL_CREATESURFACE
    SetColorKey: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHAL_SETCOLORKEY
    SetMode: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHAL_SETMODE
    WaitForVerticalBlank: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHAL_WAITFORVERTICALBLANK
    CanCreateSurface: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHAL_CANCREATESURFACE
    CreatePalette: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHAL_CREATEPALETTE
    GetScanLine: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHAL_GETSCANLINE
    SetExclusiveMode: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHAL_SETEXCLUSIVEMODE
    FlipToGDISurface: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHAL_FLIPTOGDISURFACE
class DDHAL_DDCOLORCONTROLCALLBACKS(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    ColorControl: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALCOLORCB_COLORCONTROL
class DDHAL_DDEXEBUFCALLBACKS(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    CanCreateExecuteBuffer: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALEXEBUFCB_CANCREATEEXEBUF
    CreateExecuteBuffer: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALEXEBUFCB_CREATEEXEBUF
    DestroyExecuteBuffer: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALEXEBUFCB_DESTROYEXEBUF
    LockExecuteBuffer: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALEXEBUFCB_LOCKEXEBUF
    UnlockExecuteBuffer: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALEXEBUFCB_UNLOCKEXEBUF
class DDHAL_DDKERNELCALLBACKS(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    SyncSurfaceData: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALKERNELCB_SYNCSURFACE
    SyncVideoPortData: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALKERNELCB_SYNCVIDEOPORT
class DDHAL_DDMISCELLANEOUS2CALLBACKS(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    Reserved: VoidPtr
    CreateSurfaceEx: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHAL_CREATESURFACEEX
    GetDriverState: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHAL_GETDRIVERSTATE
    DestroyDDLocal: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHAL_DESTROYDDLOCAL
class DDHAL_DDMISCELLANEOUSCALLBACKS(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    GetAvailDriverMemory: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHAL_GETAVAILDRIVERMEMORY
    UpdateNonLocalHeap: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHAL_UPDATENONLOCALHEAP
    GetHeapAlignment: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHAL_GETHEAPALIGNMENT
    GetSysmemBltStatus: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALSURFCB_GETBLTSTATUS
class DDHAL_DDMOTIONCOMPCALLBACKS(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    GetMoCompGuids: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALMOCOMPCB_GETGUIDS
    GetMoCompFormats: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALMOCOMPCB_GETFORMATS
    CreateMoComp: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALMOCOMPCB_CREATE
    GetMoCompBuffInfo: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALMOCOMPCB_GETCOMPBUFFINFO
    GetInternalMoCompInfo: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALMOCOMPCB_GETINTERNALINFO
    BeginMoCompFrame: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALMOCOMPCB_BEGINFRAME
    EndMoCompFrame: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALMOCOMPCB_ENDFRAME
    RenderMoComp: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALMOCOMPCB_RENDER
    QueryMoCompStatus: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALMOCOMPCB_QUERYSTATUS
    DestroyMoComp: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALMOCOMPCB_DESTROY
class DDHAL_DDPALETTECALLBACKS(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    DestroyPalette: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALPALCB_DESTROYPALETTE
    SetEntries: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALPALCB_SETENTRIES
class DDHAL_DDSURFACECALLBACKS(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    DestroySurface: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALSURFCB_DESTROYSURFACE
    Flip: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALSURFCB_FLIP
    SetClipList: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALSURFCB_SETCLIPLIST
    Lock: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALSURFCB_LOCK
    Unlock: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALSURFCB_UNLOCK
    Blt: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALSURFCB_BLT
    SetColorKey: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALSURFCB_SETCOLORKEY
    AddAttachedSurface: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALSURFCB_ADDATTACHEDSURFACE
    GetBltStatus: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALSURFCB_GETBLTSTATUS
    GetFlipStatus: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALSURFCB_GETFLIPSTATUS
    UpdateOverlay: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALSURFCB_UPDATEOVERLAY
    SetOverlayPosition: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALSURFCB_SETOVERLAYPOSITION
    reserved4: VoidPtr
    SetPalette: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALSURFCB_SETPALETTE
class DDHAL_DDVIDEOPORTCALLBACKS(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    CanCreateVideoPort: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALVPORTCB_CANCREATEVIDEOPORT
    CreateVideoPort: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALVPORTCB_CREATEVIDEOPORT
    FlipVideoPort: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALVPORTCB_FLIP
    GetVideoPortBandwidth: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALVPORTCB_GETBANDWIDTH
    GetVideoPortInputFormats: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALVPORTCB_GETINPUTFORMATS
    GetVideoPortOutputFormats: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALVPORTCB_GETOUTPUTFORMATS
    lpReserved1: VoidPtr
    GetVideoPortField: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALVPORTCB_GETFIELD
    GetVideoPortLine: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALVPORTCB_GETLINE
    GetVideoPortConnectInfo: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALVPORTCB_GETVPORTCONNECT
    DestroyVideoPort: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALVPORTCB_DESTROYVPORT
    GetVideoPortFlipStatus: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALVPORTCB_GETFLIPSTATUS
    UpdateVideoPort: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALVPORTCB_UPDATE
    WaitForVideoPortSync: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALVPORTCB_WAITFORSYNC
    GetVideoSignalStatus: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALVPORTCB_GETSIGNALSTATUS
    ColorControl: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALVPORTCB_COLORCONTROL
class DDHAL_DESTROYDDLOCALDATA(Structure):
    dwFlags: UInt32
    pDDLcl: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
class DDHAL_DESTROYDRIVERDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_GBL)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    DestroyDriver: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHAL_DESTROYDRIVER
class DDHAL_DESTROYMOCOMPDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    lpMoComp: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDMOTIONCOMP_LCL)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    DestroyMoComp: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALMOCOMPCB_DESTROY
class DDHAL_DESTROYPALETTEDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_GBL)
    lpDDPalette: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWPALETTE_GBL)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    DestroyPalette: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALPALCB_DESTROYPALETTE
class DDHAL_DESTROYSURFACEDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_GBL)
    lpDDSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_LCL)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    DestroySurface: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALSURFCB_DESTROYSURFACE
class DDHAL_DESTROYVPORTDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    lpVideoPort: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDVIDEOPORT_LCL)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    DestroyVideoPort: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALVPORTCB_DESTROYVPORT
class DDHAL_DRVSETCOLORKEYDATA(Structure):
    lpDDSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_LCL)
    dwFlags: UInt32
    ckNew: win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORKEY
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    SetColorKey: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHAL_SETCOLORKEY
class DDHAL_ENDMOCOMPFRAMEDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    lpMoComp: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDMOTIONCOMP_LCL)
    lpInputData: VoidPtr
    dwInputDataSize: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    EndMoCompFrame: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALMOCOMPCB_ENDFRAME
class DDHAL_FLIPDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_GBL)
    lpSurfCurr: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_LCL)
    lpSurfTarg: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_LCL)
    dwFlags: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    Flip: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALSURFCB_FLIP
    lpSurfCurrLeft: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_LCL)
    lpSurfTargLeft: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_LCL)
class DDHAL_FLIPTOGDISURFACEDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_GBL)
    dwToGDI: UInt32
    dwReserved: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    FlipToGDISurface: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHAL_FLIPTOGDISURFACE
class DDHAL_FLIPVPORTDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    lpVideoPort: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDVIDEOPORT_LCL)
    lpSurfCurr: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_LCL)
    lpSurfTarg: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_LCL)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    FlipVideoPort: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALVPORTCB_FLIP
class DDHAL_GETAVAILDRIVERMEMORYDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_GBL)
    DDSCaps: win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPS
    dwTotal: UInt32
    dwFree: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    GetAvailDriverMemory: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHAL_GETAVAILDRIVERMEMORY
    ddsCapsEx: win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPSEX
class DDHAL_GETBLTSTATUSDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_GBL)
    lpDDSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_LCL)
    dwFlags: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    GetBltStatus: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALSURFCB_GETBLTSTATUS
class DDHAL_GETDRIVERINFODATA(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    guidInfo: Guid
    dwExpectedSize: UInt32
    lpvData: VoidPtr
    dwActualSize: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    dwContext: UIntPtr
class DDHAL_GETDRIVERSTATEDATA(Structure):
    dwFlags: UInt32
    Anonymous: _Anonymous_e__Union
    lpdwStates: POINTER(UInt32)
    dwLength: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    class _Anonymous_e__Union(Union):
        dwhContext: UIntPtr
class DDHAL_GETFLIPSTATUSDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_GBL)
    lpDDSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_LCL)
    dwFlags: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    GetFlipStatus: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALSURFCB_GETFLIPSTATUS
class DDHAL_GETHEAPALIGNMENTDATA(Structure):
    dwInstance: UIntPtr
    dwHeap: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    GetHeapAlignment: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHAL_GETHEAPALIGNMENT
    Alignment: win32more.Windows.Win32.Graphics.DirectDraw.HEAPALIGNMENT
class DDHAL_GETINTERNALMOCOMPDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    lpGuid: POINTER(Guid)
    dwWidth: UInt32
    dwHeight: UInt32
    ddPixelFormat: win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT
    dwScratchMemAlloc: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    GetInternalMoCompInfo: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALMOCOMPCB_GETINTERNALINFO
class DDHAL_GETMOCOMPCOMPBUFFDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    lpGuid: POINTER(Guid)
    dwWidth: UInt32
    dwHeight: UInt32
    ddPixelFormat: win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT
    dwNumTypesCompBuffs: UInt32
    lpCompBuffInfo: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDMCCOMPBUFFERINFO)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    GetMoCompBuffInfo: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALMOCOMPCB_GETCOMPBUFFINFO
class DDHAL_GETMOCOMPFORMATSDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    lpGuid: POINTER(Guid)
    dwNumFormats: UInt32
    lpFormats: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    GetMoCompFormats: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALMOCOMPCB_GETFORMATS
class DDHAL_GETMOCOMPGUIDSDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    dwNumGuids: UInt32
    lpGuids: POINTER(Guid)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    GetMoCompGuids: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALMOCOMPCB_GETGUIDS
class DDHAL_GETSCANLINEDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_GBL)
    dwScanLine: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    GetScanLine: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHAL_GETSCANLINE
class DDHAL_GETVPORTBANDWIDTHDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    lpVideoPort: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDVIDEOPORT_LCL)
    lpddpfFormat: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT)
    dwWidth: UInt32
    dwHeight: UInt32
    dwFlags: UInt32
    lpBandwidth: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDVIDEOPORTBANDWIDTH)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    GetVideoPortBandwidth: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALVPORTCB_GETBANDWIDTH
class DDHAL_GETVPORTCONNECTDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    dwPortId: UInt32
    lpConnect: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDVIDEOPORTCONNECT)
    dwNumEntries: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    GetVideoPortConnectInfo: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALVPORTCB_GETVPORTCONNECT
class DDHAL_GETVPORTFIELDDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    lpVideoPort: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDVIDEOPORT_LCL)
    bField: win32more.Windows.Win32.Foundation.BOOL
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    GetVideoPortField: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALVPORTCB_GETFIELD
class DDHAL_GETVPORTFLIPSTATUSDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    fpSurface: UIntPtr
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    GetVideoPortFlipStatus: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALVPORTCB_GETFLIPSTATUS
class DDHAL_GETVPORTINPUTFORMATDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    lpVideoPort: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDVIDEOPORT_LCL)
    dwFlags: UInt32
    lpddpfFormat: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT)
    dwNumFormats: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    GetVideoPortInputFormats: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALVPORTCB_GETINPUTFORMATS
class DDHAL_GETVPORTLINEDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    lpVideoPort: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDVIDEOPORT_LCL)
    dwLine: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    GetVideoPortLine: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALVPORTCB_GETLINE
class DDHAL_GETVPORTOUTPUTFORMATDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    lpVideoPort: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDVIDEOPORT_LCL)
    dwFlags: UInt32
    lpddpfInputFormat: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT)
    lpddpfOutputFormats: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT)
    dwNumFormats: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    GetVideoPortOutputFormats: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALVPORTCB_GETOUTPUTFORMATS
class DDHAL_GETVPORTSIGNALDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    lpVideoPort: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDVIDEOPORT_LCL)
    dwStatus: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    GetVideoSignalStatus: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALVPORTCB_GETSIGNALSTATUS
class DDHAL_LOCKDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_GBL)
    lpDDSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_LCL)
    bHasRect: UInt32
    rArea: win32more.Windows.Win32.Foundation.RECTL
    lpSurfData: VoidPtr
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    Lock: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALSURFCB_LOCK
    dwFlags: UInt32
class DDHAL_QUERYMOCOMPSTATUSDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    lpMoComp: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDMOTIONCOMP_LCL)
    lpSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_LCL)
    dwFlags: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    QueryMoCompStatus: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALMOCOMPCB_QUERYSTATUS
class DDHAL_RENDERMOCOMPDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    lpMoComp: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDMOTIONCOMP_LCL)
    dwNumBuffers: UInt32
    lpBufferInfo: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDMCBUFFERINFO)
    dwFunction: UInt32
    lpInputData: VoidPtr
    dwInputDataSize: UInt32
    lpOutputData: VoidPtr
    dwOutputDataSize: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    RenderMoComp: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALMOCOMPCB_RENDER
class DDHAL_SETCLIPLISTDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_GBL)
    lpDDSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_LCL)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    SetClipList: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALSURFCB_SETCLIPLIST
class DDHAL_SETCOLORKEYDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_GBL)
    lpDDSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_LCL)
    dwFlags: UInt32
    ckNew: win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORKEY
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    SetColorKey: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALSURFCB_SETCOLORKEY
class DDHAL_SETENTRIESDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_GBL)
    lpDDPalette: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWPALETTE_GBL)
    dwBase: UInt32
    dwNumEntries: UInt32
    lpEntries: POINTER(win32more.Windows.Win32.Graphics.Gdi.PALETTEENTRY)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    SetEntries: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALPALCB_SETENTRIES
class DDHAL_SETEXCLUSIVEMODEDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_GBL)
    dwEnterExcl: UInt32
    dwReserved: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    SetExclusiveMode: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHAL_SETEXCLUSIVEMODE
class DDHAL_SETMODEDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_GBL)
    dwModeIndex: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    SetMode: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHAL_SETMODE
    inexcl: win32more.Windows.Win32.Foundation.BOOL
    useRefreshRate: win32more.Windows.Win32.Foundation.BOOL
class DDHAL_SETOVERLAYPOSITIONDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_GBL)
    lpDDSrcSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_LCL)
    lpDDDestSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_LCL)
    lXPos: Int32
    lYPos: Int32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    SetOverlayPosition: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALSURFCB_SETOVERLAYPOSITION
class DDHAL_SETPALETTEDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_GBL)
    lpDDSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_LCL)
    lpDDPalette: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWPALETTE_GBL)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    SetPalette: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALSURFCB_SETPALETTE
    Attach: win32more.Windows.Win32.Foundation.BOOL
class DDHAL_SYNCSURFACEDATA(Structure):
    dwSize: UInt32
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    lpDDSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_LCL)
    dwSurfaceOffset: UInt32
    fpLockPtr: UIntPtr
    lPitch: Int32
    dwOverlayOffset: UInt32
    dwOverlaySrcWidth: UInt32
    dwOverlaySrcHeight: UInt32
    dwOverlayDestWidth: UInt32
    dwOverlayDestHeight: UInt32
    dwDriverReserved1: UIntPtr
    dwDriverReserved2: UIntPtr
    dwDriverReserved3: UIntPtr
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
class DDHAL_SYNCVIDEOPORTDATA(Structure):
    dwSize: UInt32
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    lpVideoPort: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDVIDEOPORT_LCL)
    dwOriginOffset: UInt32
    dwHeight: UInt32
    dwVBIHeight: UInt32
    dwDriverReserved1: UIntPtr
    dwDriverReserved2: UIntPtr
    dwDriverReserved3: UIntPtr
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
class DDHAL_UNLOCKDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_GBL)
    lpDDSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_LCL)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    Unlock: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALSURFCB_UNLOCK
class DDHAL_UPDATENONLOCALHEAPDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_GBL)
    dwHeap: UInt32
    fpGARTLin: UIntPtr
    fpGARTDev: UIntPtr
    ulPolicyMaxBytes: UIntPtr
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    UpdateNonLocalHeap: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHAL_UPDATENONLOCALHEAP
class DDHAL_UPDATEOVERLAYDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_GBL)
    lpDDDestSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_LCL)
    rDest: win32more.Windows.Win32.Foundation.RECTL
    lpDDSrcSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_LCL)
    rSrc: win32more.Windows.Win32.Foundation.RECTL
    dwFlags: UInt32
    overlayFX: win32more.Windows.Win32.Graphics.DirectDraw.DDOVERLAYFX
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    UpdateOverlay: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALSURFCB_UPDATEOVERLAY
class DDHAL_UPDATEVPORTDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    lpVideoPort: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDVIDEOPORT_LCL)
    lplpDDSurface: POINTER(POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_INT))
    lplpDDVBISurface: POINTER(POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_INT))
    lpVideoInfo: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDVIDEOPORTINFO)
    dwFlags: UInt32
    dwNumAutoflip: UInt32
    dwNumVBIAutoflip: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    UpdateVideoPort: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALVPORTCB_UPDATE
class DDHAL_VPORTCOLORDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    lpVideoPort: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDVIDEOPORT_LCL)
    dwFlags: UInt32
    lpColorData: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORCONTROL)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    ColorControl: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALVPORTCB_COLORCONTROL
class DDHAL_WAITFORVERTICALBLANKDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_GBL)
    dwFlags: UInt32
    bIsInVB: UInt32
    hEvent: UIntPtr
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    WaitForVerticalBlank: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHAL_WAITFORVERTICALBLANK
class DDHAL_WAITFORVPORTSYNCDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    lpVideoPort: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDVIDEOPORT_LCL)
    dwFlags: UInt32
    dwLine: UInt32
    dwTimeOut: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    WaitForVideoPortSync: win32more.Windows.Win32.Graphics.DirectDraw.LPDDHALVPORTCB_WAITFORSYNC
class DDKERNELCAPS(Structure):
    dwSize: UInt32
    dwCaps: UInt32
    dwIRQCaps: UInt32
class DDLOCKININFO(Structure):
    lpSurfaceData: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDATA)
class DDLOCKOUTINFO(Structure):
    dwSurfacePtr: UIntPtr
class DDMCBUFFERINFO(Structure):
    dwSize: UInt32
    lpCompSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_LCL)
    dwDataOffset: UInt32
    dwDataSize: UInt32
    lpPrivate: VoidPtr
class DDMCCOMPBUFFERINFO(Structure):
    dwSize: UInt32
    dwNumCompBuffers: UInt32
    dwWidthToCreate: UInt32
    dwHeightToCreate: UInt32
    dwBytesToAllocate: UInt32
    ddCompCaps: win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPS2
    ddPixelFormat: win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT
class DDMDL(Structure):
    MdlNext: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDMDL)
    MdlSize: Int16
    MdlFlags: Int16
    Process: IntPtr
    lpMappedSystemVa: POINTER(UInt32)
    lpStartVa: POINTER(UInt32)
    ByteCount: UInt32
    ByteOffset: UInt32
class DDMOCOMPBUFFERINFO(Structure):
    dwSize: UInt32
    lpCompSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_LOCAL)
    dwDataOffset: UInt32
    dwDataSize: UInt32
    lpPrivate: VoidPtr
class DDMONITORINFO(Structure):
    Manufacturer: UInt16
    Product: UInt16
    SerialNumber: UInt32
    DeviceIdentifier: Guid
    Mode640x480: Int32
    Mode800x600: Int32
    Mode1024x768: Int32
    Mode1280x1024: Int32
    Mode1600x1200: Int32
    ModeReserved1: Int32
    ModeReserved2: Int32
    ModeReserved3: Int32
class DDMORESURFACECAPS(Structure):
    dwSize: UInt32
    ddsCapsMore: win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPSEX
    ddsExtendedHeapRestrictions: ExtendedHeapRestrictions * 1
    class ExtendedHeapRestrictions(Structure):
        ddsCapsEx: win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPSEX
        ddsCapsExAlt: win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPSEX
class DDNONLOCALVIDMEMCAPS(Structure):
    dwSize: UInt32
    dwNLVBCaps: UInt32
    dwNLVBCaps2: UInt32
    dwNLVBCKeyCaps: UInt32
    dwNLVBFXCaps: UInt32
    dwNLVBRops: UInt32 * 8
class DDNTCORECAPS(Structure):
    dwSize: UInt32
    dwCaps: UInt32
    dwCaps2: UInt32
    dwCKeyCaps: UInt32
    dwFXCaps: UInt32
    dwFXAlphaCaps: UInt32
    dwPalCaps: UInt32
    dwSVCaps: UInt32
    dwAlphaBltConstBitDepths: UInt32
    dwAlphaBltPixelBitDepths: UInt32
    dwAlphaBltSurfaceBitDepths: UInt32
    dwAlphaOverlayConstBitDepths: UInt32
    dwAlphaOverlayPixelBitDepths: UInt32
    dwAlphaOverlaySurfaceBitDepths: UInt32
    dwZBufferBitDepths: UInt32
    dwVidMemTotal: UInt32
    dwVidMemFree: UInt32
    dwMaxVisibleOverlays: UInt32
    dwCurrVisibleOverlays: UInt32
    dwNumFourCCCodes: UInt32
    dwAlignBoundarySrc: UInt32
    dwAlignSizeSrc: UInt32
    dwAlignBoundaryDest: UInt32
    dwAlignSizeDest: UInt32
    dwAlignStrideAlign: UInt32
    dwRops: UInt32 * 8
    ddsCaps: win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPS
    dwMinOverlayStretch: UInt32
    dwMaxOverlayStretch: UInt32
    dwMinLiveVideoStretch: UInt32
    dwMaxLiveVideoStretch: UInt32
    dwMinHwCodecStretch: UInt32
    dwMaxHwCodecStretch: UInt32
    dwReserved1: UInt32
    dwReserved2: UInt32
    dwReserved3: UInt32
    dwSVBCaps: UInt32
    dwSVBCKeyCaps: UInt32
    dwSVBFXCaps: UInt32
    dwSVBRops: UInt32 * 8
    dwVSBCaps: UInt32
    dwVSBCKeyCaps: UInt32
    dwVSBFXCaps: UInt32
    dwVSBRops: UInt32 * 8
    dwSSBCaps: UInt32
    dwSSBCKeyCaps: UInt32
    dwSSBFXCaps: UInt32
    dwSSBRops: UInt32 * 8
    dwMaxVideoPorts: UInt32
    dwCurrVideoPorts: UInt32
    dwSVBCaps2: UInt32
class DDOPTSURFACEDESC(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    ddSCaps: win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPS2
    ddOSCaps: win32more.Windows.Win32.Graphics.DirectDraw.DDOSCAPS
    guid: Guid
    dwCompressionRatio: UInt32
class DDOSCAPS(Structure):
    dwCaps: UInt32
class DDOVERLAYFX(Structure):
    dwSize: UInt32
    dwAlphaEdgeBlendBitDepth: UInt32
    dwAlphaEdgeBlend: UInt32
    dwReserved: UInt32
    dwAlphaDestConstBitDepth: UInt32
    Anonymous1: _Anonymous1_e__Union
    dwAlphaSrcConstBitDepth: UInt32
    Anonymous2: _Anonymous2_e__Union
    dckDestColorkey: win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORKEY
    dckSrcColorkey: win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORKEY
    dwDDFX: UInt32
    dwFlags: UInt32
    class _Anonymous1_e__Union(Union):
        dwAlphaDestConst: UInt32
        lpDDSAlphaDest: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface
    class _Anonymous2_e__Union(Union):
        dwAlphaSrcConst: UInt32
        lpDDSAlphaSrc: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface
class DDPIXELFORMAT(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    dwFourCC: UInt32
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    Anonymous3: _Anonymous3_e__Union
    Anonymous4: _Anonymous4_e__Union
    Anonymous5: _Anonymous5_e__Union
    class _Anonymous1_e__Union(Union):
        dwRGBBitCount: UInt32
        dwYUVBitCount: UInt32
        dwZBufferBitDepth: UInt32
        dwAlphaBitDepth: UInt32
        dwLuminanceBitCount: UInt32
        dwBumpBitCount: UInt32
        dwPrivateFormatBitCount: UInt32
    class _Anonymous2_e__Union(Union):
        dwRBitMask: UInt32
        dwYBitMask: UInt32
        dwStencilBitDepth: UInt32
        dwLuminanceBitMask: UInt32
        dwBumpDuBitMask: UInt32
        dwOperations: UInt32
    class _Anonymous3_e__Union(Union):
        dwGBitMask: UInt32
        dwUBitMask: UInt32
        dwZBitMask: UInt32
        dwBumpDvBitMask: UInt32
        MultiSampleCaps: _MultiSampleCaps_e__Struct
        class _MultiSampleCaps_e__Struct(Structure):
            wFlipMSTypes: UInt16
            wBltMSTypes: UInt16
    class _Anonymous4_e__Union(Union):
        dwBBitMask: UInt32
        dwVBitMask: UInt32
        dwStencilBitMask: UInt32
        dwBumpLuminanceBitMask: UInt32
    class _Anonymous5_e__Union(Union):
        dwRGBAlphaBitMask: UInt32
        dwYUVAlphaBitMask: UInt32
        dwLuminanceAlphaBitMask: UInt32
        dwRGBZBitMask: UInt32
        dwYUVZBitMask: UInt32
class DDRAWI_DDMOTIONCOMP_INT(Structure):
    lpVtbl: VoidPtr
    lpLcl: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDMOTIONCOMP_LCL)
    lpLink: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDMOTIONCOMP_INT)
    dwIntRefCnt: UInt32
class DDRAWI_DDMOTIONCOMP_LCL(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    guid: Guid
    dwUncompWidth: UInt32
    dwUncompHeight: UInt32
    ddUncompPixelFormat: win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT
    dwInternalFlags: UInt32
    dwRefCnt: UInt32
    dwProcessId: UInt32
    hMoComp: win32more.Windows.Win32.Foundation.HANDLE
    dwDriverReserved1: UInt32
    dwDriverReserved2: UInt32
    dwDriverReserved3: UInt32
    lpDriverReserved1: VoidPtr
    lpDriverReserved2: VoidPtr
    lpDriverReserved3: VoidPtr
class DDRAWI_DDRAWCLIPPER_GBL(Structure):
    dwRefCnt: UInt32
    dwFlags: UInt32
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_GBL)
    dwProcessId: UInt32
    dwReserved1: UIntPtr
    hWnd: UIntPtr
    lpStaticClipList: POINTER(win32more.Windows.Win32.Graphics.Gdi.RGNDATA)
class DDRAWI_DDRAWCLIPPER_INT(Structure):
    lpVtbl: VoidPtr
    lpLcl: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWCLIPPER_LCL)
    lpLink: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWCLIPPER_INT)
    dwIntRefCnt: UInt32
class DDRAWI_DDRAWCLIPPER_LCL(Structure):
    lpClipMore: UInt32
    lpGbl: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWCLIPPER_GBL)
    lpDD_lcl: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    dwLocalRefCnt: UInt32
    pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown
    lpDD_int: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_INT)
    dwReserved1: UIntPtr
    pAddrefedThisOwner: win32more.Windows.Win32.System.Com.IUnknown
class DDRAWI_DDRAWPALETTE_GBL(Structure):
    dwRefCnt: UInt32
    dwFlags: UInt32
    lpDD_lcl: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    dwProcessId: UInt32
    lpColorTable: POINTER(win32more.Windows.Win32.Graphics.Gdi.PALETTEENTRY)
    Anonymous: _Anonymous_e__Union
    dwDriverReserved: UInt32
    dwContentsStamp: UInt32
    dwSaveStamp: UInt32
    dwHandle: UInt32
    class _Anonymous_e__Union(Union):
        dwReserved1: UIntPtr
        hHELGDIPalette: win32more.Windows.Win32.Graphics.Gdi.HPALETTE
class DDRAWI_DDRAWPALETTE_INT(Structure):
    lpVtbl: VoidPtr
    lpLcl: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWPALETTE_LCL)
    lpLink: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWPALETTE_INT)
    dwIntRefCnt: UInt32
class DDRAWI_DDRAWPALETTE_LCL(Structure):
    lpPalMore: UInt32
    lpGbl: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWPALETTE_GBL)
    dwUnused0: UIntPtr
    dwLocalRefCnt: UInt32
    pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown
    lpDD_lcl: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    dwReserved1: UIntPtr
    dwDDRAWReserved1: UIntPtr
    dwDDRAWReserved2: UIntPtr
    dwDDRAWReserved3: UIntPtr
class DDRAWI_DDRAWSURFACE_GBL(Structure):
    dwRefCnt: UInt32
    dwGlobalFlags: UInt32
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    Anonymous3: _Anonymous3_e__Union
    fpVidMem: UIntPtr
    Anonymous4: _Anonymous4_e__Union
    wHeight: UInt16
    wWidth: UInt16
    dwUsageCount: UInt32
    dwReserved1: UIntPtr
    ddpfSurface: win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT
    class _Anonymous1_e__Union(Union):
        lpRectList: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.ACCESSRECTLIST)
        dwBlockSizeY: UInt32
        lSlicePitch: Int32
    class _Anonymous2_e__Union(Union):
        lpVidMemHeap: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.VMEMHEAP)
        dwBlockSizeX: UInt32
    class _Anonymous3_e__Union(Union):
        lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_GBL)
        lpDDHandle: VoidPtr
    class _Anonymous4_e__Union(Union):
        lPitch: Int32
        dwLinearSize: UInt32
class DDRAWI_DDRAWSURFACE_GBL_MORE(Structure):
    dwSize: UInt32
    Anonymous: _Anonymous_e__Union
    pPageTable: POINTER(UInt32)
    cPages: UInt32
    dwSavedDCContext: UIntPtr
    fpAliasedVidMem: UIntPtr
    dwDriverReserved: UIntPtr
    dwHELReserved: UIntPtr
    cPageUnlocks: UInt32
    hKernelSurface: UIntPtr
    dwKernelRefCnt: UInt32
    lpColorInfo: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORCONTROL)
    fpNTAlias: UIntPtr
    dwContentsStamp: UInt32
    lpvUnswappedDriverReserved: VoidPtr
    lpDDRAWReserved2: VoidPtr
    dwDDRAWReserved1: UInt32
    dwDDRAWReserved2: UInt32
    fpAliasOfVidMem: UIntPtr
    class _Anonymous_e__Union(Union):
        dwPhysicalPageTable: UInt32
        fpPhysicalVidMem: UIntPtr
class DDRAWI_DDRAWSURFACE_INT(Structure):
    lpVtbl: VoidPtr
    lpLcl: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_LCL)
    lpLink: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_INT)
    dwIntRefCnt: UInt32
class DDRAWI_DDRAWSURFACE_LCL(Structure):
    lpSurfMore: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_MORE)
    lpGbl: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_GBL)
    hDDSurface: UIntPtr
    lpAttachList: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.ATTACHLIST)
    lpAttachListFrom: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.ATTACHLIST)
    dwLocalRefCnt: UInt32
    dwProcessId: UInt32
    dwFlags: UInt32
    ddsCaps: win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPS
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    dwModeCreatedIn: UInt32
    dwBackBufferCount: UInt32
    ddckCKDestBlt: win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORKEY
    ddckCKSrcBlt: win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORKEY
    hDC: UIntPtr
    dwReserved1: UIntPtr
    ddckCKSrcOverlay: win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORKEY
    ddckCKDestOverlay: win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORKEY
    lpSurfaceOverlaying: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_INT)
    dbnOverlayNode: win32more.Windows.Win32.Graphics.DirectDraw.DBLNODE
    rcOverlaySrc: win32more.Windows.Win32.Foundation.RECT
    rcOverlayDest: win32more.Windows.Win32.Foundation.RECT
    dwClrXparent: UInt32
    dwAlpha: UInt32
    lOverlayX: Int32
    lOverlayY: Int32
    class _Anonymous1_e__Union(Union):
        lpDDPalette: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWPALETTE_INT)
        lp16DDPalette: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWPALETTE_INT)
    class _Anonymous2_e__Union(Union):
        lpDDClipper: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWCLIPPER_LCL)
        lp16DDClipper: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWCLIPPER_INT)
class DDRAWI_DDRAWSURFACE_MORE(Structure):
    dwSize: UInt32
    lpIUnknowns: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IUNKNOWN_LIST)
    lpDD_lcl: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    dwPageLockCount: UInt32
    dwBytesAllocated: UInt32
    lpDD_int: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_INT)
    dwMipMapCount: UInt32
    lpDDIClipper: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWCLIPPER_INT)
    lpHeapAliasInfo: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.HEAPALIASINFO)
    dwOverlayFlags: UInt32
    rgjunc: VoidPtr
    lpVideoPort: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDVIDEOPORT_LCL)
    lpddOverlayFX: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDOVERLAYFX)
    ddsCapsEx: win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPSEX
    dwTextureStage: UInt32
    lpDDRAWReserved: VoidPtr
    lpDDRAWReserved2: VoidPtr
    lpDDrawReserved3: VoidPtr
    dwDDrawReserved4: UInt32
    lpDDrawReserved5: VoidPtr
    lpGammaRamp: POINTER(UInt32)
    lpOriginalGammaRamp: POINTER(UInt32)
    lpDDrawReserved6: VoidPtr
    dwSurfaceHandle: UInt32
    qwDDrawReserved8: UInt32 * 2
    lpDDrawReserved9: VoidPtr
    cSurfaces: UInt32
    pCreatedDDSurfaceDesc2: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC2)
    slist: POINTER(POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_LCL))
    dwFVF: UInt32
    lpVB: VoidPtr
class DDRAWI_DDVIDEOPORT_INT(Structure):
    lpVtbl: VoidPtr
    lpLcl: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDVIDEOPORT_LCL)
    lpLink: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDVIDEOPORT_INT)
    dwIntRefCnt: UInt32
    dwFlags: UInt32
class DDRAWI_DDVIDEOPORT_LCL(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    ddvpDesc: win32more.Windows.Win32.Graphics.DirectDraw.DDVIDEOPORTDESC
    ddvpInfo: win32more.Windows.Win32.Graphics.DirectDraw.DDVIDEOPORTINFO
    lpSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_INT)
    lpVBISurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_INT)
    lpFlipInts: POINTER(POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_INT))
    dwNumAutoflip: UInt32
    dwProcessID: UInt32
    dwStateFlags: UInt32
    dwFlags: UInt32
    dwRefCnt: UInt32
    fpLastFlip: UIntPtr
    dwReserved1: UIntPtr
    dwReserved2: UIntPtr
    hDDVideoPort: win32more.Windows.Win32.Foundation.HANDLE
    dwNumVBIAutoflip: UInt32
    lpVBIDesc: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDVIDEOPORTDESC)
    lpVideoDesc: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDVIDEOPORTDESC)
    lpVBIInfo: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDVIDEOPORTINFO)
    lpVideoInfo: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDVIDEOPORTINFO)
    dwVBIProcessID: UInt32
    lpVPNotify: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDVIDEOPORT_INT)
class DDRAWI_DIRECTDRAW_GBL(Structure):
    dwRefCnt: UInt32
    dwFlags: UInt32
    fpPrimaryOrig: UIntPtr
    ddCaps: win32more.Windows.Win32.Graphics.DirectDraw.DDCORECAPS
    dwInternal1: UInt32
    dwUnused1: UInt32 * 9
    lpDDCBtmp: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_CALLBACKS)
    dsList: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_INT)
    palList: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWPALETTE_INT)
    clipperList: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWCLIPPER_INT)
    lp16DD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_GBL)
    dwMaxOverlays: UInt32
    dwCurrOverlays: UInt32
    dwMonitorFrequency: UInt32
    ddHELCaps: win32more.Windows.Win32.Graphics.DirectDraw.DDCORECAPS
    dwUnused2: UInt32 * 50
    ddckCKDestOverlay: win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORKEY
    ddckCKSrcOverlay: win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORKEY
    vmiData: win32more.Windows.Win32.Graphics.DirectDraw.VIDMEMINFO
    lpDriverHandle: VoidPtr
    lpExclusiveOwner: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    dwModeIndex: UInt32
    dwModeIndexOrig: UInt32
    dwNumFourCC: UInt32
    lpdwFourCC: POINTER(UInt32)
    dwNumModes: UInt32
    lpModeInfo: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHALMODEINFO)
    plProcessList: win32more.Windows.Win32.Graphics.DirectDraw.PROCESS_LIST
    dwSurfaceLockCount: UInt32
    dwAliasedLockCnt: UInt32
    dwReserved3: UIntPtr
    hDD: UIntPtr
    cObsolete: win32more.Windows.Win32.Foundation.CHAR * 12
    dwReserved1: UInt32
    dwReserved2: UInt32
    dbnOverlayRoot: win32more.Windows.Win32.Graphics.DirectDraw.DBLNODE
    lpwPDeviceFlags: POINTER(UInt16)
    dwPDevice: UInt32
    dwWin16LockCnt: UInt32
    dwUnused3: UInt32
    hInstance: UInt32
    dwEvent16: UInt32
    dwSaveNumModes: UInt32
    lpD3DGlobalDriverData: UIntPtr
    lpD3DHALCallbacks: UIntPtr
    ddBothCaps: win32more.Windows.Win32.Graphics.DirectDraw.DDCORECAPS
    lpDDVideoPortCaps: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDVIDEOPORTCAPS)
    dvpList: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDVIDEOPORT_INT)
    lpD3DHALCallbacks2: UIntPtr
    rectDevice: win32more.Windows.Win32.Foundation.RECT
    cMonitors: UInt32
    gpbmiSrc: VoidPtr
    gpbmiDest: VoidPtr
    phaiHeapAliases: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.HEAPALIASINFO)
    hKernelHandle: UIntPtr
    pfnNotifyProc: UIntPtr
    lpDDKernelCaps: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDKERNELCAPS)
    lpddNLVCaps: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDNONLOCALVIDMEMCAPS)
    lpddNLVHELCaps: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDNONLOCALVIDMEMCAPS)
    lpddNLVBothCaps: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDNONLOCALVIDMEMCAPS)
    lpD3DExtendedCaps: UIntPtr
    dwDOSBoxEvent: UInt32
    rectDesktop: win32more.Windows.Win32.Foundation.RECT
    cDriverName: win32more.Windows.Win32.Foundation.CHAR * 32
    lpD3DHALCallbacks3: UIntPtr
    dwNumZPixelFormats: UInt32
    lpZPixelFormats: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT)
    mcList: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDMOTIONCOMP_INT)
    hDDVxd: UInt32
    ddsCapsMore: win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPSEX
class DDRAWI_DIRECTDRAW_INT(Structure):
    lpVtbl: VoidPtr
    lpLcl: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_LCL)
    lpLink: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_INT)
    dwIntRefCnt: UInt32
class DDRAWI_DIRECTDRAW_LCL(Structure):
    lpDDMore: UInt32
    lpGbl: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_GBL)
    dwUnused0: UInt32
    dwLocalFlags: UInt32
    dwLocalRefCnt: UInt32
    dwProcessId: UInt32
    pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown
    dwObsolete1: UInt32
    hWnd: UIntPtr
    hDC: UIntPtr
    dwErrorMode: UInt32
    lpPrimary: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_INT)
    lpCB: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DDRAWSURFACE_INT)
    dwPreferredMode: UInt32
    hD3DInstance: win32more.Windows.Win32.Foundation.HINSTANCE
    pD3DIUnknown: win32more.Windows.Win32.System.Com.IUnknown
    lpDDCB: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_CALLBACKS)
    hDDVxd: UIntPtr
    dwAppHackFlags: UInt32
    hFocusWnd: UIntPtr
    dwHotTracking: UInt32
    dwIMEState: UInt32
    hWndPopup: UIntPtr
    hDD: UIntPtr
    hGammaCalibrator: UIntPtr
    lpGammaCalibrator: win32more.Windows.Win32.Graphics.DirectDraw.LPDDGAMMACALIBRATORPROC
class DDRGBA(Structure):
    red: Byte
    green: Byte
    blue: Byte
    alpha: Byte
class DDSCAPS(Structure):
    dwCaps: UInt32
class DDSCAPS2(Structure):
    dwCaps: UInt32
    dwCaps2: UInt32
    dwCaps3: UInt32
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        dwCaps4: UInt32
        dwVolumeDepth: UInt32
class DDSCAPSEX(Structure):
    dwCaps2: UInt32
    dwCaps3: UInt32
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        dwCaps4: UInt32
        dwVolumeDepth: UInt32
class DDSETSTATEININFO(Structure):
    lpSurfaceData: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDATA)
    lpVideoPortData: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDVIDEOPORTDATA)
class DDSETSTATEOUTINFO(Structure):
    bSoftwareAutoflip: win32more.Windows.Win32.Foundation.BOOL
    dwSurfaceIndex: UInt32
    dwVBISurfaceIndex: UInt32
class DDSKIPNEXTFIELDINFO(Structure):
    lpVideoPortData: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDVIDEOPORTDATA)
    dwSkipFlags: UInt32
class DDSTEREOMODE(Structure):
    dwSize: UInt32
    dwHeight: UInt32
    dwWidth: UInt32
    dwBpp: UInt32
    dwRefreshRate: UInt32
    bSupported: win32more.Windows.Win32.Foundation.BOOL
class DDSURFACEDATA(Structure):
    ddsCaps: UInt32
    dwSurfaceOffset: UInt32
    fpLockPtr: UIntPtr
    dwWidth: UInt32
    dwHeight: UInt32
    lPitch: Int32
    dwOverlayFlags: UInt32
    dwOverlayOffset: UInt32
    dwOverlaySrcWidth: UInt32
    dwOverlaySrcHeight: UInt32
    dwOverlayDestWidth: UInt32
    dwOverlayDestHeight: UInt32
    dwVideoPortId: UInt32
    dwFormatFlags: UInt32
    dwFormatFourCC: UInt32
    dwFormatBitCount: UInt32
    dwRBitMask: UInt32
    dwGBitMask: UInt32
    dwBBitMask: UInt32
    dwDriverReserved1: UInt32
    dwDriverReserved2: UInt32
    dwDriverReserved3: UInt32
    dwDriverReserved4: UInt32
class DDSURFACEDESC(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    dwHeight: UInt32
    dwWidth: UInt32
    Anonymous1: _Anonymous1_e__Union
    dwBackBufferCount: UInt32
    Anonymous2: _Anonymous2_e__Union
    dwAlphaBitDepth: UInt32
    dwReserved: UInt32
    lpSurface: VoidPtr
    ddckCKDestOverlay: win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORKEY
    ddckCKDestBlt: win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORKEY
    ddckCKSrcOverlay: win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORKEY
    ddckCKSrcBlt: win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORKEY
    ddpfPixelFormat: win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT
    ddsCaps: win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPS
    class _Anonymous1_e__Union(Union):
        lPitch: Int32
        dwLinearSize: UInt32
    class _Anonymous2_e__Union(Union):
        dwMipMapCount: UInt32
        dwZBufferBitDepth: UInt32
        dwRefreshRate: UInt32
class DDSURFACEDESC2(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    dwHeight: UInt32
    dwWidth: UInt32
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    Anonymous3: _Anonymous3_e__Union
    dwAlphaBitDepth: UInt32
    dwReserved: UInt32
    lpSurface: VoidPtr
    Anonymous4: _Anonymous4_e__Union
    ddckCKDestBlt: win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORKEY
    ddckCKSrcOverlay: win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORKEY
    ddckCKSrcBlt: win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORKEY
    Anonymous5: _Anonymous5_e__Union
    ddsCaps: win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPS2
    dwTextureStage: UInt32
    class _Anonymous1_e__Union(Union):
        lPitch: Int32
        dwLinearSize: UInt32
    class _Anonymous2_e__Union(Union):
        dwBackBufferCount: UInt32
        dwDepth: UInt32
    class _Anonymous3_e__Union(Union):
        dwMipMapCount: UInt32
        dwRefreshRate: UInt32
        dwSrcVBHandle: UInt32
    class _Anonymous4_e__Union(Union):
        ddckCKDestOverlay: win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORKEY
        dwEmptyFaceColor: UInt32
    class _Anonymous5_e__Union(Union):
        ddpfPixelFormat: win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT
        dwFVF: UInt32
class DDTRANSFERININFO(Structure):
    lpSurfaceData: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDATA)
    dwStartLine: UInt32
    dwEndLine: UInt32
    dwTransferID: UIntPtr
    dwTransferFlags: UInt32
    lpDestMDL: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDMDL)
class DDTRANSFEROUTINFO(Structure):
    dwBufferPolarity: UInt32
class DDVERSIONDATA(Structure):
    dwHALVersion: UInt32
    dwReserved1: UIntPtr
    dwReserved2: UIntPtr
class DDVIDEOPORTBANDWIDTH(Structure):
    dwSize: UInt32
    dwCaps: UInt32
    dwOverlay: UInt32
    dwColorkey: UInt32
    dwYInterpolate: UInt32
    dwYInterpAndColorkey: UInt32
    dwReserved1: UIntPtr
    dwReserved2: UIntPtr
class DDVIDEOPORTCAPS(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    dwMaxWidth: UInt32
    dwMaxVBIWidth: UInt32
    dwMaxHeight: UInt32
    dwVideoPortID: UInt32
    dwCaps: UInt32
    dwFX: UInt32
    dwNumAutoFlipSurfaces: UInt32
    dwAlignVideoPortBoundary: UInt32
    dwAlignVideoPortPrescaleWidth: UInt32
    dwAlignVideoPortCropBoundary: UInt32
    dwAlignVideoPortCropWidth: UInt32
    dwPreshrinkXStep: UInt32
    dwPreshrinkYStep: UInt32
    dwNumVBIAutoFlipSurfaces: UInt32
    dwNumPreferredAutoflip: UInt32
    wNumFilterTapsX: UInt16
    wNumFilterTapsY: UInt16
class DDVIDEOPORTCONNECT(Structure):
    dwSize: UInt32
    dwPortWidth: UInt32
    guidTypeID: Guid
    dwFlags: UInt32
    dwReserved1: UIntPtr
class DDVIDEOPORTDATA(Structure):
    dwVideoPortId: UInt32
    dwVPFlags: UInt32
    dwOriginOffset: UInt32
    dwHeight: UInt32
    dwVBIHeight: UInt32
    dwDriverReserved1: UInt32
    dwDriverReserved2: UInt32
    dwDriverReserved3: UInt32
class DDVIDEOPORTDESC(Structure):
    dwSize: UInt32
    dwFieldWidth: UInt32
    dwVBIWidth: UInt32
    dwFieldHeight: UInt32
    dwMicrosecondsPerField: UInt32
    dwMaxPixelsPerSecond: UInt32
    dwVideoPortID: UInt32
    dwReserved1: UInt32
    VideoPortType: win32more.Windows.Win32.Graphics.DirectDraw.DDVIDEOPORTCONNECT
    dwReserved2: UIntPtr
    dwReserved3: UIntPtr
class DDVIDEOPORTINFO(Structure):
    dwSize: UInt32
    dwOriginX: UInt32
    dwOriginY: UInt32
    dwVPFlags: UInt32
    rCrop: win32more.Windows.Win32.Foundation.RECT
    dwPrescaleWidth: UInt32
    dwPrescaleHeight: UInt32
    lpddpfInputFormat: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT)
    lpddpfVBIInputFormat: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT)
    lpddpfVBIOutputFormat: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT)
    dwVBIHeight: UInt32
    dwReserved1: UIntPtr
    dwReserved2: UIntPtr
class DDVIDEOPORTNOTIFY(Structure):
    ApproximateTimeStamp: Int64
    lField: Int32
    dwSurfaceIndex: UInt32
    lDone: Int32
class DDVIDEOPORTSTATUS(Structure):
    dwSize: UInt32
    bInUse: win32more.Windows.Win32.Foundation.BOOL
    dwFlags: UInt32
    dwReserved1: UInt32
    VideoPortType: win32more.Windows.Win32.Graphics.DirectDraw.DDVIDEOPORTCONNECT
    dwReserved2: UIntPtr
    dwReserved3: UIntPtr
class DD_ADDATTACHEDSURFACEDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_GLOBAL)
    lpDDSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_LOCAL)
    lpSurfAttached: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_LOCAL)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    AddAttachedSurface: VoidPtr
class DD_ATTACHLIST(Structure):
    lpLink: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_ATTACHLIST)
    lpAttached: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_LOCAL)
class DD_BEGINMOCOMPFRAMEDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_LOCAL)
    lpMoComp: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_MOTIONCOMP_LOCAL)
    lpDestSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_LOCAL)
    dwInputDataSize: UInt32
    lpInputData: VoidPtr
    dwOutputDataSize: UInt32
    lpOutputData: VoidPtr
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
class DD_BLTDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_GLOBAL)
    lpDDDestSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_LOCAL)
    rDest: win32more.Windows.Win32.Foundation.RECTL
    lpDDSrcSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_LOCAL)
    rSrc: win32more.Windows.Win32.Foundation.RECTL
    dwFlags: UInt32
    dwROPFlags: UInt32
    bltFX: win32more.Windows.Win32.Graphics.DirectDraw.DDBLTFX
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    Blt: VoidPtr
    IsClipped: win32more.Windows.Win32.Foundation.BOOL
    rOrigDest: win32more.Windows.Win32.Foundation.RECTL
    rOrigSrc: win32more.Windows.Win32.Foundation.RECTL
    dwRectCnt: UInt32
    prDestRects: POINTER(win32more.Windows.Win32.Foundation.RECT)
    dwAFlags: UInt32
    ddargbScaleFactors: win32more.Windows.Win32.Graphics.DirectDraw.DDARGB
class DD_CALLBACKS(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    DestroyDriver: win32more.Windows.Win32.Graphics.DirectDraw.PDD_DESTROYDRIVER
    CreateSurface: win32more.Windows.Win32.Graphics.DirectDraw.PDD_CREATESURFACE
    SetColorKey: win32more.Windows.Win32.Graphics.DirectDraw.PDD_SETCOLORKEY
    SetMode: win32more.Windows.Win32.Graphics.DirectDraw.PDD_SETMODE
    WaitForVerticalBlank: win32more.Windows.Win32.Graphics.DirectDraw.PDD_WAITFORVERTICALBLANK
    CanCreateSurface: win32more.Windows.Win32.Graphics.DirectDraw.PDD_CANCREATESURFACE
    CreatePalette: win32more.Windows.Win32.Graphics.DirectDraw.PDD_CREATEPALETTE
    GetScanLine: win32more.Windows.Win32.Graphics.DirectDraw.PDD_GETSCANLINE
    MapMemory: win32more.Windows.Win32.Graphics.DirectDraw.PDD_MAPMEMORY
class DD_CANCREATESURFACEDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_GLOBAL)
    lpDDSurfaceDesc: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC)
    bIsDifferentPixelFormat: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    CanCreateSurface: VoidPtr
class DD_CANCREATEVPORTDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_LOCAL)
    lpDDVideoPortDesc: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDVIDEOPORTDESC)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    CanCreateVideoPort: VoidPtr
class DD_CLIPPER_GLOBAL(Structure):
    dwReserved1: UIntPtr
class DD_CLIPPER_LOCAL(Structure):
    dwReserved1: UIntPtr
class DD_COLORCONTROLCALLBACKS(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    ColorControl: win32more.Windows.Win32.Graphics.DirectDraw.PDD_COLORCB_COLORCONTROL
class DD_COLORCONTROLDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_GLOBAL)
    lpDDSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_LOCAL)
    lpColorData: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORCONTROL)
    dwFlags: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    ColorControl: VoidPtr
class DD_CREATEMOCOMPDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_LOCAL)
    lpMoComp: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_MOTIONCOMP_LOCAL)
    lpGuid: POINTER(Guid)
    dwUncompWidth: UInt32
    dwUncompHeight: UInt32
    ddUncompPixelFormat: win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT
    lpData: VoidPtr
    dwDataSize: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
class DD_CREATEPALETTEDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_GLOBAL)
    lpDDPalette: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_PALETTE_GLOBAL)
    lpColorTable: POINTER(win32more.Windows.Win32.Graphics.Gdi.PALETTEENTRY)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    CreatePalette: VoidPtr
    is_excl: win32more.Windows.Win32.Foundation.BOOL
class DD_CREATESURFACEDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_GLOBAL)
    lpDDSurfaceDesc: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC)
    lplpSList: POINTER(POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_LOCAL))
    dwSCnt: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    CreateSurface: VoidPtr
class DD_CREATESURFACEEXDATA(Structure):
    dwFlags: UInt32
    lpDDLcl: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_LOCAL)
    lpDDSLcl: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_LOCAL)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
class DD_CREATEVPORTDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_LOCAL)
    lpDDVideoPortDesc: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDVIDEOPORTDESC)
    lpVideoPort: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_VIDEOPORT_LOCAL)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    CreateVideoPort: VoidPtr
class DD_D3DBUFCALLBACKS(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    CanCreateD3DBuffer: win32more.Windows.Win32.Graphics.DirectDraw.PDD_CANCREATESURFACE
    CreateD3DBuffer: win32more.Windows.Win32.Graphics.DirectDraw.PDD_CREATESURFACE
    DestroyD3DBuffer: win32more.Windows.Win32.Graphics.DirectDraw.PDD_SURFCB_DESTROYSURFACE
    LockD3DBuffer: win32more.Windows.Win32.Graphics.DirectDraw.PDD_SURFCB_LOCK
    UnlockD3DBuffer: win32more.Windows.Win32.Graphics.DirectDraw.PDD_SURFCB_UNLOCK
class DD_DESTROYDDLOCALDATA(Structure):
    dwFlags: UInt32
    pDDLcl: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_LOCAL)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
class DD_DESTROYMOCOMPDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_LOCAL)
    lpMoComp: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_MOTIONCOMP_LOCAL)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
class DD_DESTROYPALETTEDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_GLOBAL)
    lpDDPalette: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_PALETTE_GLOBAL)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    DestroyPalette: VoidPtr
class DD_DESTROYSURFACEDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_GLOBAL)
    lpDDSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_LOCAL)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    DestroySurface: VoidPtr
class DD_DESTROYVPORTDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_LOCAL)
    lpVideoPort: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_VIDEOPORT_LOCAL)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    DestroyVideoPort: VoidPtr
class DD_DIRECTDRAW_GLOBAL(Structure):
    dhpdev: VoidPtr
    dwReserved1: UIntPtr
    dwReserved2: UIntPtr
    lpDDVideoPortCaps: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDVIDEOPORTCAPS)
class DD_DIRECTDRAW_LOCAL(Structure):
    lpGbl: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_GLOBAL)
class DD_DRVSETCOLORKEYDATA(Structure):
    lpDDSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_LOCAL)
    dwFlags: UInt32
    ckNew: win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORKEY
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    SetColorKey: VoidPtr
class DD_ENDMOCOMPFRAMEDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_LOCAL)
    lpMoComp: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_MOTIONCOMP_LOCAL)
    lpInputData: VoidPtr
    dwInputDataSize: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
class DD_FLIPDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_GLOBAL)
    lpSurfCurr: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_LOCAL)
    lpSurfTarg: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_LOCAL)
    dwFlags: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    Flip: VoidPtr
    lpSurfCurrLeft: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_LOCAL)
    lpSurfTargLeft: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_LOCAL)
class DD_FLIPTOGDISURFACEDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_GLOBAL)
    dwToGDI: UInt32
    dwReserved: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    FlipToGDISurface: VoidPtr
class DD_FLIPVPORTDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_LOCAL)
    lpVideoPort: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_VIDEOPORT_LOCAL)
    lpSurfCurr: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_LOCAL)
    lpSurfTarg: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_LOCAL)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    FlipVideoPort: VoidPtr
class DD_FREEDRIVERMEMORYDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_GLOBAL)
    lpDDSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_LOCAL)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    FreeDriverMemory: VoidPtr
class DD_GETAVAILDRIVERMEMORYDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_GLOBAL)
    DDSCaps: win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPS
    dwTotal: UInt32
    dwFree: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    GetAvailDriverMemory: VoidPtr
class DD_GETBLTSTATUSDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_GLOBAL)
    lpDDSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_LOCAL)
    dwFlags: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    GetBltStatus: VoidPtr
class DD_GETDRIVERINFODATA(Structure):
    dhpdev: VoidPtr
    dwSize: UInt32
    dwFlags: UInt32
    guidInfo: Guid
    dwExpectedSize: UInt32
    lpvData: VoidPtr
    dwActualSize: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
class DD_GETDRIVERSTATEDATA(Structure):
    dwFlags: UInt32
    Anonymous: _Anonymous_e__Union
    lpdwStates: POINTER(UInt32)
    dwLength: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    class _Anonymous_e__Union(Union):
        lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_GLOBAL)
        dwhContext: UIntPtr
class DD_GETFLIPSTATUSDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_GLOBAL)
    lpDDSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_LOCAL)
    dwFlags: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    GetFlipStatus: VoidPtr
class DD_GETHEAPALIGNMENTDATA(Structure):
    dwInstance: UIntPtr
    dwHeap: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    GetHeapAlignment: VoidPtr
    Alignment: win32more.Windows.Win32.Graphics.DirectDraw.HEAPALIGNMENT
class DD_GETINTERNALMOCOMPDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_LOCAL)
    lpGuid: POINTER(Guid)
    dwWidth: UInt32
    dwHeight: UInt32
    ddPixelFormat: win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT
    dwScratchMemAlloc: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
class DD_GETMOCOMPCOMPBUFFDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_LOCAL)
    lpGuid: POINTER(Guid)
    dwWidth: UInt32
    dwHeight: UInt32
    ddPixelFormat: win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT
    dwNumTypesCompBuffs: UInt32
    lpCompBuffInfo: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDCOMPBUFFERINFO)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
class DD_GETMOCOMPFORMATSDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_LOCAL)
    lpGuid: POINTER(Guid)
    dwNumFormats: UInt32
    lpFormats: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
class DD_GETMOCOMPGUIDSDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_LOCAL)
    dwNumGuids: UInt32
    lpGuids: POINTER(Guid)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
class DD_GETSCANLINEDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_GLOBAL)
    dwScanLine: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    GetScanLine: VoidPtr
class DD_GETVPORTBANDWIDTHDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_LOCAL)
    lpVideoPort: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_VIDEOPORT_LOCAL)
    lpddpfFormat: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT)
    dwWidth: UInt32
    dwHeight: UInt32
    dwFlags: UInt32
    lpBandwidth: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDVIDEOPORTBANDWIDTH)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    GetVideoPortBandwidth: VoidPtr
class DD_GETVPORTCONNECTDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_LOCAL)
    dwPortId: UInt32
    lpConnect: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDVIDEOPORTCONNECT)
    dwNumEntries: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    GetVideoPortConnectInfo: VoidPtr
class DD_GETVPORTFIELDDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_LOCAL)
    lpVideoPort: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_VIDEOPORT_LOCAL)
    bField: win32more.Windows.Win32.Foundation.BOOL
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    GetVideoPortField: VoidPtr
class DD_GETVPORTFLIPSTATUSDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_LOCAL)
    fpSurface: UIntPtr
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    GetVideoPortFlipStatus: VoidPtr
class DD_GETVPORTINPUTFORMATDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_LOCAL)
    lpVideoPort: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_VIDEOPORT_LOCAL)
    dwFlags: UInt32
    lpddpfFormat: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT)
    dwNumFormats: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    GetVideoPortInputFormats: VoidPtr
class DD_GETVPORTLINEDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_LOCAL)
    lpVideoPort: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_VIDEOPORT_LOCAL)
    dwLine: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    GetVideoPortLine: VoidPtr
class DD_GETVPORTOUTPUTFORMATDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_LOCAL)
    lpVideoPort: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_VIDEOPORT_LOCAL)
    dwFlags: UInt32
    lpddpfInputFormat: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT)
    lpddpfOutputFormats: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT)
    dwNumFormats: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    GetVideoPortInputFormats: VoidPtr
class DD_GETVPORTSIGNALDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_LOCAL)
    lpVideoPort: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_VIDEOPORT_LOCAL)
    dwStatus: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    GetVideoSignalStatus: VoidPtr
class DD_HALINFO(Structure):
    dwSize: UInt32
    vmiData: win32more.Windows.Win32.Graphics.DirectDraw.VIDEOMEMORYINFO
    ddCaps: win32more.Windows.Win32.Graphics.DirectDraw.DDNTCORECAPS
    GetDriverInfo: win32more.Windows.Win32.Graphics.DirectDraw.PDD_GETDRIVERINFO
    dwFlags: UInt32
    lpD3DGlobalDriverData: VoidPtr
    lpD3DHALCallbacks: VoidPtr
    lpD3DBufCallbacks: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_D3DBUFCALLBACKS)
class DD_HALINFO_V4(Structure):
    dwSize: UInt32
    vmiData: win32more.Windows.Win32.Graphics.DirectDraw.VIDEOMEMORYINFO
    ddCaps: win32more.Windows.Win32.Graphics.DirectDraw.DDNTCORECAPS
    GetDriverInfo: win32more.Windows.Win32.Graphics.DirectDraw.PDD_GETDRIVERINFO
    dwFlags: UInt32
class DD_KERNELCALLBACKS(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    SyncSurfaceData: win32more.Windows.Win32.Graphics.DirectDraw.PDD_KERNELCB_SYNCSURFACE
    SyncVideoPortData: win32more.Windows.Win32.Graphics.DirectDraw.PDD_KERNELCB_SYNCVIDEOPORT
class DD_LOCKDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_GLOBAL)
    lpDDSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_LOCAL)
    bHasRect: UInt32
    rArea: win32more.Windows.Win32.Foundation.RECTL
    lpSurfData: VoidPtr
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    Lock: VoidPtr
    dwFlags: UInt32
    fpProcess: UIntPtr
class DD_MAPMEMORYDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_GLOBAL)
    bMap: win32more.Windows.Win32.Foundation.BOOL
    hProcess: win32more.Windows.Win32.Foundation.HANDLE
    fpProcess: UIntPtr
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
class DD_MISCELLANEOUS2CALLBACKS(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    AlphaBlt: win32more.Windows.Win32.Graphics.DirectDraw.PDD_ALPHABLT
    CreateSurfaceEx: win32more.Windows.Win32.Graphics.DirectDraw.PDD_CREATESURFACEEX
    GetDriverState: win32more.Windows.Win32.Graphics.DirectDraw.PDD_GETDRIVERSTATE
    DestroyDDLocal: win32more.Windows.Win32.Graphics.DirectDraw.PDD_DESTROYDDLOCAL
class DD_MISCELLANEOUSCALLBACKS(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    GetAvailDriverMemory: win32more.Windows.Win32.Graphics.DirectDraw.PDD_GETAVAILDRIVERMEMORY
class DD_MORECAPS(Structure):
    dwSize: UInt32
    dwAlphaCaps: UInt32
    dwSVBAlphaCaps: UInt32
    dwVSBAlphaCaps: UInt32
    dwSSBAlphaCaps: UInt32
    dwFilterCaps: UInt32
    dwSVBFilterCaps: UInt32
    dwVSBFilterCaps: UInt32
    dwSSBFilterCaps: UInt32
class DD_MORESURFACECAPS(Structure):
    dwSize: UInt32
    ddsCapsMore: win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPSEX
    ddsExtendedHeapRestrictions: NTExtendedHeapRestrictions * 1
    class NTExtendedHeapRestrictions(Structure):
        ddsCapsEx: win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPSEX
        ddsCapsExAlt: win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPSEX
class DD_MOTIONCOMPCALLBACKS(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    GetMoCompGuids: win32more.Windows.Win32.Graphics.DirectDraw.PDD_MOCOMPCB_GETGUIDS
    GetMoCompFormats: win32more.Windows.Win32.Graphics.DirectDraw.PDD_MOCOMPCB_GETFORMATS
    CreateMoComp: win32more.Windows.Win32.Graphics.DirectDraw.PDD_MOCOMPCB_CREATE
    GetMoCompBuffInfo: win32more.Windows.Win32.Graphics.DirectDraw.PDD_MOCOMPCB_GETCOMPBUFFINFO
    GetInternalMoCompInfo: win32more.Windows.Win32.Graphics.DirectDraw.PDD_MOCOMPCB_GETINTERNALINFO
    BeginMoCompFrame: win32more.Windows.Win32.Graphics.DirectDraw.PDD_MOCOMPCB_BEGINFRAME
    EndMoCompFrame: win32more.Windows.Win32.Graphics.DirectDraw.PDD_MOCOMPCB_ENDFRAME
    RenderMoComp: win32more.Windows.Win32.Graphics.DirectDraw.PDD_MOCOMPCB_RENDER
    QueryMoCompStatus: win32more.Windows.Win32.Graphics.DirectDraw.PDD_MOCOMPCB_QUERYSTATUS
    DestroyMoComp: win32more.Windows.Win32.Graphics.DirectDraw.PDD_MOCOMPCB_DESTROY
class DD_MOTIONCOMP_LOCAL(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_LOCAL)
    guid: Guid
    dwUncompWidth: UInt32
    dwUncompHeight: UInt32
    ddUncompPixelFormat: win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT
    dwDriverReserved1: UInt32
    dwDriverReserved2: UInt32
    dwDriverReserved3: UInt32
    lpDriverReserved1: VoidPtr
    lpDriverReserved2: VoidPtr
    lpDriverReserved3: VoidPtr
class DD_NONLOCALVIDMEMCAPS(Structure):
    dwSize: UInt32
    dwNLVBCaps: UInt32
    dwNLVBCaps2: UInt32
    dwNLVBCKeyCaps: UInt32
    dwNLVBFXCaps: UInt32
    dwNLVBRops: UInt32 * 8
class DD_NTCALLBACKS(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    FreeDriverMemory: win32more.Windows.Win32.Graphics.DirectDraw.PDD_FREEDRIVERMEMORY
    SetExclusiveMode: win32more.Windows.Win32.Graphics.DirectDraw.PDD_SETEXCLUSIVEMODE
    FlipToGDISurface: win32more.Windows.Win32.Graphics.DirectDraw.PDD_FLIPTOGDISURFACE
class DD_NTPRIVATEDRIVERCAPS(Structure):
    dwSize: UInt32
    dwPrivateCaps: UInt32
class DD_PALETTECALLBACKS(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    DestroyPalette: win32more.Windows.Win32.Graphics.DirectDraw.PDD_PALCB_DESTROYPALETTE
    SetEntries: win32more.Windows.Win32.Graphics.DirectDraw.PDD_PALCB_SETENTRIES
class DD_PALETTE_GLOBAL(Structure):
    dwReserved1: UIntPtr
class DD_PALETTE_LOCAL(Structure):
    dwReserved0: UInt32
    dwReserved1: UIntPtr
class DD_QUERYMOCOMPSTATUSDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_LOCAL)
    lpMoComp: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_MOTIONCOMP_LOCAL)
    lpSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_LOCAL)
    dwFlags: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
class DD_RENDERMOCOMPDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_LOCAL)
    lpMoComp: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_MOTIONCOMP_LOCAL)
    dwNumBuffers: UInt32
    lpBufferInfo: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDMOCOMPBUFFERINFO)
    dwFunction: UInt32
    lpInputData: VoidPtr
    dwInputDataSize: UInt32
    lpOutputData: VoidPtr
    dwOutputDataSize: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
class DD_SETCLIPLISTDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_GLOBAL)
    lpDDSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_LOCAL)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    SetClipList: VoidPtr
class DD_SETCOLORKEYDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_GLOBAL)
    lpDDSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_LOCAL)
    dwFlags: UInt32
    ckNew: win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORKEY
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    SetColorKey: VoidPtr
class DD_SETENTRIESDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_GLOBAL)
    lpDDPalette: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_PALETTE_GLOBAL)
    dwBase: UInt32
    dwNumEntries: UInt32
    lpEntries: POINTER(win32more.Windows.Win32.Graphics.Gdi.PALETTEENTRY)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    SetEntries: VoidPtr
class DD_SETEXCLUSIVEMODEDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_GLOBAL)
    dwEnterExcl: UInt32
    dwReserved: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    SetExclusiveMode: VoidPtr
class DD_SETOVERLAYPOSITIONDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_GLOBAL)
    lpDDSrcSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_LOCAL)
    lpDDDestSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_LOCAL)
    lXPos: Int32
    lYPos: Int32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    SetOverlayPosition: VoidPtr
class DD_SETPALETTEDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_GLOBAL)
    lpDDSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_LOCAL)
    lpDDPalette: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_PALETTE_GLOBAL)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    SetPalette: VoidPtr
    Attach: win32more.Windows.Win32.Foundation.BOOL
class DD_STEREOMODE(Structure):
    dwSize: UInt32
    dwHeight: UInt32
    dwWidth: UInt32
    dwBpp: UInt32
    dwRefreshRate: UInt32
    bSupported: win32more.Windows.Win32.Foundation.BOOL
class DD_SURFACECALLBACKS(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    DestroySurface: win32more.Windows.Win32.Graphics.DirectDraw.PDD_SURFCB_DESTROYSURFACE
    Flip: win32more.Windows.Win32.Graphics.DirectDraw.PDD_SURFCB_FLIP
    SetClipList: win32more.Windows.Win32.Graphics.DirectDraw.PDD_SURFCB_SETCLIPLIST
    Lock: win32more.Windows.Win32.Graphics.DirectDraw.PDD_SURFCB_LOCK
    Unlock: win32more.Windows.Win32.Graphics.DirectDraw.PDD_SURFCB_UNLOCK
    Blt: win32more.Windows.Win32.Graphics.DirectDraw.PDD_SURFCB_BLT
    SetColorKey: win32more.Windows.Win32.Graphics.DirectDraw.PDD_SURFCB_SETCOLORKEY
    AddAttachedSurface: win32more.Windows.Win32.Graphics.DirectDraw.PDD_SURFCB_ADDATTACHEDSURFACE
    GetBltStatus: win32more.Windows.Win32.Graphics.DirectDraw.PDD_SURFCB_GETBLTSTATUS
    GetFlipStatus: win32more.Windows.Win32.Graphics.DirectDraw.PDD_SURFCB_GETFLIPSTATUS
    UpdateOverlay: win32more.Windows.Win32.Graphics.DirectDraw.PDD_SURFCB_UPDATEOVERLAY
    SetOverlayPosition: win32more.Windows.Win32.Graphics.DirectDraw.PDD_SURFCB_SETOVERLAYPOSITION
    reserved4: VoidPtr
    SetPalette: win32more.Windows.Win32.Graphics.DirectDraw.PDD_SURFCB_SETPALETTE
class DD_SURFACE_GLOBAL(Structure):
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    fpVidMem: UIntPtr
    Anonymous3: _Anonymous3_e__Union
    yHint: Int32
    xHint: Int32
    wHeight: UInt32
    wWidth: UInt32
    dwReserved1: UIntPtr
    ddpfSurface: win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT
    fpHeapOffset: UIntPtr
    hCreatorProcess: win32more.Windows.Win32.Foundation.HANDLE
    class _Anonymous1_e__Union(Union):
        dwBlockSizeY: UInt32
        lSlicePitch: Int32
    class _Anonymous2_e__Union(Union):
        lpVidMemHeap: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.VIDEOMEMORY)
        dwBlockSizeX: UInt32
        dwUserMemSize: UInt32
    class _Anonymous3_e__Union(Union):
        lPitch: Int32
        dwLinearSize: UInt32
class DD_SURFACE_INT(Structure):
    lpLcl: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_LOCAL)
class DD_SURFACE_LOCAL(Structure):
    lpGbl: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_GLOBAL)
    dwFlags: UInt32
    ddsCaps: win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPS
    dwReserved1: UIntPtr
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    lpSurfMore: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_MORE)
    lpAttachList: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_ATTACHLIST)
    lpAttachListFrom: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_ATTACHLIST)
    rcOverlaySrc: win32more.Windows.Win32.Foundation.RECT
    class _Anonymous1_e__Union(Union):
        ddckCKSrcOverlay: win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORKEY
        ddckCKSrcBlt: win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORKEY
    class _Anonymous2_e__Union(Union):
        ddckCKDestOverlay: win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORKEY
        ddckCKDestBlt: win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORKEY
class DD_SURFACE_MORE(Structure):
    dwMipMapCount: UInt32
    lpVideoPort: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_VIDEOPORT_LOCAL)
    dwOverlayFlags: UInt32
    ddsCapsEx: win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPSEX
    dwSurfaceHandle: UInt32
class DD_SYNCSURFACEDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_LOCAL)
    lpDDSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_LOCAL)
    dwSurfaceOffset: UInt32
    fpLockPtr: UIntPtr
    lPitch: Int32
    dwOverlayOffset: UInt32
    dwDriverReserved1: UInt32
    dwDriverReserved2: UInt32
    dwDriverReserved3: UInt32
    dwDriverReserved4: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
class DD_SYNCVIDEOPORTDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_LOCAL)
    lpVideoPort: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_VIDEOPORT_LOCAL)
    dwOriginOffset: UInt32
    dwHeight: UInt32
    dwVBIHeight: UInt32
    dwDriverReserved1: UInt32
    dwDriverReserved2: UInt32
    dwDriverReserved3: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
class DD_UNLOCKDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_GLOBAL)
    lpDDSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_LOCAL)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    Unlock: VoidPtr
class DD_UPDATENONLOCALHEAPDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_GLOBAL)
    dwHeap: UInt32
    fpGARTLin: UIntPtr
    fpGARTDev: UIntPtr
    ulPolicyMaxBytes: UIntPtr
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    UpdateNonLocalHeap: VoidPtr
class DD_UPDATEOVERLAYDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_GLOBAL)
    lpDDDestSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_LOCAL)
    rDest: win32more.Windows.Win32.Foundation.RECTL
    lpDDSrcSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_LOCAL)
    rSrc: win32more.Windows.Win32.Foundation.RECTL
    dwFlags: UInt32
    overlayFX: win32more.Windows.Win32.Graphics.DirectDraw.DDOVERLAYFX
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    UpdateOverlay: VoidPtr
class DD_UPDATEVPORTDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_LOCAL)
    lpVideoPort: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_VIDEOPORT_LOCAL)
    lplpDDSurface: POINTER(POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_INT))
    lplpDDVBISurface: POINTER(POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_INT))
    lpVideoInfo: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDVIDEOPORTINFO)
    dwFlags: UInt32
    dwNumAutoflip: UInt32
    dwNumVBIAutoflip: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    UpdateVideoPort: VoidPtr
class DD_VIDEOPORTCALLBACKS(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    CanCreateVideoPort: win32more.Windows.Win32.Graphics.DirectDraw.PDD_VPORTCB_CANCREATEVIDEOPORT
    CreateVideoPort: win32more.Windows.Win32.Graphics.DirectDraw.PDD_VPORTCB_CREATEVIDEOPORT
    FlipVideoPort: win32more.Windows.Win32.Graphics.DirectDraw.PDD_VPORTCB_FLIP
    GetVideoPortBandwidth: win32more.Windows.Win32.Graphics.DirectDraw.PDD_VPORTCB_GETBANDWIDTH
    GetVideoPortInputFormats: win32more.Windows.Win32.Graphics.DirectDraw.PDD_VPORTCB_GETINPUTFORMATS
    GetVideoPortOutputFormats: win32more.Windows.Win32.Graphics.DirectDraw.PDD_VPORTCB_GETOUTPUTFORMATS
    lpReserved1: VoidPtr
    GetVideoPortField: win32more.Windows.Win32.Graphics.DirectDraw.PDD_VPORTCB_GETFIELD
    GetVideoPortLine: win32more.Windows.Win32.Graphics.DirectDraw.PDD_VPORTCB_GETLINE
    GetVideoPortConnectInfo: win32more.Windows.Win32.Graphics.DirectDraw.PDD_VPORTCB_GETVPORTCONNECT
    DestroyVideoPort: win32more.Windows.Win32.Graphics.DirectDraw.PDD_VPORTCB_DESTROYVPORT
    GetVideoPortFlipStatus: win32more.Windows.Win32.Graphics.DirectDraw.PDD_VPORTCB_GETFLIPSTATUS
    UpdateVideoPort: win32more.Windows.Win32.Graphics.DirectDraw.PDD_VPORTCB_UPDATE
    WaitForVideoPortSync: win32more.Windows.Win32.Graphics.DirectDraw.PDD_VPORTCB_WAITFORSYNC
    GetVideoSignalStatus: win32more.Windows.Win32.Graphics.DirectDraw.PDD_VPORTCB_GETSIGNALSTATUS
    ColorControl: win32more.Windows.Win32.Graphics.DirectDraw.PDD_VPORTCB_COLORCONTROL
class DD_VIDEOPORT_LOCAL(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_LOCAL)
    ddvpDesc: win32more.Windows.Win32.Graphics.DirectDraw.DDVIDEOPORTDESC
    ddvpInfo: win32more.Windows.Win32.Graphics.DirectDraw.DDVIDEOPORTINFO
    lpSurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_INT)
    lpVBISurface: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SURFACE_INT)
    dwNumAutoflip: UInt32
    dwNumVBIAutoflip: UInt32
    dwReserved1: UIntPtr
    dwReserved2: UIntPtr
    dwReserved3: UIntPtr
class DD_VPORTCOLORDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_LOCAL)
    lpVideoPort: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_VIDEOPORT_LOCAL)
    dwFlags: UInt32
    lpColorData: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORCONTROL)
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    ColorControl: VoidPtr
class DD_WAITFORVERTICALBLANKDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_GLOBAL)
    dwFlags: UInt32
    bIsInVB: UInt32
    hEvent: UIntPtr
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    WaitForVerticalBlank: VoidPtr
class DD_WAITFORVPORTSYNCDATA(Structure):
    lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DIRECTDRAW_LOCAL)
    lpVideoPort: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_VIDEOPORT_LOCAL)
    dwFlags: UInt32
    dwLine: UInt32
    dwTimeOut: UInt32
    ddRVal: win32more.Windows.Win32.Foundation.HRESULT
    UpdateVideoPort: VoidPtr
class DXAPI_INTERFACE(Structure):
    Size: UInt16
    Version: UInt16
    Context: VoidPtr
    InterfaceReference: VoidPtr
    InterfaceDereference: VoidPtr
    DxGetIrqInfo: win32more.Windows.Win32.Graphics.DirectDraw.PDX_GETIRQINFO
    DxEnableIrq: win32more.Windows.Win32.Graphics.DirectDraw.PDX_ENABLEIRQ
    DxSkipNextField: win32more.Windows.Win32.Graphics.DirectDraw.PDX_SKIPNEXTFIELD
    DxBobNextField: win32more.Windows.Win32.Graphics.DirectDraw.PDX_BOBNEXTFIELD
    DxSetState: win32more.Windows.Win32.Graphics.DirectDraw.PDX_SETSTATE
    DxLock: win32more.Windows.Win32.Graphics.DirectDraw.PDX_LOCK
    DxFlipOverlay: win32more.Windows.Win32.Graphics.DirectDraw.PDX_FLIPOVERLAY
    DxFlipVideoPort: win32more.Windows.Win32.Graphics.DirectDraw.PDX_FLIPVIDEOPORT
    DxGetPolarity: win32more.Windows.Win32.Graphics.DirectDraw.PDX_GETPOLARITY
    DxGetCurrentAutoflip: win32more.Windows.Win32.Graphics.DirectDraw.PDX_GETCURRENTAUTOFLIP
    DxGetPreviousAutoflip: win32more.Windows.Win32.Graphics.DirectDraw.PDX_GETPREVIOUSAUTOFLIP
    DxTransfer: win32more.Windows.Win32.Graphics.DirectDraw.PDX_TRANSFER
    DxGetTransferStatus: win32more.Windows.Win32.Graphics.DirectDraw.PDX_GETTRANSFERSTATUS
class DX_IRQDATA(Structure):
    dwIrqFlags: UInt32
class HEAPALIAS(Structure):
    fpVidMem: UIntPtr
    lpAlias: VoidPtr
    dwAliasSize: UInt32
class HEAPALIASINFO(Structure):
    dwRefCnt: UInt32
    dwFlags: UInt32
    dwNumHeaps: UInt32
    lpAliases: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.HEAPALIAS)
class HEAPALIGNMENT(Structure):
    dwSize: UInt32
    ddsCaps: win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPS
    dwReserved: UInt32
    ExecuteBuffer: win32more.Windows.Win32.Graphics.DirectDraw.SURFACEALIGNMENT
    Overlay: win32more.Windows.Win32.Graphics.DirectDraw.SURFACEALIGNMENT
    Texture: win32more.Windows.Win32.Graphics.DirectDraw.SURFACEALIGNMENT
    ZBuffer: win32more.Windows.Win32.Graphics.DirectDraw.SURFACEALIGNMENT
    AlphaBuffer: win32more.Windows.Win32.Graphics.DirectDraw.SURFACEALIGNMENT
    Offscreen: win32more.Windows.Win32.Graphics.DirectDraw.SURFACEALIGNMENT
    FlipTarget: win32more.Windows.Win32.Graphics.DirectDraw.SURFACEALIGNMENT
class IDDVideoPortContainer(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{6c142760-a733-11ce-a521-0020af0be560}')
    @commethod(3)
    def CreateVideoPort(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDVIDEOPORTDESC), param2: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawVideoPort), param3: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def EnumVideoPorts(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDVIDEOPORTCAPS), param2: VoidPtr, param3: win32more.Windows.Win32.Graphics.DirectDraw.LPDDENUMVIDEOCALLBACK) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetVideoPortConnectInfo(self, param0: UInt32, pcInfo: POINTER(UInt32), param2: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDVIDEOPORTCONNECT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def QueryVideoPortStatus(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDVIDEOPORTSTATUS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirectDraw(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{6c14db80-a733-11ce-a521-0020af0be560}')
    @commethod(3)
    def Compact(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreateClipper(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawClipper), param2: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CreatePalette(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Graphics.Gdi.PALETTEENTRY), param2: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawPalette), param3: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def CreateSurface(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC), param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface), param2: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def DuplicateSurface(self, param0: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def EnumDisplayModes(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC), param2: VoidPtr, param3: win32more.Windows.Win32.Graphics.DirectDraw.LPDDENUMMODESCALLBACK) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def EnumSurfaces(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC), param2: VoidPtr, param3: win32more.Windows.Win32.Graphics.DirectDraw.LPDDENUMSURFACESCALLBACK) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def FlipToGDISurface(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetCaps(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDCAPS_DX7), param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDCAPS_DX7)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetDisplayMode(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetFourCCCodes(self, param0: POINTER(UInt32), param1: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetGDISurface(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetMonitorFrequency(self, param0: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetScanLine(self, param0: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetVerticalBlankStatus(self, param0: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def Initialize(self, param0: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def RestoreDisplayMode(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def SetCooperativeLevel(self, param0: win32more.Windows.Win32.Foundation.HWND, param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def SetDisplayMode(self, param0: UInt32, param1: UInt32, param2: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def WaitForVerticalBlank(self, param0: UInt32, param1: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirectDraw2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{b3a6f3e0-2b43-11cf-a2de-00aa00b93356}')
    @commethod(3)
    def Compact(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreateClipper(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawClipper), param2: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CreatePalette(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Graphics.Gdi.PALETTEENTRY), param2: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawPalette), param3: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def CreateSurface(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC), param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface), param2: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def DuplicateSurface(self, param0: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def EnumDisplayModes(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC), param2: VoidPtr, param3: win32more.Windows.Win32.Graphics.DirectDraw.LPDDENUMMODESCALLBACK) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def EnumSurfaces(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC), param2: VoidPtr, param3: win32more.Windows.Win32.Graphics.DirectDraw.LPDDENUMSURFACESCALLBACK) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def FlipToGDISurface(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetCaps(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDCAPS_DX7), param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDCAPS_DX7)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetDisplayMode(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetFourCCCodes(self, param0: POINTER(UInt32), param1: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetGDISurface(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetMonitorFrequency(self, param0: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetScanLine(self, param0: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetVerticalBlankStatus(self, param0: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def Initialize(self, param0: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def RestoreDisplayMode(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def SetCooperativeLevel(self, param0: win32more.Windows.Win32.Foundation.HWND, param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def SetDisplayMode(self, param0: UInt32, param1: UInt32, param2: UInt32, param3: UInt32, param4: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def WaitForVerticalBlank(self, param0: UInt32, param1: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def GetAvailableVidMem(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPS), param1: POINTER(UInt32), param2: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirectDraw4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{9c59509a-39bd-11d1-8c4a-00c04fd930c5}')
    @commethod(3)
    def Compact(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreateClipper(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawClipper), param2: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CreatePalette(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Graphics.Gdi.PALETTEENTRY), param2: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawPalette), param3: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def CreateSurface(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC2), param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface4), param2: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def DuplicateSurface(self, param0: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface4, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface4)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def EnumDisplayModes(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC2), param2: VoidPtr, param3: win32more.Windows.Win32.Graphics.DirectDraw.LPDDENUMMODESCALLBACK2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def EnumSurfaces(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC2), param2: VoidPtr, param3: win32more.Windows.Win32.Graphics.DirectDraw.LPDDENUMSURFACESCALLBACK2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def FlipToGDISurface(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetCaps(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDCAPS_DX7), param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDCAPS_DX7)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetDisplayMode(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetFourCCCodes(self, param0: POINTER(UInt32), param1: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetGDISurface(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface4)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetMonitorFrequency(self, param0: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetScanLine(self, param0: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetVerticalBlankStatus(self, param0: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def Initialize(self, param0: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def RestoreDisplayMode(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def SetCooperativeLevel(self, param0: win32more.Windows.Win32.Foundation.HWND, param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def SetDisplayMode(self, param0: UInt32, param1: UInt32, param2: UInt32, param3: UInt32, param4: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def WaitForVerticalBlank(self, param0: UInt32, param1: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def GetAvailableVidMem(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPS2), param1: POINTER(UInt32), param2: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def GetSurfaceFromDC(self, param0: win32more.Windows.Win32.Graphics.Gdi.HDC, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface4)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def RestoreAllSurfaces(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def TestCooperativeLevel(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def GetDeviceIdentifier(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDDEVICEIDENTIFIER), param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirectDraw7(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{15e65ec0-3b9c-11d2-b92f-00609797ea5b}')
    @commethod(3)
    def Compact(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreateClipper(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawClipper), param2: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CreatePalette(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Graphics.Gdi.PALETTEENTRY), param2: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawPalette), param3: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def CreateSurface(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC2), param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface7), param2: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def DuplicateSurface(self, param0: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface7, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface7)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def EnumDisplayModes(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC2), param2: VoidPtr, param3: win32more.Windows.Win32.Graphics.DirectDraw.LPDDENUMMODESCALLBACK2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def EnumSurfaces(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC2), param2: VoidPtr, param3: win32more.Windows.Win32.Graphics.DirectDraw.LPDDENUMSURFACESCALLBACK7) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def FlipToGDISurface(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetCaps(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDCAPS_DX7), param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDCAPS_DX7)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetDisplayMode(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetFourCCCodes(self, param0: POINTER(UInt32), param1: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetGDISurface(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface7)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetMonitorFrequency(self, param0: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetScanLine(self, param0: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetVerticalBlankStatus(self, param0: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def Initialize(self, param0: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def RestoreDisplayMode(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def SetCooperativeLevel(self, param0: win32more.Windows.Win32.Foundation.HWND, param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def SetDisplayMode(self, param0: UInt32, param1: UInt32, param2: UInt32, param3: UInt32, param4: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def WaitForVerticalBlank(self, param0: UInt32, param1: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def GetAvailableVidMem(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPS2), param1: POINTER(UInt32), param2: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def GetSurfaceFromDC(self, param0: win32more.Windows.Win32.Graphics.Gdi.HDC, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface7)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def RestoreAllSurfaces(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def TestCooperativeLevel(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def GetDeviceIdentifier(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDDEVICEIDENTIFIER2), param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def StartModeTest(self, param0: POINTER(win32more.Windows.Win32.Foundation.SIZE), param1: UInt32, param2: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def EvaluateMode(self, param0: UInt32, param1: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirectDrawClipper(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{6c14db85-a733-11ce-a521-0020af0be560}')
    @commethod(3)
    def GetClipList(self, param0: POINTER(win32more.Windows.Win32.Foundation.RECT), param1: POINTER(win32more.Windows.Win32.Graphics.Gdi.RGNDATA), param2: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetHWnd(self, param0: POINTER(win32more.Windows.Win32.Foundation.HWND)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Initialize(self, param0: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDraw, param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def IsClipListChanged(self, param0: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetClipList(self, param0: POINTER(win32more.Windows.Win32.Graphics.Gdi.RGNDATA), param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetHWnd(self, param0: UInt32, param1: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirectDrawColorControl(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{4b9f0ee0-0d7e-11d0-9b06-00a0c903a3b8}')
    @commethod(3)
    def GetColorControls(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORCONTROL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetColorControls(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORCONTROL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirectDrawGammaControl(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{69c11c3e-b46b-11d1-ad7a-00c04fc29b4e}')
    @commethod(3)
    def GetGammaRamp(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDGAMMARAMP)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetGammaRamp(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDGAMMARAMP)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirectDrawKernel(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{8d56c120-6a08-11d0-9b06-00a0c903a3b8}')
    @commethod(3)
    def GetCaps(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDKERNELCAPS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetKernelHandle(self, param0: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def ReleaseKernelHandle(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirectDrawPalette(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{6c14db84-a733-11ce-a521-0020af0be560}')
    @commethod(3)
    def GetCaps(self, param0: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetEntries(self, param0: UInt32, param1: UInt32, param2: UInt32, param3: POINTER(win32more.Windows.Win32.Graphics.Gdi.PALETTEENTRY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Initialize(self, param0: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDraw, param1: UInt32, param2: POINTER(win32more.Windows.Win32.Graphics.Gdi.PALETTEENTRY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetEntries(self, param0: UInt32, param1: UInt32, param2: UInt32, param3: POINTER(win32more.Windows.Win32.Graphics.Gdi.PALETTEENTRY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirectDrawSurface(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{6c14db81-a733-11ce-a521-0020af0be560}')
    @commethod(3)
    def AddAttachedSurface(self, param0: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def AddOverlayDirtyRect(self, param0: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Blt(self, param0: POINTER(win32more.Windows.Win32.Foundation.RECT), param1: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface, param2: POINTER(win32more.Windows.Win32.Foundation.RECT), param3: UInt32, param4: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDBLTFX)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def BltBatch(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDBLTBATCH), param1: UInt32, param2: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def BltFast(self, param0: UInt32, param1: UInt32, param2: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface, param3: POINTER(win32more.Windows.Win32.Foundation.RECT), param4: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def DeleteAttachedSurface(self, param0: UInt32, param1: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def EnumAttachedSurfaces(self, param0: VoidPtr, param1: win32more.Windows.Win32.Graphics.DirectDraw.LPDDENUMSURFACESCALLBACK) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def EnumOverlayZOrders(self, param0: UInt32, param1: VoidPtr, param2: win32more.Windows.Win32.Graphics.DirectDraw.LPDDENUMSURFACESCALLBACK) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def Flip(self, param0: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface, param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetAttachedSurface(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPS), param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetBltStatus(self, param0: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetCaps(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetClipper(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawClipper)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetColorKey(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORKEY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetDC(self, param0: POINTER(win32more.Windows.Win32.Graphics.Gdi.HDC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetFlipStatus(self, param0: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def GetOverlayPosition(self, param0: POINTER(Int32), param1: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def GetPalette(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawPalette)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def GetPixelFormat(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def GetSurfaceDesc(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def Initialize(self, param0: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDraw, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def IsLost(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def Lock(self, param0: POINTER(win32more.Windows.Win32.Foundation.RECT), param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC), param2: UInt32, param3: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def ReleaseDC(self, param0: win32more.Windows.Win32.Graphics.Gdi.HDC) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def Restore(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def SetClipper(self, param0: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawClipper) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def SetColorKey(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORKEY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def SetOverlayPosition(self, param0: Int32, param1: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def SetPalette(self, param0: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawPalette) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def Unlock(self, param0: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def UpdateOverlay(self, param0: POINTER(win32more.Windows.Win32.Foundation.RECT), param1: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface, param2: POINTER(win32more.Windows.Win32.Foundation.RECT), param3: UInt32, param4: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDOVERLAYFX)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def UpdateOverlayDisplay(self, param0: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def UpdateOverlayZOrder(self, param0: UInt32, param1: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirectDrawSurface2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{57805885-6eec-11cf-9441-a82303c10e27}')
    @commethod(3)
    def AddAttachedSurface(self, param0: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def AddOverlayDirtyRect(self, param0: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Blt(self, param0: POINTER(win32more.Windows.Win32.Foundation.RECT), param1: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface2, param2: POINTER(win32more.Windows.Win32.Foundation.RECT), param3: UInt32, param4: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDBLTFX)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def BltBatch(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDBLTBATCH), param1: UInt32, param2: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def BltFast(self, param0: UInt32, param1: UInt32, param2: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface2, param3: POINTER(win32more.Windows.Win32.Foundation.RECT), param4: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def DeleteAttachedSurface(self, param0: UInt32, param1: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def EnumAttachedSurfaces(self, param0: VoidPtr, param1: win32more.Windows.Win32.Graphics.DirectDraw.LPDDENUMSURFACESCALLBACK) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def EnumOverlayZOrders(self, param0: UInt32, param1: VoidPtr, param2: win32more.Windows.Win32.Graphics.DirectDraw.LPDDENUMSURFACESCALLBACK) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def Flip(self, param0: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface2, param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetAttachedSurface(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPS), param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetBltStatus(self, param0: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetCaps(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetClipper(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawClipper)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetColorKey(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORKEY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetDC(self, param0: POINTER(win32more.Windows.Win32.Graphics.Gdi.HDC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetFlipStatus(self, param0: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def GetOverlayPosition(self, param0: POINTER(Int32), param1: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def GetPalette(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawPalette)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def GetPixelFormat(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def GetSurfaceDesc(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def Initialize(self, param0: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDraw, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def IsLost(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def Lock(self, param0: POINTER(win32more.Windows.Win32.Foundation.RECT), param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC), param2: UInt32, param3: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def ReleaseDC(self, param0: win32more.Windows.Win32.Graphics.Gdi.HDC) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def Restore(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def SetClipper(self, param0: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawClipper) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def SetColorKey(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORKEY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def SetOverlayPosition(self, param0: Int32, param1: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def SetPalette(self, param0: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawPalette) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def Unlock(self, param0: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def UpdateOverlay(self, param0: POINTER(win32more.Windows.Win32.Foundation.RECT), param1: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface2, param2: POINTER(win32more.Windows.Win32.Foundation.RECT), param3: UInt32, param4: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDOVERLAYFX)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def UpdateOverlayDisplay(self, param0: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def UpdateOverlayZOrder(self, param0: UInt32, param1: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def GetDDInterface(self, param0: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def PageLock(self, param0: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def PageUnlock(self, param0: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirectDrawSurface3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{da044e00-69b2-11d0-a1d5-00aa00b8dfbb}')
    @commethod(3)
    def AddAttachedSurface(self, param0: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface3) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def AddOverlayDirtyRect(self, param0: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Blt(self, param0: POINTER(win32more.Windows.Win32.Foundation.RECT), param1: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface3, param2: POINTER(win32more.Windows.Win32.Foundation.RECT), param3: UInt32, param4: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDBLTFX)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def BltBatch(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDBLTBATCH), param1: UInt32, param2: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def BltFast(self, param0: UInt32, param1: UInt32, param2: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface3, param3: POINTER(win32more.Windows.Win32.Foundation.RECT), param4: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def DeleteAttachedSurface(self, param0: UInt32, param1: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface3) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def EnumAttachedSurfaces(self, param0: VoidPtr, param1: win32more.Windows.Win32.Graphics.DirectDraw.LPDDENUMSURFACESCALLBACK) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def EnumOverlayZOrders(self, param0: UInt32, param1: VoidPtr, param2: win32more.Windows.Win32.Graphics.DirectDraw.LPDDENUMSURFACESCALLBACK) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def Flip(self, param0: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface3, param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetAttachedSurface(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPS), param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface3)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetBltStatus(self, param0: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetCaps(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetClipper(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawClipper)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetColorKey(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORKEY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetDC(self, param0: POINTER(win32more.Windows.Win32.Graphics.Gdi.HDC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetFlipStatus(self, param0: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def GetOverlayPosition(self, param0: POINTER(Int32), param1: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def GetPalette(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawPalette)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def GetPixelFormat(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def GetSurfaceDesc(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def Initialize(self, param0: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDraw, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def IsLost(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def Lock(self, param0: POINTER(win32more.Windows.Win32.Foundation.RECT), param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC), param2: UInt32, param3: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def ReleaseDC(self, param0: win32more.Windows.Win32.Graphics.Gdi.HDC) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def Restore(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def SetClipper(self, param0: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawClipper) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def SetColorKey(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORKEY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def SetOverlayPosition(self, param0: Int32, param1: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def SetPalette(self, param0: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawPalette) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def Unlock(self, param0: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def UpdateOverlay(self, param0: POINTER(win32more.Windows.Win32.Foundation.RECT), param1: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface3, param2: POINTER(win32more.Windows.Win32.Foundation.RECT), param3: UInt32, param4: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDOVERLAYFX)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def UpdateOverlayDisplay(self, param0: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def UpdateOverlayZOrder(self, param0: UInt32, param1: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface3) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def GetDDInterface(self, param0: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def PageLock(self, param0: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def PageUnlock(self, param0: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def SetSurfaceDesc(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC), param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirectDrawSurface4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0b2b8630-ad35-11d0-8ea6-00609797ea5b}')
    @commethod(3)
    def AddAttachedSurface(self, param0: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface4) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def AddOverlayDirtyRect(self, param0: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Blt(self, param0: POINTER(win32more.Windows.Win32.Foundation.RECT), param1: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface4, param2: POINTER(win32more.Windows.Win32.Foundation.RECT), param3: UInt32, param4: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDBLTFX)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def BltBatch(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDBLTBATCH), param1: UInt32, param2: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def BltFast(self, param0: UInt32, param1: UInt32, param2: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface4, param3: POINTER(win32more.Windows.Win32.Foundation.RECT), param4: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def DeleteAttachedSurface(self, param0: UInt32, param1: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface4) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def EnumAttachedSurfaces(self, param0: VoidPtr, param1: win32more.Windows.Win32.Graphics.DirectDraw.LPDDENUMSURFACESCALLBACK2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def EnumOverlayZOrders(self, param0: UInt32, param1: VoidPtr, param2: win32more.Windows.Win32.Graphics.DirectDraw.LPDDENUMSURFACESCALLBACK2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def Flip(self, param0: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface4, param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetAttachedSurface(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPS2), param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface4)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetBltStatus(self, param0: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetCaps(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPS2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetClipper(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawClipper)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetColorKey(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORKEY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetDC(self, param0: POINTER(win32more.Windows.Win32.Graphics.Gdi.HDC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetFlipStatus(self, param0: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def GetOverlayPosition(self, param0: POINTER(Int32), param1: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def GetPalette(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawPalette)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def GetPixelFormat(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def GetSurfaceDesc(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def Initialize(self, param0: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDraw, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def IsLost(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def Lock(self, param0: POINTER(win32more.Windows.Win32.Foundation.RECT), param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC2), param2: UInt32, param3: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def ReleaseDC(self, param0: win32more.Windows.Win32.Graphics.Gdi.HDC) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def Restore(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def SetClipper(self, param0: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawClipper) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def SetColorKey(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORKEY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def SetOverlayPosition(self, param0: Int32, param1: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def SetPalette(self, param0: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawPalette) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def Unlock(self, param0: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def UpdateOverlay(self, param0: POINTER(win32more.Windows.Win32.Foundation.RECT), param1: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface4, param2: POINTER(win32more.Windows.Win32.Foundation.RECT), param3: UInt32, param4: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDOVERLAYFX)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def UpdateOverlayDisplay(self, param0: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def UpdateOverlayZOrder(self, param0: UInt32, param1: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface4) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def GetDDInterface(self, param0: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def PageLock(self, param0: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def PageUnlock(self, param0: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def SetSurfaceDesc(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC2), param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def SetPrivateData(self, param0: POINTER(Guid), param1: VoidPtr, param2: UInt32, param3: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def GetPrivateData(self, param0: POINTER(Guid), param1: VoidPtr, param2: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def FreePrivateData(self, param0: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def GetUniquenessValue(self, param0: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def ChangeUniquenessValue(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirectDrawSurface7(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{06675a80-3b9b-11d2-b92f-00609797ea5b}')
    @commethod(3)
    def AddAttachedSurface(self, param0: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface7) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def AddOverlayDirtyRect(self, param0: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Blt(self, param0: POINTER(win32more.Windows.Win32.Foundation.RECT), param1: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface7, param2: POINTER(win32more.Windows.Win32.Foundation.RECT), param3: UInt32, param4: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDBLTFX)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def BltBatch(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDBLTBATCH), param1: UInt32, param2: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def BltFast(self, param0: UInt32, param1: UInt32, param2: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface7, param3: POINTER(win32more.Windows.Win32.Foundation.RECT), param4: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def DeleteAttachedSurface(self, param0: UInt32, param1: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface7) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def EnumAttachedSurfaces(self, param0: VoidPtr, param1: win32more.Windows.Win32.Graphics.DirectDraw.LPDDENUMSURFACESCALLBACK7) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def EnumOverlayZOrders(self, param0: UInt32, param1: VoidPtr, param2: win32more.Windows.Win32.Graphics.DirectDraw.LPDDENUMSURFACESCALLBACK7) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def Flip(self, param0: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface7, param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetAttachedSurface(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPS2), param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface7)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetBltStatus(self, param0: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetCaps(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPS2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetClipper(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawClipper)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetColorKey(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORKEY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetDC(self, param0: POINTER(win32more.Windows.Win32.Graphics.Gdi.HDC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetFlipStatus(self, param0: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def GetOverlayPosition(self, param0: POINTER(Int32), param1: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def GetPalette(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawPalette)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def GetPixelFormat(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def GetSurfaceDesc(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def Initialize(self, param0: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDraw, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def IsLost(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def Lock(self, param0: POINTER(win32more.Windows.Win32.Foundation.RECT), param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC2), param2: UInt32, param3: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def ReleaseDC(self, param0: win32more.Windows.Win32.Graphics.Gdi.HDC) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def Restore(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def SetClipper(self, param0: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawClipper) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def SetColorKey(self, param0: UInt32, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORKEY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def SetOverlayPosition(self, param0: Int32, param1: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def SetPalette(self, param0: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawPalette) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def Unlock(self, param0: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def UpdateOverlay(self, param0: POINTER(win32more.Windows.Win32.Foundation.RECT), param1: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface7, param2: POINTER(win32more.Windows.Win32.Foundation.RECT), param3: UInt32, param4: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDOVERLAYFX)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def UpdateOverlayDisplay(self, param0: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def UpdateOverlayZOrder(self, param0: UInt32, param1: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface7) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def GetDDInterface(self, param0: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def PageLock(self, param0: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def PageUnlock(self, param0: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def SetSurfaceDesc(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC2), param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def SetPrivateData(self, param0: POINTER(Guid), param1: VoidPtr, param2: UInt32, param3: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def GetPrivateData(self, param0: POINTER(Guid), param1: VoidPtr, param2: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def FreePrivateData(self, param0: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def GetUniquenessValue(self, param0: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def ChangeUniquenessValue(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def SetPriority(self, param0: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def GetPriority(self, param0: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def SetLOD(self, param0: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def GetLOD(self, param0: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirectDrawSurfaceKernel(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{60755da0-6a40-11d0-9b06-00a0c903a3b8}')
    @commethod(3)
    def GetKernelHandle(self, param0: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def ReleaseKernelHandle(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirectDrawVideoPort(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{b36d93e0-2b43-11cf-a2de-00aa00b93356}')
    @commethod(3)
    def Flip(self, param0: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface, param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetBandwidthInfo(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT), param1: UInt32, param2: UInt32, param3: UInt32, param4: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDVIDEOPORTBANDWIDTH)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetColorControls(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORCONTROL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetInputFormats(self, lpNumFormats: POINTER(UInt32), param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT), param2: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetOutputFormats(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT), lpNumFormats: POINTER(UInt32), param2: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT), param3: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetFieldPolarity(self, param0: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetVideoLine(self, param0: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetVideoSignalStatus(self, param0: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SetColorControls(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDCOLORCONTROL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def SetTargetSurface(self, param0: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface, param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def StartVideo(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDVIDEOPORTINFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def StopVideo(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def UpdateVideo(self, param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDVIDEOPORTINFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def WaitForSync(self, param0: UInt32, param1: UInt32, param2: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirectDrawVideoPortNotify(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a655fb94-0589-4e57-b333-567a89468c88}')
    @commethod(3)
    def AcquireNotification(self, param0: POINTER(win32more.Windows.Win32.Foundation.HANDLE), param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDVIDEOPORTNOTIFY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def ReleaseNotification(self, param0: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUNKNOWN_LIST(Structure):
    lpLink: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.IUNKNOWN_LIST)
    lpGuid: POINTER(Guid)
    lpIUnknown: win32more.Windows.Win32.System.Com.IUnknown
@winfunctype_pointer
def LPCLIPPERCALLBACK(lpDDClipper: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawClipper, hWnd: win32more.Windows.Win32.Foundation.HWND, code: UInt32, lpContext: VoidPtr) -> UInt32: ...
@winfunctype_pointer
def LPDD32BITDRIVERINIT(dwContext: UInt32) -> UInt32: ...
@winfunctype_pointer
def LPDDENUMCALLBACKA(param0: POINTER(Guid), param1: win32more.Windows.Win32.Foundation.PSTR, param2: win32more.Windows.Win32.Foundation.PSTR, param3: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def LPDDENUMCALLBACKEXA(param0: POINTER(Guid), param1: win32more.Windows.Win32.Foundation.PSTR, param2: win32more.Windows.Win32.Foundation.PSTR, param3: VoidPtr, param4: win32more.Windows.Win32.Graphics.Gdi.HMONITOR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def LPDDENUMCALLBACKEXW(param0: POINTER(Guid), param1: win32more.Windows.Win32.Foundation.PWSTR, param2: win32more.Windows.Win32.Foundation.PWSTR, param3: VoidPtr, param4: win32more.Windows.Win32.Graphics.Gdi.HMONITOR) -> win32more.Windows.Win32.Foundation.BOOL: ...
LPDDENUMCALLBACKEX = UnicodeAlias('LPDDENUMCALLBACKEXW')
@winfunctype_pointer
def LPDDENUMCALLBACKW(param0: POINTER(Guid), param1: win32more.Windows.Win32.Foundation.PWSTR, param2: win32more.Windows.Win32.Foundation.PWSTR, param3: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
LPDDENUMCALLBACK = UnicodeAlias('LPDDENUMCALLBACKW')
@winfunctype_pointer
def LPDDENUMMODESCALLBACK(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC), param1: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def LPDDENUMMODESCALLBACK2(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC2), param1: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def LPDDENUMSURFACESCALLBACK(param0: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC), param2: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def LPDDENUMSURFACESCALLBACK2(param0: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface4, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC2), param2: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def LPDDENUMSURFACESCALLBACK7(param0: win32more.Windows.Win32.Graphics.DirectDraw.IDirectDrawSurface7, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC2), param2: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def LPDDENUMVIDEOCALLBACK(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDVIDEOPORTCAPS), param1: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
LPDDFXROP = IntPtr
@winfunctype_pointer
def LPDDGAMMACALIBRATORPROC(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDGAMMARAMP), param1: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def LPDDHALCOLORCB_COLORCONTROL(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_COLORCONTROLDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALEXEBUFCB_CANCREATEEXEBUF(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_CANCREATESURFACEDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALEXEBUFCB_CREATEEXEBUF(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_CREATESURFACEDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALEXEBUFCB_DESTROYEXEBUF(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_DESTROYSURFACEDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALEXEBUFCB_LOCKEXEBUF(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_LOCKDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALEXEBUFCB_UNLOCKEXEBUF(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_UNLOCKDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALKERNELCB_SYNCSURFACE(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_SYNCSURFACEDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALKERNELCB_SYNCVIDEOPORT(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_SYNCVIDEOPORTDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALMOCOMPCB_BEGINFRAME(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_BEGINMOCOMPFRAMEDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALMOCOMPCB_CREATE(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_CREATEMOCOMPDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALMOCOMPCB_DESTROY(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_DESTROYMOCOMPDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALMOCOMPCB_ENDFRAME(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_ENDMOCOMPFRAMEDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALMOCOMPCB_GETCOMPBUFFINFO(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_GETMOCOMPCOMPBUFFDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALMOCOMPCB_GETFORMATS(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_GETMOCOMPFORMATSDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALMOCOMPCB_GETGUIDS(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_GETMOCOMPGUIDSDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALMOCOMPCB_GETINTERNALINFO(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_GETINTERNALMOCOMPDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALMOCOMPCB_QUERYSTATUS(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_QUERYMOCOMPSTATUSDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALMOCOMPCB_RENDER(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_RENDERMOCOMPDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALPALCB_DESTROYPALETTE(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_DESTROYPALETTEDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALPALCB_SETENTRIES(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_SETENTRIESDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALSURFCB_ADDATTACHEDSURFACE(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_ADDATTACHEDSURFACEDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALSURFCB_BLT(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_BLTDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALSURFCB_DESTROYSURFACE(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_DESTROYSURFACEDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALSURFCB_FLIP(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_FLIPDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALSURFCB_GETBLTSTATUS(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_GETBLTSTATUSDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALSURFCB_GETFLIPSTATUS(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_GETFLIPSTATUSDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALSURFCB_LOCK(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_LOCKDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALSURFCB_SETCLIPLIST(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_SETCLIPLISTDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALSURFCB_SETCOLORKEY(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_SETCOLORKEYDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALSURFCB_SETOVERLAYPOSITION(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_SETOVERLAYPOSITIONDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALSURFCB_SETPALETTE(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_SETPALETTEDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALSURFCB_UNLOCK(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_UNLOCKDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALSURFCB_UPDATEOVERLAY(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_UPDATEOVERLAYDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALVPORTCB_CANCREATEVIDEOPORT(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_CANCREATEVPORTDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALVPORTCB_COLORCONTROL(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_VPORTCOLORDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALVPORTCB_CREATEVIDEOPORT(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_CREATEVPORTDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALVPORTCB_DESTROYVPORT(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_DESTROYVPORTDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALVPORTCB_FLIP(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_FLIPVPORTDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALVPORTCB_GETBANDWIDTH(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_GETVPORTBANDWIDTHDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALVPORTCB_GETFIELD(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_GETVPORTFIELDDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALVPORTCB_GETFLIPSTATUS(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_GETVPORTFLIPSTATUSDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALVPORTCB_GETINPUTFORMATS(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_GETVPORTINPUTFORMATDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALVPORTCB_GETLINE(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_GETVPORTLINEDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALVPORTCB_GETOUTPUTFORMATS(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_GETVPORTOUTPUTFORMATDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALVPORTCB_GETSIGNALSTATUS(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_GETVPORTSIGNALDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALVPORTCB_GETVPORTCONNECT(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_GETVPORTCONNECTDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALVPORTCB_UPDATE(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_UPDATEVPORTDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHALVPORTCB_WAITFORSYNC(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_WAITFORVPORTSYNCDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHAL_CANCREATESURFACE(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_CANCREATESURFACEDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHAL_CREATEPALETTE(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_CREATEPALETTEDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHAL_CREATESURFACE(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_CREATESURFACEDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHAL_CREATESURFACEEX(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_CREATESURFACEEXDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHAL_DESTROYDDLOCAL(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_DESTROYDDLOCALDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHAL_DESTROYDRIVER(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_DESTROYDRIVERDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHAL_FLIPTOGDISURFACE(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_FLIPTOGDISURFACEDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHAL_GETAVAILDRIVERMEMORY(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_GETAVAILDRIVERMEMORYDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHAL_GETDRIVERINFO(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_GETDRIVERINFODATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHAL_GETDRIVERSTATE(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_GETDRIVERSTATEDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHAL_GETHEAPALIGNMENT(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_GETHEAPALIGNMENTDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHAL_GETSCANLINE(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_GETSCANLINEDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHAL_SETCOLORKEY(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_DRVSETCOLORKEYDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHAL_SETEXCLUSIVEMODE(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_SETEXCLUSIVEMODEDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHAL_SETINFO(lpDDHalInfo: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHALINFO), reset: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def LPDDHAL_SETMODE(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_SETMODEDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHAL_UPDATENONLOCALHEAP(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_UPDATENONLOCALHEAPDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHAL_VIDMEMALLOC(lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_GBL), heap: Int32, dwWidth: UInt32, dwHeight: UInt32) -> UIntPtr: ...
@winfunctype_pointer
def LPDDHAL_VIDMEMFREE(lpDD: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_GBL), heap: Int32, fpMem: UIntPtr) -> Void: ...
@winfunctype_pointer
def LPDDHAL_WAITFORVERTICALBLANK(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDHAL_WAITFORVERTICALBLANKDATA)) -> UInt32: ...
@winfunctype_pointer
def LPDDHEL_INIT(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDRAWI_DIRECTDRAW_GBL), param1: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def LPDIRECTDRAWENUMERATEEXA(lpCallback: win32more.Windows.Win32.Graphics.DirectDraw.LPDDENUMCALLBACKEXA, lpContext: VoidPtr, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def LPDIRECTDRAWENUMERATEEXW(lpCallback: win32more.Windows.Win32.Graphics.DirectDraw.LPDDENUMCALLBACKEXW, lpContext: VoidPtr, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
LPDIRECTDRAWENUMERATEEX = UnicodeAlias('LPDIRECTDRAWENUMERATEEXW')
@winfunctype_pointer
def PDD_ALPHABLT(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_BLTDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_CANCREATESURFACE(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_CANCREATESURFACEDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_COLORCB_COLORCONTROL(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_COLORCONTROLDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_CREATEPALETTE(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_CREATEPALETTEDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_CREATESURFACE(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_CREATESURFACEDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_CREATESURFACEEX(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_CREATESURFACEEXDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_DESTROYDDLOCAL(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DESTROYDDLOCALDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_DESTROYDRIVER(param0: win32more.Windows.Win32.Graphics.DirectDraw.PDD_DESTROYDRIVERDATA) -> UInt32: ...
PDD_DESTROYDRIVERDATA = IntPtr
@winfunctype_pointer
def PDD_FLIPTOGDISURFACE(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_FLIPTOGDISURFACEDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_FREEDRIVERMEMORY(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_FREEDRIVERMEMORYDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_GETAVAILDRIVERMEMORY(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_GETAVAILDRIVERMEMORYDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_GETDRIVERINFO(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_GETDRIVERINFODATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_GETDRIVERSTATE(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_GETDRIVERSTATEDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_GETSCANLINE(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_GETSCANLINEDATA)) -> UInt32: ...
PDD_GETVPORTAUTOFLIPSURFACEDATA = IntPtr
@winfunctype_pointer
def PDD_KERNELCB_SYNCSURFACE(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SYNCSURFACEDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_KERNELCB_SYNCVIDEOPORT(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SYNCVIDEOPORTDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_MAPMEMORY(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_MAPMEMORYDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_MOCOMPCB_BEGINFRAME(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_BEGINMOCOMPFRAMEDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_MOCOMPCB_CREATE(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_CREATEMOCOMPDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_MOCOMPCB_DESTROY(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DESTROYMOCOMPDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_MOCOMPCB_ENDFRAME(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_ENDMOCOMPFRAMEDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_MOCOMPCB_GETCOMPBUFFINFO(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_GETMOCOMPCOMPBUFFDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_MOCOMPCB_GETFORMATS(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_GETMOCOMPFORMATSDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_MOCOMPCB_GETGUIDS(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_GETMOCOMPGUIDSDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_MOCOMPCB_GETINTERNALINFO(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_GETINTERNALMOCOMPDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_MOCOMPCB_QUERYSTATUS(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_QUERYMOCOMPSTATUSDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_MOCOMPCB_RENDER(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_RENDERMOCOMPDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_PALCB_DESTROYPALETTE(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DESTROYPALETTEDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_PALCB_SETENTRIES(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SETENTRIESDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_SETCOLORKEY(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DRVSETCOLORKEYDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_SETEXCLUSIVEMODE(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SETEXCLUSIVEMODEDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_SETMODE(param0: win32more.Windows.Win32.Graphics.DirectDraw.PDD_SETMODEDATA) -> UInt32: ...
PDD_SETMODEDATA = IntPtr
@winfunctype_pointer
def PDD_SURFCB_ADDATTACHEDSURFACE(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_ADDATTACHEDSURFACEDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_SURFCB_BLT(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_BLTDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_SURFCB_DESTROYSURFACE(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DESTROYSURFACEDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_SURFCB_FLIP(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_FLIPDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_SURFCB_GETBLTSTATUS(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_GETBLTSTATUSDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_SURFCB_GETFLIPSTATUS(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_GETFLIPSTATUSDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_SURFCB_LOCK(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_LOCKDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_SURFCB_SETCLIPLIST(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SETCLIPLISTDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_SURFCB_SETCOLORKEY(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SETCOLORKEYDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_SURFCB_SETOVERLAYPOSITION(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SETOVERLAYPOSITIONDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_SURFCB_SETPALETTE(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_SETPALETTEDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_SURFCB_UNLOCK(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_UNLOCKDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_SURFCB_UPDATEOVERLAY(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_UPDATEOVERLAYDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_VPORTCB_CANCREATEVIDEOPORT(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_CANCREATEVPORTDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_VPORTCB_COLORCONTROL(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_VPORTCOLORDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_VPORTCB_CREATEVIDEOPORT(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_CREATEVPORTDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_VPORTCB_DESTROYVPORT(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_DESTROYVPORTDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_VPORTCB_FLIP(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_FLIPVPORTDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_VPORTCB_GETAUTOFLIPSURF(param0: win32more.Windows.Win32.Graphics.DirectDraw.PDD_GETVPORTAUTOFLIPSURFACEDATA) -> UInt32: ...
@winfunctype_pointer
def PDD_VPORTCB_GETBANDWIDTH(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_GETVPORTBANDWIDTHDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_VPORTCB_GETFIELD(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_GETVPORTFIELDDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_VPORTCB_GETFLIPSTATUS(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_GETVPORTFLIPSTATUSDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_VPORTCB_GETINPUTFORMATS(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_GETVPORTINPUTFORMATDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_VPORTCB_GETLINE(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_GETVPORTLINEDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_VPORTCB_GETOUTPUTFORMATS(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_GETVPORTOUTPUTFORMATDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_VPORTCB_GETSIGNALSTATUS(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_GETVPORTSIGNALDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_VPORTCB_GETVPORTCONNECT(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_GETVPORTCONNECTDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_VPORTCB_UPDATE(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_UPDATEVPORTDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_VPORTCB_WAITFORSYNC(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_WAITFORVPORTSYNCDATA)) -> UInt32: ...
@winfunctype_pointer
def PDD_WAITFORVERTICALBLANK(param0: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DD_WAITFORVERTICALBLANKDATA)) -> UInt32: ...
@winfunctype_pointer
def PDX_BOBNEXTFIELD(param0: VoidPtr, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDBOBNEXTFIELDINFO), param2: VoidPtr) -> UInt32: ...
@winfunctype_pointer
def PDX_ENABLEIRQ(param0: VoidPtr, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDENABLEIRQINFO), param2: VoidPtr) -> UInt32: ...
@winfunctype_pointer
def PDX_FLIPOVERLAY(param0: VoidPtr, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDFLIPOVERLAYINFO), param2: VoidPtr) -> UInt32: ...
@winfunctype_pointer
def PDX_FLIPVIDEOPORT(param0: VoidPtr, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDFLIPVIDEOPORTINFO), param2: VoidPtr) -> UInt32: ...
@winfunctype_pointer
def PDX_GETCURRENTAUTOFLIP(param0: VoidPtr, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDGETCURRENTAUTOFLIPININFO), param2: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDGETCURRENTAUTOFLIPOUTINFO)) -> UInt32: ...
@winfunctype_pointer
def PDX_GETIRQINFO(param0: VoidPtr, param1: VoidPtr, param2: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDGETIRQINFO)) -> UInt32: ...
@winfunctype_pointer
def PDX_GETPOLARITY(param0: VoidPtr, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDGETPOLARITYININFO), param2: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDGETPOLARITYOUTINFO)) -> UInt32: ...
@winfunctype_pointer
def PDX_GETPREVIOUSAUTOFLIP(param0: VoidPtr, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDGETPREVIOUSAUTOFLIPININFO), param2: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDGETPREVIOUSAUTOFLIPOUTINFO)) -> UInt32: ...
@winfunctype_pointer
def PDX_GETTRANSFERSTATUS(param0: VoidPtr, param1: VoidPtr, param2: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDGETTRANSFERSTATUSOUTINFO)) -> UInt32: ...
@winfunctype_pointer
def PDX_IRQCALLBACK(pIrqData: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DX_IRQDATA)) -> Void: ...
@winfunctype_pointer
def PDX_LOCK(param0: VoidPtr, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDLOCKININFO), param2: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDLOCKOUTINFO)) -> UInt32: ...
@winfunctype_pointer
def PDX_SETSTATE(param0: VoidPtr, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSETSTATEININFO), param2: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSETSTATEOUTINFO)) -> UInt32: ...
@winfunctype_pointer
def PDX_SKIPNEXTFIELD(param0: VoidPtr, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSKIPNEXTFIELDINFO), param2: VoidPtr) -> UInt32: ...
@winfunctype_pointer
def PDX_TRANSFER(param0: VoidPtr, param1: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDTRANSFERININFO), param2: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDTRANSFEROUTINFO)) -> UInt32: ...
class PROCESS_LIST(Structure):
    lpLink: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.PROCESS_LIST)
    dwProcessId: UInt32
    dwRefCnt: UInt32
    dwAlphaDepth: UInt32
    dwZDepth: UInt32
class SURFACEALIGNMENT(Structure):
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Linear: _Linear_e__Struct
        Rectangular: _Rectangular_e__Struct
        class _Linear_e__Struct(Structure):
            dwStartAlignment: UInt32
            dwPitchAlignment: UInt32
            dwFlags: UInt32
            dwReserved2: UInt32
        class _Rectangular_e__Struct(Structure):
            dwXAlignment: UInt32
            dwYAlignment: UInt32
            dwFlags: UInt32
            dwReserved2: UInt32
class VIDEOMEMORY(Structure):
    dwFlags: UInt32
    fpStart: UIntPtr
    Anonymous1: _Anonymous1_e__Union
    ddsCaps: win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPS
    ddsCapsAlt: win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPS
    Anonymous2: _Anonymous2_e__Union
    class _Anonymous1_e__Union(Union):
        fpEnd: UIntPtr
        dwWidth: UInt32
    class _Anonymous2_e__Union(Union):
        lpHeap: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.VMEMHEAP)
        dwHeight: UInt32
class VIDEOMEMORYINFO(Structure):
    fpPrimary: UIntPtr
    dwFlags: UInt32
    dwDisplayWidth: UInt32
    dwDisplayHeight: UInt32
    lDisplayPitch: Int32
    ddpfDisplay: win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT
    dwOffscreenAlign: UInt32
    dwOverlayAlign: UInt32
    dwTextureAlign: UInt32
    dwZBufferAlign: UInt32
    dwAlphaAlign: UInt32
    pvPrimary: VoidPtr
class VIDMEM(Structure):
    dwFlags: UInt32
    fpStart: UIntPtr
    Anonymous1: _Anonymous1_e__Union
    ddsCaps: win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPS
    ddsCapsAlt: win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPS
    Anonymous2: _Anonymous2_e__Union
    class _Anonymous1_e__Union(Union):
        fpEnd: UIntPtr
        dwWidth: UInt32
    class _Anonymous2_e__Union(Union):
        lpHeap: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.VMEMHEAP)
        dwHeight: UInt32
class VIDMEMINFO(Structure):
    fpPrimary: UIntPtr
    dwFlags: UInt32
    dwDisplayWidth: UInt32
    dwDisplayHeight: UInt32
    lDisplayPitch: Int32
    ddpfDisplay: win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT
    dwOffscreenAlign: UInt32
    dwOverlayAlign: UInt32
    dwTextureAlign: UInt32
    dwZBufferAlign: UInt32
    dwAlphaAlign: UInt32
    dwNumHeaps: UInt32
    pvmList: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.VIDMEM)
class VMEMHEAP(Structure):
    dwFlags: UInt32
    stride: UInt32
    freeList: VoidPtr
    allocList: VoidPtr
    dwTotalSize: UInt32
    fpGARTLin: UIntPtr
    fpGARTDev: UIntPtr
    dwCommitedSize: UInt32
    dwCoalesceCount: UInt32
    Alignment: win32more.Windows.Win32.Graphics.DirectDraw.HEAPALIGNMENT
    ddsCapsEx: win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPSEX
    ddsCapsExAlt: win32more.Windows.Win32.Graphics.DirectDraw.DDSCAPSEX
    liPhysAGPBase: Int64
    hdevAGP: win32more.Windows.Win32.Foundation.HANDLE
    pvPhysRsrv: VoidPtr
    pAgpCommitMask: POINTER(Byte)
    dwAgpCommitMaskSize: UInt32
class VMEML(Structure):
    next: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.VMEML)
    ptr: UIntPtr
    size: UInt32
    bDiscardable: win32more.Windows.Win32.Foundation.BOOL
class VMEMR(Structure):
    next: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.VMEMR)
    prev: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.VMEMR)
    pUp: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.VMEMR)
    pDown: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.VMEMR)
    pLeft: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.VMEMR)
    pRight: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.VMEMR)
    ptr: UIntPtr
    size: UInt32
    x: UInt32
    y: UInt32
    cx: UInt32
    cy: UInt32
    flags: UInt32
    pBits: UIntPtr
    bDiscardable: win32more.Windows.Win32.Foundation.BOOL


make_ready(__name__)
