from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Graphics.Gdi
import win32more.Windows.Win32.Media
import win32more.Windows.Win32.Media.Audio
import win32more.Windows.Win32.Media.Multimedia
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.IO
import win32more.Windows.Win32.UI.Controls
import win32more.Windows.Win32.UI.Controls.Dialogs
class ADPCMCOEFSET(Structure):
    iCoef1: Int16
    iCoef2: Int16
    _pack_ = 1
class ADPCMEWAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    wSamplesPerBlock: UInt16
    _pack_ = 1
class ADPCMWAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    wSamplesPerBlock: UInt16
    wNumCoef: UInt16
    aCoef: win32more.Windows.Win32.Media.Multimedia.ADPCMCOEFSET * 1
    _pack_ = 1
class APTXWAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    _pack_ = 1
class AUDIOFILE_AF10WAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    _pack_ = 1
class AUDIOFILE_AF36WAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    _pack_ = 1
class AVICOMPRESSOPTIONS(Structure):
    fccType: UInt32
    fccHandler: UInt32
    dwKeyFrameEvery: UInt32
    dwQuality: UInt32
    dwBytesPerSecond: UInt32
    dwFlags: UInt32
    lpFormat: VoidPtr
    cbFormat: UInt32
    lpParms: VoidPtr
    cbParms: UInt32
    dwInterleaveEvery: UInt32
class AVIFILEINFOA(Structure):
    dwMaxBytesPerSec: UInt32
    dwFlags: UInt32
    dwCaps: UInt32
    dwStreams: UInt32
    dwSuggestedBufferSize: UInt32
    dwWidth: UInt32
    dwHeight: UInt32
    dwScale: UInt32
    dwRate: UInt32
    dwLength: UInt32
    dwEditCount: UInt32
    szFileType: win32more.Windows.Win32.Foundation.CHAR * 64
class AVIFILEINFOW(Structure):
    dwMaxBytesPerSec: UInt32
    dwFlags: UInt32
    dwCaps: UInt32
    dwStreams: UInt32
    dwSuggestedBufferSize: UInt32
    dwWidth: UInt32
    dwHeight: UInt32
    dwScale: UInt32
    dwRate: UInt32
    dwLength: UInt32
    dwEditCount: UInt32
    szFileType: Char * 64
AVIFILEINFO = UnicodeAlias('AVIFILEINFOW')
@winfunctype_pointer
def AVISAVECALLBACK(param0: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
class AVISTREAMINFOA(Structure):
    fccType: UInt32
    fccHandler: UInt32
    dwFlags: UInt32
    dwCaps: UInt32
    wPriority: UInt16
    wLanguage: UInt16
    dwScale: UInt32
    dwRate: UInt32
    dwStart: UInt32
    dwLength: UInt32
    dwInitialFrames: UInt32
    dwSuggestedBufferSize: UInt32
    dwQuality: UInt32
    dwSampleSize: UInt32
    rcFrame: win32more.Windows.Win32.Foundation.RECT
    dwEditCount: UInt32
    dwFormatChangeCount: UInt32
    szName: win32more.Windows.Win32.Foundation.CHAR * 64
class AVISTREAMINFOW(Structure):
    fccType: UInt32
    fccHandler: UInt32
    dwFlags: UInt32
    dwCaps: UInt32
    wPriority: UInt16
    wLanguage: UInt16
    dwScale: UInt32
    dwRate: UInt32
    dwStart: UInt32
    dwLength: UInt32
    dwInitialFrames: UInt32
    dwSuggestedBufferSize: UInt32
    dwQuality: UInt32
    dwSampleSize: UInt32
    rcFrame: win32more.Windows.Win32.Foundation.RECT
    dwEditCount: UInt32
    dwFormatChangeCount: UInt32
    szName: Char * 64
AVISTREAMINFO = UnicodeAlias('AVISTREAMINFOW')
WM_CAP_START: UInt32 = 1024
MODM_USER: UInt32 = 16384
MIDM_USER: UInt32 = 16384
MODM_MAPPER: UInt32 = 8192
MIDM_MAPPER: UInt32 = 8192
MODM_INIT: UInt32 = 100
MIDM_INIT: UInt32 = 100
MODM_INIT_EX: UInt32 = 104
MIDM_INIT_EX: UInt32 = 104
DRV_MCI_FIRST: UInt32 = 2048
ACMDM_BASE: UInt32 = 24576
ICM_RESERVED: UInt32 = 20480
MCI_TEST: Int32 = 32
MCI_CAPTURE: UInt32 = 2160
MCI_MONITOR: UInt32 = 2161
MCI_RESERVE: UInt32 = 2162
MCI_SETAUDIO: UInt32 = 2163
MCI_SIGNAL: UInt32 = 2165
MCI_SETVIDEO: UInt32 = 2166
MCI_QUALITY: UInt32 = 2167
MCI_LIST: UInt32 = 2168
MCI_UNDO: UInt32 = 2169
MCI_CONFIGURE: UInt32 = 2170
MCI_RESTORE: UInt32 = 2171
MCI_ON: UInt32 = 1
MCI_OFF: UInt32 = 0
MCI_DGV_FILE_MODE_SAVING: UInt32 = 1
MCI_DGV_FILE_MODE_LOADING: UInt32 = 2
MCI_DGV_FILE_MODE_EDITING: UInt32 = 3
MCI_DGV_FILE_MODE_IDLE: UInt32 = 4
MCI_ON_S: Int32 = 32768
MCI_OFF_S: Int32 = 32769
MCI_DGV_FILE_S: Int32 = 32770
MCI_DGV_INPUT_S: Int32 = 32771
MCI_DGV_FILE_MODE_SAVING_S: Int32 = 32772
MCI_DGV_FILE_MODE_LOADING_S: Int32 = 32773
MCI_DGV_FILE_MODE_EDITING_S: Int32 = 32774
MCI_DGV_FILE_MODE_IDLE_S: Int32 = 32775
MCI_DGV_SETVIDEO_SRC_NTSC_S: Int32 = 32784
MCI_DGV_SETVIDEO_SRC_RGB_S: Int32 = 32785
MCI_DGV_SETVIDEO_SRC_SVIDEO_S: Int32 = 32786
MCI_DGV_SETVIDEO_SRC_PAL_S: Int32 = 32787
MCI_DGV_SETVIDEO_SRC_SECAM_S: Int32 = 32788
MCI_DGV_SETVIDEO_SRC_GENERIC_S: Int32 = 32789
MCI_DGV_SETAUDIO_SRC_LEFT_S: Int32 = 32800
MCI_DGV_SETAUDIO_SRC_RIGHT_S: Int32 = 32801
MCI_DGV_SETAUDIO_SRC_AVERAGE_S: Int32 = 32802
MCI_DGV_SETAUDIO_SRC_STEREO_S: Int32 = 32803
MCIERR_DGV_DEVICE_LIMIT: UInt32 = 512
MCIERR_DGV_IOERR: UInt32 = 513
MCIERR_DGV_WORKSPACE_EMPTY: UInt32 = 514
MCIERR_DGV_DISK_FULL: UInt32 = 515
MCIERR_DGV_DEVICE_MEMORY_FULL: UInt32 = 516
MCIERR_DGV_BAD_CLIPBOARD_RANGE: UInt32 = 517
MCI_DGV_METHOD_PRE: Int32 = 40960
MCI_DGV_METHOD_POST: Int32 = 40961
MCI_DGV_METHOD_DIRECT: Int32 = 40962
MCI_DGV_FF_AVSS: Int32 = 16384
MCI_DGV_FF_AVI: Int32 = 16385
MCI_DGV_FF_DIB: Int32 = 16386
MCI_DGV_FF_RDIB: Int32 = 16387
MCI_DGV_FF_JPEG: Int32 = 16388
MCI_DGV_FF_RJPEG: Int32 = 16389
MCI_DGV_FF_JFIF: Int32 = 16390
MCI_DGV_FF_MPEG: Int32 = 16391
MCI_DGV_GETDEVCAPS_CAN_LOCK: Int32 = 16384
MCI_DGV_GETDEVCAPS_CAN_STRETCH: Int32 = 16385
MCI_DGV_GETDEVCAPS_CAN_FREEZE: Int32 = 16386
MCI_DGV_GETDEVCAPS_MAX_WINDOWS: Int32 = 16387
MCI_DGV_GETDEVCAPS_CAN_REVERSE: Int32 = 16388
MCI_DGV_GETDEVCAPS_HAS_STILL: Int32 = 16389
MCI_DGV_GETDEVCAPS_PALETTES: Int32 = 16390
MCI_DGV_GETDEVCAPS_CAN_STR_IN: Int32 = 16392
MCI_DGV_GETDEVCAPS_CAN_TEST: Int32 = 16393
MCI_DGV_GETDEVCAPS_MAXIMUM_RATE: Int32 = 16394
MCI_DGV_GETDEVCAPS_MINIMUM_RATE: Int32 = 16395
MCI_DGV_CAPTURE_AS: Int32 = 65536
MCI_DGV_CAPTURE_AT: Int32 = 131072
MCI_DGV_COPY_AT: Int32 = 65536
MCI_DGV_COPY_AUDIO_STREAM: Int32 = 131072
MCI_DGV_COPY_VIDEO_STREAM: Int32 = 262144
MCI_DGV_CUE_INPUT: Int32 = 65536
MCI_DGV_CUE_OUTPUT: Int32 = 131072
MCI_DGV_CUE_NOSHOW: Int32 = 262144
MCI_DGV_CUT_AT: Int32 = 65536
MCI_DGV_CUT_AUDIO_STREAM: Int32 = 131072
MCI_DGV_CUT_VIDEO_STREAM: Int32 = 262144
MCI_DGV_DELETE_AT: Int32 = 65536
MCI_DGV_DELETE_AUDIO_STREAM: Int32 = 131072
MCI_DGV_DELETE_VIDEO_STREAM: Int32 = 262144
MCI_DGV_FREEZE_AT: Int32 = 65536
MCI_DGV_FREEZE_OUTSIDE: Int32 = 131072
MCI_DGV_INFO_TEXT: Int32 = 65536
MCI_DGV_INFO_ITEM: Int32 = 131072
MCI_INFO_VERSION: Int32 = 1024
MCI_DGV_INFO_USAGE: Int32 = 16384
MCI_DGV_INFO_AUDIO_QUALITY: Int32 = 16385
MCI_DGV_INFO_STILL_QUALITY: Int32 = 16386
MCI_DGV_INFO_VIDEO_QUALITY: Int32 = 16387
MCI_DGV_INFO_AUDIO_ALG: Int32 = 16388
MCI_DGV_INFO_STILL_ALG: Int32 = 16389
MCI_DGV_INFO_VIDEO_ALG: Int32 = 16390
MCI_DGV_LIST_ITEM: Int32 = 65536
MCI_DGV_LIST_COUNT: Int32 = 131072
MCI_DGV_LIST_NUMBER: Int32 = 262144
MCI_DGV_LIST_ALG: Int32 = 524288
MCI_DGV_LIST_AUDIO_ALG: Int32 = 16384
MCI_DGV_LIST_AUDIO_QUALITY: Int32 = 16385
MCI_DGV_LIST_AUDIO_STREAM: Int32 = 16386
MCI_DGV_LIST_STILL_ALG: Int32 = 16387
MCI_DGV_LIST_STILL_QUALITY: Int32 = 16388
MCI_DGV_LIST_VIDEO_ALG: Int32 = 16389
MCI_DGV_LIST_VIDEO_QUALITY: Int32 = 16390
MCI_DGV_LIST_VIDEO_STREAM: Int32 = 16391
MCI_DGV_LIST_VIDEO_SOURCE: Int32 = 16392
MCI_DGV_MONITOR_METHOD: Int32 = 65536
MCI_DGV_MONITOR_SOURCE: Int32 = 131072
MCI_DGV_MONITOR_INPUT: Int32 = 16384
MCI_DGV_MONITOR_FILE: Int32 = 16385
MCI_DGV_OPEN_WS: Int32 = 65536
MCI_DGV_OPEN_PARENT: Int32 = 131072
MCI_DGV_OPEN_NOSTATIC: Int32 = 262144
MCI_DGV_OPEN_16BIT: Int32 = 524288
MCI_DGV_OPEN_32BIT: Int32 = 1048576
MCI_DGV_PASTE_AT: Int32 = 65536
MCI_DGV_PASTE_AUDIO_STREAM: Int32 = 131072
MCI_DGV_PASTE_VIDEO_STREAM: Int32 = 262144
MCI_DGV_PASTE_INSERT: Int32 = 524288
MCI_DGV_PASTE_OVERWRITE: Int32 = 1048576
MCI_DGV_PLAY_REPEAT: Int32 = 65536
MCI_DGV_PLAY_REVERSE: Int32 = 131072
MCI_DGV_RECT: Int32 = 65536
MCI_DGV_PUT_SOURCE: Int32 = 131072
MCI_DGV_PUT_DESTINATION: Int32 = 262144
MCI_DGV_PUT_FRAME: Int32 = 524288
MCI_DGV_PUT_VIDEO: Int32 = 1048576
MCI_DGV_PUT_WINDOW: Int32 = 2097152
MCI_DGV_PUT_CLIENT: Int32 = 4194304
MCI_QUALITY_ITEM: Int32 = 65536
MCI_QUALITY_NAME: Int32 = 131072
MCI_QUALITY_ALG: Int32 = 262144
MCI_QUALITY_DIALOG: Int32 = 524288
MCI_QUALITY_HANDLE: Int32 = 1048576
MCI_QUALITY_ITEM_AUDIO: Int32 = 16384
MCI_QUALITY_ITEM_STILL: Int32 = 16385
MCI_QUALITY_ITEM_VIDEO: Int32 = 16386
MCI_DGV_REALIZE_NORM: Int32 = 65536
MCI_DGV_REALIZE_BKGD: Int32 = 131072
MCI_DGV_RECORD_HOLD: Int32 = 131072
MCI_DGV_RECORD_AUDIO_STREAM: Int32 = 262144
MCI_DGV_RECORD_VIDEO_STREAM: Int32 = 524288
MCI_DGV_RESERVE_IN: Int32 = 65536
MCI_DGV_RESERVE_SIZE: Int32 = 131072
MCI_DGV_RESTORE_FROM: Int32 = 65536
MCI_DGV_RESTORE_AT: Int32 = 131072
MCI_DGV_SAVE_ABORT: Int32 = 131072
MCI_DGV_SAVE_KEEPRESERVE: Int32 = 262144
MCI_DGV_SET_SEEK_EXACTLY: Int32 = 65536
MCI_DGV_SET_SPEED: Int32 = 131072
MCI_DGV_SET_STILL: Int32 = 262144
MCI_DGV_SET_FILEFORMAT: Int32 = 524288
MCI_DGV_SETAUDIO_OVER: Int32 = 65536
MCI_DGV_SETAUDIO_CLOCKTIME: Int32 = 131072
MCI_DGV_SETAUDIO_ALG: Int32 = 262144
MCI_DGV_SETAUDIO_QUALITY: Int32 = 524288
MCI_DGV_SETAUDIO_RECORD: Int32 = 1048576
MCI_DGV_SETAUDIO_LEFT: Int32 = 2097152
MCI_DGV_SETAUDIO_RIGHT: Int32 = 4194304
MCI_DGV_SETAUDIO_ITEM: Int32 = 8388608
MCI_DGV_SETAUDIO_VALUE: Int32 = 16777216
MCI_DGV_SETAUDIO_INPUT: Int32 = 33554432
MCI_DGV_SETAUDIO_OUTPUT: Int32 = 67108864
MCI_DGV_SETAUDIO_TREBLE: Int32 = 16384
MCI_DGV_SETAUDIO_BASS: Int32 = 16385
MCI_DGV_SETAUDIO_VOLUME: Int32 = 16386
MCI_DGV_SETAUDIO_STREAM: Int32 = 16387
MCI_DGV_SETAUDIO_SOURCE: Int32 = 16388
MCI_DGV_SETAUDIO_SAMPLESPERSEC: Int32 = 16389
MCI_DGV_SETAUDIO_AVGBYTESPERSEC: Int32 = 16390
MCI_DGV_SETAUDIO_BLOCKALIGN: Int32 = 16391
MCI_DGV_SETAUDIO_BITSPERSAMPLE: Int32 = 16392
MCI_DGV_SETAUDIO_SOURCE_STEREO: Int32 = 0
MCI_DGV_SETAUDIO_SOURCE_LEFT: Int32 = 1
MCI_DGV_SETAUDIO_SOURCE_RIGHT: Int32 = 2
MCI_DGV_SETAUDIO_SOURCE_AVERAGE: Int32 = 16384
MCI_DGV_SETVIDEO_QUALITY: Int32 = 65536
MCI_DGV_SETVIDEO_ALG: Int32 = 131072
MCI_DGV_SETVIDEO_CLOCKTIME: Int32 = 262144
MCI_DGV_SETVIDEO_SRC_NUMBER: Int32 = 524288
MCI_DGV_SETVIDEO_ITEM: Int32 = 1048576
MCI_DGV_SETVIDEO_OVER: Int32 = 2097152
MCI_DGV_SETVIDEO_RECORD: Int32 = 4194304
MCI_DGV_SETVIDEO_STILL: Int32 = 8388608
MCI_DGV_SETVIDEO_VALUE: Int32 = 16777216
MCI_DGV_SETVIDEO_INPUT: Int32 = 33554432
MCI_DGV_SETVIDEO_OUTPUT: Int32 = 67108864
MCI_DGV_SETVIDEO_SRC_NTSC: Int32 = 16384
MCI_DGV_SETVIDEO_SRC_RGB: Int32 = 16385
MCI_DGV_SETVIDEO_SRC_SVIDEO: Int32 = 16386
MCI_DGV_SETVIDEO_SRC_PAL: Int32 = 16387
MCI_DGV_SETVIDEO_SRC_SECAM: Int32 = 16388
MCI_DGV_SETVIDEO_SRC_GENERIC: Int32 = 16389
MCI_DGV_SETVIDEO_BRIGHTNESS: Int32 = 16384
MCI_DGV_SETVIDEO_COLOR: Int32 = 16385
MCI_DGV_SETVIDEO_CONTRAST: Int32 = 16386
MCI_DGV_SETVIDEO_TINT: Int32 = 16387
MCI_DGV_SETVIDEO_SHARPNESS: Int32 = 16388
MCI_DGV_SETVIDEO_GAMMA: Int32 = 16389
MCI_DGV_SETVIDEO_STREAM: Int32 = 16390
MCI_DGV_SETVIDEO_PALHANDLE: Int32 = 16391
MCI_DGV_SETVIDEO_FRAME_RATE: Int32 = 16392
MCI_DGV_SETVIDEO_SOURCE: Int32 = 16393
MCI_DGV_SETVIDEO_KEY_INDEX: Int32 = 16394
MCI_DGV_SETVIDEO_KEY_COLOR: Int32 = 16395
MCI_DGV_SETVIDEO_BITSPERPEL: Int32 = 16396
MCI_DGV_SIGNAL_AT: Int32 = 65536
MCI_DGV_SIGNAL_EVERY: Int32 = 131072
MCI_DGV_SIGNAL_USERVAL: Int32 = 262144
MCI_DGV_SIGNAL_CANCEL: Int32 = 524288
MCI_DGV_SIGNAL_POSITION: Int32 = 1048576
MCI_DGV_STATUS_NOMINAL: Int32 = 131072
MCI_DGV_STATUS_REFERENCE: Int32 = 262144
MCI_DGV_STATUS_LEFT: Int32 = 524288
MCI_DGV_STATUS_RIGHT: Int32 = 1048576
MCI_DGV_STATUS_DISKSPACE: Int32 = 2097152
MCI_DGV_STATUS_INPUT: Int32 = 4194304
MCI_DGV_STATUS_OUTPUT: Int32 = 8388608
MCI_DGV_STATUS_RECORD: Int32 = 16777216
MCI_DGV_STATUS_AUDIO_INPUT: Int32 = 16384
MCI_DGV_STATUS_HWND: Int32 = 16385
MCI_DGV_STATUS_SPEED: Int32 = 16387
MCI_DGV_STATUS_HPAL: Int32 = 16388
MCI_DGV_STATUS_BRIGHTNESS: Int32 = 16389
MCI_DGV_STATUS_COLOR: Int32 = 16390
MCI_DGV_STATUS_CONTRAST: Int32 = 16391
MCI_DGV_STATUS_FILEFORMAT: Int32 = 16392
MCI_DGV_STATUS_AUDIO_SOURCE: Int32 = 16393
MCI_DGV_STATUS_GAMMA: Int32 = 16394
MCI_DGV_STATUS_MONITOR: Int32 = 16395
MCI_DGV_STATUS_MONITOR_METHOD: Int32 = 16396
MCI_DGV_STATUS_FRAME_RATE: Int32 = 16398
MCI_DGV_STATUS_BASS: Int32 = 16399
MCI_DGV_STATUS_SIZE: Int32 = 16400
MCI_DGV_STATUS_SEEK_EXACTLY: Int32 = 16401
MCI_DGV_STATUS_SHARPNESS: Int32 = 16402
MCI_DGV_STATUS_SMPTE: Int32 = 16403
MCI_DGV_STATUS_AUDIO: Int32 = 16404
MCI_DGV_STATUS_TINT: Int32 = 16405
MCI_DGV_STATUS_TREBLE: Int32 = 16406
MCI_DGV_STATUS_UNSAVED: Int32 = 16407
MCI_DGV_STATUS_VIDEO: Int32 = 16408
MCI_DGV_STATUS_VOLUME: Int32 = 16409
MCI_DGV_STATUS_AUDIO_RECORD: Int32 = 16410
MCI_DGV_STATUS_VIDEO_SOURCE: Int32 = 16411
MCI_DGV_STATUS_VIDEO_RECORD: Int32 = 16412
MCI_DGV_STATUS_STILL_FILEFORMAT: Int32 = 16413
MCI_DGV_STATUS_VIDEO_SRC_NUM: Int32 = 16414
MCI_DGV_STATUS_FILE_MODE: Int32 = 16415
MCI_DGV_STATUS_FILE_COMPLETION: Int32 = 16416
MCI_DGV_STATUS_WINDOW_VISIBLE: Int32 = 16417
MCI_DGV_STATUS_WINDOW_MINIMIZED: Int32 = 16418
MCI_DGV_STATUS_WINDOW_MAXIMIZED: Int32 = 16419
MCI_DGV_STATUS_KEY_INDEX: Int32 = 16420
MCI_DGV_STATUS_KEY_COLOR: Int32 = 16421
MCI_DGV_STATUS_PAUSE_MODE: Int32 = 16422
MCI_DGV_STATUS_SAMPLESPERSEC: Int32 = 16423
MCI_DGV_STATUS_AVGBYTESPERSEC: Int32 = 16424
MCI_DGV_STATUS_BLOCKALIGN: Int32 = 16425
MCI_DGV_STATUS_BITSPERSAMPLE: Int32 = 16426
MCI_DGV_STATUS_BITSPERPEL: Int32 = 16427
MCI_DGV_STATUS_FORWARD: Int32 = 16428
MCI_DGV_STATUS_AUDIO_STREAM: Int32 = 16429
MCI_DGV_STATUS_VIDEO_STREAM: Int32 = 16430
MCI_DGV_STEP_REVERSE: Int32 = 65536
MCI_DGV_STEP_FRAMES: Int32 = 131072
MCI_DGV_STOP_HOLD: Int32 = 65536
MCI_DGV_UPDATE_HDC: Int32 = 131072
MCI_DGV_UPDATE_PAINT: Int32 = 262144
MCI_DGV_WHERE_SOURCE: Int32 = 131072
MCI_DGV_WHERE_DESTINATION: Int32 = 262144
MCI_DGV_WHERE_FRAME: Int32 = 524288
MCI_DGV_WHERE_VIDEO: Int32 = 1048576
MCI_DGV_WHERE_WINDOW: Int32 = 2097152
MCI_DGV_WHERE_MAX: Int32 = 4194304
MCI_DGV_WINDOW_HWND: Int32 = 65536
MCI_DGV_WINDOW_STATE: Int32 = 262144
MCI_DGV_WINDOW_TEXT: Int32 = 524288
MCI_DGV_WINDOW_DEFAULT: Int32 = 0
MM_CREATIVE: UInt32 = 2
MM_MEDIAVISION: UInt32 = 3
MM_FUJITSU: UInt32 = 4
MM_PRAGMATRAX: UInt32 = 5
MM_CYRIX: UInt32 = 6
MM_PHILIPS_SPEECH_PROCESSING: UInt32 = 7
MM_NETXL: UInt32 = 8
MM_ZYXEL: UInt32 = 9
MM_BECUBED: UInt32 = 10
MM_AARDVARK: UInt32 = 11
MM_BINTEC: UInt32 = 12
MM_HEWLETT_PACKARD: UInt32 = 13
MM_ACULAB: UInt32 = 14
MM_FAITH: UInt32 = 15
MM_MITEL: UInt32 = 16
MM_QUANTUM3D: UInt32 = 17
MM_SNI: UInt32 = 18
MM_EMU: UInt32 = 19
MM_ARTISOFT: UInt32 = 20
MM_TURTLE_BEACH: UInt32 = 21
MM_IBM: UInt32 = 22
MM_VOCALTEC: UInt32 = 23
MM_ROLAND: UInt32 = 24
MM_DSP_SOLUTIONS: UInt32 = 25
MM_NEC: UInt32 = 26
MM_ATI: UInt32 = 27
MM_WANGLABS: UInt32 = 28
MM_TANDY: UInt32 = 29
MM_VOYETRA: UInt32 = 30
MM_ANTEX: UInt32 = 31
MM_ICL_PS: UInt32 = 32
MM_INTEL: UInt32 = 33
MM_GRAVIS: UInt32 = 34
MM_VAL: UInt32 = 35
MM_INTERACTIVE: UInt32 = 36
MM_YAMAHA: UInt32 = 37
MM_EVEREX: UInt32 = 38
MM_ECHO: UInt32 = 39
MM_SIERRA: UInt32 = 40
MM_CAT: UInt32 = 41
MM_APPS: UInt32 = 42
MM_DSP_GROUP: UInt32 = 43
MM_MELABS: UInt32 = 44
MM_COMPUTER_FRIENDS: UInt32 = 45
MM_ESS: UInt32 = 46
MM_AUDIOFILE: UInt32 = 47
MM_MOTOROLA: UInt32 = 48
MM_CANOPUS: UInt32 = 49
MM_EPSON: UInt32 = 50
MM_TRUEVISION: UInt32 = 51
MM_AZTECH: UInt32 = 52
MM_VIDEOLOGIC: UInt32 = 53
MM_SCALACS: UInt32 = 54
MM_KORG: UInt32 = 55
MM_APT: UInt32 = 56
MM_ICS: UInt32 = 57
MM_ITERATEDSYS: UInt32 = 58
MM_METHEUS: UInt32 = 59
MM_LOGITECH: UInt32 = 60
MM_WINNOV: UInt32 = 61
MM_NCR: UInt32 = 62
MM_EXAN: UInt32 = 63
MM_AST: UInt32 = 64
MM_WILLOWPOND: UInt32 = 65
MM_SONICFOUNDRY: UInt32 = 66
MM_VITEC: UInt32 = 67
MM_MOSCOM: UInt32 = 68
MM_SILICONSOFT: UInt32 = 69
MM_TERRATEC: UInt32 = 70
MM_MEDIASONIC: UInt32 = 71
MM_SANYO: UInt32 = 72
MM_SUPERMAC: UInt32 = 73
MM_AUDIOPT: UInt32 = 74
MM_NOGATECH: UInt32 = 75
MM_SPEECHCOMP: UInt32 = 76
MM_AHEAD: UInt32 = 77
MM_DOLBY: UInt32 = 78
MM_OKI: UInt32 = 79
MM_AURAVISION: UInt32 = 80
MM_OLIVETTI: UInt32 = 81
MM_IOMAGIC: UInt32 = 82
MM_MATSUSHITA: UInt32 = 83
MM_CONTROLRES: UInt32 = 84
MM_XEBEC: UInt32 = 85
MM_NEWMEDIA: UInt32 = 86
MM_NMS: UInt32 = 87
MM_LYRRUS: UInt32 = 88
MM_COMPUSIC: UInt32 = 89
MM_OPTI: UInt32 = 90
MM_ADLACC: UInt32 = 91
MM_COMPAQ: UInt32 = 92
MM_DIALOGIC: UInt32 = 93
MM_INSOFT: UInt32 = 94
MM_MPTUS: UInt32 = 95
MM_WEITEK: UInt32 = 96
MM_LERNOUT_AND_HAUSPIE: UInt32 = 97
MM_QCIAR: UInt32 = 98
MM_APPLE: UInt32 = 99
MM_DIGITAL: UInt32 = 100
MM_MOTU: UInt32 = 101
MM_WORKBIT: UInt32 = 102
MM_OSITECH: UInt32 = 103
MM_MIRO: UInt32 = 104
MM_CIRRUSLOGIC: UInt32 = 105
MM_ISOLUTION: UInt32 = 106
MM_HORIZONS: UInt32 = 107
MM_CONCEPTS: UInt32 = 108
MM_VTG: UInt32 = 109
MM_RADIUS: UInt32 = 110
MM_ROCKWELL: UInt32 = 111
MM_XYZ: UInt32 = 112
MM_OPCODE: UInt32 = 113
MM_VOXWARE: UInt32 = 114
MM_NORTHERN_TELECOM: UInt32 = 115
MM_APICOM: UInt32 = 116
MM_GRANDE: UInt32 = 117
MM_ADDX: UInt32 = 118
MM_WILDCAT: UInt32 = 119
MM_RHETOREX: UInt32 = 120
MM_BROOKTREE: UInt32 = 121
MM_ENSONIQ: UInt32 = 125
MM_FAST: UInt32 = 126
MM_NVIDIA: UInt32 = 127
MM_OKSORI: UInt32 = 128
MM_DIACOUSTICS: UInt32 = 129
MM_GULBRANSEN: UInt32 = 130
MM_KAY_ELEMETRICS: UInt32 = 131
MM_CRYSTAL: UInt32 = 132
MM_SPLASH_STUDIOS: UInt32 = 133
MM_QUARTERDECK: UInt32 = 134
MM_TDK: UInt32 = 135
MM_DIGITAL_AUDIO_LABS: UInt32 = 136
MM_SEERSYS: UInt32 = 137
MM_PICTURETEL: UInt32 = 138
MM_ATT_MICROELECTRONICS: UInt32 = 139
MM_OSPREY: UInt32 = 140
MM_MEDIATRIX: UInt32 = 141
MM_SOUNDESIGNS: UInt32 = 142
MM_ALDIGITAL: UInt32 = 143
MM_SPECTRUM_SIGNAL_PROCESSING: UInt32 = 144
MM_ECS: UInt32 = 145
MM_AMD: UInt32 = 146
MM_COREDYNAMICS: UInt32 = 147
MM_CANAM: UInt32 = 148
MM_SOFTSOUND: UInt32 = 149
MM_NORRIS: UInt32 = 150
MM_DDD: UInt32 = 151
MM_EUPHONICS: UInt32 = 152
MM_PRECEPT: UInt32 = 153
MM_CRYSTAL_NET: UInt32 = 154
MM_CHROMATIC: UInt32 = 155
MM_VOICEINFO: UInt32 = 156
MM_VIENNASYS: UInt32 = 157
MM_CONNECTIX: UInt32 = 158
MM_GADGETLABS: UInt32 = 159
MM_FRONTIER: UInt32 = 160
MM_VIONA: UInt32 = 161
MM_CASIO: UInt32 = 162
MM_DIAMONDMM: UInt32 = 163
MM_S3: UInt32 = 164
MM_DVISION: UInt32 = 165
MM_NETSCAPE: UInt32 = 166
MM_SOUNDSPACE: UInt32 = 167
MM_VANKOEVERING: UInt32 = 168
MM_QTEAM: UInt32 = 169
MM_ZEFIRO: UInt32 = 170
MM_STUDER: UInt32 = 171
MM_FRAUNHOFER_IIS: UInt32 = 172
MM_QUICKNET: UInt32 = 173
MM_ALARIS: UInt32 = 174
MM_SICRESOURCE: UInt32 = 175
MM_NEOMAGIC: UInt32 = 176
MM_MERGING_TECHNOLOGIES: UInt32 = 177
MM_XIRLINK: UInt32 = 178
MM_COLORGRAPH: UInt32 = 179
MM_OTI: UInt32 = 180
MM_AUREAL: UInt32 = 181
MM_VIVO: UInt32 = 182
MM_SHARP: UInt32 = 183
MM_LUCENT: UInt32 = 184
MM_ATT: UInt32 = 185
MM_SUNCOM: UInt32 = 186
MM_SORVIS: UInt32 = 187
MM_INVISION: UInt32 = 188
MM_BERKOM: UInt32 = 189
MM_MARIAN: UInt32 = 190
MM_DPSINC: UInt32 = 191
MM_BCB: UInt32 = 192
MM_MOTIONPIXELS: UInt32 = 193
MM_QDESIGN: UInt32 = 194
MM_NMP: UInt32 = 195
MM_DATAFUSION: UInt32 = 196
MM_DUCK: UInt32 = 197
MM_FTR: UInt32 = 198
MM_BERCOS: UInt32 = 199
MM_ONLIVE: UInt32 = 200
MM_SIEMENS_SBC: UInt32 = 201
MM_TERALOGIC: UInt32 = 202
MM_PHONET: UInt32 = 203
MM_WINBOND: UInt32 = 204
MM_VIRTUALMUSIC: UInt32 = 205
MM_ENET: UInt32 = 206
MM_GUILLEMOT: UInt32 = 207
MM_EMAGIC: UInt32 = 208
MM_MWM: UInt32 = 209
MM_PACIFICRESEARCH: UInt32 = 210
MM_SIPROLAB: UInt32 = 211
MM_LYNX: UInt32 = 212
MM_SPECTRUM_PRODUCTIONS: UInt32 = 213
MM_DICTAPHONE: UInt32 = 214
MM_QUALCOMM: UInt32 = 215
MM_RZS: UInt32 = 216
MM_AUDIOSCIENCE: UInt32 = 217
MM_PINNACLE: UInt32 = 218
MM_EES: UInt32 = 219
MM_HAFTMANN: UInt32 = 220
MM_LUCID: UInt32 = 221
MM_HEADSPACE: UInt32 = 222
MM_UNISYS: UInt32 = 223
MM_LUMINOSITI: UInt32 = 224
MM_ACTIVEVOICE: UInt32 = 225
MM_DTS: UInt32 = 226
MM_DIGIGRAM: UInt32 = 227
MM_SOFTLAB_NSK: UInt32 = 228
MM_FORTEMEDIA: UInt32 = 229
MM_SONORUS: UInt32 = 230
MM_ARRAY: UInt32 = 231
MM_DATARAN: UInt32 = 232
MM_I_LINK: UInt32 = 233
MM_SELSIUS_SYSTEMS: UInt32 = 234
MM_ADMOS: UInt32 = 235
MM_LEXICON: UInt32 = 236
MM_SGI: UInt32 = 237
MM_IPI: UInt32 = 238
MM_ICE: UInt32 = 239
MM_VQST: UInt32 = 240
MM_ETEK: UInt32 = 241
MM_CS: UInt32 = 242
MM_ALESIS: UInt32 = 243
MM_INTERNET: UInt32 = 244
MM_SONY: UInt32 = 245
MM_HYPERACTIVE: UInt32 = 246
MM_UHER_INFORMATIC: UInt32 = 247
MM_SYDEC_NV: UInt32 = 248
MM_FLEXION: UInt32 = 249
MM_VIA: UInt32 = 250
MM_MICRONAS: UInt32 = 251
MM_ANALOGDEVICES: UInt32 = 252
MM_HP: UInt32 = 253
MM_MATROX_DIV: UInt32 = 254
MM_QUICKAUDIO: UInt32 = 255
MM_YOUCOM: UInt32 = 256
MM_RICHMOND: UInt32 = 257
MM_IODD: UInt32 = 258
MM_ICCC: UInt32 = 259
MM_3COM: UInt32 = 260
MM_MALDEN: UInt32 = 261
MM_3DFX: UInt32 = 262
MM_MINDMAKER: UInt32 = 263
MM_TELEKOL: UInt32 = 264
MM_ST_MICROELECTRONICS: UInt32 = 265
MM_ALGOVISION: UInt32 = 266
MM_UNMAPPED: UInt32 = 65535
MM_PID_UNMAPPED: UInt32 = 65535
MM_PCSPEAKER_WAVEOUT: UInt32 = 13
MM_MSFT_WSS_WAVEIN: UInt32 = 14
MM_MSFT_WSS_WAVEOUT: UInt32 = 15
MM_MSFT_WSS_FMSYNTH_STEREO: UInt32 = 16
MM_MSFT_WSS_MIXER: UInt32 = 17
MM_MSFT_WSS_OEM_WAVEIN: UInt32 = 18
MM_MSFT_WSS_OEM_WAVEOUT: UInt32 = 19
MM_MSFT_WSS_OEM_FMSYNTH_STEREO: UInt32 = 20
MM_MSFT_WSS_AUX: UInt32 = 21
MM_MSFT_WSS_OEM_AUX: UInt32 = 22
MM_MSFT_GENERIC_WAVEIN: UInt32 = 23
MM_MSFT_GENERIC_WAVEOUT: UInt32 = 24
MM_MSFT_GENERIC_MIDIIN: UInt32 = 25
MM_MSFT_GENERIC_MIDIOUT: UInt32 = 26
MM_MSFT_GENERIC_MIDISYNTH: UInt32 = 27
MM_MSFT_GENERIC_AUX_LINE: UInt32 = 28
MM_MSFT_GENERIC_AUX_MIC: UInt32 = 29
MM_MSFT_GENERIC_AUX_CD: UInt32 = 30
MM_MSFT_WSS_OEM_MIXER: UInt32 = 31
MM_MSFT_MSACM: UInt32 = 32
MM_MSFT_ACM_MSADPCM: UInt32 = 33
MM_MSFT_ACM_IMAADPCM: UInt32 = 34
MM_MSFT_ACM_MSFILTER: UInt32 = 35
MM_MSFT_ACM_GSM610: UInt32 = 36
MM_MSFT_ACM_G711: UInt32 = 37
MM_MSFT_ACM_PCM: UInt32 = 38
MM_WSS_SB16_WAVEIN: UInt32 = 39
MM_WSS_SB16_WAVEOUT: UInt32 = 40
MM_WSS_SB16_MIDIIN: UInt32 = 41
MM_WSS_SB16_MIDIOUT: UInt32 = 42
MM_WSS_SB16_SYNTH: UInt32 = 43
MM_WSS_SB16_AUX_LINE: UInt32 = 44
MM_WSS_SB16_AUX_CD: UInt32 = 45
MM_WSS_SB16_MIXER: UInt32 = 46
MM_WSS_SBPRO_WAVEIN: UInt32 = 47
MM_WSS_SBPRO_WAVEOUT: UInt32 = 48
MM_WSS_SBPRO_MIDIIN: UInt32 = 49
MM_WSS_SBPRO_MIDIOUT: UInt32 = 50
MM_WSS_SBPRO_SYNTH: UInt32 = 51
MM_WSS_SBPRO_AUX_LINE: UInt32 = 52
MM_WSS_SBPRO_AUX_CD: UInt32 = 53
MM_WSS_SBPRO_MIXER: UInt32 = 54
MM_MSFT_WSS_NT_WAVEIN: UInt32 = 55
MM_MSFT_WSS_NT_WAVEOUT: UInt32 = 56
MM_MSFT_WSS_NT_FMSYNTH_STEREO: UInt32 = 57
MM_MSFT_WSS_NT_MIXER: UInt32 = 58
MM_MSFT_WSS_NT_AUX: UInt32 = 59
MM_MSFT_SB16_WAVEIN: UInt32 = 60
MM_MSFT_SB16_WAVEOUT: UInt32 = 61
MM_MSFT_SB16_MIDIIN: UInt32 = 62
MM_MSFT_SB16_MIDIOUT: UInt32 = 63
MM_MSFT_SB16_SYNTH: UInt32 = 64
MM_MSFT_SB16_AUX_LINE: UInt32 = 65
MM_MSFT_SB16_AUX_CD: UInt32 = 66
MM_MSFT_SB16_MIXER: UInt32 = 67
MM_MSFT_SBPRO_WAVEIN: UInt32 = 68
MM_MSFT_SBPRO_WAVEOUT: UInt32 = 69
MM_MSFT_SBPRO_MIDIIN: UInt32 = 70
MM_MSFT_SBPRO_MIDIOUT: UInt32 = 71
MM_MSFT_SBPRO_SYNTH: UInt32 = 72
MM_MSFT_SBPRO_AUX_LINE: UInt32 = 73
MM_MSFT_SBPRO_AUX_CD: UInt32 = 74
MM_MSFT_SBPRO_MIXER: UInt32 = 75
MM_MSFT_MSOPL_SYNTH: UInt32 = 76
MM_MSFT_VMDMS_LINE_WAVEIN: UInt32 = 80
MM_MSFT_VMDMS_LINE_WAVEOUT: UInt32 = 81
MM_MSFT_VMDMS_HANDSET_WAVEIN: UInt32 = 82
MM_MSFT_VMDMS_HANDSET_WAVEOUT: UInt32 = 83
MM_MSFT_VMDMW_LINE_WAVEIN: UInt32 = 84
MM_MSFT_VMDMW_LINE_WAVEOUT: UInt32 = 85
MM_MSFT_VMDMW_HANDSET_WAVEIN: UInt32 = 86
MM_MSFT_VMDMW_HANDSET_WAVEOUT: UInt32 = 87
MM_MSFT_VMDMW_MIXER: UInt32 = 88
MM_MSFT_VMDM_GAME_WAVEOUT: UInt32 = 89
MM_MSFT_VMDM_GAME_WAVEIN: UInt32 = 90
MM_MSFT_ACM_MSNAUDIO: UInt32 = 91
MM_MSFT_ACM_MSG723: UInt32 = 92
MM_MSFT_ACM_MSRT24: UInt32 = 93
MM_MSFT_WDMAUDIO_WAVEOUT: UInt32 = 100
MM_MSFT_WDMAUDIO_WAVEIN: UInt32 = 101
MM_MSFT_WDMAUDIO_MIDIOUT: UInt32 = 102
MM_MSFT_WDMAUDIO_MIDIIN: UInt32 = 103
MM_MSFT_WDMAUDIO_MIXER: UInt32 = 104
MM_MSFT_WDMAUDIO_AUX: UInt32 = 105
MM_CREATIVE_SB15_WAVEIN: UInt32 = 1
MM_CREATIVE_SB20_WAVEIN: UInt32 = 2
MM_CREATIVE_SBPRO_WAVEIN: UInt32 = 3
MM_CREATIVE_SBP16_WAVEIN: UInt32 = 4
MM_CREATIVE_PHNBLST_WAVEIN: UInt32 = 5
MM_CREATIVE_SB15_WAVEOUT: UInt32 = 101
MM_CREATIVE_SB20_WAVEOUT: UInt32 = 102
MM_CREATIVE_SBPRO_WAVEOUT: UInt32 = 103
MM_CREATIVE_SBP16_WAVEOUT: UInt32 = 104
MM_CREATIVE_PHNBLST_WAVEOUT: UInt32 = 105
MM_CREATIVE_MIDIOUT: UInt32 = 201
MM_CREATIVE_MIDIIN: UInt32 = 202
MM_CREATIVE_FMSYNTH_MONO: UInt32 = 301
MM_CREATIVE_FMSYNTH_STEREO: UInt32 = 302
MM_CREATIVE_MIDI_AWE32: UInt32 = 303
MM_CREATIVE_AUX_CD: UInt32 = 401
MM_CREATIVE_AUX_LINE: UInt32 = 402
MM_CREATIVE_AUX_MIC: UInt32 = 403
MM_CREATIVE_AUX_MASTER: UInt32 = 404
MM_CREATIVE_AUX_PCSPK: UInt32 = 405
MM_CREATIVE_AUX_WAVE: UInt32 = 406
MM_CREATIVE_AUX_MIDI: UInt32 = 407
MM_CREATIVE_SBPRO_MIXER: UInt32 = 408
MM_CREATIVE_SB16_MIXER: UInt32 = 409
MM_MEDIAVISION_PROAUDIO: UInt32 = 16
MM_PROAUD_MIDIOUT: UInt32 = 17
MM_PROAUD_MIDIIN: UInt32 = 18
MM_PROAUD_SYNTH: UInt32 = 19
MM_PROAUD_WAVEOUT: UInt32 = 20
MM_PROAUD_WAVEIN: UInt32 = 21
MM_PROAUD_MIXER: UInt32 = 22
MM_PROAUD_AUX: UInt32 = 23
MM_MEDIAVISION_THUNDER: UInt32 = 32
MM_THUNDER_SYNTH: UInt32 = 35
MM_THUNDER_WAVEOUT: UInt32 = 36
MM_THUNDER_WAVEIN: UInt32 = 37
MM_THUNDER_AUX: UInt32 = 39
MM_MEDIAVISION_TPORT: UInt32 = 64
MM_TPORT_WAVEOUT: UInt32 = 65
MM_TPORT_WAVEIN: UInt32 = 66
MM_TPORT_SYNTH: UInt32 = 67
MM_MEDIAVISION_PROAUDIO_PLUS: UInt32 = 80
MM_PROAUD_PLUS_MIDIOUT: UInt32 = 81
MM_PROAUD_PLUS_MIDIIN: UInt32 = 82
MM_PROAUD_PLUS_SYNTH: UInt32 = 83
MM_PROAUD_PLUS_WAVEOUT: UInt32 = 84
MM_PROAUD_PLUS_WAVEIN: UInt32 = 85
MM_PROAUD_PLUS_MIXER: UInt32 = 86
MM_PROAUD_PLUS_AUX: UInt32 = 87
MM_MEDIAVISION_PROAUDIO_16: UInt32 = 96
MM_PROAUD_16_MIDIOUT: UInt32 = 97
MM_PROAUD_16_MIDIIN: UInt32 = 98
MM_PROAUD_16_SYNTH: UInt32 = 99
MM_PROAUD_16_WAVEOUT: UInt32 = 100
MM_PROAUD_16_WAVEIN: UInt32 = 101
MM_PROAUD_16_MIXER: UInt32 = 102
MM_PROAUD_16_AUX: UInt32 = 103
MM_MEDIAVISION_PROSTUDIO_16: UInt32 = 96
MM_STUDIO_16_MIDIOUT: UInt32 = 97
MM_STUDIO_16_MIDIIN: UInt32 = 98
MM_STUDIO_16_SYNTH: UInt32 = 99
MM_STUDIO_16_WAVEOUT: UInt32 = 100
MM_STUDIO_16_WAVEIN: UInt32 = 101
MM_STUDIO_16_MIXER: UInt32 = 102
MM_STUDIO_16_AUX: UInt32 = 103
MM_MEDIAVISION_CDPC: UInt32 = 112
MM_CDPC_MIDIOUT: UInt32 = 113
MM_CDPC_MIDIIN: UInt32 = 114
MM_CDPC_SYNTH: UInt32 = 115
MM_CDPC_WAVEOUT: UInt32 = 116
MM_CDPC_WAVEIN: UInt32 = 117
MM_CDPC_MIXER: UInt32 = 118
MM_CDPC_AUX: UInt32 = 119
MM_MEDIAVISION_OPUS1208: UInt32 = 128
MM_OPUS401_MIDIOUT: UInt32 = 129
MM_OPUS401_MIDIIN: UInt32 = 130
MM_OPUS1208_SYNTH: UInt32 = 131
MM_OPUS1208_WAVEOUT: UInt32 = 132
MM_OPUS1208_WAVEIN: UInt32 = 133
MM_OPUS1208_MIXER: UInt32 = 134
MM_OPUS1208_AUX: UInt32 = 135
MM_MEDIAVISION_OPUS1216: UInt32 = 144
MM_OPUS1216_MIDIOUT: UInt32 = 145
MM_OPUS1216_MIDIIN: UInt32 = 146
MM_OPUS1216_SYNTH: UInt32 = 147
MM_OPUS1216_WAVEOUT: UInt32 = 148
MM_OPUS1216_WAVEIN: UInt32 = 149
MM_OPUS1216_MIXER: UInt32 = 150
MM_OPUS1216_AUX: UInt32 = 151
MM_CYRIX_XASYNTH: UInt32 = 1
MM_CYRIX_XAMIDIIN: UInt32 = 2
MM_CYRIX_XAMIDIOUT: UInt32 = 3
MM_CYRIX_XAWAVEIN: UInt32 = 4
MM_CYRIX_XAWAVEOUT: UInt32 = 5
MM_CYRIX_XAAUX: UInt32 = 6
MM_CYRIX_XAMIXER: UInt32 = 7
MM_PHILIPS_ACM_LPCBB: UInt32 = 1
MM_NETXL_XLVIDEO: UInt32 = 1
MM_ZYXEL_ACM_ADPCM: UInt32 = 1
MM_AARDVARK_STUDIO12_WAVEOUT: UInt32 = 1
MM_AARDVARK_STUDIO12_WAVEIN: UInt32 = 2
MM_AARDVARK_STUDIO88_WAVEOUT: UInt32 = 3
MM_AARDVARK_STUDIO88_WAVEIN: UInt32 = 4
MM_BINTEC_TAPI_WAVE: UInt32 = 1
MM_HEWLETT_PACKARD_CU_CODEC: UInt32 = 1
MM_MITEL_TALKTO_LINE_WAVEOUT: UInt32 = 100
MM_MITEL_TALKTO_LINE_WAVEIN: UInt32 = 101
MM_MITEL_TALKTO_HANDSET_WAVEOUT: UInt32 = 102
MM_MITEL_TALKTO_HANDSET_WAVEIN: UInt32 = 103
MM_MITEL_TALKTO_BRIDGED_WAVEOUT: UInt32 = 104
MM_MITEL_TALKTO_BRIDGED_WAVEIN: UInt32 = 105
MM_MITEL_MPA_HANDSET_WAVEOUT: UInt32 = 200
MM_MITEL_MPA_HANDSET_WAVEIN: UInt32 = 201
MM_MITEL_MPA_HANDSFREE_WAVEOUT: UInt32 = 202
MM_MITEL_MPA_HANDSFREE_WAVEIN: UInt32 = 203
MM_MITEL_MPA_LINE1_WAVEOUT: UInt32 = 204
MM_MITEL_MPA_LINE1_WAVEIN: UInt32 = 205
MM_MITEL_MPA_LINE2_WAVEOUT: UInt32 = 206
MM_MITEL_MPA_LINE2_WAVEIN: UInt32 = 207
MM_MITEL_MEDIAPATH_WAVEOUT: UInt32 = 300
MM_MITEL_MEDIAPATH_WAVEIN: UInt32 = 301
MM_SNI_ACM_G721: UInt32 = 1
MM_EMU_APSSYNTH: UInt32 = 1
MM_EMU_APSMIDIIN: UInt32 = 2
MM_EMU_APSMIDIOUT: UInt32 = 3
MM_EMU_APSWAVEIN: UInt32 = 4
MM_EMU_APSWAVEOUT: UInt32 = 5
MM_ARTISOFT_SBWAVEIN: UInt32 = 1
MM_ARTISOFT_SBWAVEOUT: UInt32 = 2
MM_TBS_TROPEZ_WAVEIN: UInt32 = 37
MM_TBS_TROPEZ_WAVEOUT: UInt32 = 38
MM_TBS_TROPEZ_AUX1: UInt32 = 39
MM_TBS_TROPEZ_AUX2: UInt32 = 40
MM_TBS_TROPEZ_LINE: UInt32 = 41
MM_MMOTION_WAVEAUX: UInt32 = 1
MM_MMOTION_WAVEOUT: UInt32 = 2
MM_MMOTION_WAVEIN: UInt32 = 3
MM_IBM_PCMCIA_WAVEIN: UInt32 = 11
MM_IBM_PCMCIA_WAVEOUT: UInt32 = 12
MM_IBM_PCMCIA_SYNTH: UInt32 = 13
MM_IBM_PCMCIA_MIDIIN: UInt32 = 14
MM_IBM_PCMCIA_MIDIOUT: UInt32 = 15
MM_IBM_PCMCIA_AUX: UInt32 = 16
MM_IBM_THINKPAD200: UInt32 = 17
MM_IBM_MWAVE_WAVEIN: UInt32 = 18
MM_IBM_MWAVE_WAVEOUT: UInt32 = 19
MM_IBM_MWAVE_MIXER: UInt32 = 20
MM_IBM_MWAVE_MIDIIN: UInt32 = 21
MM_IBM_MWAVE_MIDIOUT: UInt32 = 22
MM_IBM_MWAVE_AUX: UInt32 = 23
MM_IBM_WC_MIDIOUT: UInt32 = 30
MM_IBM_WC_WAVEOUT: UInt32 = 31
MM_IBM_WC_MIXEROUT: UInt32 = 33
MM_VOCALTEC_WAVEOUT: UInt32 = 1
MM_VOCALTEC_WAVEIN: UInt32 = 2
MM_ROLAND_RAP10_MIDIOUT: UInt32 = 10
MM_ROLAND_RAP10_MIDIIN: UInt32 = 11
MM_ROLAND_RAP10_SYNTH: UInt32 = 12
MM_ROLAND_RAP10_WAVEOUT: UInt32 = 13
MM_ROLAND_RAP10_WAVEIN: UInt32 = 14
MM_ROLAND_MPU401_MIDIOUT: UInt32 = 15
MM_ROLAND_MPU401_MIDIIN: UInt32 = 16
MM_ROLAND_SMPU_MIDIOUTA: UInt32 = 17
MM_ROLAND_SMPU_MIDIOUTB: UInt32 = 18
MM_ROLAND_SMPU_MIDIINA: UInt32 = 19
MM_ROLAND_SMPU_MIDIINB: UInt32 = 20
MM_ROLAND_SC7_MIDIOUT: UInt32 = 21
MM_ROLAND_SC7_MIDIIN: UInt32 = 22
MM_ROLAND_SERIAL_MIDIOUT: UInt32 = 23
MM_ROLAND_SERIAL_MIDIIN: UInt32 = 24
MM_ROLAND_SCP_MIDIOUT: UInt32 = 38
MM_ROLAND_SCP_MIDIIN: UInt32 = 39
MM_ROLAND_SCP_WAVEOUT: UInt32 = 40
MM_ROLAND_SCP_WAVEIN: UInt32 = 41
MM_ROLAND_SCP_MIXER: UInt32 = 42
MM_ROLAND_SCP_AUX: UInt32 = 48
MM_DSP_SOLUTIONS_WAVEOUT: UInt32 = 1
MM_DSP_SOLUTIONS_WAVEIN: UInt32 = 2
MM_DSP_SOLUTIONS_SYNTH: UInt32 = 3
MM_DSP_SOLUTIONS_AUX: UInt32 = 4
MM_NEC_73_86_SYNTH: UInt32 = 5
MM_NEC_73_86_WAVEOUT: UInt32 = 6
MM_NEC_73_86_WAVEIN: UInt32 = 7
MM_NEC_26_SYNTH: UInt32 = 9
MM_NEC_MPU401_MIDIOUT: UInt32 = 10
MM_NEC_MPU401_MIDIIN: UInt32 = 11
MM_NEC_JOYSTICK: UInt32 = 12
MM_WANGLABS_WAVEIN1: UInt32 = 1
MM_WANGLABS_WAVEOUT1: UInt32 = 2
MM_TANDY_VISWAVEIN: UInt32 = 1
MM_TANDY_VISWAVEOUT: UInt32 = 2
MM_TANDY_VISBIOSSYNTH: UInt32 = 3
MM_TANDY_SENS_MMAWAVEIN: UInt32 = 4
MM_TANDY_SENS_MMAWAVEOUT: UInt32 = 5
MM_TANDY_SENS_MMAMIDIIN: UInt32 = 6
MM_TANDY_SENS_MMAMIDIOUT: UInt32 = 7
MM_TANDY_SENS_VISWAVEOUT: UInt32 = 8
MM_TANDY_PSSJWAVEIN: UInt32 = 9
MM_TANDY_PSSJWAVEOUT: UInt32 = 10
MM_ANTEX_SX12_WAVEIN: UInt32 = 1
MM_ANTEX_SX12_WAVEOUT: UInt32 = 2
MM_ANTEX_SX15_WAVEIN: UInt32 = 3
MM_ANTEX_SX15_WAVEOUT: UInt32 = 4
MM_ANTEX_VP625_WAVEIN: UInt32 = 5
MM_ANTEX_VP625_WAVEOUT: UInt32 = 6
MM_ANTEX_AUDIOPORT22_WAVEIN: UInt32 = 7
MM_ANTEX_AUDIOPORT22_WAVEOUT: UInt32 = 8
MM_ANTEX_AUDIOPORT22_FEEDTHRU: UInt32 = 9
MM_INTELOPD_WAVEIN: UInt32 = 1
MM_INTELOPD_WAVEOUT: UInt32 = 101
MM_INTELOPD_AUX: UInt32 = 401
MM_INTEL_NSPMODEMLINEIN: UInt32 = 501
MM_INTEL_NSPMODEMLINEOUT: UInt32 = 502
MM_VAL_MICROKEY_AP_WAVEIN: UInt32 = 1
MM_VAL_MICROKEY_AP_WAVEOUT: UInt32 = 2
MM_INTERACTIVE_WAVEIN: UInt32 = 69
MM_INTERACTIVE_WAVEOUT: UInt32 = 69
MM_YAMAHA_GSS_SYNTH: UInt32 = 1
MM_YAMAHA_GSS_WAVEOUT: UInt32 = 2
MM_YAMAHA_GSS_WAVEIN: UInt32 = 3
MM_YAMAHA_GSS_MIDIOUT: UInt32 = 4
MM_YAMAHA_GSS_MIDIIN: UInt32 = 5
MM_YAMAHA_GSS_AUX: UInt32 = 6
MM_YAMAHA_SERIAL_MIDIOUT: UInt32 = 7
MM_YAMAHA_SERIAL_MIDIIN: UInt32 = 8
MM_YAMAHA_OPL3SA_WAVEOUT: UInt32 = 16
MM_YAMAHA_OPL3SA_WAVEIN: UInt32 = 17
MM_YAMAHA_OPL3SA_FMSYNTH: UInt32 = 18
MM_YAMAHA_OPL3SA_YSYNTH: UInt32 = 19
MM_YAMAHA_OPL3SA_MIDIOUT: UInt32 = 20
MM_YAMAHA_OPL3SA_MIDIIN: UInt32 = 21
MM_YAMAHA_OPL3SA_MIXER: UInt32 = 23
MM_YAMAHA_OPL3SA_JOYSTICK: UInt32 = 24
MM_YAMAHA_YMF724LEG_MIDIOUT: UInt32 = 25
MM_YAMAHA_YMF724LEG_MIDIIN: UInt32 = 26
MM_YAMAHA_YMF724_WAVEOUT: UInt32 = 27
MM_YAMAHA_YMF724_WAVEIN: UInt32 = 28
MM_YAMAHA_YMF724_MIDIOUT: UInt32 = 29
MM_YAMAHA_YMF724_AUX: UInt32 = 30
MM_YAMAHA_YMF724_MIXER: UInt32 = 31
MM_YAMAHA_YMF724LEG_FMSYNTH: UInt32 = 32
MM_YAMAHA_YMF724LEG_MIXER: UInt32 = 33
MM_YAMAHA_SXG_MIDIOUT: UInt32 = 34
MM_YAMAHA_SXG_WAVEOUT: UInt32 = 35
MM_YAMAHA_SXG_MIXER: UInt32 = 36
MM_YAMAHA_ACXG_WAVEIN: UInt32 = 37
MM_YAMAHA_ACXG_WAVEOUT: UInt32 = 38
MM_YAMAHA_ACXG_MIDIOUT: UInt32 = 39
MM_YAMAHA_ACXG_MIXER: UInt32 = 40
MM_YAMAHA_ACXG_AUX: UInt32 = 41
MM_EVEREX_CARRIER: UInt32 = 1
MM_ECHO_SYNTH: UInt32 = 1
MM_ECHO_WAVEOUT: UInt32 = 2
MM_ECHO_WAVEIN: UInt32 = 3
MM_ECHO_MIDIOUT: UInt32 = 4
MM_ECHO_MIDIIN: UInt32 = 5
MM_ECHO_AUX: UInt32 = 6
MM_SIERRA_ARIA_MIDIOUT: UInt32 = 20
MM_SIERRA_ARIA_MIDIIN: UInt32 = 21
MM_SIERRA_ARIA_SYNTH: UInt32 = 22
MM_SIERRA_ARIA_WAVEOUT: UInt32 = 23
MM_SIERRA_ARIA_WAVEIN: UInt32 = 24
MM_SIERRA_ARIA_AUX: UInt32 = 25
MM_SIERRA_ARIA_AUX2: UInt32 = 32
MM_SIERRA_QUARTET_WAVEIN: UInt32 = 80
MM_SIERRA_QUARTET_WAVEOUT: UInt32 = 81
MM_SIERRA_QUARTET_MIDIIN: UInt32 = 82
MM_SIERRA_QUARTET_MIDIOUT: UInt32 = 83
MM_SIERRA_QUARTET_SYNTH: UInt32 = 84
MM_SIERRA_QUARTET_AUX_CD: UInt32 = 85
MM_SIERRA_QUARTET_AUX_LINE: UInt32 = 86
MM_SIERRA_QUARTET_AUX_MODEM: UInt32 = 87
MM_SIERRA_QUARTET_MIXER: UInt32 = 88
MM_CAT_WAVEOUT: UInt32 = 1
MM_DSP_GROUP_TRUESPEECH: UInt32 = 1
MM_MELABS_MIDI2GO: UInt32 = 1
MM_ESS_AMWAVEOUT: UInt32 = 1
MM_ESS_AMWAVEIN: UInt32 = 2
MM_ESS_AMAUX: UInt32 = 3
MM_ESS_AMSYNTH: UInt32 = 4
MM_ESS_AMMIDIOUT: UInt32 = 5
MM_ESS_AMMIDIIN: UInt32 = 6
MM_ESS_MIXER: UInt32 = 7
MM_ESS_AUX_CD: UInt32 = 8
MM_ESS_MPU401_MIDIOUT: UInt32 = 9
MM_ESS_MPU401_MIDIIN: UInt32 = 10
MM_ESS_ES488_WAVEOUT: UInt32 = 16
MM_ESS_ES488_WAVEIN: UInt32 = 17
MM_ESS_ES488_MIXER: UInt32 = 18
MM_ESS_ES688_WAVEOUT: UInt32 = 19
MM_ESS_ES688_WAVEIN: UInt32 = 20
MM_ESS_ES688_MIXER: UInt32 = 21
MM_ESS_ES1488_WAVEOUT: UInt32 = 22
MM_ESS_ES1488_WAVEIN: UInt32 = 23
MM_ESS_ES1488_MIXER: UInt32 = 24
MM_ESS_ES1688_WAVEOUT: UInt32 = 25
MM_ESS_ES1688_WAVEIN: UInt32 = 26
MM_ESS_ES1688_MIXER: UInt32 = 27
MM_ESS_ES1788_WAVEOUT: UInt32 = 28
MM_ESS_ES1788_WAVEIN: UInt32 = 29
MM_ESS_ES1788_MIXER: UInt32 = 30
MM_ESS_ES1888_WAVEOUT: UInt32 = 31
MM_ESS_ES1888_WAVEIN: UInt32 = 32
MM_ESS_ES1888_MIXER: UInt32 = 33
MM_ESS_ES1868_WAVEOUT: UInt32 = 34
MM_ESS_ES1868_WAVEIN: UInt32 = 35
MM_ESS_ES1868_MIXER: UInt32 = 36
MM_ESS_ES1878_WAVEOUT: UInt32 = 37
MM_ESS_ES1878_WAVEIN: UInt32 = 38
MM_ESS_ES1878_MIXER: UInt32 = 39
MM_CANOPUS_ACM_DVREX: UInt32 = 1
MM_EPS_FMSND: UInt32 = 1
MM_TRUEVISION_WAVEIN1: UInt32 = 1
MM_TRUEVISION_WAVEOUT1: UInt32 = 2
MM_AZTECH_MIDIOUT: UInt32 = 3
MM_AZTECH_MIDIIN: UInt32 = 4
MM_AZTECH_WAVEIN: UInt32 = 17
MM_AZTECH_WAVEOUT: UInt32 = 18
MM_AZTECH_FMSYNTH: UInt32 = 20
MM_AZTECH_MIXER: UInt32 = 21
MM_AZTECH_PRO16_WAVEIN: UInt32 = 33
MM_AZTECH_PRO16_WAVEOUT: UInt32 = 34
MM_AZTECH_PRO16_FMSYNTH: UInt32 = 38
MM_AZTECH_DSP16_WAVEIN: UInt32 = 65
MM_AZTECH_DSP16_WAVEOUT: UInt32 = 66
MM_AZTECH_DSP16_FMSYNTH: UInt32 = 68
MM_AZTECH_DSP16_WAVESYNTH: UInt32 = 70
MM_AZTECH_NOVA16_WAVEIN: UInt32 = 71
MM_AZTECH_NOVA16_WAVEOUT: UInt32 = 72
MM_AZTECH_NOVA16_MIXER: UInt32 = 73
MM_AZTECH_WASH16_WAVEIN: UInt32 = 74
MM_AZTECH_WASH16_WAVEOUT: UInt32 = 75
MM_AZTECH_WASH16_MIXER: UInt32 = 76
MM_AZTECH_AUX_CD: UInt32 = 401
MM_AZTECH_AUX_LINE: UInt32 = 402
MM_AZTECH_AUX_MIC: UInt32 = 403
MM_AZTECH_AUX: UInt32 = 404
MM_VIDEOLOGIC_MSWAVEIN: UInt32 = 1
MM_VIDEOLOGIC_MSWAVEOUT: UInt32 = 2
MM_KORG_PCIF_MIDIOUT: UInt32 = 1
MM_KORG_PCIF_MIDIIN: UInt32 = 2
MM_KORG_1212IO_MSWAVEIN: UInt32 = 3
MM_KORG_1212IO_MSWAVEOUT: UInt32 = 4
MM_APT_ACE100CD: UInt32 = 1
MM_ICS_WAVEDECK_WAVEOUT: UInt32 = 1
MM_ICS_WAVEDECK_WAVEIN: UInt32 = 2
MM_ICS_WAVEDECK_MIXER: UInt32 = 3
MM_ICS_WAVEDECK_AUX: UInt32 = 4
MM_ICS_WAVEDECK_SYNTH: UInt32 = 5
MM_ICS_WAVEDEC_SB_WAVEOUT: UInt32 = 6
MM_ICS_WAVEDEC_SB_WAVEIN: UInt32 = 7
MM_ICS_WAVEDEC_SB_FM_MIDIOUT: UInt32 = 8
MM_ICS_WAVEDEC_SB_MPU401_MIDIOUT: UInt32 = 9
MM_ICS_WAVEDEC_SB_MPU401_MIDIIN: UInt32 = 10
MM_ICS_WAVEDEC_SB_MIXER: UInt32 = 11
MM_ICS_WAVEDEC_SB_AUX: UInt32 = 12
MM_ICS_2115_LITE_MIDIOUT: UInt32 = 13
MM_ICS_2120_LITE_MIDIOUT: UInt32 = 14
MM_ITERATEDSYS_FUFCODEC: UInt32 = 1
MM_METHEUS_ZIPPER: UInt32 = 1
MM_WINNOV_CAVIAR_WAVEIN: UInt32 = 1
MM_WINNOV_CAVIAR_WAVEOUT: UInt32 = 2
MM_WINNOV_CAVIAR_VIDC: UInt32 = 3
MM_WINNOV_CAVIAR_CHAMPAGNE: UInt32 = 4
MM_WINNOV_CAVIAR_YUV8: UInt32 = 5
MM_NCR_BA_WAVEIN: UInt32 = 1
MM_NCR_BA_WAVEOUT: UInt32 = 2
MM_NCR_BA_SYNTH: UInt32 = 3
MM_NCR_BA_AUX: UInt32 = 4
MM_NCR_BA_MIXER: UInt32 = 5
MM_AST_MODEMWAVE_WAVEIN: UInt32 = 13
MM_AST_MODEMWAVE_WAVEOUT: UInt32 = 14
MM_WILLOWPOND_FMSYNTH_STEREO: UInt32 = 20
MM_WILLOWPOND_MPU401: UInt32 = 21
MM_WILLOWPOND_SNDPORT_WAVEIN: UInt32 = 100
MM_WILLOWPOND_SNDPORT_WAVEOUT: UInt32 = 101
MM_WILLOWPOND_SNDPORT_MIXER: UInt32 = 102
MM_WILLOWPOND_SNDPORT_AUX: UInt32 = 103
MM_WILLOWPOND_PH_WAVEIN: UInt32 = 104
MM_WILLOWPOND_PH_WAVEOUT: UInt32 = 105
MM_WILLOWPOND_PH_MIXER: UInt32 = 106
MM_WILLOWPOND_PH_AUX: UInt32 = 107
MM_WILLOPOND_SNDCOMM_WAVEIN: UInt32 = 108
MM_WILLOWPOND_SNDCOMM_WAVEOUT: UInt32 = 109
MM_WILLOWPOND_SNDCOMM_MIXER: UInt32 = 110
MM_WILLOWPOND_SNDCOMM_AUX: UInt32 = 111
MM_WILLOWPOND_GENERIC_WAVEIN: UInt32 = 112
MM_WILLOWPOND_GENERIC_WAVEOUT: UInt32 = 113
MM_WILLOWPOND_GENERIC_MIXER: UInt32 = 114
MM_WILLOWPOND_GENERIC_AUX: UInt32 = 115
MM_VITEC_VMAKER: UInt32 = 1
MM_VITEC_VMPRO: UInt32 = 2
MM_MOSCOM_VPC2400_IN: UInt32 = 1
MM_MOSCOM_VPC2400_OUT: UInt32 = 2
MM_SILICONSOFT_SC1_WAVEIN: UInt32 = 1
MM_SILICONSOFT_SC1_WAVEOUT: UInt32 = 2
MM_SILICONSOFT_SC2_WAVEIN: UInt32 = 3
MM_SILICONSOFT_SC2_WAVEOUT: UInt32 = 4
MM_SILICONSOFT_SOUNDJR2_WAVEOUT: UInt32 = 5
MM_SILICONSOFT_SOUNDJR2PR_WAVEIN: UInt32 = 6
MM_SILICONSOFT_SOUNDJR2PR_WAVEOUT: UInt32 = 7
MM_SILICONSOFT_SOUNDJR3_WAVEOUT: UInt32 = 8
MM_TTEWS_WAVEIN: UInt32 = 1
MM_TTEWS_WAVEOUT: UInt32 = 2
MM_TTEWS_MIDIIN: UInt32 = 3
MM_TTEWS_MIDIOUT: UInt32 = 4
MM_TTEWS_MIDISYNTH: UInt32 = 5
MM_TTEWS_MIDIMONITOR: UInt32 = 6
MM_TTEWS_VMIDIIN: UInt32 = 7
MM_TTEWS_VMIDIOUT: UInt32 = 8
MM_TTEWS_AUX: UInt32 = 9
MM_TTEWS_MIXER: UInt32 = 10
MM_MEDIASONIC_ACM_G723: UInt32 = 1
MM_MEDIASONIC_ICOM: UInt32 = 2
MM_ICOM_WAVEIN: UInt32 = 3
MM_ICOM_WAVEOUT: UInt32 = 4
MM_ICOM_MIXER: UInt32 = 5
MM_ICOM_AUX: UInt32 = 6
MM_ICOM_LINE: UInt32 = 7
MM_SANYO_ACM_LD_ADPCM: UInt32 = 1
MM_AHEAD_MULTISOUND: UInt32 = 1
MM_AHEAD_SOUNDBLASTER: UInt32 = 2
MM_AHEAD_PROAUDIO: UInt32 = 3
MM_AHEAD_GENERIC: UInt32 = 4
MM_OLIVETTI_WAVEIN: UInt32 = 1
MM_OLIVETTI_WAVEOUT: UInt32 = 2
MM_OLIVETTI_MIXER: UInt32 = 3
MM_OLIVETTI_AUX: UInt32 = 4
MM_OLIVETTI_MIDIIN: UInt32 = 5
MM_OLIVETTI_MIDIOUT: UInt32 = 6
MM_OLIVETTI_SYNTH: UInt32 = 7
MM_OLIVETTI_JOYSTICK: UInt32 = 8
MM_OLIVETTI_ACM_GSM: UInt32 = 9
MM_OLIVETTI_ACM_ADPCM: UInt32 = 10
MM_OLIVETTI_ACM_CELP: UInt32 = 11
MM_OLIVETTI_ACM_SBC: UInt32 = 12
MM_OLIVETTI_ACM_OPR: UInt32 = 13
MM_IOMAGIC_TEMPO_WAVEOUT: UInt32 = 1
MM_IOMAGIC_TEMPO_WAVEIN: UInt32 = 2
MM_IOMAGIC_TEMPO_SYNTH: UInt32 = 3
MM_IOMAGIC_TEMPO_MIDIOUT: UInt32 = 4
MM_IOMAGIC_TEMPO_MXDOUT: UInt32 = 5
MM_IOMAGIC_TEMPO_AUXOUT: UInt32 = 6
MM_MATSUSHITA_WAVEIN: UInt32 = 1
MM_MATSUSHITA_WAVEOUT: UInt32 = 2
MM_MATSUSHITA_FMSYNTH_STEREO: UInt32 = 3
MM_MATSUSHITA_MIXER: UInt32 = 4
MM_MATSUSHITA_AUX: UInt32 = 5
MM_NEWMEDIA_WAVJAMMER: UInt32 = 1
MM_LYRRUS_BRIDGE_GUITAR: UInt32 = 1
MM_OPTI_M16_FMSYNTH_STEREO: UInt32 = 1
MM_OPTI_M16_MIDIIN: UInt32 = 2
MM_OPTI_M16_MIDIOUT: UInt32 = 3
MM_OPTI_M16_WAVEIN: UInt32 = 4
MM_OPTI_M16_WAVEOUT: UInt32 = 5
MM_OPTI_M16_MIXER: UInt32 = 6
MM_OPTI_M16_AUX: UInt32 = 7
MM_OPTI_P16_FMSYNTH_STEREO: UInt32 = 16
MM_OPTI_P16_MIDIIN: UInt32 = 17
MM_OPTI_P16_MIDIOUT: UInt32 = 18
MM_OPTI_P16_WAVEIN: UInt32 = 19
MM_OPTI_P16_WAVEOUT: UInt32 = 20
MM_OPTI_P16_MIXER: UInt32 = 21
MM_OPTI_P16_AUX: UInt32 = 22
MM_OPTI_M32_WAVEIN: UInt32 = 32
MM_OPTI_M32_WAVEOUT: UInt32 = 33
MM_OPTI_M32_MIDIIN: UInt32 = 34
MM_OPTI_M32_MIDIOUT: UInt32 = 35
MM_OPTI_M32_SYNTH_STEREO: UInt32 = 36
MM_OPTI_M32_MIXER: UInt32 = 37
MM_OPTI_M32_AUX: UInt32 = 38
MM_COMPAQ_BB_WAVEIN: UInt32 = 1
MM_COMPAQ_BB_WAVEOUT: UInt32 = 2
MM_COMPAQ_BB_WAVEAUX: UInt32 = 3
MM_MPTUS_SPWAVEOUT: UInt32 = 1
MM_LERNOUT_ANDHAUSPIE_LHCODECACM: UInt32 = 1
MM_DIGITAL_AV320_WAVEIN: UInt32 = 1
MM_DIGITAL_AV320_WAVEOUT: UInt32 = 2
MM_DIGITAL_ACM_G723: UInt32 = 3
MM_DIGITAL_ICM_H263: UInt32 = 4
MM_DIGITAL_ICM_H261: UInt32 = 5
MM_MOTU_MTP_MIDIOUT_ALL: UInt32 = 100
MM_MOTU_MTP_MIDIIN_1: UInt32 = 101
MM_MOTU_MTP_MIDIOUT_1: UInt32 = 101
MM_MOTU_MTP_MIDIIN_2: UInt32 = 102
MM_MOTU_MTP_MIDIOUT_2: UInt32 = 102
MM_MOTU_MTP_MIDIIN_3: UInt32 = 103
MM_MOTU_MTP_MIDIOUT_3: UInt32 = 103
MM_MOTU_MTP_MIDIIN_4: UInt32 = 104
MM_MOTU_MTP_MIDIOUT_4: UInt32 = 104
MM_MOTU_MTP_MIDIIN_5: UInt32 = 105
MM_MOTU_MTP_MIDIOUT_5: UInt32 = 105
MM_MOTU_MTP_MIDIIN_6: UInt32 = 106
MM_MOTU_MTP_MIDIOUT_6: UInt32 = 106
MM_MOTU_MTP_MIDIIN_7: UInt32 = 107
MM_MOTU_MTP_MIDIOUT_7: UInt32 = 107
MM_MOTU_MTP_MIDIIN_8: UInt32 = 108
MM_MOTU_MTP_MIDIOUT_8: UInt32 = 108
MM_MOTU_MTPII_MIDIOUT_ALL: UInt32 = 200
MM_MOTU_MTPII_MIDIIN_SYNC: UInt32 = 200
MM_MOTU_MTPII_MIDIIN_1: UInt32 = 201
MM_MOTU_MTPII_MIDIOUT_1: UInt32 = 201
MM_MOTU_MTPII_MIDIIN_2: UInt32 = 202
MM_MOTU_MTPII_MIDIOUT_2: UInt32 = 202
MM_MOTU_MTPII_MIDIIN_3: UInt32 = 203
MM_MOTU_MTPII_MIDIOUT_3: UInt32 = 203
MM_MOTU_MTPII_MIDIIN_4: UInt32 = 204
MM_MOTU_MTPII_MIDIOUT_4: UInt32 = 204
MM_MOTU_MTPII_MIDIIN_5: UInt32 = 205
MM_MOTU_MTPII_MIDIOUT_5: UInt32 = 205
MM_MOTU_MTPII_MIDIIN_6: UInt32 = 206
MM_MOTU_MTPII_MIDIOUT_6: UInt32 = 206
MM_MOTU_MTPII_MIDIIN_7: UInt32 = 207
MM_MOTU_MTPII_MIDIOUT_7: UInt32 = 207
MM_MOTU_MTPII_MIDIIN_8: UInt32 = 208
MM_MOTU_MTPII_MIDIOUT_8: UInt32 = 208
MM_MOTU_MTPII_NET_MIDIIN_1: UInt32 = 209
MM_MOTU_MTPII_NET_MIDIOUT_1: UInt32 = 209
MM_MOTU_MTPII_NET_MIDIIN_2: UInt32 = 210
MM_MOTU_MTPII_NET_MIDIOUT_2: UInt32 = 210
MM_MOTU_MTPII_NET_MIDIIN_3: UInt32 = 211
MM_MOTU_MTPII_NET_MIDIOUT_3: UInt32 = 211
MM_MOTU_MTPII_NET_MIDIIN_4: UInt32 = 212
MM_MOTU_MTPII_NET_MIDIOUT_4: UInt32 = 212
MM_MOTU_MTPII_NET_MIDIIN_5: UInt32 = 213
MM_MOTU_MTPII_NET_MIDIOUT_5: UInt32 = 213
MM_MOTU_MTPII_NET_MIDIIN_6: UInt32 = 214
MM_MOTU_MTPII_NET_MIDIOUT_6: UInt32 = 214
MM_MOTU_MTPII_NET_MIDIIN_7: UInt32 = 215
MM_MOTU_MTPII_NET_MIDIOUT_7: UInt32 = 215
MM_MOTU_MTPII_NET_MIDIIN_8: UInt32 = 216
MM_MOTU_MTPII_NET_MIDIOUT_8: UInt32 = 216
MM_MOTU_MXP_MIDIIN_MIDIOUT_ALL: UInt32 = 300
MM_MOTU_MXP_MIDIIN_SYNC: UInt32 = 300
MM_MOTU_MXP_MIDIIN_MIDIIN_1: UInt32 = 301
MM_MOTU_MXP_MIDIIN_MIDIOUT_1: UInt32 = 301
MM_MOTU_MXP_MIDIIN_MIDIIN_2: UInt32 = 302
MM_MOTU_MXP_MIDIIN_MIDIOUT_2: UInt32 = 302
MM_MOTU_MXP_MIDIIN_MIDIIN_3: UInt32 = 303
MM_MOTU_MXP_MIDIIN_MIDIOUT_3: UInt32 = 303
MM_MOTU_MXP_MIDIIN_MIDIIN_4: UInt32 = 304
MM_MOTU_MXP_MIDIIN_MIDIOUT_4: UInt32 = 304
MM_MOTU_MXP_MIDIIN_MIDIIN_5: UInt32 = 305
MM_MOTU_MXP_MIDIIN_MIDIOUT_5: UInt32 = 305
MM_MOTU_MXP_MIDIIN_MIDIIN_6: UInt32 = 306
MM_MOTU_MXP_MIDIIN_MIDIOUT_6: UInt32 = 306
MM_MOTU_MXPMPU_MIDIOUT_ALL: UInt32 = 400
MM_MOTU_MXPMPU_MIDIIN_SYNC: UInt32 = 400
MM_MOTU_MXPMPU_MIDIIN_1: UInt32 = 401
MM_MOTU_MXPMPU_MIDIOUT_1: UInt32 = 401
MM_MOTU_MXPMPU_MIDIIN_2: UInt32 = 402
MM_MOTU_MXPMPU_MIDIOUT_2: UInt32 = 402
MM_MOTU_MXPMPU_MIDIIN_3: UInt32 = 403
MM_MOTU_MXPMPU_MIDIOUT_3: UInt32 = 403
MM_MOTU_MXPMPU_MIDIIN_4: UInt32 = 404
MM_MOTU_MXPMPU_MIDIOUT_4: UInt32 = 404
MM_MOTU_MXPMPU_MIDIIN_5: UInt32 = 405
MM_MOTU_MXPMPU_MIDIOUT_5: UInt32 = 405
MM_MOTU_MXPMPU_MIDIIN_6: UInt32 = 406
MM_MOTU_MXPMPU_MIDIOUT_6: UInt32 = 406
MM_MOTU_MXN_MIDIOUT_ALL: UInt32 = 500
MM_MOTU_MXN_MIDIIN_SYNC: UInt32 = 500
MM_MOTU_MXN_MIDIIN_1: UInt32 = 501
MM_MOTU_MXN_MIDIOUT_1: UInt32 = 501
MM_MOTU_MXN_MIDIIN_2: UInt32 = 502
MM_MOTU_MXN_MIDIOUT_2: UInt32 = 502
MM_MOTU_MXN_MIDIIN_3: UInt32 = 503
MM_MOTU_MXN_MIDIOUT_3: UInt32 = 503
MM_MOTU_MXN_MIDIIN_4: UInt32 = 504
MM_MOTU_MXN_MIDIOUT_4: UInt32 = 504
MM_MOTU_FLYER_MIDI_IN_SYNC: UInt32 = 600
MM_MOTU_FLYER_MIDI_IN_A: UInt32 = 601
MM_MOTU_FLYER_MIDI_OUT_A: UInt32 = 601
MM_MOTU_FLYER_MIDI_IN_B: UInt32 = 602
MM_MOTU_FLYER_MIDI_OUT_B: UInt32 = 602
MM_MOTU_PKX_MIDI_IN_SYNC: UInt32 = 700
MM_MOTU_PKX_MIDI_IN_A: UInt32 = 701
MM_MOTU_PKX_MIDI_OUT_A: UInt32 = 701
MM_MOTU_PKX_MIDI_IN_B: UInt32 = 702
MM_MOTU_PKX_MIDI_OUT_B: UInt32 = 702
MM_MOTU_DTX_MIDI_IN_SYNC: UInt32 = 800
MM_MOTU_DTX_MIDI_IN_A: UInt32 = 801
MM_MOTU_DTX_MIDI_OUT_A: UInt32 = 801
MM_MOTU_DTX_MIDI_IN_B: UInt32 = 802
MM_MOTU_DTX_MIDI_OUT_B: UInt32 = 802
MM_MOTU_MTPAV_MIDIOUT_ALL: UInt32 = 900
MM_MOTU_MTPAV_MIDIIN_SYNC: UInt32 = 900
MM_MOTU_MTPAV_MIDIIN_1: UInt32 = 901
MM_MOTU_MTPAV_MIDIOUT_1: UInt32 = 901
MM_MOTU_MTPAV_MIDIIN_2: UInt32 = 902
MM_MOTU_MTPAV_MIDIOUT_2: UInt32 = 902
MM_MOTU_MTPAV_MIDIIN_3: UInt32 = 903
MM_MOTU_MTPAV_MIDIOUT_3: UInt32 = 903
MM_MOTU_MTPAV_MIDIIN_4: UInt32 = 904
MM_MOTU_MTPAV_MIDIOUT_4: UInt32 = 904
MM_MOTU_MTPAV_MIDIIN_5: UInt32 = 905
MM_MOTU_MTPAV_MIDIOUT_5: UInt32 = 905
MM_MOTU_MTPAV_MIDIIN_6: UInt32 = 906
MM_MOTU_MTPAV_MIDIOUT_6: UInt32 = 906
MM_MOTU_MTPAV_MIDIIN_7: UInt32 = 907
MM_MOTU_MTPAV_MIDIOUT_7: UInt32 = 907
MM_MOTU_MTPAV_MIDIIN_8: UInt32 = 908
MM_MOTU_MTPAV_MIDIOUT_8: UInt32 = 908
MM_MOTU_MTPAV_NET_MIDIIN_1: UInt32 = 909
MM_MOTU_MTPAV_NET_MIDIOUT_1: UInt32 = 909
MM_MOTU_MTPAV_NET_MIDIIN_2: UInt32 = 910
MM_MOTU_MTPAV_NET_MIDIOUT_2: UInt32 = 910
MM_MOTU_MTPAV_NET_MIDIIN_3: UInt32 = 911
MM_MOTU_MTPAV_NET_MIDIOUT_3: UInt32 = 911
MM_MOTU_MTPAV_NET_MIDIIN_4: UInt32 = 912
MM_MOTU_MTPAV_NET_MIDIOUT_4: UInt32 = 912
MM_MOTU_MTPAV_NET_MIDIIN_5: UInt32 = 913
MM_MOTU_MTPAV_NET_MIDIOUT_5: UInt32 = 913
MM_MOTU_MTPAV_NET_MIDIIN_6: UInt32 = 914
MM_MOTU_MTPAV_NET_MIDIOUT_6: UInt32 = 914
MM_MOTU_MTPAV_NET_MIDIIN_7: UInt32 = 915
MM_MOTU_MTPAV_NET_MIDIOUT_7: UInt32 = 915
MM_MOTU_MTPAV_NET_MIDIIN_8: UInt32 = 916
MM_MOTU_MTPAV_NET_MIDIOUT_8: UInt32 = 916
MM_MOTU_MTPAV_MIDIIN_ADAT: UInt32 = 917
MM_MOTU_MTPAV_MIDIOUT_ADAT: UInt32 = 917
MM_MOTU_MXPXT_MIDIIN_SYNC: UInt32 = 1000
MM_MOTU_MXPXT_MIDIOUT_ALL: UInt32 = 1000
MM_MOTU_MXPXT_MIDIIN_1: UInt32 = 1001
MM_MOTU_MXPXT_MIDIOUT_1: UInt32 = 1001
MM_MOTU_MXPXT_MIDIOUT_2: UInt32 = 1002
MM_MOTU_MXPXT_MIDIIN_2: UInt32 = 1002
MM_MOTU_MXPXT_MIDIIN_3: UInt32 = 1003
MM_MOTU_MXPXT_MIDIOUT_3: UInt32 = 1003
MM_MOTU_MXPXT_MIDIIN_4: UInt32 = 1004
MM_MOTU_MXPXT_MIDIOUT_4: UInt32 = 1004
MM_MOTU_MXPXT_MIDIIN_5: UInt32 = 1005
MM_MOTU_MXPXT_MIDIOUT_5: UInt32 = 1005
MM_MOTU_MXPXT_MIDIOUT_6: UInt32 = 1006
MM_MOTU_MXPXT_MIDIIN_6: UInt32 = 1006
MM_MOTU_MXPXT_MIDIOUT_7: UInt32 = 1007
MM_MOTU_MXPXT_MIDIIN_7: UInt32 = 1007
MM_MOTU_MXPXT_MIDIOUT_8: UInt32 = 1008
MM_MOTU_MXPXT_MIDIIN_8: UInt32 = 1008
MM_WORKBIT_MIXER: UInt32 = 1
MM_WORKBIT_WAVEOUT: UInt32 = 2
MM_WORKBIT_WAVEIN: UInt32 = 3
MM_WORKBIT_MIDIIN: UInt32 = 4
MM_WORKBIT_MIDIOUT: UInt32 = 5
MM_WORKBIT_FMSYNTH: UInt32 = 6
MM_WORKBIT_AUX: UInt32 = 7
MM_WORKBIT_JOYSTICK: UInt32 = 8
MM_OSITECH_TRUMPCARD: UInt32 = 1
MM_MIRO_MOVIEPRO: UInt32 = 1
MM_MIRO_VIDEOD1: UInt32 = 2
MM_MIRO_VIDEODC1TV: UInt32 = 3
MM_MIRO_VIDEOTD: UInt32 = 4
MM_MIRO_DC30_WAVEOUT: UInt32 = 5
MM_MIRO_DC30_WAVEIN: UInt32 = 6
MM_MIRO_DC30_MIX: UInt32 = 7
MM_ISOLUTION_PASCAL: UInt32 = 1
MM_VOICEMIXER: UInt32 = 1
ROCKWELL_WA1_WAVEIN: UInt32 = 100
ROCKWELL_WA1_WAVEOUT: UInt32 = 101
ROCKWELL_WA1_SYNTH: UInt32 = 102
ROCKWELL_WA1_MIXER: UInt32 = 103
ROCKWELL_WA1_MPU401_IN: UInt32 = 104
ROCKWELL_WA1_MPU401_OUT: UInt32 = 105
ROCKWELL_WA2_WAVEIN: UInt32 = 200
ROCKWELL_WA2_WAVEOUT: UInt32 = 201
ROCKWELL_WA2_SYNTH: UInt32 = 202
ROCKWELL_WA2_MIXER: UInt32 = 203
ROCKWELL_WA2_MPU401_IN: UInt32 = 204
ROCKWELL_WA2_MPU401_OUT: UInt32 = 205
MM_VOXWARE_CODEC: UInt32 = 1
MM_NORTEL_MPXAC_WAVEIN: UInt32 = 1
MM_NORTEL_MPXAC_WAVEOUT: UInt32 = 2
MM_ADDX_PCTV_DIGITALMIX: UInt32 = 1
MM_ADDX_PCTV_WAVEIN: UInt32 = 2
MM_ADDX_PCTV_WAVEOUT: UInt32 = 3
MM_ADDX_PCTV_MIXER: UInt32 = 4
MM_ADDX_PCTV_AUX_CD: UInt32 = 5
MM_ADDX_PCTV_AUX_LINE: UInt32 = 6
MM_WILDCAT_AUTOSCOREMIDIIN: UInt32 = 1
MM_RHETOREX_WAVEIN: UInt32 = 1
MM_RHETOREX_WAVEOUT: UInt32 = 2
MM_BTV_WAVEIN: UInt32 = 1
MM_BTV_WAVEOUT: UInt32 = 2
MM_BTV_MIDIIN: UInt32 = 3
MM_BTV_MIDIOUT: UInt32 = 4
MM_BTV_MIDISYNTH: UInt32 = 5
MM_BTV_AUX_LINE: UInt32 = 6
MM_BTV_AUX_MIC: UInt32 = 7
MM_BTV_AUX_CD: UInt32 = 8
MM_BTV_DIGITALIN: UInt32 = 9
MM_BTV_DIGITALOUT: UInt32 = 10
MM_BTV_MIDIWAVESTREAM: UInt32 = 11
MM_BTV_MIXER: UInt32 = 12
MM_ENSONIQ_SOUNDSCAPE: UInt32 = 16
MM_SOUNDSCAPE_WAVEOUT: UInt32 = 17
MM_SOUNDSCAPE_WAVEOUT_AUX: UInt32 = 18
MM_SOUNDSCAPE_WAVEIN: UInt32 = 19
MM_SOUNDSCAPE_MIDIOUT: UInt32 = 20
MM_SOUNDSCAPE_MIDIIN: UInt32 = 21
MM_SOUNDSCAPE_SYNTH: UInt32 = 22
MM_SOUNDSCAPE_MIXER: UInt32 = 23
MM_SOUNDSCAPE_AUX: UInt32 = 24
MM_NVIDIA_WAVEOUT: UInt32 = 1
MM_NVIDIA_WAVEIN: UInt32 = 2
MM_NVIDIA_MIDIOUT: UInt32 = 3
MM_NVIDIA_MIDIIN: UInt32 = 4
MM_NVIDIA_GAMEPORT: UInt32 = 5
MM_NVIDIA_MIXER: UInt32 = 6
MM_NVIDIA_AUX: UInt32 = 7
MM_OKSORI_BASE: UInt32 = 0
MM_OKSORI_OSR8_WAVEOUT: UInt32 = 1
MM_OKSORI_OSR8_WAVEIN: UInt32 = 2
MM_OKSORI_OSR16_WAVEOUT: UInt32 = 3
MM_OKSORI_OSR16_WAVEIN: UInt32 = 4
MM_OKSORI_FM_OPL4: UInt32 = 5
MM_OKSORI_MIX_MASTER: UInt32 = 6
MM_OKSORI_MIX_WAVE: UInt32 = 7
MM_OKSORI_MIX_FM: UInt32 = 8
MM_OKSORI_MIX_LINE: UInt32 = 9
MM_OKSORI_MIX_CD: UInt32 = 10
MM_OKSORI_MIX_MIC: UInt32 = 11
MM_OKSORI_MIX_ECHO: UInt32 = 12
MM_OKSORI_MIX_AUX1: UInt32 = 13
MM_OKSORI_MIX_LINE1: UInt32 = 14
MM_OKSORI_EXT_MIC1: UInt32 = 15
MM_OKSORI_EXT_MIC2: UInt32 = 16
MM_OKSORI_MIDIOUT: UInt32 = 17
MM_OKSORI_MIDIIN: UInt32 = 18
MM_OKSORI_MPEG_CDVISION: UInt32 = 19
MM_DIACOUSTICS_DRUM_ACTION: UInt32 = 1
MM_KAY_ELEMETRICS_CSL: UInt32 = 17152
MM_KAY_ELEMETRICS_CSL_DAT: UInt32 = 17160
MM_KAY_ELEMETRICS_CSL_4CHANNEL: UInt32 = 17161
MM_CRYSTAL_CS4232_WAVEIN: UInt32 = 1
MM_CRYSTAL_CS4232_WAVEOUT: UInt32 = 2
MM_CRYSTAL_CS4232_WAVEMIXER: UInt32 = 3
MM_CRYSTAL_CS4232_WAVEAUX_AUX1: UInt32 = 4
MM_CRYSTAL_CS4232_WAVEAUX_AUX2: UInt32 = 5
MM_CRYSTAL_CS4232_WAVEAUX_LINE: UInt32 = 6
MM_CRYSTAL_CS4232_WAVEAUX_MONO: UInt32 = 7
MM_CRYSTAL_CS4232_WAVEAUX_MASTER: UInt32 = 8
MM_CRYSTAL_CS4232_MIDIIN: UInt32 = 9
MM_CRYSTAL_CS4232_MIDIOUT: UInt32 = 10
MM_CRYSTAL_CS4232_INPUTGAIN_AUX1: UInt32 = 13
MM_CRYSTAL_CS4232_INPUTGAIN_LOOP: UInt32 = 14
MM_CRYSTAL_SOUND_FUSION_WAVEIN: UInt32 = 21
MM_CRYSTAL_SOUND_FUSION_WAVEOUT: UInt32 = 22
MM_CRYSTAL_SOUND_FUSION_MIXER: UInt32 = 23
MM_CRYSTAL_SOUND_FUSION_MIDIIN: UInt32 = 24
MM_CRYSTAL_SOUND_FUSION_MIDIOUT: UInt32 = 25
MM_CRYSTAL_SOUND_FUSION_JOYSTICK: UInt32 = 26
MM_QUARTERDECK_LHWAVEIN: UInt32 = 0
MM_QUARTERDECK_LHWAVEOUT: UInt32 = 1
MM_TDK_MW_MIDI_SYNTH: UInt32 = 1
MM_TDK_MW_MIDI_IN: UInt32 = 2
MM_TDK_MW_MIDI_OUT: UInt32 = 3
MM_TDK_MW_WAVE_IN: UInt32 = 4
MM_TDK_MW_WAVE_OUT: UInt32 = 5
MM_TDK_MW_AUX: UInt32 = 6
MM_TDK_MW_MIXER: UInt32 = 10
MM_TDK_MW_AUX_MASTER: UInt32 = 100
MM_TDK_MW_AUX_BASS: UInt32 = 101
MM_TDK_MW_AUX_TREBLE: UInt32 = 102
MM_TDK_MW_AUX_MIDI_VOL: UInt32 = 103
MM_TDK_MW_AUX_WAVE_VOL: UInt32 = 104
MM_TDK_MW_AUX_WAVE_RVB: UInt32 = 105
MM_TDK_MW_AUX_WAVE_CHR: UInt32 = 106
MM_TDK_MW_AUX_VOL: UInt32 = 107
MM_TDK_MW_AUX_RVB: UInt32 = 108
MM_TDK_MW_AUX_CHR: UInt32 = 109
MM_DIGITAL_AUDIO_LABS_TC: UInt32 = 1
MM_DIGITAL_AUDIO_LABS_DOC: UInt32 = 2
MM_DIGITAL_AUDIO_LABS_V8: UInt32 = 16
MM_DIGITAL_AUDIO_LABS_CPRO: UInt32 = 17
MM_DIGITAL_AUDIO_LABS_VP: UInt32 = 18
MM_DIGITAL_AUDIO_LABS_CDLX: UInt32 = 19
MM_DIGITAL_AUDIO_LABS_CTDIF: UInt32 = 20
MM_SEERSYS_SEERSYNTH: UInt32 = 1
MM_SEERSYS_SEERWAVE: UInt32 = 2
MM_SEERSYS_SEERMIX: UInt32 = 3
MM_SEERSYS_WAVESYNTH: UInt32 = 4
MM_SEERSYS_WAVESYNTH_WG: UInt32 = 5
MM_SEERSYS_REALITY: UInt32 = 6
MM_OSPREY_1000WAVEIN: UInt32 = 1
MM_OSPREY_1000WAVEOUT: UInt32 = 2
MM_SOUNDESIGNS_WAVEIN: UInt32 = 1
MM_SOUNDESIGNS_WAVEOUT: UInt32 = 2
MM_SSP_SNDFESWAVEIN: UInt32 = 1
MM_SSP_SNDFESWAVEOUT: UInt32 = 2
MM_SSP_SNDFESMIDIIN: UInt32 = 3
MM_SSP_SNDFESMIDIOUT: UInt32 = 4
MM_SSP_SNDFESSYNTH: UInt32 = 5
MM_SSP_SNDFESMIX: UInt32 = 6
MM_SSP_SNDFESAUX: UInt32 = 7
MM_ECS_AADF_MIDI_IN: UInt32 = 10
MM_ECS_AADF_MIDI_OUT: UInt32 = 11
MM_ECS_AADF_WAVE2MIDI_IN: UInt32 = 12
MM_AMD_INTERWAVE_WAVEIN: UInt32 = 1
MM_AMD_INTERWAVE_WAVEOUT: UInt32 = 2
MM_AMD_INTERWAVE_SYNTH: UInt32 = 3
MM_AMD_INTERWAVE_MIXER1: UInt32 = 4
MM_AMD_INTERWAVE_MIXER2: UInt32 = 5
MM_AMD_INTERWAVE_JOYSTICK: UInt32 = 6
MM_AMD_INTERWAVE_EX_CD: UInt32 = 7
MM_AMD_INTERWAVE_MIDIIN: UInt32 = 8
MM_AMD_INTERWAVE_MIDIOUT: UInt32 = 9
MM_AMD_INTERWAVE_AUX1: UInt32 = 10
MM_AMD_INTERWAVE_AUX2: UInt32 = 11
MM_AMD_INTERWAVE_AUX_MIC: UInt32 = 12
MM_AMD_INTERWAVE_AUX_CD: UInt32 = 13
MM_AMD_INTERWAVE_MONO_IN: UInt32 = 14
MM_AMD_INTERWAVE_MONO_OUT: UInt32 = 15
MM_AMD_INTERWAVE_EX_TELEPHONY: UInt32 = 16
MM_AMD_INTERWAVE_WAVEOUT_BASE: UInt32 = 17
MM_AMD_INTERWAVE_WAVEOUT_TREBLE: UInt32 = 18
MM_AMD_INTERWAVE_STEREO_ENHANCED: UInt32 = 19
MM_COREDYNAMICS_DYNAMIXHR: UInt32 = 1
MM_COREDYNAMICS_DYNASONIX_SYNTH: UInt32 = 2
MM_COREDYNAMICS_DYNASONIX_MIDI_IN: UInt32 = 3
MM_COREDYNAMICS_DYNASONIX_MIDI_OUT: UInt32 = 4
MM_COREDYNAMICS_DYNASONIX_WAVE_IN: UInt32 = 5
MM_COREDYNAMICS_DYNASONIX_WAVE_OUT: UInt32 = 6
MM_COREDYNAMICS_DYNASONIX_AUDIO_IN: UInt32 = 7
MM_COREDYNAMICS_DYNASONIX_AUDIO_OUT: UInt32 = 8
MM_COREDYNAMICS_DYNAGRAFX_VGA: UInt32 = 9
MM_COREDYNAMICS_DYNAGRAFX_WAVE_IN: UInt32 = 10
MM_COREDYNAMICS_DYNAGRAFX_WAVE_OUT: UInt32 = 11
MM_CANAM_CBXWAVEOUT: UInt32 = 1
MM_CANAM_CBXWAVEIN: UInt32 = 2
MM_SOFTSOUND_CODEC: UInt32 = 1
MM_NORRIS_VOICELINK: UInt32 = 1
MM_DDD_MIDILINK_MIDIIN: UInt32 = 1
MM_DDD_MIDILINK_MIDIOUT: UInt32 = 2
MM_EUPHONICS_AUX_CD: UInt32 = 1
MM_EUPHONICS_AUX_LINE: UInt32 = 2
MM_EUPHONICS_AUX_MASTER: UInt32 = 3
MM_EUPHONICS_AUX_MIC: UInt32 = 4
MM_EUPHONICS_AUX_MIDI: UInt32 = 5
MM_EUPHONICS_AUX_WAVE: UInt32 = 6
MM_EUPHONICS_FMSYNTH_MONO: UInt32 = 7
MM_EUPHONICS_FMSYNTH_STEREO: UInt32 = 8
MM_EUPHONICS_MIDIIN: UInt32 = 9
MM_EUPHONICS_MIDIOUT: UInt32 = 10
MM_EUPHONICS_MIXER: UInt32 = 11
MM_EUPHONICS_WAVEIN: UInt32 = 12
MM_EUPHONICS_WAVEOUT: UInt32 = 13
MM_EUPHONICS_EUSYNTH: UInt32 = 14
CRYSTAL_NET_SFM_CODEC: UInt32 = 1
MM_CHROMATIC_M1: UInt32 = 1
MM_CHROMATIC_M1_WAVEIN: UInt32 = 2
MM_CHROMATIC_M1_WAVEOUT: UInt32 = 3
MM_CHROMATIC_M1_FMSYNTH: UInt32 = 4
MM_CHROMATIC_M1_MIXER: UInt32 = 5
MM_CHROMATIC_M1_AUX: UInt32 = 6
MM_CHROMATIC_M1_AUX_CD: UInt32 = 7
MM_CHROMATIC_M1_MIDIIN: UInt32 = 8
MM_CHROMATIC_M1_MIDIOUT: UInt32 = 9
MM_CHROMATIC_M1_WTSYNTH: UInt32 = 16
MM_CHROMATIC_M1_MPEGWAVEIN: UInt32 = 17
MM_CHROMATIC_M1_MPEGWAVEOUT: UInt32 = 18
MM_CHROMATIC_M2: UInt32 = 19
MM_CHROMATIC_M2_WAVEIN: UInt32 = 20
MM_CHROMATIC_M2_WAVEOUT: UInt32 = 21
MM_CHROMATIC_M2_FMSYNTH: UInt32 = 22
MM_CHROMATIC_M2_MIXER: UInt32 = 23
MM_CHROMATIC_M2_AUX: UInt32 = 24
MM_CHROMATIC_M2_AUX_CD: UInt32 = 25
MM_CHROMATIC_M2_MIDIIN: UInt32 = 32
MM_CHROMATIC_M2_MIDIOUT: UInt32 = 33
MM_CHROMATIC_M2_WTSYNTH: UInt32 = 34
MM_CHROMATIC_M2_MPEGWAVEIN: UInt32 = 35
MM_CHROMATIC_M2_MPEGWAVEOUT: UInt32 = 36
MM_VIENNASYS_TSP_WAVE_DRIVER: UInt32 = 1
MM_CONNECTIX_VIDEC_CODEC: UInt32 = 1
MM_GADGETLABS_WAVE44_WAVEIN: UInt32 = 1
MM_GADGETLABS_WAVE44_WAVEOUT: UInt32 = 2
MM_GADGETLABS_WAVE42_WAVEIN: UInt32 = 3
MM_GADGETLABS_WAVE42_WAVEOUT: UInt32 = 4
MM_GADGETLABS_WAVE4_MIDIIN: UInt32 = 5
MM_GADGETLABS_WAVE4_MIDIOUT: UInt32 = 6
MM_FRONTIER_WAVECENTER_MIDIIN: UInt32 = 1
MM_FRONTIER_WAVECENTER_MIDIOUT: UInt32 = 2
MM_FRONTIER_WAVECENTER_WAVEIN: UInt32 = 3
MM_FRONTIER_WAVECENTER_WAVEOUT: UInt32 = 4
MM_VIONA_QVINPCI_MIXER: UInt32 = 1
MM_VIONA_QVINPCI_WAVEIN: UInt32 = 2
MM_VIONAQVINPCI_WAVEOUT: UInt32 = 3
MM_VIONA_BUSTER_MIXER: UInt32 = 4
MM_VIONA_CINEMASTER_MIXER: UInt32 = 5
MM_VIONA_CONCERTO_MIXER: UInt32 = 6
MM_CASIO_WP150_MIDIOUT: UInt32 = 1
MM_CASIO_WP150_MIDIIN: UInt32 = 2
MM_CASIO_LSG_MIDIOUT: UInt32 = 3
MM_DIMD_PLATFORM: UInt32 = 0
MM_DIMD_DIRSOUND: UInt32 = 1
MM_DIMD_VIRTMPU: UInt32 = 2
MM_DIMD_VIRTSB: UInt32 = 3
MM_DIMD_VIRTJOY: UInt32 = 4
MM_DIMD_WAVEIN: UInt32 = 5
MM_DIMD_WAVEOUT: UInt32 = 6
MM_DIMD_MIDIIN: UInt32 = 7
MM_DIMD_MIDIOUT: UInt32 = 8
MM_DIMD_AUX_LINE: UInt32 = 9
MM_DIMD_MIXER: UInt32 = 10
MM_DIMD_WSS_WAVEIN: UInt32 = 14
MM_DIMD_WSS_WAVEOUT: UInt32 = 15
MM_DIMD_WSS_MIXER: UInt32 = 17
MM_DIMD_WSS_AUX: UInt32 = 21
MM_DIMD_WSS_SYNTH: UInt32 = 76
MM_S3_WAVEOUT: UInt32 = 1
MM_S3_WAVEIN: UInt32 = 2
MM_S3_MIDIOUT: UInt32 = 3
MM_S3_MIDIIN: UInt32 = 4
MM_S3_FMSYNTH: UInt32 = 5
MM_S3_MIXER: UInt32 = 6
MM_S3_AUX: UInt32 = 7
MM_VKC_MPU401_MIDIIN: UInt32 = 256
MM_VKC_SERIAL_MIDIIN: UInt32 = 257
MM_VKC_MPU401_MIDIOUT: UInt32 = 512
MM_VKC_SERIAL_MIDIOUT: UInt32 = 513
MM_ZEFIRO_ZA2: UInt32 = 2
MM_FHGIIS_MPEGLAYER3_DECODE: UInt32 = 9
MM_FHGIIS_MPEGLAYER3: UInt32 = 10
MM_FHGIIS_MPEGLAYER3_LITE: UInt32 = 10
MM_FHGIIS_MPEGLAYER3_BASIC: UInt32 = 11
MM_FHGIIS_MPEGLAYER3_ADVANCED: UInt32 = 12
MM_FHGIIS_MPEGLAYER3_PROFESSIONAL: UInt32 = 13
MM_FHGIIS_MPEGLAYER3_ADVANCEDPLUS: UInt32 = 14
MM_QUICKNET_PJWAVEIN: UInt32 = 1
MM_QUICKNET_PJWAVEOUT: UInt32 = 2
MM_SICRESOURCE_SSO3D: UInt32 = 2
MM_SICRESOURCE_SSOW3DI: UInt32 = 3
MM_NEOMAGIC_SYNTH: UInt32 = 1
MM_NEOMAGIC_WAVEOUT: UInt32 = 2
MM_NEOMAGIC_WAVEIN: UInt32 = 3
MM_NEOMAGIC_MIDIOUT: UInt32 = 4
MM_NEOMAGIC_MIDIIN: UInt32 = 5
MM_NEOMAGIC_AUX: UInt32 = 6
MM_NEOMAGIC_MW3DX_WAVEOUT: UInt32 = 10
MM_NEOMAGIC_MW3DX_WAVEIN: UInt32 = 11
MM_NEOMAGIC_MW3DX_MIDIOUT: UInt32 = 12
MM_NEOMAGIC_MW3DX_MIDIIN: UInt32 = 13
MM_NEOMAGIC_MW3DX_FMSYNTH: UInt32 = 14
MM_NEOMAGIC_MW3DX_GMSYNTH: UInt32 = 15
MM_NEOMAGIC_MW3DX_MIXER: UInt32 = 16
MM_NEOMAGIC_MW3DX_AUX: UInt32 = 17
MM_NEOMAGIC_MWAVE_WAVEOUT: UInt32 = 20
MM_NEOMAGIC_MWAVE_WAVEIN: UInt32 = 21
MM_NEOMAGIC_MWAVE_MIDIOUT: UInt32 = 22
MM_NEOMAGIC_MWAVE_MIDIIN: UInt32 = 23
MM_NEOMAGIC_MWAVE_MIXER: UInt32 = 24
MM_NEOMAGIC_MWAVE_AUX: UInt32 = 25
MM_MERGING_MPEGL3: UInt32 = 1
MM_XIRLINK_VISIONLINK: UInt32 = 1
MM_OTI_611WAVEIN: UInt32 = 5
MM_OTI_611WAVEOUT: UInt32 = 6
MM_OTI_611MIXER: UInt32 = 7
MM_OTI_611MIDIN: UInt32 = 18
MM_OTI_611MIDIOUT: UInt32 = 19
MM_AUREAL_AU8820: UInt32 = 16
MM_AU8820_SYNTH: UInt32 = 17
MM_AU8820_WAVEOUT: UInt32 = 18
MM_AU8820_WAVEIN: UInt32 = 19
MM_AU8820_MIXER: UInt32 = 20
MM_AU8820_AUX: UInt32 = 21
MM_AU8820_MIDIOUT: UInt32 = 22
MM_AU8820_MIDIIN: UInt32 = 23
MM_AUREAL_AU8830: UInt32 = 32
MM_AU8830_SYNTH: UInt32 = 33
MM_AU8830_WAVEOUT: UInt32 = 34
MM_AU8830_WAVEIN: UInt32 = 35
MM_AU8830_MIXER: UInt32 = 36
MM_AU8830_AUX: UInt32 = 37
MM_AU8830_MIDIOUT: UInt32 = 38
MM_AU8830_MIDIIN: UInt32 = 39
MM_VIVO_AUDIO_CODEC: UInt32 = 1
MM_SHARP_MDC_MIDI_SYNTH: UInt32 = 1
MM_SHARP_MDC_MIDI_IN: UInt32 = 2
MM_SHARP_MDC_MIDI_OUT: UInt32 = 3
MM_SHARP_MDC_WAVE_IN: UInt32 = 4
MM_SHARP_MDC_WAVE_OUT: UInt32 = 5
MM_SHARP_MDC_AUX: UInt32 = 6
MM_SHARP_MDC_MIXER: UInt32 = 10
MM_SHARP_MDC_AUX_MASTER: UInt32 = 100
MM_SHARP_MDC_AUX_BASS: UInt32 = 101
MM_SHARP_MDC_AUX_TREBLE: UInt32 = 102
MM_SHARP_MDC_AUX_MIDI_VOL: UInt32 = 103
MM_SHARP_MDC_AUX_WAVE_VOL: UInt32 = 104
MM_SHARP_MDC_AUX_WAVE_RVB: UInt32 = 105
MM_SHARP_MDC_AUX_WAVE_CHR: UInt32 = 106
MM_SHARP_MDC_AUX_VOL: UInt32 = 107
MM_SHARP_MDC_AUX_RVB: UInt32 = 108
MM_SHARP_MDC_AUX_CHR: UInt32 = 109
MM_LUCENT_ACM_G723: UInt32 = 0
MM_ATT_G729A: UInt32 = 1
MM_MARIAN_ARC44WAVEIN: UInt32 = 1
MM_MARIAN_ARC44WAVEOUT: UInt32 = 2
MM_MARIAN_PRODIF24WAVEIN: UInt32 = 3
MM_MARIAN_PRODIF24WAVEOUT: UInt32 = 4
MM_MARIAN_ARC88WAVEIN: UInt32 = 5
MM_MARIAN_ARC88WAVEOUT: UInt32 = 6
MM_BCB_NETBOARD_10: UInt32 = 1
MM_BCB_TT75_10: UInt32 = 2
MM_MOTIONPIXELS_MVI2: UInt32 = 1
MM_QDESIGN_ACM_MPEG: UInt32 = 1
MM_QDESIGN_ACM_QDESIGN_MUSIC: UInt32 = 2
MM_NMP_CCP_WAVEIN: UInt32 = 1
MM_NMP_CCP_WAVEOUT: UInt32 = 2
MM_NMP_ACM_AMR: UInt32 = 10
MM_DF_ACM_G726: UInt32 = 1
MM_DF_ACM_GSM610: UInt32 = 2
MM_BERCOS_WAVEIN: UInt32 = 1
MM_BERCOS_MIXER: UInt32 = 2
MM_BERCOS_WAVEOUT: UInt32 = 3
MM_ONLIVE_MPCODEC: UInt32 = 1
MM_PHONET_PP_WAVEOUT: UInt32 = 1
MM_PHONET_PP_WAVEIN: UInt32 = 2
MM_PHONET_PP_MIXER: UInt32 = 3
MM_FTR_ENCODER_WAVEIN: UInt32 = 1
MM_FTR_ACM: UInt32 = 2
MM_ENET_T2000_LINEIN: UInt32 = 1
MM_ENET_T2000_LINEOUT: UInt32 = 2
MM_ENET_T2000_HANDSETIN: UInt32 = 3
MM_ENET_T2000_HANDSETOUT: UInt32 = 4
MM_EMAGIC_UNITOR8: UInt32 = 1
MM_SIPROLAB_ACELPNET: UInt32 = 1
MM_DICTAPHONE_G726: UInt32 = 1
MM_RZS_ACM_TUBGSM: UInt32 = 1
MM_EES_PCMIDI14: UInt32 = 1
MM_EES_PCMIDI14_IN: UInt32 = 2
MM_EES_PCMIDI14_OUT1: UInt32 = 3
MM_EES_PCMIDI14_OUT2: UInt32 = 4
MM_EES_PCMIDI14_OUT3: UInt32 = 5
MM_EES_PCMIDI14_OUT4: UInt32 = 6
MM_HAFTMANN_LPTDAC2: UInt32 = 1
MM_LUCID_PCI24WAVEIN: UInt32 = 1
MM_LUCID_PCI24WAVEOUT: UInt32 = 2
MM_HEADSPACE_HAESYNTH: UInt32 = 1
MM_HEADSPACE_HAEWAVEOUT: UInt32 = 2
MM_HEADSPACE_HAEWAVEIN: UInt32 = 3
MM_HEADSPACE_HAEMIXER: UInt32 = 4
MM_UNISYS_ACM_NAP: UInt32 = 1
MM_LUMINOSITI_SCWAVEIN: UInt32 = 1
MM_LUMINOSITI_SCWAVEOUT: UInt32 = 2
MM_LUMINOSITI_SCWAVEMIX: UInt32 = 3
MM_ACTIVEVOICE_ACM_VOXADPCM: UInt32 = 1
MM_DTS_DS: UInt32 = 1
MM_SOFTLAB_NSK_FRW_WAVEIN: UInt32 = 1
MM_SOFTLAB_NSK_FRW_WAVEOUT: UInt32 = 2
MM_SOFTLAB_NSK_FRW_MIXER: UInt32 = 3
MM_SOFTLAB_NSK_FRW_AUX: UInt32 = 4
MM_FORTEMEDIA_WAVEIN: UInt32 = 1
MM_FORTEMEDIA_WAVEOUT: UInt32 = 2
MM_FORTEMEDIA_FMSYNC: UInt32 = 3
MM_FORTEMEDIA_MIXER: UInt32 = 4
MM_FORTEMEDIA_AUX: UInt32 = 5
MM_SONORUS_STUDIO: UInt32 = 1
MM_I_LINK_VOICE_CODER: UInt32 = 1
MM_SELSIUS_SYSTEMS_RTPWAVEOUT: UInt32 = 1
MM_SELSIUS_SYSTEMS_RTPWAVEIN: UInt32 = 2
MM_ADMOS_FM_SYNTH: UInt32 = 1
MM_ADMOS_QS3AMIDIOUT: UInt32 = 2
MM_ADMOS_QS3AMIDIIN: UInt32 = 3
MM_ADMOS_QS3AWAVEOUT: UInt32 = 4
MM_ADMOS_QS3AWAVEIN: UInt32 = 5
MM_LEXICON_STUDIO_WAVE_OUT: UInt32 = 1
MM_LEXICON_STUDIO_WAVE_IN: UInt32 = 2
MM_SGI_320_WAVEIN: UInt32 = 1
MM_SGI_320_WAVEOUT: UInt32 = 2
MM_SGI_320_MIXER: UInt32 = 3
MM_SGI_540_WAVEIN: UInt32 = 4
MM_SGI_540_WAVEOUT: UInt32 = 5
MM_SGI_540_MIXER: UInt32 = 6
MM_SGI_RAD_ADATMONO1_WAVEIN: UInt32 = 7
MM_SGI_RAD_ADATMONO2_WAVEIN: UInt32 = 8
MM_SGI_RAD_ADATMONO3_WAVEIN: UInt32 = 9
MM_SGI_RAD_ADATMONO4_WAVEIN: UInt32 = 10
MM_SGI_RAD_ADATMONO5_WAVEIN: UInt32 = 11
MM_SGI_RAD_ADATMONO6_WAVEIN: UInt32 = 12
MM_SGI_RAD_ADATMONO7_WAVEIN: UInt32 = 13
MM_SGI_RAD_ADATMONO8_WAVEIN: UInt32 = 14
MM_SGI_RAD_ADATSTEREO12_WAVEIN: UInt32 = 15
MM_SGI_RAD_ADATSTEREO34_WAVEIN: UInt32 = 16
MM_SGI_RAD_ADATSTEREO56_WAVEIN: UInt32 = 17
MM_SGI_RAD_ADATSTEREO78_WAVEIN: UInt32 = 18
MM_SGI_RAD_ADAT8CHAN_WAVEIN: UInt32 = 19
MM_SGI_RAD_ADATMONO1_WAVEOUT: UInt32 = 20
MM_SGI_RAD_ADATMONO2_WAVEOUT: UInt32 = 21
MM_SGI_RAD_ADATMONO3_WAVEOUT: UInt32 = 22
MM_SGI_RAD_ADATMONO4_WAVEOUT: UInt32 = 23
MM_SGI_RAD_ADATMONO5_WAVEOUT: UInt32 = 24
MM_SGI_RAD_ADATMONO6_WAVEOUT: UInt32 = 25
MM_SGI_RAD_ADATMONO7_WAVEOUT: UInt32 = 26
MM_SGI_RAD_ADATMONO8_WAVEOUT: UInt32 = 27
MM_SGI_RAD_ADATSTEREO12_WAVEOUT: UInt32 = 28
MM_SGI_RAD_ADATSTEREO32_WAVEOUT: UInt32 = 29
MM_SGI_RAD_ADATSTEREO56_WAVEOUT: UInt32 = 30
MM_SGI_RAD_ADATSTEREO78_WAVEOUT: UInt32 = 31
MM_SGI_RAD_ADAT8CHAN_WAVEOUT: UInt32 = 32
MM_SGI_RAD_AESMONO1_WAVEIN: UInt32 = 33
MM_SGI_RAD_AESMONO2_WAVEIN: UInt32 = 34
MM_SGI_RAD_AESSTEREO_WAVEIN: UInt32 = 35
MM_SGI_RAD_AESMONO1_WAVEOUT: UInt32 = 36
MM_SGI_RAD_AESMONO2_WAVEOUT: UInt32 = 37
MM_SGI_RAD_AESSTEREO_WAVEOUT: UInt32 = 38
MM_IPI_ACM_HSX: UInt32 = 1
MM_IPI_ACM_RPELP: UInt32 = 2
MM_IPI_WF_ASSS: UInt32 = 3
MM_IPI_AT_WAVEOUT: UInt32 = 4
MM_IPI_AT_WAVEIN: UInt32 = 5
MM_IPI_AT_MIXER: UInt32 = 6
MM_ICE_WAVEOUT: UInt32 = 1
MM_ICE_WAVEIN: UInt32 = 2
MM_ICE_MTWAVEOUT: UInt32 = 3
MM_ICE_MTWAVEIN: UInt32 = 4
MM_ICE_MIDIOUT1: UInt32 = 5
MM_ICE_MIDIIN1: UInt32 = 6
MM_ICE_MIDIOUT2: UInt32 = 7
MM_ICE_MIDIIN2: UInt32 = 8
MM_ICE_SYNTH: UInt32 = 9
MM_ICE_MIXER: UInt32 = 10
MM_ICE_AUX: UInt32 = 11
MM_VQST_VQC1: UInt32 = 1
MM_VQST_VQC2: UInt32 = 2
MM_ETEK_KWIKMIDI_MIDIIN: UInt32 = 1
MM_ETEK_KWIKMIDI_MIDIOUT: UInt32 = 2
MM_INTERNET_SSW_MIDIOUT: UInt32 = 10
MM_INTERNET_SSW_MIDIIN: UInt32 = 11
MM_INTERNET_SSW_WAVEOUT: UInt32 = 12
MM_INTERNET_SSW_WAVEIN: UInt32 = 13
MM_SONY_ACM_SCX: UInt32 = 1
MM_UH_ACM_ADPCM: UInt32 = 1
MM_SYDEC_NV_WAVEIN: UInt32 = 1
MM_SYDEC_NV_WAVEOUT: UInt32 = 2
MM_FLEXION_X300_WAVEIN: UInt32 = 1
MM_FLEXION_X300_WAVEOUT: UInt32 = 2
MM_VIA_WAVEOUT: UInt32 = 1
MM_VIA_WAVEIN: UInt32 = 2
MM_VIA_MIXER: UInt32 = 3
MM_VIA_AUX: UInt32 = 4
MM_VIA_MPU401_MIDIOUT: UInt32 = 5
MM_VIA_MPU401_MIDIIN: UInt32 = 6
MM_VIA_SWFM_SYNTH: UInt32 = 7
MM_VIA_WDM_WAVEOUT: UInt32 = 8
MM_VIA_WDM_WAVEIN: UInt32 = 9
MM_VIA_WDM_MIXER: UInt32 = 10
MM_VIA_WDM_MPU401_MIDIOUT: UInt32 = 11
MM_VIA_WDM_MPU401_MIDIIN: UInt32 = 12
MM_MICRONAS_SC4: UInt32 = 1
MM_MICRONAS_CLP833: UInt32 = 2
MM_HP_WAVEOUT: UInt32 = 1
MM_HP_WAVEIN: UInt32 = 2
MM_QUICKAUDIO_MINIMIDI: UInt32 = 1
MM_QUICKAUDIO_MAXIMIDI: UInt32 = 2
MM_ICCC_UNA3_WAVEIN: UInt32 = 1
MM_ICCC_UNA3_WAVEOUT: UInt32 = 2
MM_ICCC_UNA3_AUX: UInt32 = 3
MM_ICCC_UNA3_MIXER: UInt32 = 4
MM_3COM_CB_MIXER: UInt32 = 1
MM_3COM_CB_WAVEIN: UInt32 = 2
MM_3COM_CB_WAVEOUT: UInt32 = 3
MM_MINDMAKER_GC_WAVEIN: UInt32 = 1
MM_MINDMAKER_GC_WAVEOUT: UInt32 = 2
MM_MINDMAKER_GC_MIXER: UInt32 = 3
MM_TELEKOL_WAVEOUT: UInt32 = 1
MM_TELEKOL_WAVEIN: UInt32 = 2
MM_ALGOVISION_VB80WAVEOUT: UInt32 = 1
MM_ALGOVISION_VB80WAVEIN: UInt32 = 2
MM_ALGOVISION_VB80MIXER: UInt32 = 3
MM_ALGOVISION_VB80AUX: UInt32 = 4
MM_ALGOVISION_VB80AUX2: UInt32 = 5
WAVE_FORMAT_UNKNOWN: UInt32 = 0
WAVE_FORMAT_ADPCM: UInt32 = 2
WAVE_FORMAT_IEEE_FLOAT: UInt32 = 3
WAVE_FORMAT_VSELP: UInt32 = 4
WAVE_FORMAT_IBM_CVSD: UInt32 = 5
WAVE_FORMAT_ALAW: UInt32 = 6
WAVE_FORMAT_MULAW: UInt32 = 7
WAVE_FORMAT_DTS: UInt32 = 8
WAVE_FORMAT_DRM: UInt32 = 9
WAVE_FORMAT_WMAVOICE9: UInt32 = 10
WAVE_FORMAT_WMAVOICE10: UInt32 = 11
WAVE_FORMAT_OKI_ADPCM: UInt32 = 16
WAVE_FORMAT_DVI_ADPCM: UInt32 = 17
WAVE_FORMAT_IMA_ADPCM: UInt32 = 17
WAVE_FORMAT_MEDIASPACE_ADPCM: UInt32 = 18
WAVE_FORMAT_SIERRA_ADPCM: UInt32 = 19
WAVE_FORMAT_G723_ADPCM: UInt32 = 20
WAVE_FORMAT_DIGISTD: UInt32 = 21
WAVE_FORMAT_DIGIFIX: UInt32 = 22
WAVE_FORMAT_DIALOGIC_OKI_ADPCM: UInt32 = 23
WAVE_FORMAT_MEDIAVISION_ADPCM: UInt32 = 24
WAVE_FORMAT_CU_CODEC: UInt32 = 25
WAVE_FORMAT_HP_DYN_VOICE: UInt32 = 26
WAVE_FORMAT_YAMAHA_ADPCM: UInt32 = 32
WAVE_FORMAT_SONARC: UInt32 = 33
WAVE_FORMAT_DSPGROUP_TRUESPEECH: UInt32 = 34
WAVE_FORMAT_ECHOSC1: UInt32 = 35
WAVE_FORMAT_AUDIOFILE_AF36: UInt32 = 36
WAVE_FORMAT_APTX: UInt32 = 37
WAVE_FORMAT_AUDIOFILE_AF10: UInt32 = 38
WAVE_FORMAT_PROSODY_1612: UInt32 = 39
WAVE_FORMAT_LRC: UInt32 = 40
WAVE_FORMAT_DOLBY_AC2: UInt32 = 48
WAVE_FORMAT_GSM610: UInt32 = 49
WAVE_FORMAT_MSNAUDIO: UInt32 = 50
WAVE_FORMAT_ANTEX_ADPCME: UInt32 = 51
WAVE_FORMAT_CONTROL_RES_VQLPC: UInt32 = 52
WAVE_FORMAT_DIGIREAL: UInt32 = 53
WAVE_FORMAT_DIGIADPCM: UInt32 = 54
WAVE_FORMAT_CONTROL_RES_CR10: UInt32 = 55
WAVE_FORMAT_NMS_VBXADPCM: UInt32 = 56
WAVE_FORMAT_CS_IMAADPCM: UInt32 = 57
WAVE_FORMAT_ECHOSC3: UInt32 = 58
WAVE_FORMAT_ROCKWELL_ADPCM: UInt32 = 59
WAVE_FORMAT_ROCKWELL_DIGITALK: UInt32 = 60
WAVE_FORMAT_XEBEC: UInt32 = 61
WAVE_FORMAT_G721_ADPCM: UInt32 = 64
WAVE_FORMAT_G728_CELP: UInt32 = 65
WAVE_FORMAT_MSG723: UInt32 = 66
WAVE_FORMAT_INTEL_G723_1: UInt32 = 67
WAVE_FORMAT_INTEL_G729: UInt32 = 68
WAVE_FORMAT_SHARP_G726: UInt32 = 69
WAVE_FORMAT_MPEG: UInt32 = 80
WAVE_FORMAT_RT24: UInt32 = 82
WAVE_FORMAT_PAC: UInt32 = 83
WAVE_FORMAT_MPEGLAYER3: UInt32 = 85
WAVE_FORMAT_LUCENT_G723: UInt32 = 89
WAVE_FORMAT_CIRRUS: UInt32 = 96
WAVE_FORMAT_ESPCM: UInt32 = 97
WAVE_FORMAT_VOXWARE: UInt32 = 98
WAVE_FORMAT_CANOPUS_ATRAC: UInt32 = 99
WAVE_FORMAT_G726_ADPCM: UInt32 = 100
WAVE_FORMAT_G722_ADPCM: UInt32 = 101
WAVE_FORMAT_DSAT: UInt32 = 102
WAVE_FORMAT_DSAT_DISPLAY: UInt32 = 103
WAVE_FORMAT_VOXWARE_BYTE_ALIGNED: UInt32 = 105
WAVE_FORMAT_VOXWARE_AC8: UInt32 = 112
WAVE_FORMAT_VOXWARE_AC10: UInt32 = 113
WAVE_FORMAT_VOXWARE_AC16: UInt32 = 114
WAVE_FORMAT_VOXWARE_AC20: UInt32 = 115
WAVE_FORMAT_VOXWARE_RT24: UInt32 = 116
WAVE_FORMAT_VOXWARE_RT29: UInt32 = 117
WAVE_FORMAT_VOXWARE_RT29HW: UInt32 = 118
WAVE_FORMAT_VOXWARE_VR12: UInt32 = 119
WAVE_FORMAT_VOXWARE_VR18: UInt32 = 120
WAVE_FORMAT_VOXWARE_TQ40: UInt32 = 121
WAVE_FORMAT_VOXWARE_SC3: UInt32 = 122
WAVE_FORMAT_VOXWARE_SC3_1: UInt32 = 123
WAVE_FORMAT_SOFTSOUND: UInt32 = 128
WAVE_FORMAT_VOXWARE_TQ60: UInt32 = 129
WAVE_FORMAT_MSRT24: UInt32 = 130
WAVE_FORMAT_G729A: UInt32 = 131
WAVE_FORMAT_MVI_MVI2: UInt32 = 132
WAVE_FORMAT_DF_G726: UInt32 = 133
WAVE_FORMAT_DF_GSM610: UInt32 = 134
WAVE_FORMAT_ISIAUDIO: UInt32 = 136
WAVE_FORMAT_ONLIVE: UInt32 = 137
WAVE_FORMAT_MULTITUDE_FT_SX20: UInt32 = 138
WAVE_FORMAT_INFOCOM_ITS_G721_ADPCM: UInt32 = 139
WAVE_FORMAT_CONVEDIA_G729: UInt32 = 140
WAVE_FORMAT_CONGRUENCY: UInt32 = 141
WAVE_FORMAT_SBC24: UInt32 = 145
WAVE_FORMAT_DOLBY_AC3_SPDIF: UInt32 = 146
WAVE_FORMAT_MEDIASONIC_G723: UInt32 = 147
WAVE_FORMAT_PROSODY_8KBPS: UInt32 = 148
WAVE_FORMAT_ZYXEL_ADPCM: UInt32 = 151
WAVE_FORMAT_PHILIPS_LPCBB: UInt32 = 152
WAVE_FORMAT_PACKED: UInt32 = 153
WAVE_FORMAT_MALDEN_PHONYTALK: UInt32 = 160
WAVE_FORMAT_RACAL_RECORDER_GSM: UInt32 = 161
WAVE_FORMAT_RACAL_RECORDER_G720_A: UInt32 = 162
WAVE_FORMAT_RACAL_RECORDER_G723_1: UInt32 = 163
WAVE_FORMAT_RACAL_RECORDER_TETRA_ACELP: UInt32 = 164
WAVE_FORMAT_NEC_AAC: UInt32 = 176
WAVE_FORMAT_RAW_AAC1: UInt32 = 255
WAVE_FORMAT_RHETOREX_ADPCM: UInt32 = 256
WAVE_FORMAT_IRAT: UInt32 = 257
WAVE_FORMAT_VIVO_G723: UInt32 = 273
WAVE_FORMAT_VIVO_SIREN: UInt32 = 274
WAVE_FORMAT_PHILIPS_CELP: UInt32 = 288
WAVE_FORMAT_PHILIPS_GRUNDIG: UInt32 = 289
WAVE_FORMAT_DIGITAL_G723: UInt32 = 291
WAVE_FORMAT_SANYO_LD_ADPCM: UInt32 = 293
WAVE_FORMAT_SIPROLAB_ACEPLNET: UInt32 = 304
WAVE_FORMAT_SIPROLAB_ACELP4800: UInt32 = 305
WAVE_FORMAT_SIPROLAB_ACELP8V3: UInt32 = 306
WAVE_FORMAT_SIPROLAB_G729: UInt32 = 307
WAVE_FORMAT_SIPROLAB_G729A: UInt32 = 308
WAVE_FORMAT_SIPROLAB_KELVIN: UInt32 = 309
WAVE_FORMAT_VOICEAGE_AMR: UInt32 = 310
WAVE_FORMAT_G726ADPCM: UInt32 = 320
WAVE_FORMAT_DICTAPHONE_CELP68: UInt32 = 321
WAVE_FORMAT_DICTAPHONE_CELP54: UInt32 = 322
WAVE_FORMAT_QUALCOMM_PUREVOICE: UInt32 = 336
WAVE_FORMAT_QUALCOMM_HALFRATE: UInt32 = 337
WAVE_FORMAT_TUBGSM: UInt32 = 341
WAVE_FORMAT_MSAUDIO1: UInt32 = 352
WAVE_FORMAT_WMAUDIO2: UInt32 = 353
WAVE_FORMAT_WMAUDIO3: UInt32 = 354
WAVE_FORMAT_WMAUDIO_LOSSLESS: UInt32 = 355
WAVE_FORMAT_WMASPDIF: UInt32 = 356
WAVE_FORMAT_UNISYS_NAP_ADPCM: UInt32 = 368
WAVE_FORMAT_UNISYS_NAP_ULAW: UInt32 = 369
WAVE_FORMAT_UNISYS_NAP_ALAW: UInt32 = 370
WAVE_FORMAT_UNISYS_NAP_16K: UInt32 = 371
WAVE_FORMAT_SYCOM_ACM_SYC008: UInt32 = 372
WAVE_FORMAT_SYCOM_ACM_SYC701_G726L: UInt32 = 373
WAVE_FORMAT_SYCOM_ACM_SYC701_CELP54: UInt32 = 374
WAVE_FORMAT_SYCOM_ACM_SYC701_CELP68: UInt32 = 375
WAVE_FORMAT_KNOWLEDGE_ADVENTURE_ADPCM: UInt32 = 376
WAVE_FORMAT_FRAUNHOFER_IIS_MPEG2_AAC: UInt32 = 384
WAVE_FORMAT_DTS_DS: UInt32 = 400
WAVE_FORMAT_CREATIVE_ADPCM: UInt32 = 512
WAVE_FORMAT_CREATIVE_FASTSPEECH8: UInt32 = 514
WAVE_FORMAT_CREATIVE_FASTSPEECH10: UInt32 = 515
WAVE_FORMAT_UHER_ADPCM: UInt32 = 528
WAVE_FORMAT_ULEAD_DV_AUDIO: UInt32 = 533
WAVE_FORMAT_ULEAD_DV_AUDIO_1: UInt32 = 534
WAVE_FORMAT_QUARTERDECK: UInt32 = 544
WAVE_FORMAT_ILINK_VC: UInt32 = 560
WAVE_FORMAT_RAW_SPORT: UInt32 = 576
WAVE_FORMAT_ESST_AC3: UInt32 = 577
WAVE_FORMAT_GENERIC_PASSTHRU: UInt32 = 585
WAVE_FORMAT_IPI_HSX: UInt32 = 592
WAVE_FORMAT_IPI_RPELP: UInt32 = 593
WAVE_FORMAT_CS2: UInt32 = 608
WAVE_FORMAT_SONY_SCX: UInt32 = 624
WAVE_FORMAT_SONY_SCY: UInt32 = 625
WAVE_FORMAT_SONY_ATRAC3: UInt32 = 626
WAVE_FORMAT_SONY_SPC: UInt32 = 627
WAVE_FORMAT_TELUM_AUDIO: UInt32 = 640
WAVE_FORMAT_TELUM_IA_AUDIO: UInt32 = 641
WAVE_FORMAT_NORCOM_VOICE_SYSTEMS_ADPCM: UInt32 = 645
WAVE_FORMAT_FM_TOWNS_SND: UInt32 = 768
WAVE_FORMAT_MICRONAS: UInt32 = 848
WAVE_FORMAT_MICRONAS_CELP833: UInt32 = 849
WAVE_FORMAT_BTV_DIGITAL: UInt32 = 1024
WAVE_FORMAT_INTEL_MUSIC_CODER: UInt32 = 1025
WAVE_FORMAT_INDEO_AUDIO: UInt32 = 1026
WAVE_FORMAT_QDESIGN_MUSIC: UInt32 = 1104
WAVE_FORMAT_ON2_VP7_AUDIO: UInt32 = 1280
WAVE_FORMAT_ON2_VP6_AUDIO: UInt32 = 1281
WAVE_FORMAT_VME_VMPCM: UInt32 = 1664
WAVE_FORMAT_TPC: UInt32 = 1665
WAVE_FORMAT_LIGHTWAVE_LOSSLESS: UInt32 = 2222
WAVE_FORMAT_OLIGSM: UInt32 = 4096
WAVE_FORMAT_OLIADPCM: UInt32 = 4097
WAVE_FORMAT_OLICELP: UInt32 = 4098
WAVE_FORMAT_OLISBC: UInt32 = 4099
WAVE_FORMAT_OLIOPR: UInt32 = 4100
WAVE_FORMAT_LH_CODEC: UInt32 = 4352
WAVE_FORMAT_LH_CODEC_CELP: UInt32 = 4353
WAVE_FORMAT_LH_CODEC_SBC8: UInt32 = 4354
WAVE_FORMAT_LH_CODEC_SBC12: UInt32 = 4355
WAVE_FORMAT_LH_CODEC_SBC16: UInt32 = 4356
WAVE_FORMAT_NORRIS: UInt32 = 5120
WAVE_FORMAT_ISIAUDIO_2: UInt32 = 5121
WAVE_FORMAT_SOUNDSPACE_MUSICOMPRESS: UInt32 = 5376
WAVE_FORMAT_MPEG_ADTS_AAC: UInt32 = 5632
WAVE_FORMAT_MPEG_RAW_AAC: UInt32 = 5633
WAVE_FORMAT_MPEG_LOAS: UInt32 = 5634
WAVE_FORMAT_NOKIA_MPEG_ADTS_AAC: UInt32 = 5640
WAVE_FORMAT_NOKIA_MPEG_RAW_AAC: UInt32 = 5641
WAVE_FORMAT_VODAFONE_MPEG_ADTS_AAC: UInt32 = 5642
WAVE_FORMAT_VODAFONE_MPEG_RAW_AAC: UInt32 = 5643
WAVE_FORMAT_MPEG_HEAAC: UInt32 = 5648
WAVE_FORMAT_VOXWARE_RT24_SPEECH: UInt32 = 6172
WAVE_FORMAT_SONICFOUNDRY_LOSSLESS: UInt32 = 6513
WAVE_FORMAT_INNINGS_TELECOM_ADPCM: UInt32 = 6521
WAVE_FORMAT_LUCENT_SX8300P: UInt32 = 7175
WAVE_FORMAT_LUCENT_SX5363S: UInt32 = 7180
WAVE_FORMAT_CUSEEME: UInt32 = 7939
WAVE_FORMAT_NTCSOFT_ALF2CM_ACM: UInt32 = 8132
WAVE_FORMAT_DVM: UInt32 = 8192
WAVE_FORMAT_DTS2: UInt32 = 8193
WAVE_FORMAT_MAKEAVIS: UInt32 = 13075
WAVE_FORMAT_DIVIO_MPEG4_AAC: UInt32 = 16707
WAVE_FORMAT_NOKIA_ADAPTIVE_MULTIRATE: UInt32 = 16897
WAVE_FORMAT_DIVIO_G726: UInt32 = 16963
WAVE_FORMAT_LEAD_SPEECH: UInt32 = 17228
WAVE_FORMAT_LEAD_VORBIS: UInt32 = 22092
WAVE_FORMAT_WAVPACK_AUDIO: UInt32 = 22358
WAVE_FORMAT_ALAC: UInt32 = 27745
WAVE_FORMAT_OGG_VORBIS_MODE_1: UInt32 = 26447
WAVE_FORMAT_OGG_VORBIS_MODE_2: UInt32 = 26448
WAVE_FORMAT_OGG_VORBIS_MODE_3: UInt32 = 26449
WAVE_FORMAT_OGG_VORBIS_MODE_1_PLUS: UInt32 = 26479
WAVE_FORMAT_OGG_VORBIS_MODE_2_PLUS: UInt32 = 26480
WAVE_FORMAT_OGG_VORBIS_MODE_3_PLUS: UInt32 = 26481
WAVE_FORMAT_3COM_NBX: UInt32 = 28672
WAVE_FORMAT_OPUS: UInt32 = 28751
WAVE_FORMAT_FAAD_AAC: UInt32 = 28781
WAVE_FORMAT_AMR_NB: UInt32 = 29537
WAVE_FORMAT_AMR_WB: UInt32 = 29538
WAVE_FORMAT_AMR_WP: UInt32 = 29539
WAVE_FORMAT_GSM_AMR_CBR: UInt32 = 31265
WAVE_FORMAT_GSM_AMR_VBR_SID: UInt32 = 31266
WAVE_FORMAT_COMVERSE_INFOSYS_G723_1: UInt32 = 41216
WAVE_FORMAT_COMVERSE_INFOSYS_AVQSBC: UInt32 = 41217
WAVE_FORMAT_COMVERSE_INFOSYS_SBC: UInt32 = 41218
WAVE_FORMAT_SYMBOL_G729_A: UInt32 = 41219
WAVE_FORMAT_VOICEAGE_AMR_WB: UInt32 = 41220
WAVE_FORMAT_INGENIENT_G726: UInt32 = 41221
WAVE_FORMAT_MPEG4_AAC: UInt32 = 41222
WAVE_FORMAT_ENCORE_G726: UInt32 = 41223
WAVE_FORMAT_ZOLL_ASAO: UInt32 = 41224
WAVE_FORMAT_SPEEX_VOICE: UInt32 = 41225
WAVE_FORMAT_VIANIX_MASC: UInt32 = 41226
WAVE_FORMAT_WM9_SPECTRUM_ANALYZER: UInt32 = 41227
WAVE_FORMAT_WMF_SPECTRUM_ANAYZER: UInt32 = 41228
WAVE_FORMAT_GSM_610: UInt32 = 41229
WAVE_FORMAT_GSM_620: UInt32 = 41230
WAVE_FORMAT_GSM_660: UInt32 = 41231
WAVE_FORMAT_GSM_690: UInt32 = 41232
WAVE_FORMAT_GSM_ADAPTIVE_MULTIRATE_WB: UInt32 = 41233
WAVE_FORMAT_POLYCOM_G722: UInt32 = 41234
WAVE_FORMAT_POLYCOM_G728: UInt32 = 41235
WAVE_FORMAT_POLYCOM_G729_A: UInt32 = 41236
WAVE_FORMAT_POLYCOM_SIREN: UInt32 = 41237
WAVE_FORMAT_GLOBAL_IP_ILBC: UInt32 = 41238
WAVE_FORMAT_RADIOTIME_TIME_SHIFT_RADIO: UInt32 = 41239
WAVE_FORMAT_NICE_ACA: UInt32 = 41240
WAVE_FORMAT_NICE_ADPCM: UInt32 = 41241
WAVE_FORMAT_VOCORD_G721: UInt32 = 41242
WAVE_FORMAT_VOCORD_G726: UInt32 = 41243
WAVE_FORMAT_VOCORD_G722_1: UInt32 = 41244
WAVE_FORMAT_VOCORD_G728: UInt32 = 41245
WAVE_FORMAT_VOCORD_G729: UInt32 = 41246
WAVE_FORMAT_VOCORD_G729_A: UInt32 = 41247
WAVE_FORMAT_VOCORD_G723_1: UInt32 = 41248
WAVE_FORMAT_VOCORD_LBC: UInt32 = 41249
WAVE_FORMAT_NICE_G728: UInt32 = 41250
WAVE_FORMAT_FRACE_TELECOM_G729: UInt32 = 41251
WAVE_FORMAT_CODIAN: UInt32 = 41252
WAVE_FORMAT_DOLBY_AC4: UInt32 = 44096
WAVE_FORMAT_FLAC: UInt32 = 61868
WAVE_FORMAT_DEVELOPMENT: UInt32 = 65535
ACM_MPEG_LAYER1: UInt32 = 1
ACM_MPEG_LAYER2: UInt32 = 2
ACM_MPEG_LAYER3: UInt32 = 4
ACM_MPEG_STEREO: UInt32 = 1
ACM_MPEG_JOINTSTEREO: UInt32 = 2
ACM_MPEG_DUALCHANNEL: UInt32 = 4
ACM_MPEG_SINGLECHANNEL: UInt32 = 8
ACM_MPEG_PRIVATEBIT: UInt32 = 1
ACM_MPEG_COPYRIGHT: UInt32 = 2
ACM_MPEG_ORIGINALHOME: UInt32 = 4
ACM_MPEG_PROTECTIONBIT: UInt32 = 8
ACM_MPEG_ID_MPEG1: UInt32 = 16
MPEGLAYER3_WFX_EXTRA_BYTES: UInt32 = 12
MPEGLAYER3_ID_UNKNOWN: UInt32 = 0
MPEGLAYER3_ID_MPEG: UInt32 = 1
MPEGLAYER3_ID_CONSTANTFRAMESIZE: UInt32 = 2
MM_MSFT_ACM_WMAUDIO: UInt32 = 39
WMAUDIO_BITS_PER_SAMPLE: UInt32 = 16
WMAUDIO_MAX_CHANNELS: UInt32 = 2
MM_MSFT_ACM_MSAUDIO1: UInt32 = 39
MSAUDIO1_BITS_PER_SAMPLE: UInt32 = 16
MSAUDIO1_MAX_CHANNELS: UInt32 = 2
MM_MSFT_ACM_WMAUDIO2: UInt32 = 101
WMAUDIO2_BITS_PER_SAMPLE: UInt32 = 16
WMAUDIO2_MAX_CHANNELS: UInt32 = 2
WAVE_FILTER_UNKNOWN: UInt32 = 0
WAVE_FILTER_DEVELOPMENT: UInt32 = 65535
WAVE_FILTER_VOLUME: UInt32 = 1
WAVE_FILTER_ECHO: UInt32 = 2
JPEG_PROCESS_BASELINE: UInt32 = 0
AVIIF_CONTROLFRAME: Int32 = 512
JIFMK_SOF0: UInt32 = 65472
JIFMK_SOF1: UInt32 = 65473
JIFMK_SOF2: UInt32 = 65474
JIFMK_SOF3: UInt32 = 65475
JIFMK_SOF5: UInt32 = 65477
JIFMK_SOF6: UInt32 = 65478
JIFMK_SOF7: UInt32 = 65479
JIFMK_JPG: UInt32 = 65480
JIFMK_SOF9: UInt32 = 65481
JIFMK_SOF10: UInt32 = 65482
JIFMK_SOF11: UInt32 = 65483
JIFMK_SOF13: UInt32 = 65485
JIFMK_SOF14: UInt32 = 65486
JIFMK_SOF15: UInt32 = 65487
JIFMK_DHT: UInt32 = 65476
JIFMK_DAC: UInt32 = 65484
JIFMK_RST0: UInt32 = 65488
JIFMK_RST1: UInt32 = 65489
JIFMK_RST2: UInt32 = 65490
JIFMK_RST3: UInt32 = 65491
JIFMK_RST4: UInt32 = 65492
JIFMK_RST5: UInt32 = 65493
JIFMK_RST6: UInt32 = 65494
JIFMK_RST7: UInt32 = 65495
JIFMK_SOI: UInt32 = 65496
JIFMK_EOI: UInt32 = 65497
JIFMK_SOS: UInt32 = 65498
JIFMK_DQT: UInt32 = 65499
JIFMK_DNL: UInt32 = 65500
JIFMK_DRI: UInt32 = 65501
JIFMK_DHP: UInt32 = 65502
JIFMK_EXP: UInt32 = 65503
JIFMK_APP0: UInt32 = 65504
JIFMK_APP1: UInt32 = 65505
JIFMK_APP2: UInt32 = 65506
JIFMK_APP3: UInt32 = 65507
JIFMK_APP4: UInt32 = 65508
JIFMK_APP5: UInt32 = 65509
JIFMK_APP6: UInt32 = 65510
JIFMK_APP7: UInt32 = 65511
JIFMK_JPG0: UInt32 = 65520
JIFMK_JPG1: UInt32 = 65521
JIFMK_JPG2: UInt32 = 65522
JIFMK_JPG3: UInt32 = 65523
JIFMK_JPG4: UInt32 = 65524
JIFMK_JPG5: UInt32 = 65525
JIFMK_JPG6: UInt32 = 65526
JIFMK_JPG7: UInt32 = 65527
JIFMK_JPG8: UInt32 = 65528
JIFMK_JPG9: UInt32 = 65529
JIFMK_JPG10: UInt32 = 65530
JIFMK_JPG11: UInt32 = 65531
JIFMK_JPG12: UInt32 = 65532
JIFMK_JPG13: UInt32 = 65533
JIFMK_COM: UInt32 = 65534
JIFMK_TEM: UInt32 = 65281
JIFMK_RES: UInt32 = 65282
JIFMK_00: UInt32 = 65280
JIFMK_FF: UInt32 = 65535
JPEG_Y: UInt32 = 1
JPEG_YCbCr: UInt32 = 2
JPEG_RGB: UInt32 = 3
MIXERCONTROL_CONTROLTYPE_SRS_MTS: UInt32 = 536936454
MIXERCONTROL_CONTROLTYPE_SRS_ONOFF: UInt32 = 536936455
MIXERCONTROL_CONTROLTYPE_SRS_SYNTHSELECT: UInt32 = 536936456
VP_COMMAND_GET: UInt32 = 1
VP_COMMAND_SET: UInt32 = 2
VP_FLAGS_TV_MODE: UInt32 = 1
VP_FLAGS_TV_STANDARD: UInt32 = 2
VP_FLAGS_FLICKER: UInt32 = 4
VP_FLAGS_OVERSCAN: UInt32 = 8
VP_FLAGS_MAX_UNSCALED: UInt32 = 16
VP_FLAGS_POSITION: UInt32 = 32
VP_FLAGS_BRIGHTNESS: UInt32 = 64
VP_FLAGS_CONTRAST: UInt32 = 128
VP_FLAGS_COPYPROTECT: UInt32 = 256
VP_MODE_WIN_GRAPHICS: UInt32 = 1
VP_MODE_TV_PLAYBACK: UInt32 = 2
VP_TV_STANDARD_NTSC_M: UInt32 = 1
VP_TV_STANDARD_NTSC_M_J: UInt32 = 2
VP_TV_STANDARD_PAL_B: UInt32 = 4
VP_TV_STANDARD_PAL_D: UInt32 = 8
VP_TV_STANDARD_PAL_H: UInt32 = 16
VP_TV_STANDARD_PAL_I: UInt32 = 32
VP_TV_STANDARD_PAL_M: UInt32 = 64
VP_TV_STANDARD_PAL_N: UInt32 = 128
VP_TV_STANDARD_SECAM_B: UInt32 = 256
VP_TV_STANDARD_SECAM_D: UInt32 = 512
VP_TV_STANDARD_SECAM_G: UInt32 = 1024
VP_TV_STANDARD_SECAM_H: UInt32 = 2048
VP_TV_STANDARD_SECAM_K: UInt32 = 4096
VP_TV_STANDARD_SECAM_K1: UInt32 = 8192
VP_TV_STANDARD_SECAM_L: UInt32 = 16384
VP_TV_STANDARD_WIN_VGA: UInt32 = 32768
VP_TV_STANDARD_NTSC_433: UInt32 = 65536
VP_TV_STANDARD_PAL_G: UInt32 = 131072
VP_TV_STANDARD_PAL_60: UInt32 = 262144
VP_TV_STANDARD_SECAM_L1: UInt32 = 524288
VP_CP_TYPE_APS_TRIGGER: UInt32 = 1
VP_CP_TYPE_MACROVISION: UInt32 = 2
VP_CP_CMD_ACTIVATE: UInt32 = 1
VP_CP_CMD_DEACTIVATE: UInt32 = 2
VP_CP_CMD_CHANGE: UInt32 = 4
ICVERSION: UInt32 = 260
BI_1632: UInt32 = 842217009
ICERR_OK: Int32 = 0
ICERR_DONTDRAW: Int32 = 1
ICERR_NEWPALETTE: Int32 = 2
ICERR_GOTOKEYFRAME: Int32 = 3
ICERR_STOPDRAWING: Int32 = 4
ICERR_UNSUPPORTED: Int32 = -1
ICERR_BADFORMAT: Int32 = -2
ICERR_MEMORY: Int32 = -3
ICERR_INTERNAL: Int32 = -4
ICERR_BADFLAGS: Int32 = -5
ICERR_BADPARAM: Int32 = -6
ICERR_BADSIZE: Int32 = -7
ICERR_BADHANDLE: Int32 = -8
ICERR_CANTUPDATE: Int32 = -9
ICERR_ABORT: Int32 = -10
ICERR_ERROR: Int32 = -100
ICERR_BADBITDEPTH: Int32 = -200
ICERR_BADIMAGESIZE: Int32 = -201
ICERR_CUSTOM: Int32 = -400
ICMODE_COMPRESS: UInt32 = 1
ICMODE_DECOMPRESS: UInt32 = 2
ICMODE_FASTDECOMPRESS: UInt32 = 3
ICMODE_QUERY: UInt32 = 4
ICMODE_FASTCOMPRESS: UInt32 = 5
ICMODE_DRAW: UInt32 = 8
ICMODE_INTERNALF_FUNCTION32: UInt32 = 32768
ICMODE_INTERNALF_MASK: UInt32 = 32768
AVIIF_TWOCC: Int32 = 2
ICQUALITY_LOW: UInt32 = 0
ICQUALITY_HIGH: UInt32 = 10000
ICQUALITY_DEFAULT: Int32 = -1
ICM_USER: UInt32 = 16384
ICM_RESERVED_LOW: UInt32 = 20480
ICM_RESERVED_HIGH: UInt32 = 24576
ICM_GETSTATE: UInt32 = 20480
ICM_SETSTATE: UInt32 = 20481
ICM_GETINFO: UInt32 = 20482
ICM_CONFIGURE: UInt32 = 20490
ICM_ABOUT: UInt32 = 20491
ICM_GETERRORTEXT: UInt32 = 20492
ICM_GETFORMATNAME: UInt32 = 20500
ICM_ENUMFORMATS: UInt32 = 20501
ICM_GETDEFAULTQUALITY: UInt32 = 20510
ICM_GETQUALITY: UInt32 = 20511
ICM_SETQUALITY: UInt32 = 20512
ICM_SET: UInt32 = 20520
ICM_GET: UInt32 = 20521
ICM_COMPRESS_GET_FORMAT: UInt32 = 16388
ICM_COMPRESS_GET_SIZE: UInt32 = 16389
ICM_COMPRESS_QUERY: UInt32 = 16390
ICM_COMPRESS_BEGIN: UInt32 = 16391
ICM_COMPRESS: UInt32 = 16392
ICM_COMPRESS_END: UInt32 = 16393
ICM_DECOMPRESS_GET_FORMAT: UInt32 = 16394
ICM_DECOMPRESS_QUERY: UInt32 = 16395
ICM_DECOMPRESS_BEGIN: UInt32 = 16396
ICM_DECOMPRESS: UInt32 = 16397
ICM_DECOMPRESS_END: UInt32 = 16398
ICM_DECOMPRESS_SET_PALETTE: UInt32 = 16413
ICM_DECOMPRESS_GET_PALETTE: UInt32 = 16414
ICM_DRAW_QUERY: UInt32 = 16415
ICM_DRAW_BEGIN: UInt32 = 16399
ICM_DRAW_GET_PALETTE: UInt32 = 16400
ICM_DRAW_UPDATE: UInt32 = 16401
ICM_DRAW_START: UInt32 = 16402
ICM_DRAW_STOP: UInt32 = 16403
ICM_DRAW_BITS: UInt32 = 16404
ICM_DRAW_END: UInt32 = 16405
ICM_DRAW_GETTIME: UInt32 = 16416
ICM_DRAW: UInt32 = 16417
ICM_DRAW_WINDOW: UInt32 = 16418
ICM_DRAW_SETTIME: UInt32 = 16419
ICM_DRAW_REALIZE: UInt32 = 16420
ICM_DRAW_FLUSH: UInt32 = 16421
ICM_DRAW_RENDERBUFFER: UInt32 = 16422
ICM_DRAW_START_PLAY: UInt32 = 16423
ICM_DRAW_STOP_PLAY: UInt32 = 16424
ICM_DRAW_SUGGESTFORMAT: UInt32 = 16434
ICM_DRAW_CHANGEPALETTE: UInt32 = 16435
ICM_DRAW_IDLE: UInt32 = 16436
ICM_GETBUFFERSWANTED: UInt32 = 16425
ICM_GETDEFAULTKEYFRAMERATE: UInt32 = 16426
ICM_DECOMPRESSEX_BEGIN: UInt32 = 16444
ICM_DECOMPRESSEX_QUERY: UInt32 = 16445
ICM_DECOMPRESSEX: UInt32 = 16446
ICM_DECOMPRESSEX_END: UInt32 = 16447
ICM_COMPRESS_FRAMES_INFO: UInt32 = 16454
ICM_COMPRESS_FRAMES: UInt32 = 16455
ICM_SET_STATUS_PROC: UInt32 = 16456
VIDCF_QUALITY: UInt32 = 1
VIDCF_CRUNCH: UInt32 = 2
VIDCF_TEMPORAL: UInt32 = 4
VIDCF_COMPRESSFRAMES: UInt32 = 8
VIDCF_DRAW: UInt32 = 16
VIDCF_FASTTEMPORALC: UInt32 = 32
VIDCF_FASTTEMPORALD: UInt32 = 128
ICCOMPRESS_KEYFRAME: Int32 = 1
ICCOMPRESSFRAMES_PADDING: UInt32 = 1
ICSTATUS_START: UInt32 = 0
ICSTATUS_STATUS: UInt32 = 1
ICSTATUS_END: UInt32 = 2
ICSTATUS_ERROR: UInt32 = 3
ICSTATUS_YIELD: UInt32 = 4
ICDECOMPRESS_HURRYUP: Int32 = -2147483648
ICDECOMPRESS_UPDATE: Int32 = 1073741824
ICDECOMPRESS_PREROLL: Int32 = 536870912
ICDECOMPRESS_NULLFRAME: Int32 = 268435456
ICDECOMPRESS_NOTKEYFRAME: Int32 = 134217728
ICDRAW_QUERY: Int32 = 1
ICDRAW_FULLSCREEN: Int32 = 2
ICDRAW_HDC: Int32 = 4
ICDRAW_ANIMATE: Int32 = 8
ICDRAW_CONTINUE: Int32 = 16
ICDRAW_MEMORYDC: Int32 = 32
ICDRAW_UPDATING: Int32 = 64
ICDRAW_RENDER: Int32 = 128
ICDRAW_BUFFER: Int32 = 256
ICDRAW_HURRYUP: Int32 = -2147483648
ICDRAW_UPDATE: Int32 = 1073741824
ICDRAW_PREROLL: Int32 = 536870912
ICDRAW_NULLFRAME: Int32 = 268435456
ICDRAW_NOTKEYFRAME: Int32 = 134217728
ICINSTALL_UNICODE: UInt32 = 32768
ICINSTALL_FUNCTION: UInt32 = 1
ICINSTALL_DRIVER: UInt32 = 2
ICINSTALL_HDRV: UInt32 = 4
ICINSTALL_DRIVERW: UInt32 = 32770
ICMF_CONFIGURE_QUERY: UInt32 = 1
ICMF_ABOUT_QUERY: UInt32 = 1
ICMF_COMPVARS_VALID: UInt32 = 1
ICMF_CHOOSE_KEYFRAME: UInt32 = 1
ICMF_CHOOSE_DATARATE: UInt32 = 2
ICMF_CHOOSE_PREVIEW: UInt32 = 4
ICMF_CHOOSE_ALLCOMPRESSORS: UInt32 = 8
DDF_0001: UInt32 = 1
DDF_UPDATE: UInt32 = 2
DDF_SAME_HDC: UInt32 = 4
DDF_SAME_DRAW: UInt32 = 8
DDF_DONTDRAW: UInt32 = 16
DDF_ANIMATE: UInt32 = 32
DDF_BUFFER: UInt32 = 64
DDF_JUSTDRAWIT: UInt32 = 128
DDF_FULLSCREEN: UInt32 = 256
DDF_BACKGROUNDPAL: UInt32 = 512
DDF_NOTKEYFRAME: UInt32 = 1024
DDF_HURRYUP: UInt32 = 2048
DDF_HALFTONE: UInt32 = 4096
DDF_2000: UInt32 = 8192
DDF_PREROLL: UInt32 = 16
DDF_SAME_DIB: UInt32 = 8
DDF_SAME_SIZE: UInt32 = 8
PD_CAN_DRAW_DIB: UInt32 = 1
PD_CAN_STRETCHDIB: UInt32 = 2
PD_STRETCHDIB_1_1_OK: UInt32 = 4
PD_STRETCHDIB_1_2_OK: UInt32 = 8
PD_STRETCHDIB_1_N_OK: UInt32 = 16
AVIGETFRAMEF_BESTDISPLAYFMT: UInt32 = 1
AVISTREAMINFO_DISABLED: UInt32 = 1
AVISTREAMINFO_FORMATCHANGES: UInt32 = 65536
AVIFILEINFO_HASINDEX: UInt32 = 16
AVIFILEINFO_MUSTUSEINDEX: UInt32 = 32
AVIFILEINFO_ISINTERLEAVED: UInt32 = 256
AVIFILEINFO_WASCAPTUREFILE: UInt32 = 65536
AVIFILEINFO_COPYRIGHTED: UInt32 = 131072
AVIFILECAPS_CANREAD: UInt32 = 1
AVIFILECAPS_CANWRITE: UInt32 = 2
AVIFILECAPS_ALLKEYFRAMES: UInt32 = 16
AVIFILECAPS_NOCOMPRESSION: UInt32 = 32
AVICOMPRESSF_INTERLEAVE: UInt32 = 1
AVICOMPRESSF_DATARATE: UInt32 = 2
AVICOMPRESSF_KEYFRAMES: UInt32 = 4
AVICOMPRESSF_VALID: UInt32 = 8
CLSID_AVISimpleUnMarshal: Guid = Guid('{00020009-0000-0000-c000-000000000046}')
CLSID_AVIFile: Guid = Guid('{00020000-0000-0000-c000-000000000046}')
AVIFILEHANDLER_CANREAD: UInt32 = 1
AVIFILEHANDLER_CANWRITE: UInt32 = 2
AVIFILEHANDLER_CANACCEPTNONRGB: UInt32 = 4
AVISTREAMREAD_CONVENIENT: Int32 = -1
FIND_DIR: Int32 = 15
FIND_NEXT: Int32 = 1
FIND_PREV: Int32 = 4
FIND_FROM_START: Int32 = 8
FIND_TYPE: Int32 = 240
FIND_KEY: Int32 = 16
FIND_ANY: Int32 = 32
FIND_FORMAT: Int32 = 64
FIND_RET: Int32 = 61440
FIND_POS: Int32 = 0
FIND_LENGTH: Int32 = 4096
FIND_OFFSET: Int32 = 8192
FIND_SIZE: Int32 = 12288
FIND_INDEX: Int32 = 16384
SEARCH_NEAREST: Int32 = 4
SEARCH_BACKWARD: Int32 = 4
SEARCH_FORWARD: Int32 = 1
SEARCH_KEY: Int32 = 16
SEARCH_ANY: Int32 = 32
AVIERR_OK: Int32 = 0
MCIWND_WINDOW_CLASS: String = 'MCIWndClass'
MCIWNDOPENF_NEW: UInt32 = 1
MCIWNDF_NOAUTOSIZEWINDOW: UInt32 = 1
MCIWNDF_NOPLAYBAR: UInt32 = 2
MCIWNDF_NOAUTOSIZEMOVIE: UInt32 = 4
MCIWNDF_NOMENU: UInt32 = 8
MCIWNDF_SHOWNAME: UInt32 = 16
MCIWNDF_SHOWPOS: UInt32 = 32
MCIWNDF_SHOWMODE: UInt32 = 64
MCIWNDF_SHOWALL: UInt32 = 112
MCIWNDF_NOTIFYMODE: UInt32 = 256
MCIWNDF_NOTIFYPOS: UInt32 = 512
MCIWNDF_NOTIFYSIZE: UInt32 = 1024
MCIWNDF_NOTIFYERROR: UInt32 = 4096
MCIWNDF_NOTIFYALL: UInt32 = 7936
MCIWNDF_NOTIFYANSI: UInt32 = 128
MCIWNDF_NOTIFYMEDIAA: UInt32 = 2176
MCIWNDF_NOTIFYMEDIAW: UInt32 = 2048
MCIWNDF_NOTIFYMEDIA: UInt32 = 2048
MCIWNDF_RECORD: UInt32 = 8192
MCIWNDF_NOERRORDLG: UInt32 = 16384
MCIWNDF_NOOPEN: UInt32 = 32768
MCIWNDM_GETDEVICEID: UInt32 = 1124
MCIWNDM_GETSTART: UInt32 = 1127
MCIWNDM_GETLENGTH: UInt32 = 1128
MCIWNDM_GETEND: UInt32 = 1129
MCIWNDM_EJECT: UInt32 = 1131
MCIWNDM_SETZOOM: UInt32 = 1132
MCIWNDM_GETZOOM: UInt32 = 1133
MCIWNDM_SETVOLUME: UInt32 = 1134
MCIWNDM_GETVOLUME: UInt32 = 1135
MCIWNDM_SETSPEED: UInt32 = 1136
MCIWNDM_GETSPEED: UInt32 = 1137
MCIWNDM_SETREPEAT: UInt32 = 1138
MCIWNDM_GETREPEAT: UInt32 = 1139
MCIWNDM_REALIZE: UInt32 = 1142
MCIWNDM_VALIDATEMEDIA: UInt32 = 1145
MCIWNDM_PLAYFROM: UInt32 = 1146
MCIWNDM_PLAYTO: UInt32 = 1147
MCIWNDM_GETPALETTE: UInt32 = 1150
MCIWNDM_SETPALETTE: UInt32 = 1151
MCIWNDM_SETTIMERS: UInt32 = 1153
MCIWNDM_SETACTIVETIMER: UInt32 = 1154
MCIWNDM_SETINACTIVETIMER: UInt32 = 1155
MCIWNDM_GETACTIVETIMER: UInt32 = 1156
MCIWNDM_GETINACTIVETIMER: UInt32 = 1157
MCIWNDM_CHANGESTYLES: UInt32 = 1159
MCIWNDM_GETSTYLES: UInt32 = 1160
MCIWNDM_GETALIAS: UInt32 = 1161
MCIWNDM_PLAYREVERSE: UInt32 = 1163
MCIWNDM_GET_SOURCE: UInt32 = 1164
MCIWNDM_PUT_SOURCE: UInt32 = 1165
MCIWNDM_GET_DEST: UInt32 = 1166
MCIWNDM_PUT_DEST: UInt32 = 1167
MCIWNDM_CAN_PLAY: UInt32 = 1168
MCIWNDM_CAN_WINDOW: UInt32 = 1169
MCIWNDM_CAN_RECORD: UInt32 = 1170
MCIWNDM_CAN_SAVE: UInt32 = 1171
MCIWNDM_CAN_EJECT: UInt32 = 1172
MCIWNDM_CAN_CONFIG: UInt32 = 1173
MCIWNDM_PALETTEKICK: UInt32 = 1174
MCIWNDM_OPENINTERFACE: UInt32 = 1175
MCIWNDM_SETOWNER: UInt32 = 1176
MCIWNDM_SENDSTRINGA: UInt32 = 1125
MCIWNDM_GETPOSITIONA: UInt32 = 1126
MCIWNDM_GETMODEA: UInt32 = 1130
MCIWNDM_SETTIMEFORMATA: UInt32 = 1143
MCIWNDM_GETTIMEFORMATA: UInt32 = 1144
MCIWNDM_GETFILENAMEA: UInt32 = 1148
MCIWNDM_GETDEVICEA: UInt32 = 1149
MCIWNDM_GETERRORA: UInt32 = 1152
MCIWNDM_NEWA: UInt32 = 1158
MCIWNDM_RETURNSTRINGA: UInt32 = 1162
MCIWNDM_OPENA: UInt32 = 1177
MCIWNDM_SENDSTRINGW: UInt32 = 1225
MCIWNDM_GETPOSITIONW: UInt32 = 1226
MCIWNDM_GETMODEW: UInt32 = 1230
MCIWNDM_SETTIMEFORMATW: UInt32 = 1243
MCIWNDM_GETTIMEFORMATW: UInt32 = 1244
MCIWNDM_GETFILENAMEW: UInt32 = 1248
MCIWNDM_GETDEVICEW: UInt32 = 1249
MCIWNDM_GETERRORW: UInt32 = 1252
MCIWNDM_NEWW: UInt32 = 1258
MCIWNDM_RETURNSTRINGW: UInt32 = 1262
MCIWNDM_OPENW: UInt32 = 1276
MCIWNDM_SENDSTRING: UInt32 = 1225
MCIWNDM_GETPOSITION: UInt32 = 1226
MCIWNDM_GETMODE: UInt32 = 1230
MCIWNDM_SETTIMEFORMAT: UInt32 = 1243
MCIWNDM_GETTIMEFORMAT: UInt32 = 1244
MCIWNDM_GETFILENAME: UInt32 = 1248
MCIWNDM_GETDEVICE: UInt32 = 1249
MCIWNDM_GETERROR: UInt32 = 1252
MCIWNDM_NEW: UInt32 = 1258
MCIWNDM_RETURNSTRING: UInt32 = 1262
MCIWNDM_OPEN: UInt32 = 1276
MCIWNDM_NOTIFYMODE: UInt32 = 1224
MCIWNDM_NOTIFYPOS: UInt32 = 1225
MCIWNDM_NOTIFYSIZE: UInt32 = 1226
MCIWNDM_NOTIFYMEDIA: UInt32 = 1227
MCIWNDM_NOTIFYERROR: UInt32 = 1229
MCIWND_START: Int32 = -1
MCIWND_END: Int32 = -2
MCI_OPEN: UInt32 = 2051
MCI_CLOSE: UInt32 = 2052
MCI_PLAY: UInt32 = 2054
MCI_SEEK: UInt32 = 2055
MCI_STOP: UInt32 = 2056
MCI_PAUSE: UInt32 = 2057
MCI_STEP: UInt32 = 2062
MCI_RECORD: UInt32 = 2063
MCI_SAVE: UInt32 = 2067
MCI_CUT: UInt32 = 2129
MCI_COPY: UInt32 = 2130
MCI_PASTE: UInt32 = 2131
MCI_RESUME: UInt32 = 2133
MCI_DELETE: UInt32 = 2134
MCI_MODE_NOT_READY: UInt32 = 524
MCI_MODE_STOP: UInt32 = 525
MCI_MODE_PLAY: UInt32 = 526
MCI_MODE_RECORD: UInt32 = 527
MCI_MODE_SEEK: UInt32 = 528
MCI_MODE_PAUSE: UInt32 = 529
MCI_MODE_OPEN: UInt32 = 530
DV_ERR_OK: UInt32 = 0
DV_ERR_BASE: UInt32 = 1
DV_ERR_NONSPECIFIC: UInt32 = 1
DV_ERR_BADFORMAT: UInt32 = 2
DV_ERR_STILLPLAYING: UInt32 = 3
DV_ERR_UNPREPARED: UInt32 = 4
DV_ERR_SYNC: UInt32 = 5
DV_ERR_TOOMANYCHANNELS: UInt32 = 6
DV_ERR_NOTDETECTED: UInt32 = 7
DV_ERR_BADINSTALL: UInt32 = 8
DV_ERR_CREATEPALETTE: UInt32 = 9
DV_ERR_SIZEFIELD: UInt32 = 10
DV_ERR_PARAM1: UInt32 = 11
DV_ERR_PARAM2: UInt32 = 12
DV_ERR_CONFIG1: UInt32 = 13
DV_ERR_CONFIG2: UInt32 = 14
DV_ERR_FLAGS: UInt32 = 15
DV_ERR_13: UInt32 = 16
DV_ERR_NOTSUPPORTED: UInt32 = 17
DV_ERR_NOMEM: UInt32 = 18
DV_ERR_ALLOCATED: UInt32 = 19
DV_ERR_BADDEVICEID: UInt32 = 20
DV_ERR_INVALHANDLE: UInt32 = 21
DV_ERR_BADERRNUM: UInt32 = 22
DV_ERR_NO_BUFFERS: UInt32 = 23
DV_ERR_MEM_CONFLICT: UInt32 = 24
DV_ERR_IO_CONFLICT: UInt32 = 25
DV_ERR_DMA_CONFLICT: UInt32 = 26
DV_ERR_INT_CONFLICT: UInt32 = 27
DV_ERR_PROTECT_ONLY: UInt32 = 28
DV_ERR_LASTERROR: UInt32 = 28
DV_ERR_USER_MSG: UInt32 = 1001
DV_VM_OPEN: UInt32 = 976
DV_VM_CLOSE: UInt32 = 977
DV_VM_DATA: UInt32 = 978
DV_VM_ERROR: UInt32 = 979
VHDR_DONE: UInt32 = 1
VHDR_PREPARED: UInt32 = 2
VHDR_INQUEUE: UInt32 = 4
VHDR_KEYFRAME: UInt32 = 8
VHDR_VALID: UInt32 = 15
VCAPS_OVERLAY: UInt32 = 1
VCAPS_SRC_CAN_CLIP: UInt32 = 2
VCAPS_DST_CAN_CLIP: UInt32 = 4
VCAPS_CAN_SCALE: UInt32 = 8
VIDEO_EXTERNALIN: UInt32 = 1
VIDEO_EXTERNALOUT: UInt32 = 2
VIDEO_IN: UInt32 = 4
VIDEO_OUT: UInt32 = 8
VIDEO_DLG_QUERY: UInt32 = 16
VIDEO_CONFIGURE_QUERY: UInt32 = 32768
VIDEO_CONFIGURE_SET: UInt32 = 4096
VIDEO_CONFIGURE_GET: UInt32 = 8192
VIDEO_CONFIGURE_QUERYSIZE: UInt32 = 1
VIDEO_CONFIGURE_CURRENT: UInt32 = 16
VIDEO_CONFIGURE_NOMINAL: UInt32 = 32
VIDEO_CONFIGURE_MIN: UInt32 = 64
VIDEO_CONFIGURE_MAX: UInt32 = 128
DVM_USER: UInt32 = 16384
DVM_CONFIGURE_START: UInt32 = 4096
DVM_CONFIGURE_END: UInt32 = 8191
DVM_PALETTE: UInt32 = 4097
DVM_FORMAT: UInt32 = 4098
DVM_PALETTERGB555: UInt32 = 4099
DVM_SRC_RECT: UInt32 = 4100
DVM_DST_RECT: UInt32 = 4101
WM_CAP_UNICODE_START: UInt32 = 1124
WM_CAP_GET_CAPSTREAMPTR: UInt32 = 1025
WM_CAP_SET_CALLBACK_ERRORW: UInt32 = 1126
WM_CAP_SET_CALLBACK_STATUSW: UInt32 = 1127
WM_CAP_SET_CALLBACK_ERRORA: UInt32 = 1026
WM_CAP_SET_CALLBACK_STATUSA: UInt32 = 1027
WM_CAP_SET_CALLBACK_ERROR: UInt32 = 1126
WM_CAP_SET_CALLBACK_STATUS: UInt32 = 1127
WM_CAP_SET_CALLBACK_YIELD: UInt32 = 1028
WM_CAP_SET_CALLBACK_FRAME: UInt32 = 1029
WM_CAP_SET_CALLBACK_VIDEOSTREAM: UInt32 = 1030
WM_CAP_SET_CALLBACK_WAVESTREAM: UInt32 = 1031
WM_CAP_GET_USER_DATA: UInt32 = 1032
WM_CAP_SET_USER_DATA: UInt32 = 1033
WM_CAP_DRIVER_CONNECT: UInt32 = 1034
WM_CAP_DRIVER_DISCONNECT: UInt32 = 1035
WM_CAP_DRIVER_GET_NAMEA: UInt32 = 1036
WM_CAP_DRIVER_GET_VERSIONA: UInt32 = 1037
WM_CAP_DRIVER_GET_NAMEW: UInt32 = 1136
WM_CAP_DRIVER_GET_VERSIONW: UInt32 = 1137
WM_CAP_DRIVER_GET_NAME: UInt32 = 1136
WM_CAP_DRIVER_GET_VERSION: UInt32 = 1137
WM_CAP_DRIVER_GET_CAPS: UInt32 = 1038
WM_CAP_FILE_SET_CAPTURE_FILEA: UInt32 = 1044
WM_CAP_FILE_GET_CAPTURE_FILEA: UInt32 = 1045
WM_CAP_FILE_SAVEASA: UInt32 = 1047
WM_CAP_FILE_SAVEDIBA: UInt32 = 1049
WM_CAP_FILE_SET_CAPTURE_FILEW: UInt32 = 1144
WM_CAP_FILE_GET_CAPTURE_FILEW: UInt32 = 1145
WM_CAP_FILE_SAVEASW: UInt32 = 1147
WM_CAP_FILE_SAVEDIBW: UInt32 = 1149
WM_CAP_FILE_SET_CAPTURE_FILE: UInt32 = 1144
WM_CAP_FILE_GET_CAPTURE_FILE: UInt32 = 1145
WM_CAP_FILE_SAVEAS: UInt32 = 1147
WM_CAP_FILE_SAVEDIB: UInt32 = 1149
WM_CAP_FILE_ALLOCATE: UInt32 = 1046
WM_CAP_FILE_SET_INFOCHUNK: UInt32 = 1048
WM_CAP_EDIT_COPY: UInt32 = 1054
WM_CAP_SET_AUDIOFORMAT: UInt32 = 1059
WM_CAP_GET_AUDIOFORMAT: UInt32 = 1060
WM_CAP_DLG_VIDEOFORMAT: UInt32 = 1065
WM_CAP_DLG_VIDEOSOURCE: UInt32 = 1066
WM_CAP_DLG_VIDEODISPLAY: UInt32 = 1067
WM_CAP_GET_VIDEOFORMAT: UInt32 = 1068
WM_CAP_SET_VIDEOFORMAT: UInt32 = 1069
WM_CAP_DLG_VIDEOCOMPRESSION: UInt32 = 1070
WM_CAP_SET_PREVIEW: UInt32 = 1074
WM_CAP_SET_OVERLAY: UInt32 = 1075
WM_CAP_SET_PREVIEWRATE: UInt32 = 1076
WM_CAP_SET_SCALE: UInt32 = 1077
WM_CAP_GET_STATUS: UInt32 = 1078
WM_CAP_SET_SCROLL: UInt32 = 1079
WM_CAP_GRAB_FRAME: UInt32 = 1084
WM_CAP_GRAB_FRAME_NOSTOP: UInt32 = 1085
WM_CAP_SEQUENCE: UInt32 = 1086
WM_CAP_SEQUENCE_NOFILE: UInt32 = 1087
WM_CAP_SET_SEQUENCE_SETUP: UInt32 = 1088
WM_CAP_GET_SEQUENCE_SETUP: UInt32 = 1089
WM_CAP_SET_MCI_DEVICEA: UInt32 = 1090
WM_CAP_GET_MCI_DEVICEA: UInt32 = 1091
WM_CAP_SET_MCI_DEVICEW: UInt32 = 1190
WM_CAP_GET_MCI_DEVICEW: UInt32 = 1191
WM_CAP_SET_MCI_DEVICE: UInt32 = 1190
WM_CAP_GET_MCI_DEVICE: UInt32 = 1191
WM_CAP_STOP: UInt32 = 1092
WM_CAP_ABORT: UInt32 = 1093
WM_CAP_SINGLE_FRAME_OPEN: UInt32 = 1094
WM_CAP_SINGLE_FRAME_CLOSE: UInt32 = 1095
WM_CAP_SINGLE_FRAME: UInt32 = 1096
WM_CAP_PAL_OPENA: UInt32 = 1104
WM_CAP_PAL_SAVEA: UInt32 = 1105
WM_CAP_PAL_OPENW: UInt32 = 1204
WM_CAP_PAL_SAVEW: UInt32 = 1205
WM_CAP_PAL_OPEN: UInt32 = 1204
WM_CAP_PAL_SAVE: UInt32 = 1205
WM_CAP_PAL_PASTE: UInt32 = 1106
WM_CAP_PAL_AUTOCREATE: UInt32 = 1107
WM_CAP_PAL_MANUALCREATE: UInt32 = 1108
WM_CAP_SET_CALLBACK_CAPCONTROL: UInt32 = 1109
WM_CAP_UNICODE_END: UInt32 = 1205
WM_CAP_END: UInt32 = 1205
AVSTREAMMASTER_AUDIO: UInt32 = 0
AVSTREAMMASTER_NONE: UInt32 = 1
CONTROLCALLBACK_PREROLL: UInt32 = 1
CONTROLCALLBACK_CAPTURING: UInt32 = 2
IDS_CAP_BEGIN: UInt32 = 300
IDS_CAP_END: UInt32 = 301
IDS_CAP_INFO: UInt32 = 401
IDS_CAP_OUTOFMEM: UInt32 = 402
IDS_CAP_FILEEXISTS: UInt32 = 403
IDS_CAP_ERRORPALOPEN: UInt32 = 404
IDS_CAP_ERRORPALSAVE: UInt32 = 405
IDS_CAP_ERRORDIBSAVE: UInt32 = 406
IDS_CAP_DEFAVIEXT: UInt32 = 407
IDS_CAP_DEFPALEXT: UInt32 = 408
IDS_CAP_CANTOPEN: UInt32 = 409
IDS_CAP_SEQ_MSGSTART: UInt32 = 410
IDS_CAP_SEQ_MSGSTOP: UInt32 = 411
IDS_CAP_VIDEDITERR: UInt32 = 412
IDS_CAP_READONLYFILE: UInt32 = 413
IDS_CAP_WRITEERROR: UInt32 = 414
IDS_CAP_NODISKSPACE: UInt32 = 415
IDS_CAP_SETFILESIZE: UInt32 = 416
IDS_CAP_SAVEASPERCENT: UInt32 = 417
IDS_CAP_DRIVER_ERROR: UInt32 = 418
IDS_CAP_WAVE_OPEN_ERROR: UInt32 = 419
IDS_CAP_WAVE_ALLOC_ERROR: UInt32 = 420
IDS_CAP_WAVE_PREPARE_ERROR: UInt32 = 421
IDS_CAP_WAVE_ADD_ERROR: UInt32 = 422
IDS_CAP_WAVE_SIZE_ERROR: UInt32 = 423
IDS_CAP_VIDEO_OPEN_ERROR: UInt32 = 424
IDS_CAP_VIDEO_ALLOC_ERROR: UInt32 = 425
IDS_CAP_VIDEO_PREPARE_ERROR: UInt32 = 426
IDS_CAP_VIDEO_ADD_ERROR: UInt32 = 427
IDS_CAP_VIDEO_SIZE_ERROR: UInt32 = 428
IDS_CAP_FILE_OPEN_ERROR: UInt32 = 429
IDS_CAP_FILE_WRITE_ERROR: UInt32 = 430
IDS_CAP_RECORDING_ERROR: UInt32 = 431
IDS_CAP_RECORDING_ERROR2: UInt32 = 432
IDS_CAP_AVI_INIT_ERROR: UInt32 = 433
IDS_CAP_NO_FRAME_CAP_ERROR: UInt32 = 434
IDS_CAP_NO_PALETTE_WARN: UInt32 = 435
IDS_CAP_MCI_CONTROL_ERROR: UInt32 = 436
IDS_CAP_MCI_CANT_STEP_ERROR: UInt32 = 437
IDS_CAP_NO_AUDIO_CAP_ERROR: UInt32 = 438
IDS_CAP_AVI_DRAWDIB_ERROR: UInt32 = 439
IDS_CAP_COMPRESSOR_ERROR: UInt32 = 440
IDS_CAP_AUDIO_DROP_ERROR: UInt32 = 441
IDS_CAP_AUDIO_DROP_COMPERROR: UInt32 = 442
IDS_CAP_STAT_LIVE_MODE: UInt32 = 500
IDS_CAP_STAT_OVERLAY_MODE: UInt32 = 501
IDS_CAP_STAT_CAP_INIT: UInt32 = 502
IDS_CAP_STAT_CAP_FINI: UInt32 = 503
IDS_CAP_STAT_PALETTE_BUILD: UInt32 = 504
IDS_CAP_STAT_OPTPAL_BUILD: UInt32 = 505
IDS_CAP_STAT_I_FRAMES: UInt32 = 506
IDS_CAP_STAT_L_FRAMES: UInt32 = 507
IDS_CAP_STAT_CAP_L_FRAMES: UInt32 = 508
IDS_CAP_STAT_CAP_AUDIO: UInt32 = 509
IDS_CAP_STAT_VIDEOCURRENT: UInt32 = 510
IDS_CAP_STAT_VIDEOAUDIO: UInt32 = 511
IDS_CAP_STAT_VIDEOONLY: UInt32 = 512
IDS_CAP_STAT_FRAMESDROPPED: UInt32 = 513
JOYERR_NOERROR: UInt32 = 0
JOYERR_PARMS: UInt32 = 165
JOYERR_NOCANDO: UInt32 = 166
JOYERR_UNPLUGGED: UInt32 = 167
JOY_BUTTON1: UInt32 = 1
JOY_BUTTON2: UInt32 = 2
JOY_BUTTON3: UInt32 = 4
JOY_BUTTON4: UInt32 = 8
JOY_BUTTON1CHG: UInt32 = 256
JOY_BUTTON2CHG: UInt32 = 512
JOY_BUTTON3CHG: UInt32 = 1024
JOY_BUTTON4CHG: UInt32 = 2048
JOY_BUTTON5: Int32 = 16
JOY_BUTTON6: Int32 = 32
JOY_BUTTON7: Int32 = 64
JOY_BUTTON8: Int32 = 128
JOY_BUTTON9: Int32 = 256
JOY_BUTTON10: Int32 = 512
JOY_BUTTON11: Int32 = 1024
JOY_BUTTON12: Int32 = 2048
JOY_BUTTON13: Int32 = 4096
JOY_BUTTON14: Int32 = 8192
JOY_BUTTON15: Int32 = 16384
JOY_BUTTON16: Int32 = 32768
JOY_BUTTON17: Int32 = 65536
JOY_BUTTON18: Int32 = 131072
JOY_BUTTON19: Int32 = 262144
JOY_BUTTON20: Int32 = 524288
JOY_BUTTON21: Int32 = 1048576
JOY_BUTTON22: Int32 = 2097152
JOY_BUTTON23: Int32 = 4194304
JOY_BUTTON24: Int32 = 8388608
JOY_BUTTON25: Int32 = 16777216
JOY_BUTTON26: Int32 = 33554432
JOY_BUTTON27: Int32 = 67108864
JOY_BUTTON28: Int32 = 134217728
JOY_BUTTON29: Int32 = 268435456
JOY_BUTTON30: Int32 = 536870912
JOY_BUTTON31: Int32 = 1073741824
JOY_BUTTON32: Int32 = -2147483648
JOY_POVFORWARD: UInt32 = 0
JOY_POVRIGHT: UInt32 = 9000
JOY_POVBACKWARD: UInt32 = 18000
JOY_POVLEFT: UInt32 = 27000
JOY_RETURNX: Int32 = 1
JOY_RETURNY: Int32 = 2
JOY_RETURNZ: Int32 = 4
JOY_RETURNR: Int32 = 8
JOY_RETURNU: Int32 = 16
JOY_RETURNV: Int32 = 32
JOY_RETURNPOV: Int32 = 64
JOY_RETURNBUTTONS: Int32 = 128
JOY_RETURNRAWDATA: Int32 = 256
JOY_RETURNPOVCTS: Int32 = 512
JOY_RETURNCENTERED: Int32 = 1024
JOY_USEDEADZONE: Int32 = 2048
JOY_CAL_READALWAYS: Int32 = 65536
JOY_CAL_READXYONLY: Int32 = 131072
JOY_CAL_READ3: Int32 = 262144
JOY_CAL_READ4: Int32 = 524288
JOY_CAL_READXONLY: Int32 = 1048576
JOY_CAL_READYONLY: Int32 = 2097152
JOY_CAL_READ5: Int32 = 4194304
JOY_CAL_READ6: Int32 = 8388608
JOY_CAL_READZONLY: Int32 = 16777216
JOY_CAL_READRONLY: Int32 = 33554432
JOY_CAL_READUONLY: Int32 = 67108864
JOY_CAL_READVONLY: Int32 = 134217728
JOYSTICKID1: UInt32 = 0
JOYSTICKID2: UInt32 = 1
JOYCAPS_HASZ: UInt32 = 1
JOYCAPS_HASR: UInt32 = 2
JOYCAPS_HASU: UInt32 = 4
JOYCAPS_HASV: UInt32 = 8
JOYCAPS_HASPOV: UInt32 = 16
JOYCAPS_POV4DIR: UInt32 = 32
JOYCAPS_POVCTS: UInt32 = 64
DRV_LOAD: UInt32 = 1
DRV_ENABLE: UInt32 = 2
DRV_OPEN: UInt32 = 3
DRV_CLOSE: UInt32 = 4
DRV_DISABLE: UInt32 = 5
DRV_FREE: UInt32 = 6
DRV_CONFIGURE: UInt32 = 7
DRV_QUERYCONFIGURE: UInt32 = 8
DRV_INSTALL: UInt32 = 9
DRV_REMOVE: UInt32 = 10
DRV_RESERVED: UInt32 = 2048
DRV_USER: UInt32 = 16384
DRIVERS_SECTION: String = 'DRIVERS32'
MCI_SECTION: String = 'MCI32'
DCB_NOSWITCH: UInt32 = 8
DCB_TYPEMASK: UInt32 = 7
DCB_NULL: UInt32 = 0
DCB_WINDOW: UInt32 = 1
DCB_TASK: UInt32 = 2
DCB_FUNCTION: UInt32 = 3
DCB_EVENT: UInt32 = 5
DRVM_INIT: UInt32 = 100
DRVM_EXIT: UInt32 = 101
DRVM_DISABLE: UInt32 = 102
DRVM_ENABLE: UInt32 = 103
DRVM_INIT_EX: UInt32 = 104
DRVM_USER: UInt32 = 16384
DRVM_MAPPER_RECONFIGURE: UInt32 = 8193
DRVM_MAPPER_PREFERRED_GET: UInt32 = 8213
DRVM_MAPPER_CONSOLEVOICECOM_GET: UInt32 = 8215
DRV_QUERYDEVNODE: UInt32 = 2050
DRV_QUERYMAPPABLE: UInt32 = 2053
DRV_QUERYMODULE: UInt32 = 2057
DRV_PNPINSTALL: UInt32 = 2059
DRV_QUERYDEVICEINTERFACE: UInt32 = 2060
DRV_QUERYDEVICEINTERFACESIZE: UInt32 = 2061
DRV_QUERYSTRINGID: UInt32 = 2062
DRV_QUERYSTRINGIDSIZE: UInt32 = 2063
DRV_QUERYIDFROMSTRINGID: UInt32 = 2064
DRV_QUERYFUNCTIONINSTANCEID: UInt32 = 2065
DRV_QUERYFUNCTIONINSTANCEIDSIZE: UInt32 = 2066
DRVM_MAPPER_PREFERRED_FLAGS_PREFERREDONLY: UInt32 = 1
DRVM_IOCTL: UInt32 = 256
DRVM_ADD_THRU: UInt32 = 257
DRVM_REMOVE_THRU: UInt32 = 258
DRVM_IOCTL_LAST: UInt32 = 261
DRVM_IOCTL_CMD_USER: Int32 = 0
DRVM_IOCTL_CMD_SYSTEM: Int32 = -2147483648
VADMAD_Device_ID: UInt32 = 1092
WODM_INIT: UInt32 = 100
WIDM_INIT: UInt32 = 100
WODM_INIT_EX: UInt32 = 104
WIDM_INIT_EX: UInt32 = 104
WODM_GETNUMDEVS: UInt32 = 3
WODM_GETDEVCAPS: UInt32 = 4
WODM_OPEN: UInt32 = 5
WODM_CLOSE: UInt32 = 6
WODM_PREPARE: UInt32 = 7
WODM_UNPREPARE: UInt32 = 8
WODM_WRITE: UInt32 = 9
WODM_PAUSE: UInt32 = 10
WODM_RESTART: UInt32 = 11
WODM_RESET: UInt32 = 12
WODM_GETPOS: UInt32 = 13
WODM_GETPITCH: UInt32 = 14
WODM_SETPITCH: UInt32 = 15
WODM_GETVOLUME: UInt32 = 16
WODM_SETVOLUME: UInt32 = 17
WODM_GETPLAYBACKRATE: UInt32 = 18
WODM_SETPLAYBACKRATE: UInt32 = 19
WODM_BREAKLOOP: UInt32 = 20
WODM_PREFERRED: UInt32 = 21
WODM_BUSY: UInt32 = 21
WIDM_GETNUMDEVS: UInt32 = 50
WIDM_GETDEVCAPS: UInt32 = 51
WIDM_OPEN: UInt32 = 52
WIDM_CLOSE: UInt32 = 53
WIDM_PREPARE: UInt32 = 54
WIDM_UNPREPARE: UInt32 = 55
WIDM_ADDBUFFER: UInt32 = 56
WIDM_START: UInt32 = 57
WIDM_STOP: UInt32 = 58
WIDM_RESET: UInt32 = 59
WIDM_GETPOS: UInt32 = 60
WIDM_PREFERRED: UInt32 = 61
MIDI_IO_PACKED: Int32 = 0
MIDI_IO_COOKED: Int32 = 2
MODM_GETNUMDEVS: UInt32 = 1
MODM_GETDEVCAPS: UInt32 = 2
MODM_OPEN: UInt32 = 3
MODM_CLOSE: UInt32 = 4
MODM_PREPARE: UInt32 = 5
MODM_UNPREPARE: UInt32 = 6
MODM_DATA: UInt32 = 7
MODM_LONGDATA: UInt32 = 8
MODM_RESET: UInt32 = 9
MODM_GETVOLUME: UInt32 = 10
MODM_SETVOLUME: UInt32 = 11
MODM_CACHEPATCHES: UInt32 = 12
MODM_CACHEDRUMPATCHES: UInt32 = 13
MODM_STRMDATA: UInt32 = 14
MODM_GETPOS: UInt32 = 17
MODM_PAUSE: UInt32 = 18
MODM_RESTART: UInt32 = 19
MODM_STOP: UInt32 = 20
MODM_PROPERTIES: UInt32 = 21
MODM_PREFERRED: UInt32 = 22
MODM_RECONFIGURE: UInt32 = 18280
MIDM_GETNUMDEVS: UInt32 = 53
MIDM_GETDEVCAPS: UInt32 = 54
MIDM_OPEN: UInt32 = 55
MIDM_CLOSE: UInt32 = 56
MIDM_PREPARE: UInt32 = 57
MIDM_UNPREPARE: UInt32 = 58
MIDM_ADDBUFFER: UInt32 = 59
MIDM_START: UInt32 = 60
MIDM_STOP: UInt32 = 61
MIDM_RESET: UInt32 = 62
AUXM_INIT: UInt32 = 100
AUXM_INIT_EX: UInt32 = 104
AUXDM_GETNUMDEVS: UInt32 = 3
AUXDM_GETDEVCAPS: UInt32 = 4
AUXDM_GETVOLUME: UInt32 = 5
AUXDM_SETVOLUME: UInt32 = 6
MXDM_INIT: UInt32 = 100
MXDM_INIT_EX: UInt32 = 104
MXDM_USER: UInt32 = 16384
MXDM_BASE: UInt32 = 1
MXDM_GETNUMDEVS: UInt32 = 1
MXDM_GETDEVCAPS: UInt32 = 2
MXDM_OPEN: UInt32 = 3
MXDM_CLOSE: UInt32 = 4
MXDM_GETLINEINFO: UInt32 = 5
MXDM_GETLINECONTROLS: UInt32 = 6
MXDM_GETCONTROLDETAILS: UInt32 = 7
MXDM_SETCONTROLDETAILS: UInt32 = 8
TDD_KILLTIMEREVENT: UInt32 = 2048
TDD_SETTIMEREVENT: UInt32 = 2052
TDD_GETSYSTEMTIME: UInt32 = 2056
TDD_GETDEVCAPS: UInt32 = 2060
TDD_BEGINMINPERIOD: UInt32 = 2064
TDD_ENDMINPERIOD: UInt32 = 2068
JOY_CONFIGCHANGED_MSGSTRING: String = 'MSJSTICK_VJOYD_MSGSTR'
JDD_GETNUMDEVS: UInt32 = 2049
JDD_GETDEVCAPS: UInt32 = 2050
JDD_GETPOS: UInt32 = 2305
JDD_SETCALIBRATION: UInt32 = 2306
JDD_CONFIGCHANGED: UInt32 = 2307
JDD_GETPOSEX: UInt32 = 2308
MCI_OPEN_DRIVER: UInt32 = 2049
MCI_CLOSE_DRIVER: UInt32 = 2050
MCI_FALSE: UInt32 = 531
MCI_TRUE: UInt32 = 532
MCI_FORMAT_MILLISECONDS_S: UInt32 = 533
MCI_FORMAT_HMS_S: UInt32 = 534
MCI_FORMAT_MSF_S: UInt32 = 535
MCI_FORMAT_FRAMES_S: UInt32 = 536
MCI_FORMAT_SMPTE_24_S: UInt32 = 537
MCI_FORMAT_SMPTE_25_S: UInt32 = 538
MCI_FORMAT_SMPTE_30_S: UInt32 = 539
MCI_FORMAT_SMPTE_30DROP_S: UInt32 = 540
MCI_FORMAT_BYTES_S: UInt32 = 541
MCI_FORMAT_SAMPLES_S: UInt32 = 542
MCI_FORMAT_TMSF_S: UInt32 = 543
MCI_VD_FORMAT_TRACK_S: UInt32 = 1029
WAVE_FORMAT_PCM_S: UInt32 = 1152
WAVE_MAPPER_S: UInt32 = 1153
MCI_SEQ_MAPPER_S: UInt32 = 1221
MCI_SEQ_FILE_S: UInt32 = 1222
MCI_SEQ_MIDI_S: UInt32 = 1223
MCI_SEQ_SMPTE_S: UInt32 = 1224
MCI_SEQ_FORMAT_SONGPTR_S: UInt32 = 1225
MCI_SEQ_NONE_S: UInt32 = 1226
MIDIMAPPER_S: UInt32 = 1227
MCI_MAX_DEVICE_TYPE_LENGTH: UInt32 = 80
MCI_RESOURCE_RETURNED: UInt32 = 65536
MCI_COLONIZED3_RETURN: UInt32 = 131072
MCI_COLONIZED4_RETURN: UInt32 = 262144
MCI_INTEGER_RETURNED: UInt32 = 524288
MCI_RESOURCE_DRIVER: UInt32 = 1048576
MCI_COMMAND_HEAD: UInt32 = 0
MCI_STRING: UInt32 = 1
MCI_INTEGER: UInt32 = 2
MCI_END_COMMAND: UInt32 = 3
MCI_RETURN: UInt32 = 4
MCI_FLAG: UInt32 = 5
MCI_END_COMMAND_LIST: UInt32 = 6
MCI_RECT: UInt32 = 7
MCI_CONSTANT: UInt32 = 8
MCI_END_CONSTANT: UInt32 = 9
MCI_HWND: UInt32 = 10
MCI_HPAL: UInt32 = 11
MCI_HDC: UInt32 = 12
MCI_INTEGER64: UInt32 = 13
TASKERR_NOTASKSUPPORT: UInt32 = 1
TASKERR_OUTOFMEMORY: UInt32 = 2
DRV_EXITSESSION: UInt32 = 11
DRV_POWER: UInt32 = 15
DRVCNF_CANCEL: UInt32 = 0
DRVCNF_OK: UInt32 = 1
DRVCNF_RESTART: UInt32 = 2
DRV_CANCEL: UInt32 = 0
DRV_OK: UInt32 = 1
DRV_RESTART: UInt32 = 2
DRV_MCI_LAST: UInt32 = 6143
MMIOERR_BASE: UInt32 = 256
MMIOERR_FILENOTFOUND: UInt32 = 257
MMIOERR_OUTOFMEMORY: UInt32 = 258
MMIOERR_CANNOTOPEN: UInt32 = 259
MMIOERR_CANNOTCLOSE: UInt32 = 260
MMIOERR_CANNOTREAD: UInt32 = 261
MMIOERR_CANNOTWRITE: UInt32 = 262
MMIOERR_CANNOTSEEK: UInt32 = 263
MMIOERR_CANNOTEXPAND: UInt32 = 264
MMIOERR_CHUNKNOTFOUND: UInt32 = 265
MMIOERR_UNBUFFERED: UInt32 = 266
MMIOERR_PATHNOTFOUND: UInt32 = 267
MMIOERR_ACCESSDENIED: UInt32 = 268
MMIOERR_SHARINGVIOLATION: UInt32 = 269
MMIOERR_NETWORKERROR: UInt32 = 270
MMIOERR_TOOMANYOPENFILES: UInt32 = 271
MMIOERR_INVALIDFILE: UInt32 = 272
MMIO_RWMODE: UInt32 = 3
MMIO_SHAREMODE: UInt32 = 112
MMIO_CREATE: UInt32 = 4096
MMIO_PARSE: UInt32 = 256
MMIO_DELETE: UInt32 = 512
MMIO_EXIST: UInt32 = 16384
MMIO_ALLOCBUF: UInt32 = 65536
MMIO_GETTEMP: UInt32 = 131072
MMIO_DIRTY: UInt32 = 268435456
MMIO_READ: UInt32 = 0
MMIO_WRITE: UInt32 = 1
MMIO_READWRITE: UInt32 = 2
MMIO_COMPAT: UInt32 = 0
MMIO_EXCLUSIVE: UInt32 = 16
MMIO_DENYWRITE: UInt32 = 32
MMIO_DENYREAD: UInt32 = 48
MMIO_DENYNONE: UInt32 = 64
MMIO_FHOPEN: UInt32 = 16
MMIO_EMPTYBUF: UInt32 = 16
MMIO_TOUPPER: UInt32 = 16
MMIO_INSTALLPROC: UInt32 = 65536
MMIO_GLOBALPROC: UInt32 = 268435456
MMIO_REMOVEPROC: UInt32 = 131072
MMIO_UNICODEPROC: UInt32 = 16777216
MMIO_FINDPROC: UInt32 = 262144
MMIO_FINDCHUNK: UInt32 = 16
MMIO_FINDRIFF: UInt32 = 32
MMIO_FINDLIST: UInt32 = 64
MMIO_CREATERIFF: UInt32 = 32
MMIO_CREATELIST: UInt32 = 64
MMIOM_READ: UInt32 = 0
MMIOM_WRITE: UInt32 = 1
MMIOM_SEEK: UInt32 = 2
MMIOM_OPEN: UInt32 = 3
MMIOM_CLOSE: UInt32 = 4
MMIOM_WRITEFLUSH: UInt32 = 5
MMIOM_RENAME: UInt32 = 6
MMIOM_USER: UInt32 = 32768
SEEK_SET: UInt32 = 0
SEEK_CUR: UInt32 = 1
SEEK_END: UInt32 = 2
MMIO_DEFAULTBUFFER: UInt32 = 8192
FACILITY_NS: UInt32 = 13
MCI_MCIAVI_PLAY_WINDOW: Int32 = 16777216
MCI_MCIAVI_PLAY_FULLSCREEN: Int32 = 33554432
MCI_MCIAVI_PLAY_FULLBY2: Int32 = 67108864
MCI_AVI_STATUS_FRAMES_SKIPPED: Int32 = 32769
MCI_AVI_STATUS_LAST_PLAY_SPEED: Int32 = 32770
MCI_AVI_STATUS_AUDIO_BREAKS: Int32 = 32771
MCI_AVI_SETVIDEO_DRAW_PROCEDURE: Int32 = 32768
MCI_AVI_SETVIDEO_PALETTE_COLOR: Int32 = 33024
MCI_AVI_SETVIDEO_PALETTE_HALFTONE: Int32 = 65535
MCIERR_AVI_OLDAVIFORMAT: UInt32 = 612
MCIERR_AVI_NOTINTERLEAVED: UInt32 = 613
MCIERR_AVI_NODISPDIB: UInt32 = 614
MCIERR_AVI_CANTPLAYFULLSCREEN: UInt32 = 615
MCIERR_AVI_TOOBIGFORVGA: UInt32 = 616
MCIERR_AVI_NOCOMPRESSOR: UInt32 = 617
MCIERR_AVI_DISPLAYERROR: UInt32 = 618
MCIERR_AVI_AUDIOERROR: UInt32 = 619
MCIERR_AVI_BADPALETTE: UInt32 = 620
DLG_ACMFORMATCHOOSE_ID: UInt32 = 70
IDD_ACMFORMATCHOOSE_BTN_HELP: UInt32 = 9
IDD_ACMFORMATCHOOSE_CMB_CUSTOM: UInt32 = 100
IDD_ACMFORMATCHOOSE_CMB_FORMATTAG: UInt32 = 101
IDD_ACMFORMATCHOOSE_CMB_FORMAT: UInt32 = 102
IDD_ACMFORMATCHOOSE_BTN_SETNAME: UInt32 = 103
IDD_ACMFORMATCHOOSE_BTN_DELNAME: UInt32 = 104
DLG_ACMFILTERCHOOSE_ID: UInt32 = 71
IDD_ACMFILTERCHOOSE_BTN_HELP: UInt32 = 9
IDD_ACMFILTERCHOOSE_CMB_CUSTOM: UInt32 = 100
IDD_ACMFILTERCHOOSE_CMB_FILTERTAG: UInt32 = 101
IDD_ACMFILTERCHOOSE_CMB_FILTER: UInt32 = 102
IDD_ACMFILTERCHOOSE_BTN_SETNAME: UInt32 = 103
IDD_ACMFILTERCHOOSE_BTN_DELNAME: UInt32 = 104
FACILITY_NS_WIN32: UInt32 = 7
NS_S_CALLPENDING: win32more.Windows.Win32.Foundation.HRESULT = 851968
NS_S_CALLABORTED: win32more.Windows.Win32.Foundation.HRESULT = 851969
NS_S_STREAM_TRUNCATED: win32more.Windows.Win32.Foundation.HRESULT = 851970
NS_W_SERVER_BANDWIDTH_LIMIT: win32more.Windows.Win32.Foundation.HRESULT = -2146631677
NS_W_FILE_BANDWIDTH_LIMIT: win32more.Windows.Win32.Foundation.HRESULT = -2146631676
NS_E_NOCONNECTION: win32more.Windows.Win32.Foundation.HRESULT = -1072889851
NS_E_CANNOTCONNECT: win32more.Windows.Win32.Foundation.HRESULT = -1072889850
NS_E_CANNOTDESTROYTITLE: win32more.Windows.Win32.Foundation.HRESULT = -1072889849
NS_E_CANNOTRENAMETITLE: win32more.Windows.Win32.Foundation.HRESULT = -1072889848
NS_E_CANNOTOFFLINEDISK: win32more.Windows.Win32.Foundation.HRESULT = -1072889847
NS_E_CANNOTONLINEDISK: win32more.Windows.Win32.Foundation.HRESULT = -1072889846
NS_E_NOREGISTEREDWALKER: win32more.Windows.Win32.Foundation.HRESULT = -1072889845
NS_E_NOFUNNEL: win32more.Windows.Win32.Foundation.HRESULT = -1072889844
NS_E_NO_LOCALPLAY: win32more.Windows.Win32.Foundation.HRESULT = -1072889843
NS_E_NETWORK_BUSY: win32more.Windows.Win32.Foundation.HRESULT = -1072889842
NS_E_TOO_MANY_SESS: win32more.Windows.Win32.Foundation.HRESULT = -1072889841
NS_E_ALREADY_CONNECTED: win32more.Windows.Win32.Foundation.HRESULT = -1072889840
NS_E_INVALID_INDEX: win32more.Windows.Win32.Foundation.HRESULT = -1072889839
NS_E_PROTOCOL_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -1072889838
NS_E_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -1072889837
NS_E_NET_WRITE: win32more.Windows.Win32.Foundation.HRESULT = -1072889836
NS_E_NET_READ: win32more.Windows.Win32.Foundation.HRESULT = -1072889835
NS_E_DISK_WRITE: win32more.Windows.Win32.Foundation.HRESULT = -1072889834
NS_E_DISK_READ: win32more.Windows.Win32.Foundation.HRESULT = -1072889833
NS_E_FILE_WRITE: win32more.Windows.Win32.Foundation.HRESULT = -1072889832
NS_E_FILE_READ: win32more.Windows.Win32.Foundation.HRESULT = -1072889831
NS_E_FILE_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1072889830
NS_E_FILE_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = -1072889829
NS_E_INVALID_NAME: win32more.Windows.Win32.Foundation.HRESULT = -1072889828
NS_E_FILE_OPEN_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -1072889827
NS_E_FILE_ALLOCATION_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -1072889826
NS_E_FILE_INIT_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -1072889825
NS_E_FILE_PLAY_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -1072889824
NS_E_SET_DISK_UID_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -1072889823
NS_E_INDUCED: win32more.Windows.Win32.Foundation.HRESULT = -1072889822
NS_E_CCLINK_DOWN: win32more.Windows.Win32.Foundation.HRESULT = -1072889821
NS_E_INTERNAL: win32more.Windows.Win32.Foundation.HRESULT = -1072889820
NS_E_BUSY: win32more.Windows.Win32.Foundation.HRESULT = -1072889819
NS_E_UNRECOGNIZED_STREAM_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -1072889818
NS_E_NETWORK_SERVICE_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -1072889817
NS_E_NETWORK_RESOURCE_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -1072889816
NS_E_CONNECTION_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -1072889815
NS_E_SHUTDOWN: win32more.Windows.Win32.Foundation.HRESULT = -1072889814
NS_E_INVALID_REQUEST: win32more.Windows.Win32.Foundation.HRESULT = -1072889813
NS_E_INSUFFICIENT_BANDWIDTH: win32more.Windows.Win32.Foundation.HRESULT = -1072889812
NS_E_NOT_REBUILDING: win32more.Windows.Win32.Foundation.HRESULT = -1072889811
NS_E_LATE_OPERATION: win32more.Windows.Win32.Foundation.HRESULT = -1072889810
NS_E_INVALID_DATA: win32more.Windows.Win32.Foundation.HRESULT = -1072889809
NS_E_FILE_BANDWIDTH_LIMIT: win32more.Windows.Win32.Foundation.HRESULT = -1072889808
NS_E_OPEN_FILE_LIMIT: win32more.Windows.Win32.Foundation.HRESULT = -1072889807
NS_E_BAD_CONTROL_DATA: win32more.Windows.Win32.Foundation.HRESULT = -1072889806
NS_E_NO_STREAM: win32more.Windows.Win32.Foundation.HRESULT = -1072889805
NS_E_STREAM_END: win32more.Windows.Win32.Foundation.HRESULT = -1072889804
NS_E_SERVER_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1072889803
NS_E_DUPLICATE_NAME: win32more.Windows.Win32.Foundation.HRESULT = -1072889802
NS_E_DUPLICATE_ADDRESS: win32more.Windows.Win32.Foundation.HRESULT = -1072889801
NS_E_BAD_MULTICAST_ADDRESS: win32more.Windows.Win32.Foundation.HRESULT = -1072889800
NS_E_BAD_ADAPTER_ADDRESS: win32more.Windows.Win32.Foundation.HRESULT = -1072889799
NS_E_BAD_DELIVERY_MODE: win32more.Windows.Win32.Foundation.HRESULT = -1072889798
NS_E_INVALID_CHANNEL: win32more.Windows.Win32.Foundation.HRESULT = -1072889797
NS_E_INVALID_STREAM: win32more.Windows.Win32.Foundation.HRESULT = -1072889796
NS_E_INVALID_ARCHIVE: win32more.Windows.Win32.Foundation.HRESULT = -1072889795
NS_E_NOTITLES: win32more.Windows.Win32.Foundation.HRESULT = -1072889794
NS_E_INVALID_CLIENT: win32more.Windows.Win32.Foundation.HRESULT = -1072889793
NS_E_INVALID_BLACKHOLE_ADDRESS: win32more.Windows.Win32.Foundation.HRESULT = -1072889792
NS_E_INCOMPATIBLE_FORMAT: win32more.Windows.Win32.Foundation.HRESULT = -1072889791
NS_E_INVALID_KEY: win32more.Windows.Win32.Foundation.HRESULT = -1072889790
NS_E_INVALID_PORT: win32more.Windows.Win32.Foundation.HRESULT = -1072889789
NS_E_INVALID_TTL: win32more.Windows.Win32.Foundation.HRESULT = -1072889788
NS_E_STRIDE_REFUSED: win32more.Windows.Win32.Foundation.HRESULT = -1072889787
NS_E_MMSAUTOSERVER_CANTFINDWALKER: win32more.Windows.Win32.Foundation.HRESULT = -1072889786
NS_E_MAX_BITRATE: win32more.Windows.Win32.Foundation.HRESULT = -1072889785
NS_E_LOGFILEPERIOD: win32more.Windows.Win32.Foundation.HRESULT = -1072889784
NS_E_MAX_CLIENTS: win32more.Windows.Win32.Foundation.HRESULT = -1072889783
NS_E_LOG_FILE_SIZE: win32more.Windows.Win32.Foundation.HRESULT = -1072889782
NS_E_MAX_FILERATE: win32more.Windows.Win32.Foundation.HRESULT = -1072889781
NS_E_WALKER_UNKNOWN: win32more.Windows.Win32.Foundation.HRESULT = -1072889780
NS_E_WALKER_SERVER: win32more.Windows.Win32.Foundation.HRESULT = -1072889779
NS_E_WALKER_USAGE: win32more.Windows.Win32.Foundation.HRESULT = -1072889778
NS_I_TIGER_START: win32more.Windows.Win32.Foundation.HRESULT = 1074593871
NS_E_TIGER_FAIL: win32more.Windows.Win32.Foundation.HRESULT = -1072889776
NS_I_CUB_START: win32more.Windows.Win32.Foundation.HRESULT = 1074593873
NS_I_CUB_RUNNING: win32more.Windows.Win32.Foundation.HRESULT = 1074593874
NS_E_CUB_FAIL: win32more.Windows.Win32.Foundation.HRESULT = -1072889773
NS_I_DISK_START: win32more.Windows.Win32.Foundation.HRESULT = 1074593876
NS_E_DISK_FAIL: win32more.Windows.Win32.Foundation.HRESULT = -1072889771
NS_I_DISK_REBUILD_STARTED: win32more.Windows.Win32.Foundation.HRESULT = 1074593878
NS_I_DISK_REBUILD_FINISHED: win32more.Windows.Win32.Foundation.HRESULT = 1074593879
NS_I_DISK_REBUILD_ABORTED: win32more.Windows.Win32.Foundation.HRESULT = 1074593880
NS_I_LIMIT_FUNNELS: win32more.Windows.Win32.Foundation.HRESULT = 1074593881
NS_I_START_DISK: win32more.Windows.Win32.Foundation.HRESULT = 1074593882
NS_I_STOP_DISK: win32more.Windows.Win32.Foundation.HRESULT = 1074593883
NS_I_STOP_CUB: win32more.Windows.Win32.Foundation.HRESULT = 1074593884
NS_I_KILL_USERSESSION: win32more.Windows.Win32.Foundation.HRESULT = 1074593885
NS_I_KILL_CONNECTION: win32more.Windows.Win32.Foundation.HRESULT = 1074593886
NS_I_REBUILD_DISK: win32more.Windows.Win32.Foundation.HRESULT = 1074593887
NS_W_UNKNOWN_EVENT: win32more.Windows.Win32.Foundation.HRESULT = -2146631584
NS_E_MAX_FUNNELS_ALERT: win32more.Windows.Win32.Foundation.HRESULT = -1072889760
NS_E_ALLOCATE_FILE_FAIL: win32more.Windows.Win32.Foundation.HRESULT = -1072889759
NS_E_PAGING_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072889758
NS_E_BAD_BLOCK0_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -1072889757
NS_E_BAD_DISK_UID: win32more.Windows.Win32.Foundation.HRESULT = -1072889756
NS_E_BAD_FSMAJOR_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -1072889755
NS_E_BAD_STAMPNUMBER: win32more.Windows.Win32.Foundation.HRESULT = -1072889754
NS_E_PARTIALLY_REBUILT_DISK: win32more.Windows.Win32.Foundation.HRESULT = -1072889753
NS_E_ENACTPLAN_GIVEUP: win32more.Windows.Win32.Foundation.HRESULT = -1072889752
MCMADM_I_NO_EVENTS: win32more.Windows.Win32.Foundation.HRESULT = 1074593897
MCMADM_E_REGKEY_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1072889750
NS_E_NO_FORMATS: win32more.Windows.Win32.Foundation.HRESULT = -1072889749
NS_E_NO_REFERENCES: win32more.Windows.Win32.Foundation.HRESULT = -1072889748
NS_E_WAVE_OPEN: win32more.Windows.Win32.Foundation.HRESULT = -1072889747
NS_I_LOGGING_FAILED: win32more.Windows.Win32.Foundation.HRESULT = 1074593902
NS_E_CANNOTCONNECTEVENTS: win32more.Windows.Win32.Foundation.HRESULT = -1072889745
NS_I_LIMIT_BANDWIDTH: win32more.Windows.Win32.Foundation.HRESULT = 1074593904
NS_E_NO_DEVICE: win32more.Windows.Win32.Foundation.HRESULT = -1072889743
NS_E_NO_SPECIFIED_DEVICE: win32more.Windows.Win32.Foundation.HRESULT = -1072889742
NS_E_NOTHING_TO_DO: win32more.Windows.Win32.Foundation.HRESULT = -1072887823
NS_E_NO_MULTICAST: win32more.Windows.Win32.Foundation.HRESULT = -1072887822
NS_E_MONITOR_GIVEUP: win32more.Windows.Win32.Foundation.HRESULT = -1072889656
NS_E_REMIRRORED_DISK: win32more.Windows.Win32.Foundation.HRESULT = -1072889655
NS_E_INSUFFICIENT_DATA: win32more.Windows.Win32.Foundation.HRESULT = -1072889654
NS_E_ASSERT: win32more.Windows.Win32.Foundation.HRESULT = -1072889653
NS_E_BAD_ADAPTER_NAME: win32more.Windows.Win32.Foundation.HRESULT = -1072889652
NS_E_NOT_LICENSED: win32more.Windows.Win32.Foundation.HRESULT = -1072889651
NS_E_NO_SERVER_CONTACT: win32more.Windows.Win32.Foundation.HRESULT = -1072889650
NS_E_TOO_MANY_TITLES: win32more.Windows.Win32.Foundation.HRESULT = -1072889649
NS_E_TITLE_SIZE_EXCEEDED: win32more.Windows.Win32.Foundation.HRESULT = -1072889648
NS_E_UDP_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -1072889647
NS_E_TCP_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -1072889646
NS_E_HTTP_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -1072889645
NS_E_LICENSE_EXPIRED: win32more.Windows.Win32.Foundation.HRESULT = -1072889644
NS_E_TITLE_BITRATE: win32more.Windows.Win32.Foundation.HRESULT = -1072889643
NS_E_EMPTY_PROGRAM_NAME: win32more.Windows.Win32.Foundation.HRESULT = -1072889642
NS_E_MISSING_CHANNEL: win32more.Windows.Win32.Foundation.HRESULT = -1072889641
NS_E_NO_CHANNELS: win32more.Windows.Win32.Foundation.HRESULT = -1072889640
NS_E_INVALID_INDEX2: win32more.Windows.Win32.Foundation.HRESULT = -1072889639
NS_E_CUB_FAIL_LINK: win32more.Windows.Win32.Foundation.HRESULT = -1072889456
NS_I_CUB_UNFAIL_LINK: win32more.Windows.Win32.Foundation.HRESULT = 1074594193
NS_E_BAD_CUB_UID: win32more.Windows.Win32.Foundation.HRESULT = -1072889454
NS_I_RESTRIPE_START: win32more.Windows.Win32.Foundation.HRESULT = 1074594195
NS_I_RESTRIPE_DONE: win32more.Windows.Win32.Foundation.HRESULT = 1074594196
NS_E_GLITCH_MODE: win32more.Windows.Win32.Foundation.HRESULT = -1072889451
NS_I_RESTRIPE_DISK_OUT: win32more.Windows.Win32.Foundation.HRESULT = 1074594198
NS_I_RESTRIPE_CUB_OUT: win32more.Windows.Win32.Foundation.HRESULT = 1074594199
NS_I_DISK_STOP: win32more.Windows.Win32.Foundation.HRESULT = 1074594200
NS_I_CATATONIC_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2146631271
NS_I_CATATONIC_AUTO_UNFAIL: win32more.Windows.Win32.Foundation.HRESULT = -2146631270
NS_E_NO_MEDIA_PROTOCOL: win32more.Windows.Win32.Foundation.HRESULT = -1072889445
NS_E_INVALID_INPUT_FORMAT: win32more.Windows.Win32.Foundation.HRESULT = -1072886856
NS_E_MSAUDIO_NOT_INSTALLED: win32more.Windows.Win32.Foundation.HRESULT = -1072886855
NS_E_UNEXPECTED_MSAUDIO_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072886854
NS_E_INVALID_OUTPUT_FORMAT: win32more.Windows.Win32.Foundation.HRESULT = -1072886853
NS_E_NOT_CONFIGURED: win32more.Windows.Win32.Foundation.HRESULT = -1072886852
NS_E_PROTECTED_CONTENT: win32more.Windows.Win32.Foundation.HRESULT = -1072886851
NS_E_LICENSE_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -1072886850
NS_E_TAMPERED_CONTENT: win32more.Windows.Win32.Foundation.HRESULT = -1072886849
NS_E_LICENSE_OUTOFDATE: win32more.Windows.Win32.Foundation.HRESULT = -1072886848
NS_E_LICENSE_INCORRECT_RIGHTS: win32more.Windows.Win32.Foundation.HRESULT = -1072886847
NS_E_AUDIO_CODEC_NOT_INSTALLED: win32more.Windows.Win32.Foundation.HRESULT = -1072886846
NS_E_AUDIO_CODEC_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072886845
NS_E_VIDEO_CODEC_NOT_INSTALLED: win32more.Windows.Win32.Foundation.HRESULT = -1072886844
NS_E_VIDEO_CODEC_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072886843
NS_E_INVALIDPROFILE: win32more.Windows.Win32.Foundation.HRESULT = -1072886842
NS_E_INCOMPATIBLE_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -1072886841
NS_S_REBUFFERING: win32more.Windows.Win32.Foundation.HRESULT = 854984
NS_S_DEGRADING_QUALITY: win32more.Windows.Win32.Foundation.HRESULT = 854985
NS_E_OFFLINE_MODE: win32more.Windows.Win32.Foundation.HRESULT = -1072886838
NS_E_NOT_CONNECTED: win32more.Windows.Win32.Foundation.HRESULT = -1072886837
NS_E_TOO_MUCH_DATA: win32more.Windows.Win32.Foundation.HRESULT = -1072886836
NS_E_UNSUPPORTED_PROPERTY: win32more.Windows.Win32.Foundation.HRESULT = -1072886835
NS_E_8BIT_WAVE_UNSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1072886834
NS_E_NO_MORE_SAMPLES: win32more.Windows.Win32.Foundation.HRESULT = -1072886833
NS_E_INVALID_SAMPLING_RATE: win32more.Windows.Win32.Foundation.HRESULT = -1072886832
NS_E_MAX_PACKET_SIZE_TOO_SMALL: win32more.Windows.Win32.Foundation.HRESULT = -1072886831
NS_E_LATE_PACKET: win32more.Windows.Win32.Foundation.HRESULT = -1072886830
NS_E_DUPLICATE_PACKET: win32more.Windows.Win32.Foundation.HRESULT = -1072886829
NS_E_SDK_BUFFERTOOSMALL: win32more.Windows.Win32.Foundation.HRESULT = -1072886828
NS_E_INVALID_NUM_PASSES: win32more.Windows.Win32.Foundation.HRESULT = -1072886827
NS_E_ATTRIBUTE_READ_ONLY: win32more.Windows.Win32.Foundation.HRESULT = -1072886826
NS_E_ATTRIBUTE_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -1072886825
NS_E_INVALID_EDL: win32more.Windows.Win32.Foundation.HRESULT = -1072886824
NS_E_DATA_UNIT_EXTENSION_TOO_LARGE: win32more.Windows.Win32.Foundation.HRESULT = -1072886823
NS_E_CODEC_DMO_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072886822
NS_S_TRANSCRYPTOR_EOF: win32more.Windows.Win32.Foundation.HRESULT = 855003
NS_E_FEATURE_DISABLED_BY_GROUP_POLICY: win32more.Windows.Win32.Foundation.HRESULT = -1072886820
NS_E_FEATURE_DISABLED_IN_SKU: win32more.Windows.Win32.Foundation.HRESULT = -1072886819
NS_E_WMDRM_DEPRECATED: win32more.Windows.Win32.Foundation.HRESULT = -1072886818
NS_E_NO_CD: win32more.Windows.Win32.Foundation.HRESULT = -1072885856
NS_E_CANT_READ_DIGITAL: win32more.Windows.Win32.Foundation.HRESULT = -1072885855
NS_E_DEVICE_DISCONNECTED: win32more.Windows.Win32.Foundation.HRESULT = -1072885854
NS_E_DEVICE_NOT_SUPPORT_FORMAT: win32more.Windows.Win32.Foundation.HRESULT = -1072885853
NS_E_SLOW_READ_DIGITAL: win32more.Windows.Win32.Foundation.HRESULT = -1072885852
NS_E_MIXER_INVALID_LINE: win32more.Windows.Win32.Foundation.HRESULT = -1072885851
NS_E_MIXER_INVALID_CONTROL: win32more.Windows.Win32.Foundation.HRESULT = -1072885850
NS_E_MIXER_INVALID_VALUE: win32more.Windows.Win32.Foundation.HRESULT = -1072885849
NS_E_MIXER_UNKNOWN_MMRESULT: win32more.Windows.Win32.Foundation.HRESULT = -1072885848
NS_E_USER_STOP: win32more.Windows.Win32.Foundation.HRESULT = -1072885847
NS_E_MP3_FORMAT_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1072885846
NS_E_CD_READ_ERROR_NO_CORRECTION: win32more.Windows.Win32.Foundation.HRESULT = -1072885845
NS_E_CD_READ_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072885844
NS_E_CD_SLOW_COPY: win32more.Windows.Win32.Foundation.HRESULT = -1072885843
NS_E_CD_COPYTO_CD: win32more.Windows.Win32.Foundation.HRESULT = -1072885842
NS_E_MIXER_NODRIVER: win32more.Windows.Win32.Foundation.HRESULT = -1072885841
NS_E_REDBOOK_ENABLED_WHILE_COPYING: win32more.Windows.Win32.Foundation.HRESULT = -1072885840
NS_E_CD_REFRESH: win32more.Windows.Win32.Foundation.HRESULT = -1072885839
NS_E_CD_DRIVER_PROBLEM: win32more.Windows.Win32.Foundation.HRESULT = -1072885838
NS_E_WONT_DO_DIGITAL: win32more.Windows.Win32.Foundation.HRESULT = -1072885837
NS_E_WMPXML_NOERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072885836
NS_E_WMPXML_ENDOFDATA: win32more.Windows.Win32.Foundation.HRESULT = -1072885835
NS_E_WMPXML_PARSEERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072885834
NS_E_WMPXML_ATTRIBUTENOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -1072885833
NS_E_WMPXML_PINOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -1072885832
NS_E_WMPXML_EMPTYDOC: win32more.Windows.Win32.Foundation.HRESULT = -1072885831
NS_E_WMP_PATH_ALREADY_IN_LIBRARY: win32more.Windows.Win32.Foundation.HRESULT = -1072885830
NS_E_WMP_FILESCANALREADYSTARTED: win32more.Windows.Win32.Foundation.HRESULT = -1072885826
NS_E_WMP_HME_INVALIDOBJECTID: win32more.Windows.Win32.Foundation.HRESULT = -1072885825
NS_E_WMP_MF_CODE_EXPIRED: win32more.Windows.Win32.Foundation.HRESULT = -1072885824
NS_E_WMP_HME_NOTSEARCHABLEFORITEMS: win32more.Windows.Win32.Foundation.HRESULT = -1072885823
NS_E_WMP_HME_STALEREQUEST: win32more.Windows.Win32.Foundation.HRESULT = -1072885822
NS_E_WMP_ADDTOLIBRARY_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -1072885817
NS_E_WMP_WINDOWSAPIFAILURE: win32more.Windows.Win32.Foundation.HRESULT = -1072885816
NS_E_WMP_RECORDING_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -1072885815
NS_E_DEVICE_NOT_READY: win32more.Windows.Win32.Foundation.HRESULT = -1072885814
NS_E_DAMAGED_FILE: win32more.Windows.Win32.Foundation.HRESULT = -1072885813
NS_E_MPDB_GENERIC: win32more.Windows.Win32.Foundation.HRESULT = -1072885812
NS_E_FILE_FAILED_CHECKS: win32more.Windows.Win32.Foundation.HRESULT = -1072885811
NS_E_MEDIA_LIBRARY_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -1072885810
NS_E_SHARING_VIOLATION: win32more.Windows.Win32.Foundation.HRESULT = -1072885809
NS_E_NO_ERROR_STRING_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1072885808
NS_E_WMPOCX_NO_REMOTE_CORE: win32more.Windows.Win32.Foundation.HRESULT = -1072885807
NS_E_WMPOCX_NO_ACTIVE_CORE: win32more.Windows.Win32.Foundation.HRESULT = -1072885806
NS_E_WMPOCX_NOT_RUNNING_REMOTELY: win32more.Windows.Win32.Foundation.HRESULT = -1072885805
NS_E_WMPOCX_NO_REMOTE_WINDOW: win32more.Windows.Win32.Foundation.HRESULT = -1072885804
NS_E_WMPOCX_ERRORMANAGERNOTAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -1072885803
NS_E_PLUGIN_NOTSHUTDOWN: win32more.Windows.Win32.Foundation.HRESULT = -1072885802
NS_E_WMP_CANNOT_FIND_FOLDER: win32more.Windows.Win32.Foundation.HRESULT = -1072885801
NS_E_WMP_STREAMING_RECORDING_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -1072885800
NS_E_WMP_PLUGINDLL_NOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -1072885799
NS_E_NEED_TO_ASK_USER: win32more.Windows.Win32.Foundation.HRESULT = -1072885798
NS_E_WMPOCX_PLAYER_NOT_DOCKED: win32more.Windows.Win32.Foundation.HRESULT = -1072885797
NS_E_WMP_EXTERNAL_NOTREADY: win32more.Windows.Win32.Foundation.HRESULT = -1072885796
NS_E_WMP_MLS_STALE_DATA: win32more.Windows.Win32.Foundation.HRESULT = -1072885795
NS_E_WMP_UI_SUBCONTROLSNOTSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1072885794
NS_E_WMP_UI_VERSIONMISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -1072885793
NS_E_WMP_UI_NOTATHEMEFILE: win32more.Windows.Win32.Foundation.HRESULT = -1072885792
NS_E_WMP_UI_SUBELEMENTNOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -1072885791
NS_E_WMP_UI_VERSIONPARSE: win32more.Windows.Win32.Foundation.HRESULT = -1072885790
NS_E_WMP_UI_VIEWIDNOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -1072885789
NS_E_WMP_UI_PASSTHROUGH: win32more.Windows.Win32.Foundation.HRESULT = -1072885788
NS_E_WMP_UI_OBJECTNOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -1072885787
NS_E_WMP_UI_SECONDHANDLER: win32more.Windows.Win32.Foundation.HRESULT = -1072885786
NS_E_WMP_UI_NOSKININZIP: win32more.Windows.Win32.Foundation.HRESULT = -1072885785
NS_S_WMP_UI_VERSIONMISMATCH: win32more.Windows.Win32.Foundation.HRESULT = 856040
NS_S_WMP_EXCEPTION: win32more.Windows.Win32.Foundation.HRESULT = 856041
NS_E_WMP_URLDOWNLOADFAILED: win32more.Windows.Win32.Foundation.HRESULT = -1072885782
NS_E_WMPOCX_UNABLE_TO_LOAD_SKIN: win32more.Windows.Win32.Foundation.HRESULT = -1072885781
NS_E_WMP_INVALID_SKIN: win32more.Windows.Win32.Foundation.HRESULT = -1072885780
NS_E_WMP_SENDMAILFAILED: win32more.Windows.Win32.Foundation.HRESULT = -1072885779
NS_E_WMP_LOCKEDINSKINMODE: win32more.Windows.Win32.Foundation.HRESULT = -1072885778
NS_E_WMP_FAILED_TO_SAVE_FILE: win32more.Windows.Win32.Foundation.HRESULT = -1072885777
NS_E_WMP_SAVEAS_READONLY: win32more.Windows.Win32.Foundation.HRESULT = -1072885776
NS_E_WMP_FAILED_TO_SAVE_PLAYLIST: win32more.Windows.Win32.Foundation.HRESULT = -1072885775
NS_E_WMP_FAILED_TO_OPEN_WMD: win32more.Windows.Win32.Foundation.HRESULT = -1072885774
NS_E_WMP_CANT_PLAY_PROTECTED: win32more.Windows.Win32.Foundation.HRESULT = -1072885773
NS_E_SHARING_STATE_OUT_OF_SYNC: win32more.Windows.Win32.Foundation.HRESULT = -1072885772
NS_E_WMPOCX_REMOTE_PLAYER_ALREADY_RUNNING: win32more.Windows.Win32.Foundation.HRESULT = -1072885766
NS_E_WMP_RBC_JPGMAPPINGIMAGE: win32more.Windows.Win32.Foundation.HRESULT = -1072885756
NS_E_WMP_JPGTRANSPARENCY: win32more.Windows.Win32.Foundation.HRESULT = -1072885755
NS_E_WMP_INVALID_MAX_VAL: win32more.Windows.Win32.Foundation.HRESULT = -1072885751
NS_E_WMP_INVALID_MIN_VAL: win32more.Windows.Win32.Foundation.HRESULT = -1072885750
NS_E_WMP_CS_JPGPOSITIONIMAGE: win32more.Windows.Win32.Foundation.HRESULT = -1072885746
NS_E_WMP_CS_NOTEVENLYDIVISIBLE: win32more.Windows.Win32.Foundation.HRESULT = -1072885745
NS_E_WMPZIP_NOTAZIPFILE: win32more.Windows.Win32.Foundation.HRESULT = -1072885736
NS_E_WMPZIP_CORRUPT: win32more.Windows.Win32.Foundation.HRESULT = -1072885735
NS_E_WMPZIP_FILENOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -1072885734
NS_E_WMP_IMAGE_FILETYPE_UNSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1072885726
NS_E_WMP_IMAGE_INVALID_FORMAT: win32more.Windows.Win32.Foundation.HRESULT = -1072885725
NS_E_WMP_GIF_UNEXPECTED_ENDOFFILE: win32more.Windows.Win32.Foundation.HRESULT = -1072885724
NS_E_WMP_GIF_INVALID_FORMAT: win32more.Windows.Win32.Foundation.HRESULT = -1072885723
NS_E_WMP_GIF_BAD_VERSION_NUMBER: win32more.Windows.Win32.Foundation.HRESULT = -1072885722
NS_E_WMP_GIF_NO_IMAGE_IN_FILE: win32more.Windows.Win32.Foundation.HRESULT = -1072885721
NS_E_WMP_PNG_INVALIDFORMAT: win32more.Windows.Win32.Foundation.HRESULT = -1072885720
NS_E_WMP_PNG_UNSUPPORTED_BITDEPTH: win32more.Windows.Win32.Foundation.HRESULT = -1072885719
NS_E_WMP_PNG_UNSUPPORTED_COMPRESSION: win32more.Windows.Win32.Foundation.HRESULT = -1072885718
NS_E_WMP_PNG_UNSUPPORTED_FILTER: win32more.Windows.Win32.Foundation.HRESULT = -1072885717
NS_E_WMP_PNG_UNSUPPORTED_INTERLACE: win32more.Windows.Win32.Foundation.HRESULT = -1072885716
NS_E_WMP_PNG_UNSUPPORTED_BAD_CRC: win32more.Windows.Win32.Foundation.HRESULT = -1072885715
NS_E_WMP_BMP_INVALID_BITMASK: win32more.Windows.Win32.Foundation.HRESULT = -1072885714
NS_E_WMP_BMP_TOPDOWN_DIB_UNSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1072885713
NS_E_WMP_BMP_BITMAP_NOT_CREATED: win32more.Windows.Win32.Foundation.HRESULT = -1072885712
NS_E_WMP_BMP_COMPRESSION_UNSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1072885711
NS_E_WMP_BMP_INVALID_FORMAT: win32more.Windows.Win32.Foundation.HRESULT = -1072885710
NS_E_WMP_JPG_JERR_ARITHCODING_NOTIMPL: win32more.Windows.Win32.Foundation.HRESULT = -1072885709
NS_E_WMP_JPG_INVALID_FORMAT: win32more.Windows.Win32.Foundation.HRESULT = -1072885708
NS_E_WMP_JPG_BAD_DCTSIZE: win32more.Windows.Win32.Foundation.HRESULT = -1072885707
NS_E_WMP_JPG_BAD_VERSION_NUMBER: win32more.Windows.Win32.Foundation.HRESULT = -1072885706
NS_E_WMP_JPG_BAD_PRECISION: win32more.Windows.Win32.Foundation.HRESULT = -1072885705
NS_E_WMP_JPG_CCIR601_NOTIMPL: win32more.Windows.Win32.Foundation.HRESULT = -1072885704
NS_E_WMP_JPG_NO_IMAGE_IN_FILE: win32more.Windows.Win32.Foundation.HRESULT = -1072885703
NS_E_WMP_JPG_READ_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072885702
NS_E_WMP_JPG_FRACT_SAMPLE_NOTIMPL: win32more.Windows.Win32.Foundation.HRESULT = -1072885701
NS_E_WMP_JPG_IMAGE_TOO_BIG: win32more.Windows.Win32.Foundation.HRESULT = -1072885700
NS_E_WMP_JPG_UNEXPECTED_ENDOFFILE: win32more.Windows.Win32.Foundation.HRESULT = -1072885699
NS_E_WMP_JPG_SOF_UNSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1072885698
NS_E_WMP_JPG_UNKNOWN_MARKER: win32more.Windows.Win32.Foundation.HRESULT = -1072885697
NS_S_WMP_LOADED_GIF_IMAGE: win32more.Windows.Win32.Foundation.HRESULT = 856128
NS_S_WMP_LOADED_PNG_IMAGE: win32more.Windows.Win32.Foundation.HRESULT = 856129
NS_S_WMP_LOADED_BMP_IMAGE: win32more.Windows.Win32.Foundation.HRESULT = 856130
NS_S_WMP_LOADED_JPG_IMAGE: win32more.Windows.Win32.Foundation.HRESULT = 856131
NS_E_WMP_FAILED_TO_OPEN_IMAGE: win32more.Windows.Win32.Foundation.HRESULT = -1072885692
NS_E_WMP_DAI_SONGTOOSHORT: win32more.Windows.Win32.Foundation.HRESULT = -1072885687
NS_E_WMG_RATEUNAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -1072885686
NS_E_WMG_PLUGINUNAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -1072885685
NS_E_WMG_CANNOTQUEUE: win32more.Windows.Win32.Foundation.HRESULT = -1072885684
NS_E_WMG_PREROLLLICENSEACQUISITIONNOTALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -1072885683
NS_E_WMG_UNEXPECTEDPREROLLSTATUS: win32more.Windows.Win32.Foundation.HRESULT = -1072885682
NS_S_WMG_FORCE_DROP_FRAME: win32more.Windows.Win32.Foundation.HRESULT = 856143
NS_E_WMG_INVALID_COPP_CERTIFICATE: win32more.Windows.Win32.Foundation.HRESULT = -1072885679
NS_E_WMG_COPP_SECURITY_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -1072885678
NS_E_WMG_COPP_UNSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1072885677
NS_E_WMG_INVALIDSTATE: win32more.Windows.Win32.Foundation.HRESULT = -1072885676
NS_E_WMG_SINKALREADYEXISTS: win32more.Windows.Win32.Foundation.HRESULT = -1072885675
NS_E_WMG_NOSDKINTERFACE: win32more.Windows.Win32.Foundation.HRESULT = -1072885674
NS_E_WMG_NOTALLOUTPUTSRENDERED: win32more.Windows.Win32.Foundation.HRESULT = -1072885673
NS_E_WMG_FILETRANSFERNOTALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -1072885672
NS_E_WMR_UNSUPPORTEDSTREAM: win32more.Windows.Win32.Foundation.HRESULT = -1072885671
NS_E_WMR_PINNOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -1072885670
NS_E_WMR_WAITINGONFORMATSWITCH: win32more.Windows.Win32.Foundation.HRESULT = -1072885669
NS_E_WMR_NOSOURCEFILTER: win32more.Windows.Win32.Foundation.HRESULT = -1072885668
NS_E_WMR_PINTYPENOMATCH: win32more.Windows.Win32.Foundation.HRESULT = -1072885667
NS_E_WMR_NOCALLBACKAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -1072885666
NS_S_WMR_ALREADYRENDERED: win32more.Windows.Win32.Foundation.HRESULT = 856159
NS_S_WMR_PINTYPEPARTIALMATCH: win32more.Windows.Win32.Foundation.HRESULT = 856160
NS_S_WMR_PINTYPEFULLMATCH: win32more.Windows.Win32.Foundation.HRESULT = 856161
NS_E_WMR_SAMPLEPROPERTYNOTSET: win32more.Windows.Win32.Foundation.HRESULT = -1072885662
NS_E_WMR_CANNOT_RENDER_BINARY_STREAM: win32more.Windows.Win32.Foundation.HRESULT = -1072885661
NS_E_WMG_LICENSE_TAMPERED: win32more.Windows.Win32.Foundation.HRESULT = -1072885660
NS_E_WMR_WILLNOT_RENDER_BINARY_STREAM: win32more.Windows.Win32.Foundation.HRESULT = -1072885659
NS_S_WMG_ADVISE_DROP_FRAME: win32more.Windows.Win32.Foundation.HRESULT = 856166
NS_S_WMG_ADVISE_DROP_TO_KEYFRAME: win32more.Windows.Win32.Foundation.HRESULT = 856167
NS_E_WMX_UNRECOGNIZED_PLAYLIST_FORMAT: win32more.Windows.Win32.Foundation.HRESULT = -1072885656
NS_E_ASX_INVALIDFORMAT: win32more.Windows.Win32.Foundation.HRESULT = -1072885655
NS_E_ASX_INVALIDVERSION: win32more.Windows.Win32.Foundation.HRESULT = -1072885654
NS_E_ASX_INVALID_REPEAT_BLOCK: win32more.Windows.Win32.Foundation.HRESULT = -1072885653
NS_E_ASX_NOTHING_TO_WRITE: win32more.Windows.Win32.Foundation.HRESULT = -1072885652
NS_E_URLLIST_INVALIDFORMAT: win32more.Windows.Win32.Foundation.HRESULT = -1072885651
NS_E_WMX_ATTRIBUTE_DOES_NOT_EXIST: win32more.Windows.Win32.Foundation.HRESULT = -1072885650
NS_E_WMX_ATTRIBUTE_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = -1072885649
NS_E_WMX_ATTRIBUTE_UNRETRIEVABLE: win32more.Windows.Win32.Foundation.HRESULT = -1072885648
NS_E_WMX_ITEM_DOES_NOT_EXIST: win32more.Windows.Win32.Foundation.HRESULT = -1072885647
NS_E_WMX_ITEM_TYPE_ILLEGAL: win32more.Windows.Win32.Foundation.HRESULT = -1072885646
NS_E_WMX_ITEM_UNSETTABLE: win32more.Windows.Win32.Foundation.HRESULT = -1072885645
NS_E_WMX_PLAYLIST_EMPTY: win32more.Windows.Win32.Foundation.HRESULT = -1072885644
NS_E_MLS_SMARTPLAYLIST_FILTER_NOT_REGISTERED: win32more.Windows.Win32.Foundation.HRESULT = -1072885643
NS_E_WMX_INVALID_FORMAT_OVER_NESTING: win32more.Windows.Win32.Foundation.HRESULT = -1072885642
NS_E_WMPCORE_NOSOURCEURLSTRING: win32more.Windows.Win32.Foundation.HRESULT = -1072885636
NS_E_WMPCORE_COCREATEFAILEDFORGITOBJECT: win32more.Windows.Win32.Foundation.HRESULT = -1072885635
NS_E_WMPCORE_FAILEDTOGETMARSHALLEDEVENTHANDLERINTERFACE: win32more.Windows.Win32.Foundation.HRESULT = -1072885634
NS_E_WMPCORE_BUFFERTOOSMALL: win32more.Windows.Win32.Foundation.HRESULT = -1072885633
NS_E_WMPCORE_UNAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -1072885632
NS_E_WMPCORE_INVALIDPLAYLISTMODE: win32more.Windows.Win32.Foundation.HRESULT = -1072885631
NS_E_WMPCORE_ITEMNOTINPLAYLIST: win32more.Windows.Win32.Foundation.HRESULT = -1072885626
NS_E_WMPCORE_PLAYLISTEMPTY: win32more.Windows.Win32.Foundation.HRESULT = -1072885625
NS_E_WMPCORE_NOBROWSER: win32more.Windows.Win32.Foundation.HRESULT = -1072885624
NS_E_WMPCORE_UNRECOGNIZED_MEDIA_URL: win32more.Windows.Win32.Foundation.HRESULT = -1072885623
NS_E_WMPCORE_GRAPH_NOT_IN_LIST: win32more.Windows.Win32.Foundation.HRESULT = -1072885622
NS_E_WMPCORE_PLAYLIST_EMPTY_OR_SINGLE_MEDIA: win32more.Windows.Win32.Foundation.HRESULT = -1072885621
NS_E_WMPCORE_ERRORSINKNOTREGISTERED: win32more.Windows.Win32.Foundation.HRESULT = -1072885620
NS_E_WMPCORE_ERRORMANAGERNOTAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -1072885619
NS_E_WMPCORE_WEBHELPFAILED: win32more.Windows.Win32.Foundation.HRESULT = -1072885618
NS_E_WMPCORE_MEDIA_ERROR_RESUME_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -1072885617
NS_E_WMPCORE_NO_REF_IN_ENTRY: win32more.Windows.Win32.Foundation.HRESULT = -1072885616
NS_E_WMPCORE_WMX_LIST_ATTRIBUTE_NAME_EMPTY: win32more.Windows.Win32.Foundation.HRESULT = -1072885615
NS_E_WMPCORE_WMX_LIST_ATTRIBUTE_NAME_ILLEGAL: win32more.Windows.Win32.Foundation.HRESULT = -1072885614
NS_E_WMPCORE_WMX_LIST_ATTRIBUTE_VALUE_EMPTY: win32more.Windows.Win32.Foundation.HRESULT = -1072885613
NS_E_WMPCORE_WMX_LIST_ATTRIBUTE_VALUE_ILLEGAL: win32more.Windows.Win32.Foundation.HRESULT = -1072885612
NS_E_WMPCORE_WMX_LIST_ITEM_ATTRIBUTE_NAME_EMPTY: win32more.Windows.Win32.Foundation.HRESULT = -1072885611
NS_E_WMPCORE_WMX_LIST_ITEM_ATTRIBUTE_NAME_ILLEGAL: win32more.Windows.Win32.Foundation.HRESULT = -1072885610
NS_E_WMPCORE_WMX_LIST_ITEM_ATTRIBUTE_VALUE_EMPTY: win32more.Windows.Win32.Foundation.HRESULT = -1072885609
NS_E_WMPCORE_LIST_ENTRY_NO_REF: win32more.Windows.Win32.Foundation.HRESULT = -1072885608
NS_E_WMPCORE_MISNAMED_FILE: win32more.Windows.Win32.Foundation.HRESULT = -1072885607
NS_E_WMPCORE_CODEC_NOT_TRUSTED: win32more.Windows.Win32.Foundation.HRESULT = -1072885606
NS_E_WMPCORE_CODEC_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1072885605
NS_E_WMPCORE_CODEC_DOWNLOAD_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -1072885604
NS_E_WMPCORE_ERROR_DOWNLOADING_PLAYLIST: win32more.Windows.Win32.Foundation.HRESULT = -1072885603
NS_E_WMPCORE_FAILED_TO_BUILD_PLAYLIST: win32more.Windows.Win32.Foundation.HRESULT = -1072885602
NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_NONE: win32more.Windows.Win32.Foundation.HRESULT = -1072885601
NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_EXHAUSTED: win32more.Windows.Win32.Foundation.HRESULT = -1072885600
NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_NAME_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1072885599
NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_MORPH_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -1072885598
NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_INIT_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -1072885597
NS_E_WMPCORE_MEDIA_ALTERNATE_REF_EMPTY: win32more.Windows.Win32.Foundation.HRESULT = -1072885596
NS_E_WMPCORE_PLAYLIST_NO_EVENT_NAME: win32more.Windows.Win32.Foundation.HRESULT = -1072885595
NS_E_WMPCORE_PLAYLIST_EVENT_ATTRIBUTE_ABSENT: win32more.Windows.Win32.Foundation.HRESULT = -1072885594
NS_E_WMPCORE_PLAYLIST_EVENT_EMPTY: win32more.Windows.Win32.Foundation.HRESULT = -1072885593
NS_E_WMPCORE_PLAYLIST_STACK_EMPTY: win32more.Windows.Win32.Foundation.HRESULT = -1072885592
NS_E_WMPCORE_CURRENT_MEDIA_NOT_ACTIVE: win32more.Windows.Win32.Foundation.HRESULT = -1072885591
NS_E_WMPCORE_USER_CANCEL: win32more.Windows.Win32.Foundation.HRESULT = -1072885589
NS_E_WMPCORE_PLAYLIST_REPEAT_EMPTY: win32more.Windows.Win32.Foundation.HRESULT = -1072885588
NS_E_WMPCORE_PLAYLIST_REPEAT_START_MEDIA_NONE: win32more.Windows.Win32.Foundation.HRESULT = -1072885587
NS_E_WMPCORE_PLAYLIST_REPEAT_END_MEDIA_NONE: win32more.Windows.Win32.Foundation.HRESULT = -1072885586
NS_E_WMPCORE_INVALID_PLAYLIST_URL: win32more.Windows.Win32.Foundation.HRESULT = -1072885585
NS_E_WMPCORE_MISMATCHED_RUNTIME: win32more.Windows.Win32.Foundation.HRESULT = -1072885584
NS_E_WMPCORE_PLAYLIST_IMPORT_FAILED_NO_ITEMS: win32more.Windows.Win32.Foundation.HRESULT = -1072885583
NS_E_WMPCORE_VIDEO_TRANSFORM_FILTER_INSERTION: win32more.Windows.Win32.Foundation.HRESULT = -1072885582
NS_E_WMPCORE_MEDIA_UNAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -1072885581
NS_E_WMPCORE_WMX_ENTRYREF_NO_REF: win32more.Windows.Win32.Foundation.HRESULT = -1072885580
NS_E_WMPCORE_NO_PLAYABLE_MEDIA_IN_PLAYLIST: win32more.Windows.Win32.Foundation.HRESULT = -1072885579
NS_E_WMPCORE_PLAYLIST_EMPTY_NESTED_PLAYLIST_SKIPPED_ITEMS: win32more.Windows.Win32.Foundation.HRESULT = -1072885578
NS_E_WMPCORE_BUSY: win32more.Windows.Win32.Foundation.HRESULT = -1072885577
NS_E_WMPCORE_MEDIA_CHILD_PLAYLIST_UNAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -1072885576
NS_E_WMPCORE_MEDIA_NO_CHILD_PLAYLIST: win32more.Windows.Win32.Foundation.HRESULT = -1072885575
NS_E_WMPCORE_FILE_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1072885574
NS_E_WMPCORE_TEMP_FILE_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1072885573
NS_E_WMDM_REVOKED: win32more.Windows.Win32.Foundation.HRESULT = -1072885572
NS_E_DDRAW_GENERIC: win32more.Windows.Win32.Foundation.HRESULT = -1072885571
NS_E_DISPLAY_MODE_CHANGE_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -1072885570
NS_E_PLAYLIST_CONTAINS_ERRORS: win32more.Windows.Win32.Foundation.HRESULT = -1072885569
NS_E_CHANGING_PROXY_NAME: win32more.Windows.Win32.Foundation.HRESULT = -1072885568
NS_E_CHANGING_PROXY_PORT: win32more.Windows.Win32.Foundation.HRESULT = -1072885567
NS_E_CHANGING_PROXY_EXCEPTIONLIST: win32more.Windows.Win32.Foundation.HRESULT = -1072885566
NS_E_CHANGING_PROXYBYPASS: win32more.Windows.Win32.Foundation.HRESULT = -1072885565
NS_E_CHANGING_PROXY_PROTOCOL_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1072885564
NS_E_GRAPH_NOAUDIOLANGUAGE: win32more.Windows.Win32.Foundation.HRESULT = -1072885563
NS_E_GRAPH_NOAUDIOLANGUAGESELECTED: win32more.Windows.Win32.Foundation.HRESULT = -1072885562
NS_E_CORECD_NOTAMEDIACD: win32more.Windows.Win32.Foundation.HRESULT = -1072885561
NS_E_WMPCORE_MEDIA_URL_TOO_LONG: win32more.Windows.Win32.Foundation.HRESULT = -1072885560
NS_E_WMPFLASH_CANT_FIND_COM_SERVER: win32more.Windows.Win32.Foundation.HRESULT = -1072885559
NS_E_WMPFLASH_INCOMPATIBLEVERSION: win32more.Windows.Win32.Foundation.HRESULT = -1072885558
NS_E_WMPOCXGRAPH_IE_DISALLOWS_ACTIVEX_CONTROLS: win32more.Windows.Win32.Foundation.HRESULT = -1072885557
NS_E_NEED_CORE_REFERENCE: win32more.Windows.Win32.Foundation.HRESULT = -1072885556
NS_E_MEDIACD_READ_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072885555
NS_E_IE_DISALLOWS_ACTIVEX_CONTROLS: win32more.Windows.Win32.Foundation.HRESULT = -1072885554
NS_E_FLASH_PLAYBACK_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -1072885553
NS_E_UNABLE_TO_CREATE_RIP_LOCATION: win32more.Windows.Win32.Foundation.HRESULT = -1072885552
NS_E_WMPCORE_SOME_CODECS_MISSING: win32more.Windows.Win32.Foundation.HRESULT = -1072885551
NS_E_WMP_RIP_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -1072885550
NS_E_WMP_FAILED_TO_RIP_TRACK: win32more.Windows.Win32.Foundation.HRESULT = -1072885549
NS_E_WMP_ERASE_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -1072885548
NS_E_WMP_FORMAT_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -1072885547
NS_E_WMP_CANNOT_BURN_NON_LOCAL_FILE: win32more.Windows.Win32.Foundation.HRESULT = -1072885546
NS_E_WMP_FILE_TYPE_CANNOT_BURN_TO_AUDIO_CD: win32more.Windows.Win32.Foundation.HRESULT = -1072885545
NS_E_WMP_FILE_DOES_NOT_FIT_ON_CD: win32more.Windows.Win32.Foundation.HRESULT = -1072885544
NS_E_WMP_FILE_NO_DURATION: win32more.Windows.Win32.Foundation.HRESULT = -1072885543
NS_E_PDA_FAILED_TO_BURN: win32more.Windows.Win32.Foundation.HRESULT = -1072885542
NS_S_NEED_TO_BUY_BURN_RIGHTS: win32more.Windows.Win32.Foundation.HRESULT = 856283
NS_E_FAILED_DOWNLOAD_ABORT_BURN: win32more.Windows.Win32.Foundation.HRESULT = -1072885540
NS_E_WMPCORE_DEVICE_DRIVERS_MISSING: win32more.Windows.Win32.Foundation.HRESULT = -1072885539
NS_S_WMPCORE_PLAYLISTCLEARABORT: win32more.Windows.Win32.Foundation.HRESULT = 856318
NS_S_WMPCORE_PLAYLISTREMOVEITEMABORT: win32more.Windows.Win32.Foundation.HRESULT = 856319
NS_S_WMPCORE_PLAYLIST_CREATION_PENDING: win32more.Windows.Win32.Foundation.HRESULT = 856322
NS_S_WMPCORE_MEDIA_VALIDATION_PENDING: win32more.Windows.Win32.Foundation.HRESULT = 856323
NS_S_WMPCORE_PLAYLIST_REPEAT_SECONDARY_SEGMENTS_IGNORED: win32more.Windows.Win32.Foundation.HRESULT = 856324
NS_S_WMPCORE_COMMAND_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = 856325
NS_S_WMPCORE_PLAYLIST_NAME_AUTO_GENERATED: win32more.Windows.Win32.Foundation.HRESULT = 856326
NS_S_WMPCORE_PLAYLIST_IMPORT_MISSING_ITEMS: win32more.Windows.Win32.Foundation.HRESULT = 856327
NS_S_WMPCORE_PLAYLIST_COLLAPSED_TO_SINGLE_MEDIA: win32more.Windows.Win32.Foundation.HRESULT = 856328
NS_S_WMPCORE_MEDIA_CHILD_PLAYLIST_OPEN_PENDING: win32more.Windows.Win32.Foundation.HRESULT = 856329
NS_S_WMPCORE_MORE_NODES_AVAIABLE: win32more.Windows.Win32.Foundation.HRESULT = 856330
NS_E_WMPIM_USEROFFLINE: win32more.Windows.Win32.Foundation.HRESULT = -1072885466
NS_E_WMPIM_USERCANCELED: win32more.Windows.Win32.Foundation.HRESULT = -1072885465
NS_E_WMPIM_DIALUPFAILED: win32more.Windows.Win32.Foundation.HRESULT = -1072885464
NS_E_WINSOCK_ERROR_STRING: win32more.Windows.Win32.Foundation.HRESULT = -1072885463
NS_E_WMPBR_NOLISTENER: win32more.Windows.Win32.Foundation.HRESULT = -1072885456
NS_E_WMPBR_BACKUPCANCEL: win32more.Windows.Win32.Foundation.HRESULT = -1072885455
NS_E_WMPBR_RESTORECANCEL: win32more.Windows.Win32.Foundation.HRESULT = -1072885454
NS_E_WMPBR_ERRORWITHURL: win32more.Windows.Win32.Foundation.HRESULT = -1072885453
NS_E_WMPBR_NAMECOLLISION: win32more.Windows.Win32.Foundation.HRESULT = -1072885452
NS_S_WMPBR_SUCCESS: win32more.Windows.Win32.Foundation.HRESULT = 856373
NS_S_WMPBR_PARTIALSUCCESS: win32more.Windows.Win32.Foundation.HRESULT = 856374
NS_E_WMPBR_DRIVE_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -1072885449
NS_E_WMPBR_BACKUPRESTOREFAILED: win32more.Windows.Win32.Foundation.HRESULT = -1072885448
NS_S_WMPEFFECT_TRANSPARENT: win32more.Windows.Win32.Foundation.HRESULT = 856388
NS_S_WMPEFFECT_OPAQUE: win32more.Windows.Win32.Foundation.HRESULT = 856389
NS_S_OPERATION_PENDING: win32more.Windows.Win32.Foundation.HRESULT = 856398
NS_E_WMP_CONVERT_FILE_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -1072885416
NS_E_WMP_CONVERT_NO_RIGHTS_ERRORURL: win32more.Windows.Win32.Foundation.HRESULT = -1072885415
NS_E_WMP_CONVERT_NO_RIGHTS_NOERRORURL: win32more.Windows.Win32.Foundation.HRESULT = -1072885414
NS_E_WMP_CONVERT_FILE_CORRUPT: win32more.Windows.Win32.Foundation.HRESULT = -1072885413
NS_E_WMP_CONVERT_PLUGIN_UNAVAILABLE_ERRORURL: win32more.Windows.Win32.Foundation.HRESULT = -1072885412
NS_E_WMP_CONVERT_PLUGIN_UNAVAILABLE_NOERRORURL: win32more.Windows.Win32.Foundation.HRESULT = -1072885411
NS_E_WMP_CONVERT_PLUGIN_UNKNOWN_FILE_OWNER: win32more.Windows.Win32.Foundation.HRESULT = -1072885410
NS_E_DVD_DISC_COPY_PROTECT_OUTPUT_NS: win32more.Windows.Win32.Foundation.HRESULT = -1072885408
NS_E_DVD_DISC_COPY_PROTECT_OUTPUT_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -1072885407
NS_E_DVD_NO_SUBPICTURE_STREAM: win32more.Windows.Win32.Foundation.HRESULT = -1072885406
NS_E_DVD_COPY_PROTECT: win32more.Windows.Win32.Foundation.HRESULT = -1072885405
NS_E_DVD_AUTHORING_PROBLEM: win32more.Windows.Win32.Foundation.HRESULT = -1072885404
NS_E_DVD_INVALID_DISC_REGION: win32more.Windows.Win32.Foundation.HRESULT = -1072885403
NS_E_DVD_COMPATIBLE_VIDEO_CARD: win32more.Windows.Win32.Foundation.HRESULT = -1072885402
NS_E_DVD_MACROVISION: win32more.Windows.Win32.Foundation.HRESULT = -1072885401
NS_E_DVD_SYSTEM_DECODER_REGION: win32more.Windows.Win32.Foundation.HRESULT = -1072885400
NS_E_DVD_DISC_DECODER_REGION: win32more.Windows.Win32.Foundation.HRESULT = -1072885399
NS_E_DVD_NO_VIDEO_STREAM: win32more.Windows.Win32.Foundation.HRESULT = -1072885398
NS_E_DVD_NO_AUDIO_STREAM: win32more.Windows.Win32.Foundation.HRESULT = -1072885397
NS_E_DVD_GRAPH_BUILDING: win32more.Windows.Win32.Foundation.HRESULT = -1072885396
NS_E_DVD_NO_DECODER: win32more.Windows.Win32.Foundation.HRESULT = -1072885395
NS_E_DVD_PARENTAL: win32more.Windows.Win32.Foundation.HRESULT = -1072885394
NS_E_DVD_CANNOT_JUMP: win32more.Windows.Win32.Foundation.HRESULT = -1072885393
NS_E_DVD_DEVICE_CONTENTION: win32more.Windows.Win32.Foundation.HRESULT = -1072885392
NS_E_DVD_NO_VIDEO_MEMORY: win32more.Windows.Win32.Foundation.HRESULT = -1072885391
NS_E_DVD_CANNOT_COPY_PROTECTED: win32more.Windows.Win32.Foundation.HRESULT = -1072885390
NS_E_DVD_REQUIRED_PROPERTY_NOT_SET: win32more.Windows.Win32.Foundation.HRESULT = -1072885389
NS_E_DVD_INVALID_TITLE_CHAPTER: win32more.Windows.Win32.Foundation.HRESULT = -1072885388
NS_E_NO_CD_BURNER: win32more.Windows.Win32.Foundation.HRESULT = -1072885386
NS_E_DEVICE_IS_NOT_READY: win32more.Windows.Win32.Foundation.HRESULT = -1072885385
NS_E_PDA_UNSUPPORTED_FORMAT: win32more.Windows.Win32.Foundation.HRESULT = -1072885384
NS_E_NO_PDA: win32more.Windows.Win32.Foundation.HRESULT = -1072885383
NS_E_PDA_UNSPECIFIED_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072885382
NS_E_MEMSTORAGE_BAD_DATA: win32more.Windows.Win32.Foundation.HRESULT = -1072885381
NS_E_PDA_FAIL_SELECT_DEVICE: win32more.Windows.Win32.Foundation.HRESULT = -1072885380
NS_E_PDA_FAIL_READ_WAVE_FILE: win32more.Windows.Win32.Foundation.HRESULT = -1072885379
NS_E_IMAPI_LOSSOFSTREAMING: win32more.Windows.Win32.Foundation.HRESULT = -1072885378
NS_E_PDA_DEVICE_FULL: win32more.Windows.Win32.Foundation.HRESULT = -1072885377
NS_E_FAIL_LAUNCH_ROXIO_PLUGIN: win32more.Windows.Win32.Foundation.HRESULT = -1072885376
NS_E_PDA_DEVICE_FULL_IN_SESSION: win32more.Windows.Win32.Foundation.HRESULT = -1072885375
NS_E_IMAPI_MEDIUM_INVALIDTYPE: win32more.Windows.Win32.Foundation.HRESULT = -1072885374
NS_E_PDA_MANUALDEVICE: win32more.Windows.Win32.Foundation.HRESULT = -1072885373
NS_E_PDA_PARTNERSHIPNOTEXIST: win32more.Windows.Win32.Foundation.HRESULT = -1072885372
NS_E_PDA_CANNOT_CREATE_ADDITIONAL_SYNC_RELATIONSHIP: win32more.Windows.Win32.Foundation.HRESULT = -1072885371
NS_E_PDA_NO_TRANSCODE_OF_DRM: win32more.Windows.Win32.Foundation.HRESULT = -1072885370
NS_E_PDA_TRANSCODECACHEFULL: win32more.Windows.Win32.Foundation.HRESULT = -1072885369
NS_E_PDA_TOO_MANY_FILE_COLLISIONS: win32more.Windows.Win32.Foundation.HRESULT = -1072885368
NS_E_PDA_CANNOT_TRANSCODE: win32more.Windows.Win32.Foundation.HRESULT = -1072885367
NS_E_PDA_TOO_MANY_FILES_IN_DIRECTORY: win32more.Windows.Win32.Foundation.HRESULT = -1072885366
NS_E_PROCESSINGSHOWSYNCWIZARD: win32more.Windows.Win32.Foundation.HRESULT = -1072885365
NS_E_PDA_TRANSCODE_NOT_PERMITTED: win32more.Windows.Win32.Foundation.HRESULT = -1072885364
NS_E_PDA_INITIALIZINGDEVICES: win32more.Windows.Win32.Foundation.HRESULT = -1072885363
NS_E_PDA_OBSOLETE_SP: win32more.Windows.Win32.Foundation.HRESULT = -1072885362
NS_E_PDA_TITLE_COLLISION: win32more.Windows.Win32.Foundation.HRESULT = -1072885361
NS_E_PDA_DEVICESUPPORTDISABLED: win32more.Windows.Win32.Foundation.HRESULT = -1072885360
NS_E_PDA_NO_LONGER_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -1072885359
NS_E_PDA_ENCODER_NOT_RESPONDING: win32more.Windows.Win32.Foundation.HRESULT = -1072885358
NS_E_PDA_CANNOT_SYNC_FROM_LOCATION: win32more.Windows.Win32.Foundation.HRESULT = -1072885357
NS_E_WMP_PROTOCOL_PROBLEM: win32more.Windows.Win32.Foundation.HRESULT = -1072885356
NS_E_WMP_NO_DISK_SPACE: win32more.Windows.Win32.Foundation.HRESULT = -1072885355
NS_E_WMP_LOGON_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -1072885354
NS_E_WMP_CANNOT_FIND_FILE: win32more.Windows.Win32.Foundation.HRESULT = -1072885353
NS_E_WMP_SERVER_INACCESSIBLE: win32more.Windows.Win32.Foundation.HRESULT = -1072885352
NS_E_WMP_UNSUPPORTED_FORMAT: win32more.Windows.Win32.Foundation.HRESULT = -1072885351
NS_E_WMP_DSHOW_UNSUPPORTED_FORMAT: win32more.Windows.Win32.Foundation.HRESULT = -1072885350
NS_E_WMP_PLAYLIST_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = -1072885349
NS_E_WMP_NONMEDIA_FILES: win32more.Windows.Win32.Foundation.HRESULT = -1072885348
NS_E_WMP_INVALID_ASX: win32more.Windows.Win32.Foundation.HRESULT = -1072885347
NS_E_WMP_ALREADY_IN_USE: win32more.Windows.Win32.Foundation.HRESULT = -1072885346
NS_E_WMP_IMAPI_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -1072885345
NS_E_WMP_WMDM_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -1072885344
NS_E_WMP_CODEC_NEEDED_WITH_4CC: win32more.Windows.Win32.Foundation.HRESULT = -1072885343
NS_E_WMP_CODEC_NEEDED_WITH_FORMATTAG: win32more.Windows.Win32.Foundation.HRESULT = -1072885342
NS_E_WMP_MSSAP_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -1072885341
NS_E_WMP_WMDM_INTERFACEDEAD: win32more.Windows.Win32.Foundation.HRESULT = -1072885340
NS_E_WMP_WMDM_NOTCERTIFIED: win32more.Windows.Win32.Foundation.HRESULT = -1072885339
NS_E_WMP_WMDM_LICENSE_NOTEXIST: win32more.Windows.Win32.Foundation.HRESULT = -1072885338
NS_E_WMP_WMDM_LICENSE_EXPIRED: win32more.Windows.Win32.Foundation.HRESULT = -1072885337
NS_E_WMP_WMDM_BUSY: win32more.Windows.Win32.Foundation.HRESULT = -1072885336
NS_E_WMP_WMDM_NORIGHTS: win32more.Windows.Win32.Foundation.HRESULT = -1072885335
NS_E_WMP_WMDM_INCORRECT_RIGHTS: win32more.Windows.Win32.Foundation.HRESULT = -1072885334
NS_E_WMP_IMAPI_GENERIC: win32more.Windows.Win32.Foundation.HRESULT = -1072885333
NS_E_WMP_IMAPI_DEVICE_NOTPRESENT: win32more.Windows.Win32.Foundation.HRESULT = -1072885331
NS_E_WMP_IMAPI_DEVICE_BUSY: win32more.Windows.Win32.Foundation.HRESULT = -1072885330
NS_E_WMP_IMAPI_LOSS_OF_STREAMING: win32more.Windows.Win32.Foundation.HRESULT = -1072885329
NS_E_WMP_SERVER_UNAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -1072885328
NS_E_WMP_FILE_OPEN_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -1072885327
NS_E_WMP_VERIFY_ONLINE: win32more.Windows.Win32.Foundation.HRESULT = -1072885326
NS_E_WMP_SERVER_NOT_RESPONDING: win32more.Windows.Win32.Foundation.HRESULT = -1072885325
NS_E_WMP_DRM_CORRUPT_BACKUP: win32more.Windows.Win32.Foundation.HRESULT = -1072885324
NS_E_WMP_DRM_LICENSE_SERVER_UNAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -1072885323
NS_E_WMP_NETWORK_FIREWALL: win32more.Windows.Win32.Foundation.HRESULT = -1072885322
NS_E_WMP_NO_REMOVABLE_MEDIA: win32more.Windows.Win32.Foundation.HRESULT = -1072885321
NS_E_WMP_PROXY_CONNECT_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -1072885320
NS_E_WMP_NEED_UPGRADE: win32more.Windows.Win32.Foundation.HRESULT = -1072885319
NS_E_WMP_AUDIO_HW_PROBLEM: win32more.Windows.Win32.Foundation.HRESULT = -1072885318
NS_E_WMP_INVALID_PROTOCOL: win32more.Windows.Win32.Foundation.HRESULT = -1072885317
NS_E_WMP_INVALID_LIBRARY_ADD: win32more.Windows.Win32.Foundation.HRESULT = -1072885316
NS_E_WMP_MMS_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1072885315
NS_E_WMP_NO_PROTOCOLS_SELECTED: win32more.Windows.Win32.Foundation.HRESULT = -1072885314
NS_E_WMP_GOFULLSCREEN_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -1072885313
NS_E_WMP_NETWORK_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072885312
NS_E_WMP_CONNECT_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -1072885311
NS_E_WMP_MULTICAST_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -1072885310
NS_E_WMP_SERVER_DNS_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -1072885309
NS_E_WMP_PROXY_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1072885308
NS_E_WMP_TAMPERED_CONTENT: win32more.Windows.Win32.Foundation.HRESULT = -1072885307
NS_E_WMP_OUTOFMEMORY: win32more.Windows.Win32.Foundation.HRESULT = -1072885306
NS_E_WMP_AUDIO_CODEC_NOT_INSTALLED: win32more.Windows.Win32.Foundation.HRESULT = -1072885305
NS_E_WMP_VIDEO_CODEC_NOT_INSTALLED: win32more.Windows.Win32.Foundation.HRESULT = -1072885304
NS_E_WMP_IMAPI_DEVICE_INVALIDTYPE: win32more.Windows.Win32.Foundation.HRESULT = -1072885303
NS_E_WMP_DRM_DRIVER_AUTH_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -1072885302
NS_E_WMP_NETWORK_RESOURCE_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -1072885301
NS_E_WMP_UPGRADE_APPLICATION: win32more.Windows.Win32.Foundation.HRESULT = -1072885300
NS_E_WMP_UNKNOWN_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072885299
NS_E_WMP_INVALID_KEY: win32more.Windows.Win32.Foundation.HRESULT = -1072885298
NS_E_WMP_CD_ANOTHER_USER: win32more.Windows.Win32.Foundation.HRESULT = -1072885297
NS_E_WMP_DRM_NEEDS_AUTHORIZATION: win32more.Windows.Win32.Foundation.HRESULT = -1072885296
NS_E_WMP_BAD_DRIVER: win32more.Windows.Win32.Foundation.HRESULT = -1072885295
NS_E_WMP_ACCESS_DENIED: win32more.Windows.Win32.Foundation.HRESULT = -1072885294
NS_E_WMP_LICENSE_RESTRICTS: win32more.Windows.Win32.Foundation.HRESULT = -1072885293
NS_E_WMP_INVALID_REQUEST: win32more.Windows.Win32.Foundation.HRESULT = -1072885292
NS_E_WMP_CD_STASH_NO_SPACE: win32more.Windows.Win32.Foundation.HRESULT = -1072885291
NS_E_WMP_DRM_NEW_HARDWARE: win32more.Windows.Win32.Foundation.HRESULT = -1072885290
NS_E_WMP_DRM_INVALID_SIG: win32more.Windows.Win32.Foundation.HRESULT = -1072885289
NS_E_WMP_DRM_CANNOT_RESTORE: win32more.Windows.Win32.Foundation.HRESULT = -1072885288
NS_E_WMP_BURN_DISC_OVERFLOW: win32more.Windows.Win32.Foundation.HRESULT = -1072885287
NS_E_WMP_DRM_GENERIC_LICENSE_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -1072885286
NS_E_WMP_DRM_NO_SECURE_CLOCK: win32more.Windows.Win32.Foundation.HRESULT = -1072885285
NS_E_WMP_DRM_NO_RIGHTS: win32more.Windows.Win32.Foundation.HRESULT = -1072885284
NS_E_WMP_DRM_INDIV_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -1072885283
NS_E_WMP_SERVER_NONEWCONNECTIONS: win32more.Windows.Win32.Foundation.HRESULT = -1072885282
NS_E_WMP_MULTIPLE_ERROR_IN_PLAYLIST: win32more.Windows.Win32.Foundation.HRESULT = -1072885281
NS_E_WMP_IMAPI2_ERASE_FAIL: win32more.Windows.Win32.Foundation.HRESULT = -1072885280
NS_E_WMP_IMAPI2_ERASE_DEVICE_BUSY: win32more.Windows.Win32.Foundation.HRESULT = -1072885279
NS_E_WMP_DRM_COMPONENT_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -1072885278
NS_E_WMP_DRM_NO_DEVICE_CERT: win32more.Windows.Win32.Foundation.HRESULT = -1072885277
NS_E_WMP_SERVER_SECURITY_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072885276
NS_E_WMP_AUDIO_DEVICE_LOST: win32more.Windows.Win32.Foundation.HRESULT = -1072885275
NS_E_WMP_IMAPI_MEDIA_INCOMPATIBLE: win32more.Windows.Win32.Foundation.HRESULT = -1072885274
NS_E_SYNCWIZ_DEVICE_FULL: win32more.Windows.Win32.Foundation.HRESULT = -1072885266
NS_E_SYNCWIZ_CANNOT_CHANGE_SETTINGS: win32more.Windows.Win32.Foundation.HRESULT = -1072885265
NS_E_TRANSCODE_DELETECACHEERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072885264
NS_E_CD_NO_BUFFERS_READ: win32more.Windows.Win32.Foundation.HRESULT = -1072885256
NS_E_CD_EMPTY_TRACK_QUEUE: win32more.Windows.Win32.Foundation.HRESULT = -1072885255
NS_E_CD_NO_READER: win32more.Windows.Win32.Foundation.HRESULT = -1072885254
NS_E_CD_ISRC_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -1072885253
NS_E_CD_MEDIA_CATALOG_NUMBER_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -1072885252
NS_E_SLOW_READ_DIGITAL_WITH_ERRORCORRECTION: win32more.Windows.Win32.Foundation.HRESULT = -1072885251
NS_E_CD_SPEEDDETECT_NOT_ENOUGH_READS: win32more.Windows.Win32.Foundation.HRESULT = -1072885250
NS_E_CD_QUEUEING_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -1072885249
NS_E_WMP_DRM_ACQUIRING_LICENSE: win32more.Windows.Win32.Foundation.HRESULT = -1072885246
NS_E_WMP_DRM_LICENSE_EXPIRED: win32more.Windows.Win32.Foundation.HRESULT = -1072885245
NS_E_WMP_DRM_LICENSE_NOTACQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -1072885244
NS_E_WMP_DRM_LICENSE_NOTENABLED: win32more.Windows.Win32.Foundation.HRESULT = -1072885243
NS_E_WMP_DRM_LICENSE_UNUSABLE: win32more.Windows.Win32.Foundation.HRESULT = -1072885242
NS_E_WMP_DRM_LICENSE_CONTENT_REVOKED: win32more.Windows.Win32.Foundation.HRESULT = -1072885241
NS_E_WMP_DRM_LICENSE_NOSAP: win32more.Windows.Win32.Foundation.HRESULT = -1072885240
NS_E_WMP_DRM_UNABLE_TO_ACQUIRE_LICENSE: win32more.Windows.Win32.Foundation.HRESULT = -1072885239
NS_E_WMP_LICENSE_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -1072885238
NS_E_WMP_PROTECTED_CONTENT: win32more.Windows.Win32.Foundation.HRESULT = -1072885237
NS_E_WMP_POLICY_VALUE_NOT_CONFIGURED: win32more.Windows.Win32.Foundation.HRESULT = -1072885206
NS_E_PDA_CANNOT_SYNC_FROM_INTERNET: win32more.Windows.Win32.Foundation.HRESULT = -1072885196
NS_E_PDA_CANNOT_SYNC_INVALID_PLAYLIST: win32more.Windows.Win32.Foundation.HRESULT = -1072885195
NS_E_PDA_FAILED_TO_SYNCHRONIZE_FILE: win32more.Windows.Win32.Foundation.HRESULT = -1072885194
NS_E_PDA_SYNC_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -1072885193
NS_E_PDA_DELETE_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -1072885192
NS_E_PDA_FAILED_TO_RETRIEVE_FILE: win32more.Windows.Win32.Foundation.HRESULT = -1072885191
NS_E_PDA_DEVICE_NOT_RESPONDING: win32more.Windows.Win32.Foundation.HRESULT = -1072885190
NS_E_PDA_FAILED_TO_TRANSCODE_PHOTO: win32more.Windows.Win32.Foundation.HRESULT = -1072885189
NS_E_PDA_FAILED_TO_ENCRYPT_TRANSCODED_FILE: win32more.Windows.Win32.Foundation.HRESULT = -1072885188
NS_E_PDA_CANNOT_TRANSCODE_TO_AUDIO: win32more.Windows.Win32.Foundation.HRESULT = -1072885187
NS_E_PDA_CANNOT_TRANSCODE_TO_VIDEO: win32more.Windows.Win32.Foundation.HRESULT = -1072885186
NS_E_PDA_CANNOT_TRANSCODE_TO_IMAGE: win32more.Windows.Win32.Foundation.HRESULT = -1072885185
NS_E_PDA_RETRIEVED_FILE_FILENAME_TOO_LONG: win32more.Windows.Win32.Foundation.HRESULT = -1072885184
NS_E_PDA_CEWMDM_DRM_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072885183
NS_E_INCOMPLETE_PLAYLIST: win32more.Windows.Win32.Foundation.HRESULT = -1072885182
NS_E_PDA_SYNC_RUNNING: win32more.Windows.Win32.Foundation.HRESULT = -1072885181
NS_E_PDA_SYNC_LOGIN_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072885180
NS_E_PDA_TRANSCODE_CODEC_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1072885179
NS_E_CANNOT_SYNC_DRM_TO_NON_JANUS_DEVICE: win32more.Windows.Win32.Foundation.HRESULT = -1072885178
NS_E_CANNOT_SYNC_PREVIOUS_SYNC_RUNNING: win32more.Windows.Win32.Foundation.HRESULT = -1072885177
NS_E_WMP_HWND_NOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -1072885156
NS_E_BKGDOWNLOAD_WRONG_NO_FILES: win32more.Windows.Win32.Foundation.HRESULT = -1072885155
NS_E_BKGDOWNLOAD_COMPLETECANCELLEDJOB: win32more.Windows.Win32.Foundation.HRESULT = -1072885154
NS_E_BKGDOWNLOAD_CANCELCOMPLETEDJOB: win32more.Windows.Win32.Foundation.HRESULT = -1072885153
NS_E_BKGDOWNLOAD_NOJOBPOINTER: win32more.Windows.Win32.Foundation.HRESULT = -1072885152
NS_E_BKGDOWNLOAD_INVALIDJOBSIGNATURE: win32more.Windows.Win32.Foundation.HRESULT = -1072885151
NS_E_BKGDOWNLOAD_FAILED_TO_CREATE_TEMPFILE: win32more.Windows.Win32.Foundation.HRESULT = -1072885150
NS_E_BKGDOWNLOAD_PLUGIN_FAILEDINITIALIZE: win32more.Windows.Win32.Foundation.HRESULT = -1072885149
NS_E_BKGDOWNLOAD_PLUGIN_FAILEDTOMOVEFILE: win32more.Windows.Win32.Foundation.HRESULT = -1072885148
NS_E_BKGDOWNLOAD_CALLFUNCFAILED: win32more.Windows.Win32.Foundation.HRESULT = -1072885147
NS_E_BKGDOWNLOAD_CALLFUNCTIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -1072885146
NS_E_BKGDOWNLOAD_CALLFUNCENDED: win32more.Windows.Win32.Foundation.HRESULT = -1072885145
NS_E_BKGDOWNLOAD_WMDUNPACKFAILED: win32more.Windows.Win32.Foundation.HRESULT = -1072885144
NS_E_BKGDOWNLOAD_FAILEDINITIALIZE: win32more.Windows.Win32.Foundation.HRESULT = -1072885143
NS_E_INTERFACE_NOT_REGISTERED_IN_GIT: win32more.Windows.Win32.Foundation.HRESULT = -1072885142
NS_E_BKGDOWNLOAD_INVALID_FILE_NAME: win32more.Windows.Win32.Foundation.HRESULT = -1072885141
NS_E_IMAGE_DOWNLOAD_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -1072885106
NS_E_WMP_UDRM_NOUSERLIST: win32more.Windows.Win32.Foundation.HRESULT = -1072885056
NS_E_WMP_DRM_NOT_ACQUIRING: win32more.Windows.Win32.Foundation.HRESULT = -1072885055
NS_E_WMP_BSTR_TOO_LONG: win32more.Windows.Win32.Foundation.HRESULT = -1072885006
NS_E_WMP_AUTOPLAY_INVALID_STATE: win32more.Windows.Win32.Foundation.HRESULT = -1072884996
NS_E_WMP_COMPONENT_REVOKED: win32more.Windows.Win32.Foundation.HRESULT = -1072884986
NS_E_CURL_NOTSAFE: win32more.Windows.Win32.Foundation.HRESULT = -1072884956
NS_E_CURL_INVALIDCHAR: win32more.Windows.Win32.Foundation.HRESULT = -1072884955
NS_E_CURL_INVALIDHOSTNAME: win32more.Windows.Win32.Foundation.HRESULT = -1072884954
NS_E_CURL_INVALIDPATH: win32more.Windows.Win32.Foundation.HRESULT = -1072884953
NS_E_CURL_INVALIDSCHEME: win32more.Windows.Win32.Foundation.HRESULT = -1072884952
NS_E_CURL_INVALIDURL: win32more.Windows.Win32.Foundation.HRESULT = -1072884951
NS_E_CURL_CANTWALK: win32more.Windows.Win32.Foundation.HRESULT = -1072884949
NS_E_CURL_INVALIDPORT: win32more.Windows.Win32.Foundation.HRESULT = -1072884948
NS_E_CURLHELPER_NOTADIRECTORY: win32more.Windows.Win32.Foundation.HRESULT = -1072884947
NS_E_CURLHELPER_NOTAFILE: win32more.Windows.Win32.Foundation.HRESULT = -1072884946
NS_E_CURL_CANTDECODE: win32more.Windows.Win32.Foundation.HRESULT = -1072884945
NS_E_CURLHELPER_NOTRELATIVE: win32more.Windows.Win32.Foundation.HRESULT = -1072884944
NS_E_CURL_INVALIDBUFFERSIZE: win32more.Windows.Win32.Foundation.HRESULT = -1072884943
NS_E_SUBSCRIPTIONSERVICE_PLAYBACK_DISALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -1072884906
NS_E_CANNOT_BUY_OR_DOWNLOAD_FROM_MULTIPLE_SERVICES: win32more.Windows.Win32.Foundation.HRESULT = -1072884905
NS_E_CANNOT_BUY_OR_DOWNLOAD_CONTENT: win32more.Windows.Win32.Foundation.HRESULT = -1072884904
NS_S_TRACK_BUY_REQUIRES_ALBUM_PURCHASE: win32more.Windows.Win32.Foundation.HRESULT = 856921
NS_E_NOT_CONTENT_PARTNER_TRACK: win32more.Windows.Win32.Foundation.HRESULT = -1072884902
NS_E_TRACK_DOWNLOAD_REQUIRES_ALBUM_PURCHASE: win32more.Windows.Win32.Foundation.HRESULT = -1072884901
NS_E_TRACK_DOWNLOAD_REQUIRES_PURCHASE: win32more.Windows.Win32.Foundation.HRESULT = -1072884900
NS_E_TRACK_PURCHASE_MAXIMUM_EXCEEDED: win32more.Windows.Win32.Foundation.HRESULT = -1072884899
NS_S_NAVIGATION_COMPLETE_WITH_ERRORS: win32more.Windows.Win32.Foundation.HRESULT = 856926
NS_E_SUBSCRIPTIONSERVICE_LOGIN_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -1072884897
NS_E_SUBSCRIPTIONSERVICE_DOWNLOAD_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -1072884896
NS_S_TRACK_ALREADY_DOWNLOADED: win32more.Windows.Win32.Foundation.HRESULT = 856929
NS_E_CONTENT_PARTNER_STILL_INITIALIZING: win32more.Windows.Win32.Foundation.HRESULT = -1072884894
NS_E_OPEN_CONTAINING_FOLDER_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -1072884893
NS_E_ADVANCEDEDIT_TOO_MANY_PICTURES: win32more.Windows.Win32.Foundation.HRESULT = -1072884886
NS_E_REDIRECT: win32more.Windows.Win32.Foundation.HRESULT = -1072884856
NS_E_STALE_PRESENTATION: win32more.Windows.Win32.Foundation.HRESULT = -1072884855
NS_E_NAMESPACE_WRONG_PERSIST: win32more.Windows.Win32.Foundation.HRESULT = -1072884854
NS_E_NAMESPACE_WRONG_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -1072884853
NS_E_NAMESPACE_NODE_CONFLICT: win32more.Windows.Win32.Foundation.HRESULT = -1072884852
NS_E_NAMESPACE_NODE_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1072884851
NS_E_NAMESPACE_BUFFER_TOO_SMALL: win32more.Windows.Win32.Foundation.HRESULT = -1072884850
NS_E_NAMESPACE_TOO_MANY_CALLBACKS: win32more.Windows.Win32.Foundation.HRESULT = -1072884849
NS_E_NAMESPACE_DUPLICATE_CALLBACK: win32more.Windows.Win32.Foundation.HRESULT = -1072884848
NS_E_NAMESPACE_CALLBACK_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1072884847
NS_E_NAMESPACE_NAME_TOO_LONG: win32more.Windows.Win32.Foundation.HRESULT = -1072884846
NS_E_NAMESPACE_DUPLICATE_NAME: win32more.Windows.Win32.Foundation.HRESULT = -1072884845
NS_E_NAMESPACE_EMPTY_NAME: win32more.Windows.Win32.Foundation.HRESULT = -1072884844
NS_E_NAMESPACE_INDEX_TOO_LARGE: win32more.Windows.Win32.Foundation.HRESULT = -1072884843
NS_E_NAMESPACE_BAD_NAME: win32more.Windows.Win32.Foundation.HRESULT = -1072884842
NS_E_NAMESPACE_WRONG_SECURITY: win32more.Windows.Win32.Foundation.HRESULT = -1072884841
NS_E_CACHE_ARCHIVE_CONFLICT: win32more.Windows.Win32.Foundation.HRESULT = -1072884756
NS_E_CACHE_ORIGIN_SERVER_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1072884755
NS_E_CACHE_ORIGIN_SERVER_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -1072884754
NS_E_CACHE_NOT_BROADCAST: win32more.Windows.Win32.Foundation.HRESULT = -1072884753
NS_E_CACHE_CANNOT_BE_CACHED: win32more.Windows.Win32.Foundation.HRESULT = -1072884752
NS_E_CACHE_NOT_MODIFIED: win32more.Windows.Win32.Foundation.HRESULT = -1072884751
NS_E_CANNOT_REMOVE_PUBLISHING_POINT: win32more.Windows.Win32.Foundation.HRESULT = -1072884656
NS_E_CANNOT_REMOVE_PLUGIN: win32more.Windows.Win32.Foundation.HRESULT = -1072884655
NS_E_WRONG_PUBLISHING_POINT_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -1072884654
NS_E_UNSUPPORTED_LOAD_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -1072884653
NS_E_INVALID_PLUGIN_LOAD_TYPE_CONFIGURATION: win32more.Windows.Win32.Foundation.HRESULT = -1072884652
NS_E_INVALID_PUBLISHING_POINT_NAME: win32more.Windows.Win32.Foundation.HRESULT = -1072884651
NS_E_TOO_MANY_MULTICAST_SINKS: win32more.Windows.Win32.Foundation.HRESULT = -1072884650
NS_E_PUBLISHING_POINT_INVALID_REQUEST_WHILE_STARTED: win32more.Windows.Win32.Foundation.HRESULT = -1072884649
NS_E_MULTICAST_PLUGIN_NOT_ENABLED: win32more.Windows.Win32.Foundation.HRESULT = -1072884648
NS_E_INVALID_OPERATING_SYSTEM_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -1072884647
NS_E_PUBLISHING_POINT_REMOVED: win32more.Windows.Win32.Foundation.HRESULT = -1072884646
NS_E_INVALID_PUSH_PUBLISHING_POINT_START_REQUEST: win32more.Windows.Win32.Foundation.HRESULT = -1072884645
NS_E_UNSUPPORTED_LANGUAGE: win32more.Windows.Win32.Foundation.HRESULT = -1072884644
NS_E_WRONG_OS_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -1072884643
NS_E_PUBLISHING_POINT_STOPPED: win32more.Windows.Win32.Foundation.HRESULT = -1072884642
NS_E_PLAYLIST_ENTRY_ALREADY_PLAYING: win32more.Windows.Win32.Foundation.HRESULT = -1072884556
NS_E_EMPTY_PLAYLIST: win32more.Windows.Win32.Foundation.HRESULT = -1072884555
NS_E_PLAYLIST_PARSE_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -1072884554
NS_E_PLAYLIST_UNSUPPORTED_ENTRY: win32more.Windows.Win32.Foundation.HRESULT = -1072884553
NS_E_PLAYLIST_ENTRY_NOT_IN_PLAYLIST: win32more.Windows.Win32.Foundation.HRESULT = -1072884552
NS_E_PLAYLIST_ENTRY_SEEK: win32more.Windows.Win32.Foundation.HRESULT = -1072884551
NS_E_PLAYLIST_RECURSIVE_PLAYLISTS: win32more.Windows.Win32.Foundation.HRESULT = -1072884550
NS_E_PLAYLIST_TOO_MANY_NESTED_PLAYLISTS: win32more.Windows.Win32.Foundation.HRESULT = -1072884549
NS_E_PLAYLIST_SHUTDOWN: win32more.Windows.Win32.Foundation.HRESULT = -1072884548
NS_E_PLAYLIST_END_RECEDING: win32more.Windows.Win32.Foundation.HRESULT = -1072884547
NS_I_PLAYLIST_CHANGE_RECEDING: win32more.Windows.Win32.Foundation.HRESULT = 1074599102
NS_E_DATAPATH_NO_SINK: win32more.Windows.Win32.Foundation.HRESULT = -1072884456
NS_S_PUBLISHING_POINT_STARTED_WITH_FAILED_SINKS: win32more.Windows.Win32.Foundation.HRESULT = 857369
NS_E_INVALID_PUSH_TEMPLATE: win32more.Windows.Win32.Foundation.HRESULT = -1072884454
NS_E_INVALID_PUSH_PUBLISHING_POINT: win32more.Windows.Win32.Foundation.HRESULT = -1072884453
NS_E_CRITICAL_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072884452
NS_E_NO_NEW_CONNECTIONS: win32more.Windows.Win32.Foundation.HRESULT = -1072884451
NS_E_WSX_INVALID_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -1072884450
NS_E_HEADER_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -1072884449
NS_E_PUSH_DUPLICATE_PUBLISHING_POINT_NAME: win32more.Windows.Win32.Foundation.HRESULT = -1072884448
NS_E_NO_SCRIPT_ENGINE: win32more.Windows.Win32.Foundation.HRESULT = -1072884356
NS_E_PLUGIN_ERROR_REPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1072884355
NS_E_SOURCE_PLUGIN_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1072884354
NS_E_PLAYLIST_PLUGIN_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1072884353
NS_E_DATA_SOURCE_ENUMERATION_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1072884352
NS_E_MEDIA_PARSER_INVALID_FORMAT: win32more.Windows.Win32.Foundation.HRESULT = -1072884351
NS_E_SCRIPT_DEBUGGER_NOT_INSTALLED: win32more.Windows.Win32.Foundation.HRESULT = -1072884350
NS_E_FEATURE_REQUIRES_ENTERPRISE_SERVER: win32more.Windows.Win32.Foundation.HRESULT = -1072884349
NS_E_WIZARD_RUNNING: win32more.Windows.Win32.Foundation.HRESULT = -1072884348
NS_E_INVALID_LOG_URL: win32more.Windows.Win32.Foundation.HRESULT = -1072884347
NS_E_INVALID_MTU_RANGE: win32more.Windows.Win32.Foundation.HRESULT = -1072884346
NS_E_INVALID_PLAY_STATISTICS: win32more.Windows.Win32.Foundation.HRESULT = -1072884345
NS_E_LOG_NEED_TO_BE_SKIPPED: win32more.Windows.Win32.Foundation.HRESULT = -1072884344
NS_E_HTTP_TEXT_DATACONTAINER_SIZE_LIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.HRESULT = -1072884343
NS_E_PORT_IN_USE: win32more.Windows.Win32.Foundation.HRESULT = -1072884342
NS_E_PORT_IN_USE_HTTP: win32more.Windows.Win32.Foundation.HRESULT = -1072884341
NS_E_HTTP_TEXT_DATACONTAINER_INVALID_SERVER_RESPONSE: win32more.Windows.Win32.Foundation.HRESULT = -1072884340
NS_E_ARCHIVE_REACH_QUOTA: win32more.Windows.Win32.Foundation.HRESULT = -1072884339
NS_E_ARCHIVE_ABORT_DUE_TO_BCAST: win32more.Windows.Win32.Foundation.HRESULT = -1072884338
NS_E_ARCHIVE_GAP_DETECTED: win32more.Windows.Win32.Foundation.HRESULT = -1072884337
NS_E_AUTHORIZATION_FILE_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1072884336
NS_E_BAD_MARKIN: win32more.Windows.Win32.Foundation.HRESULT = -1072882856
NS_E_BAD_MARKOUT: win32more.Windows.Win32.Foundation.HRESULT = -1072882855
NS_E_NOMATCHING_MEDIASOURCE: win32more.Windows.Win32.Foundation.HRESULT = -1072882854
NS_E_UNSUPPORTED_SOURCETYPE: win32more.Windows.Win32.Foundation.HRESULT = -1072882853
NS_E_TOO_MANY_AUDIO: win32more.Windows.Win32.Foundation.HRESULT = -1072882852
NS_E_TOO_MANY_VIDEO: win32more.Windows.Win32.Foundation.HRESULT = -1072882851
NS_E_NOMATCHING_ELEMENT: win32more.Windows.Win32.Foundation.HRESULT = -1072882850
NS_E_MISMATCHED_MEDIACONTENT: win32more.Windows.Win32.Foundation.HRESULT = -1072882849
NS_E_CANNOT_DELETE_ACTIVE_SOURCEGROUP: win32more.Windows.Win32.Foundation.HRESULT = -1072882848
NS_E_AUDIODEVICE_BUSY: win32more.Windows.Win32.Foundation.HRESULT = -1072882847
NS_E_AUDIODEVICE_UNEXPECTED: win32more.Windows.Win32.Foundation.HRESULT = -1072882846
NS_E_AUDIODEVICE_BADFORMAT: win32more.Windows.Win32.Foundation.HRESULT = -1072882845
NS_E_VIDEODEVICE_BUSY: win32more.Windows.Win32.Foundation.HRESULT = -1072882844
NS_E_VIDEODEVICE_UNEXPECTED: win32more.Windows.Win32.Foundation.HRESULT = -1072882843
NS_E_INVALIDCALL_WHILE_ENCODER_RUNNING: win32more.Windows.Win32.Foundation.HRESULT = -1072882842
NS_E_NO_PROFILE_IN_SOURCEGROUP: win32more.Windows.Win32.Foundation.HRESULT = -1072882841
NS_E_VIDEODRIVER_UNSTABLE: win32more.Windows.Win32.Foundation.HRESULT = -1072882840
NS_E_VIDCAPSTARTFAILED: win32more.Windows.Win32.Foundation.HRESULT = -1072882839
NS_E_VIDSOURCECOMPRESSION: win32more.Windows.Win32.Foundation.HRESULT = -1072882838
NS_E_VIDSOURCESIZE: win32more.Windows.Win32.Foundation.HRESULT = -1072882837
NS_E_ICMQUERYFORMAT: win32more.Windows.Win32.Foundation.HRESULT = -1072882836
NS_E_VIDCAPCREATEWINDOW: win32more.Windows.Win32.Foundation.HRESULT = -1072882835
NS_E_VIDCAPDRVINUSE: win32more.Windows.Win32.Foundation.HRESULT = -1072882834
NS_E_NO_MEDIAFORMAT_IN_SOURCE: win32more.Windows.Win32.Foundation.HRESULT = -1072882833
NS_E_NO_VALID_OUTPUT_STREAM: win32more.Windows.Win32.Foundation.HRESULT = -1072882832
NS_E_NO_VALID_SOURCE_PLUGIN: win32more.Windows.Win32.Foundation.HRESULT = -1072882831
NS_E_NO_ACTIVE_SOURCEGROUP: win32more.Windows.Win32.Foundation.HRESULT = -1072882830
NS_E_NO_SCRIPT_STREAM: win32more.Windows.Win32.Foundation.HRESULT = -1072882829
NS_E_INVALIDCALL_WHILE_ARCHIVAL_RUNNING: win32more.Windows.Win32.Foundation.HRESULT = -1072882828
NS_E_INVALIDPACKETSIZE: win32more.Windows.Win32.Foundation.HRESULT = -1072882827
NS_E_PLUGIN_CLSID_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -1072882826
NS_E_UNSUPPORTED_ARCHIVETYPE: win32more.Windows.Win32.Foundation.HRESULT = -1072882825
NS_E_UNSUPPORTED_ARCHIVEOPERATION: win32more.Windows.Win32.Foundation.HRESULT = -1072882824
NS_E_ARCHIVE_FILENAME_NOTSET: win32more.Windows.Win32.Foundation.HRESULT = -1072882823
NS_E_SOURCEGROUP_NOTPREPARED: win32more.Windows.Win32.Foundation.HRESULT = -1072882822
NS_E_PROFILE_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -1072882821
NS_E_INCORRECTCLIPSETTINGS: win32more.Windows.Win32.Foundation.HRESULT = -1072882820
NS_E_NOSTATSAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -1072882819
NS_E_NOTARCHIVING: win32more.Windows.Win32.Foundation.HRESULT = -1072882818
NS_E_INVALIDCALL_WHILE_ENCODER_STOPPED: win32more.Windows.Win32.Foundation.HRESULT = -1072882817
NS_E_NOSOURCEGROUPS: win32more.Windows.Win32.Foundation.HRESULT = -1072882816
NS_E_INVALIDINPUTFPS: win32more.Windows.Win32.Foundation.HRESULT = -1072882815
NS_E_NO_DATAVIEW_SUPPORT: win32more.Windows.Win32.Foundation.HRESULT = -1072882814
NS_E_CODEC_UNAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -1072882813
NS_E_ARCHIVE_SAME_AS_INPUT: win32more.Windows.Win32.Foundation.HRESULT = -1072882812
NS_E_SOURCE_NOTSPECIFIED: win32more.Windows.Win32.Foundation.HRESULT = -1072882811
NS_E_NO_REALTIME_TIMECOMPRESSION: win32more.Windows.Win32.Foundation.HRESULT = -1072882810
NS_E_UNSUPPORTED_ENCODER_DEVICE: win32more.Windows.Win32.Foundation.HRESULT = -1072882809
NS_E_UNEXPECTED_DISPLAY_SETTINGS: win32more.Windows.Win32.Foundation.HRESULT = -1072882808
NS_E_NO_AUDIODATA: win32more.Windows.Win32.Foundation.HRESULT = -1072882807
NS_E_INPUTSOURCE_PROBLEM: win32more.Windows.Win32.Foundation.HRESULT = -1072882806
NS_E_WME_VERSION_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -1072882805
NS_E_NO_REALTIME_PREPROCESS: win32more.Windows.Win32.Foundation.HRESULT = -1072882804
NS_E_NO_REPEAT_PREPROCESS: win32more.Windows.Win32.Foundation.HRESULT = -1072882803
NS_E_CANNOT_PAUSE_LIVEBROADCAST: win32more.Windows.Win32.Foundation.HRESULT = -1072882802
NS_E_DRM_PROFILE_NOT_SET: win32more.Windows.Win32.Foundation.HRESULT = -1072882801
NS_E_DUPLICATE_DRMPROFILE: win32more.Windows.Win32.Foundation.HRESULT = -1072882800
NS_E_INVALID_DEVICE: win32more.Windows.Win32.Foundation.HRESULT = -1072882799
NS_E_SPEECHEDL_ON_NON_MIXEDMODE: win32more.Windows.Win32.Foundation.HRESULT = -1072882798
NS_E_DRM_PASSWORD_TOO_LONG: win32more.Windows.Win32.Foundation.HRESULT = -1072882797
NS_E_DEVCONTROL_FAILED_SEEK: win32more.Windows.Win32.Foundation.HRESULT = -1072882796
NS_E_INTERLACE_REQUIRE_SAMESIZE: win32more.Windows.Win32.Foundation.HRESULT = -1072882795
NS_E_TOO_MANY_DEVICECONTROL: win32more.Windows.Win32.Foundation.HRESULT = -1072882794
NS_E_NO_MULTIPASS_FOR_LIVEDEVICE: win32more.Windows.Win32.Foundation.HRESULT = -1072882793
NS_E_MISSING_AUDIENCE: win32more.Windows.Win32.Foundation.HRESULT = -1072882792
NS_E_AUDIENCE_CONTENTTYPE_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -1072882791
NS_E_MISSING_SOURCE_INDEX: win32more.Windows.Win32.Foundation.HRESULT = -1072882790
NS_E_NUM_LANGUAGE_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -1072882789
NS_E_LANGUAGE_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -1072882788
NS_E_VBRMODE_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -1072882787
NS_E_INVALID_INPUT_AUDIENCE_INDEX: win32more.Windows.Win32.Foundation.HRESULT = -1072882786
NS_E_INVALID_INPUT_LANGUAGE: win32more.Windows.Win32.Foundation.HRESULT = -1072882785
NS_E_INVALID_INPUT_STREAM: win32more.Windows.Win32.Foundation.HRESULT = -1072882784
NS_E_EXPECT_MONO_WAV_INPUT: win32more.Windows.Win32.Foundation.HRESULT = -1072882783
NS_E_INPUT_WAVFORMAT_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -1072882782
NS_E_RECORDQ_DISK_FULL: win32more.Windows.Win32.Foundation.HRESULT = -1072882781
NS_E_NO_PAL_INVERSE_TELECINE: win32more.Windows.Win32.Foundation.HRESULT = -1072882780
NS_E_ACTIVE_SG_DEVICE_DISCONNECTED: win32more.Windows.Win32.Foundation.HRESULT = -1072882779
NS_E_ACTIVE_SG_DEVICE_CONTROL_DISCONNECTED: win32more.Windows.Win32.Foundation.HRESULT = -1072882778
NS_E_NO_FRAMES_SUBMITTED_TO_ANALYZER: win32more.Windows.Win32.Foundation.HRESULT = -1072882777
NS_E_INPUT_DOESNOT_SUPPORT_SMPTE: win32more.Windows.Win32.Foundation.HRESULT = -1072882776
NS_E_NO_SMPTE_WITH_MULTIPLE_SOURCEGROUPS: win32more.Windows.Win32.Foundation.HRESULT = -1072882775
NS_E_BAD_CONTENTEDL: win32more.Windows.Win32.Foundation.HRESULT = -1072882774
NS_E_INTERLACEMODE_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -1072882773
NS_E_NONSQUAREPIXELMODE_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -1072882772
NS_E_SMPTEMODE_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -1072882771
NS_E_END_OF_TAPE: win32more.Windows.Win32.Foundation.HRESULT = -1072882770
NS_E_NO_MEDIA_IN_AUDIENCE: win32more.Windows.Win32.Foundation.HRESULT = -1072882769
NS_E_NO_AUDIENCES: win32more.Windows.Win32.Foundation.HRESULT = -1072882768
NS_E_NO_AUDIO_COMPAT: win32more.Windows.Win32.Foundation.HRESULT = -1072882767
NS_E_INVALID_VBR_COMPAT: win32more.Windows.Win32.Foundation.HRESULT = -1072882766
NS_E_NO_PROFILE_NAME: win32more.Windows.Win32.Foundation.HRESULT = -1072882765
NS_E_INVALID_VBR_WITH_UNCOMP: win32more.Windows.Win32.Foundation.HRESULT = -1072882764
NS_E_MULTIPLE_VBR_AUDIENCES: win32more.Windows.Win32.Foundation.HRESULT = -1072882763
NS_E_UNCOMP_COMP_COMBINATION: win32more.Windows.Win32.Foundation.HRESULT = -1072882762
NS_E_MULTIPLE_AUDIO_CODECS: win32more.Windows.Win32.Foundation.HRESULT = -1072882761
NS_E_MULTIPLE_AUDIO_FORMATS: win32more.Windows.Win32.Foundation.HRESULT = -1072882760
NS_E_AUDIO_BITRATE_STEPDOWN: win32more.Windows.Win32.Foundation.HRESULT = -1072882759
NS_E_INVALID_AUDIO_PEAKRATE: win32more.Windows.Win32.Foundation.HRESULT = -1072882758
NS_E_INVALID_AUDIO_PEAKRATE_2: win32more.Windows.Win32.Foundation.HRESULT = -1072882757
NS_E_INVALID_AUDIO_BUFFERMAX: win32more.Windows.Win32.Foundation.HRESULT = -1072882756
NS_E_MULTIPLE_VIDEO_CODECS: win32more.Windows.Win32.Foundation.HRESULT = -1072882755
NS_E_MULTIPLE_VIDEO_SIZES: win32more.Windows.Win32.Foundation.HRESULT = -1072882754
NS_E_INVALID_VIDEO_BITRATE: win32more.Windows.Win32.Foundation.HRESULT = -1072882753
NS_E_VIDEO_BITRATE_STEPDOWN: win32more.Windows.Win32.Foundation.HRESULT = -1072882752
NS_E_INVALID_VIDEO_PEAKRATE: win32more.Windows.Win32.Foundation.HRESULT = -1072882751
NS_E_INVALID_VIDEO_PEAKRATE_2: win32more.Windows.Win32.Foundation.HRESULT = -1072882750
NS_E_INVALID_VIDEO_WIDTH: win32more.Windows.Win32.Foundation.HRESULT = -1072882749
NS_E_INVALID_VIDEO_HEIGHT: win32more.Windows.Win32.Foundation.HRESULT = -1072882748
NS_E_INVALID_VIDEO_FPS: win32more.Windows.Win32.Foundation.HRESULT = -1072882747
NS_E_INVALID_VIDEO_KEYFRAME: win32more.Windows.Win32.Foundation.HRESULT = -1072882746
NS_E_INVALID_VIDEO_IQUALITY: win32more.Windows.Win32.Foundation.HRESULT = -1072882745
NS_E_INVALID_VIDEO_CQUALITY: win32more.Windows.Win32.Foundation.HRESULT = -1072882744
NS_E_INVALID_VIDEO_BUFFER: win32more.Windows.Win32.Foundation.HRESULT = -1072882743
NS_E_INVALID_VIDEO_BUFFERMAX: win32more.Windows.Win32.Foundation.HRESULT = -1072882742
NS_E_INVALID_VIDEO_BUFFERMAX_2: win32more.Windows.Win32.Foundation.HRESULT = -1072882741
NS_E_INVALID_VIDEO_WIDTH_ALIGN: win32more.Windows.Win32.Foundation.HRESULT = -1072882740
NS_E_INVALID_VIDEO_HEIGHT_ALIGN: win32more.Windows.Win32.Foundation.HRESULT = -1072882739
NS_E_MULTIPLE_SCRIPT_BITRATES: win32more.Windows.Win32.Foundation.HRESULT = -1072882738
NS_E_INVALID_SCRIPT_BITRATE: win32more.Windows.Win32.Foundation.HRESULT = -1072882737
NS_E_MULTIPLE_FILE_BITRATES: win32more.Windows.Win32.Foundation.HRESULT = -1072882736
NS_E_INVALID_FILE_BITRATE: win32more.Windows.Win32.Foundation.HRESULT = -1072882735
NS_E_SAME_AS_INPUT_COMBINATION: win32more.Windows.Win32.Foundation.HRESULT = -1072882734
NS_E_SOURCE_CANNOT_LOOP: win32more.Windows.Win32.Foundation.HRESULT = -1072882733
NS_E_INVALID_FOLDDOWN_COEFFICIENTS: win32more.Windows.Win32.Foundation.HRESULT = -1072882732
NS_E_DRMPROFILE_NOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -1072882731
NS_E_INVALID_TIMECODE: win32more.Windows.Win32.Foundation.HRESULT = -1072882730
NS_E_NO_AUDIO_TIMECOMPRESSION: win32more.Windows.Win32.Foundation.HRESULT = -1072882729
NS_E_NO_TWOPASS_TIMECOMPRESSION: win32more.Windows.Win32.Foundation.HRESULT = -1072882728
NS_E_TIMECODE_REQUIRES_VIDEOSTREAM: win32more.Windows.Win32.Foundation.HRESULT = -1072882727
NS_E_NO_MBR_WITH_TIMECODE: win32more.Windows.Win32.Foundation.HRESULT = -1072882726
NS_E_INVALID_INTERLACEMODE: win32more.Windows.Win32.Foundation.HRESULT = -1072882725
NS_E_INVALID_INTERLACE_COMPAT: win32more.Windows.Win32.Foundation.HRESULT = -1072882724
NS_E_INVALID_NONSQUAREPIXEL_COMPAT: win32more.Windows.Win32.Foundation.HRESULT = -1072882723
NS_E_INVALID_SOURCE_WITH_DEVICE_CONTROL: win32more.Windows.Win32.Foundation.HRESULT = -1072882722
NS_E_CANNOT_GENERATE_BROADCAST_INFO_FOR_QUALITYVBR: win32more.Windows.Win32.Foundation.HRESULT = -1072882721
NS_E_EXCEED_MAX_DRM_PROFILE_LIMIT: win32more.Windows.Win32.Foundation.HRESULT = -1072882720
NS_E_DEVICECONTROL_UNSTABLE: win32more.Windows.Win32.Foundation.HRESULT = -1072882719
NS_E_INVALID_PIXEL_ASPECT_RATIO: win32more.Windows.Win32.Foundation.HRESULT = -1072882718
NS_E_AUDIENCE__LANGUAGE_CONTENTTYPE_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -1072882717
NS_E_INVALID_PROFILE_CONTENTTYPE: win32more.Windows.Win32.Foundation.HRESULT = -1072882716
NS_E_TRANSFORM_PLUGIN_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1072882715
NS_E_TRANSFORM_PLUGIN_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -1072882714
NS_E_EDL_REQUIRED_FOR_DEVICE_MULTIPASS: win32more.Windows.Win32.Foundation.HRESULT = -1072882713
NS_E_INVALID_VIDEO_WIDTH_FOR_INTERLACED_ENCODING: win32more.Windows.Win32.Foundation.HRESULT = -1072882712
NS_E_MARKIN_UNSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1072882711
NS_E_DRM_INVALID_APPLICATION: win32more.Windows.Win32.Foundation.HRESULT = -1072879855
NS_E_DRM_LICENSE_STORE_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072879854
NS_E_DRM_SECURE_STORE_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072879853
NS_E_DRM_LICENSE_STORE_SAVE_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072879852
NS_E_DRM_SECURE_STORE_UNLOCK_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072879851
NS_E_DRM_INVALID_CONTENT: win32more.Windows.Win32.Foundation.HRESULT = -1072879850
NS_E_DRM_UNABLE_TO_OPEN_LICENSE: win32more.Windows.Win32.Foundation.HRESULT = -1072879849
NS_E_DRM_INVALID_LICENSE: win32more.Windows.Win32.Foundation.HRESULT = -1072879848
NS_E_DRM_INVALID_MACHINE: win32more.Windows.Win32.Foundation.HRESULT = -1072879847
NS_E_DRM_ENUM_LICENSE_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -1072879845
NS_E_DRM_INVALID_LICENSE_REQUEST: win32more.Windows.Win32.Foundation.HRESULT = -1072879844
NS_E_DRM_UNABLE_TO_INITIALIZE: win32more.Windows.Win32.Foundation.HRESULT = -1072879843
NS_E_DRM_UNABLE_TO_ACQUIRE_LICENSE: win32more.Windows.Win32.Foundation.HRESULT = -1072879842
NS_E_DRM_INVALID_LICENSE_ACQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -1072879841
NS_E_DRM_NO_RIGHTS: win32more.Windows.Win32.Foundation.HRESULT = -1072879840
NS_E_DRM_KEY_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072879839
NS_E_DRM_ENCRYPT_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072879838
NS_E_DRM_DECRYPT_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072879837
NS_E_DRM_LICENSE_INVALID_XML: win32more.Windows.Win32.Foundation.HRESULT = -1072879835
NS_S_DRM_LICENSE_ACQUIRED: win32more.Windows.Win32.Foundation.HRESULT = 861990
NS_S_DRM_INDIVIDUALIZED: win32more.Windows.Win32.Foundation.HRESULT = 861991
NS_E_DRM_NEEDS_INDIVIDUALIZATION: win32more.Windows.Win32.Foundation.HRESULT = -1072879832
NS_E_DRM_ALREADY_INDIVIDUALIZED: win32more.Windows.Win32.Foundation.HRESULT = -1072879831
NS_E_DRM_ACTION_NOT_QUERIED: win32more.Windows.Win32.Foundation.HRESULT = -1072879830
NS_E_DRM_ACQUIRING_LICENSE: win32more.Windows.Win32.Foundation.HRESULT = -1072879829
NS_E_DRM_INDIVIDUALIZING: win32more.Windows.Win32.Foundation.HRESULT = -1072879828
NS_E_BACKUP_RESTORE_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -1072879827
NS_E_BACKUP_RESTORE_BAD_REQUEST_ID: win32more.Windows.Win32.Foundation.HRESULT = -1072879826
NS_E_DRM_PARAMETERS_MISMATCHED: win32more.Windows.Win32.Foundation.HRESULT = -1072879825
NS_E_DRM_UNABLE_TO_CREATE_LICENSE_OBJECT: win32more.Windows.Win32.Foundation.HRESULT = -1072879824
NS_E_DRM_UNABLE_TO_CREATE_INDI_OBJECT: win32more.Windows.Win32.Foundation.HRESULT = -1072879823
NS_E_DRM_UNABLE_TO_CREATE_ENCRYPT_OBJECT: win32more.Windows.Win32.Foundation.HRESULT = -1072879822
NS_E_DRM_UNABLE_TO_CREATE_DECRYPT_OBJECT: win32more.Windows.Win32.Foundation.HRESULT = -1072879821
NS_E_DRM_UNABLE_TO_CREATE_PROPERTIES_OBJECT: win32more.Windows.Win32.Foundation.HRESULT = -1072879820
NS_E_DRM_UNABLE_TO_CREATE_BACKUP_OBJECT: win32more.Windows.Win32.Foundation.HRESULT = -1072879819
NS_E_DRM_INDIVIDUALIZE_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072879818
NS_E_DRM_LICENSE_OPEN_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072879817
NS_E_DRM_LICENSE_CLOSE_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072879816
NS_E_DRM_GET_LICENSE_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072879815
NS_E_DRM_QUERY_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072879814
NS_E_DRM_REPORT_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072879813
NS_E_DRM_GET_LICENSESTRING_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072879812
NS_E_DRM_GET_CONTENTSTRING_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072879811
NS_E_DRM_MONITOR_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072879810
NS_E_DRM_UNABLE_TO_SET_PARAMETER: win32more.Windows.Win32.Foundation.HRESULT = -1072879809
NS_E_DRM_INVALID_APPDATA: win32more.Windows.Win32.Foundation.HRESULT = -1072879808
NS_E_DRM_INVALID_APPDATA_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -1072879807
NS_E_DRM_BACKUP_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = -1072879806
NS_E_DRM_BACKUP_CORRUPT: win32more.Windows.Win32.Foundation.HRESULT = -1072879805
NS_E_DRM_BACKUPRESTORE_BUSY: win32more.Windows.Win32.Foundation.HRESULT = -1072879804
NS_E_BACKUP_RESTORE_BAD_DATA: win32more.Windows.Win32.Foundation.HRESULT = -1072879803
NS_S_DRM_MONITOR_CANCELLED: win32more.Windows.Win32.Foundation.HRESULT = 862022
NS_S_DRM_ACQUIRE_CANCELLED: win32more.Windows.Win32.Foundation.HRESULT = 862023
NS_E_DRM_LICENSE_UNUSABLE: win32more.Windows.Win32.Foundation.HRESULT = -1072879800
NS_E_DRM_INVALID_PROPERTY: win32more.Windows.Win32.Foundation.HRESULT = -1072879799
NS_E_DRM_SECURE_STORE_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1072879798
NS_E_DRM_CACHED_CONTENT_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072879797
NS_E_DRM_INDIVIDUALIZATION_INCOMPLETE: win32more.Windows.Win32.Foundation.HRESULT = -1072879796
NS_E_DRM_DRIVER_AUTH_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -1072879795
NS_E_DRM_NEED_UPGRADE_MSSAP: win32more.Windows.Win32.Foundation.HRESULT = -1072879794
NS_E_DRM_REOPEN_CONTENT: win32more.Windows.Win32.Foundation.HRESULT = -1072879793
NS_E_DRM_DRIVER_DIGIOUT_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -1072879792
NS_E_DRM_INVALID_SECURESTORE_PASSWORD: win32more.Windows.Win32.Foundation.HRESULT = -1072879791
NS_E_DRM_APPCERT_REVOKED: win32more.Windows.Win32.Foundation.HRESULT = -1072879790
NS_E_DRM_RESTORE_FRAUD: win32more.Windows.Win32.Foundation.HRESULT = -1072879789
NS_E_DRM_HARDWARE_INCONSISTENT: win32more.Windows.Win32.Foundation.HRESULT = -1072879788
NS_E_DRM_SDMI_TRIGGER: win32more.Windows.Win32.Foundation.HRESULT = -1072879787
NS_E_DRM_SDMI_NOMORECOPIES: win32more.Windows.Win32.Foundation.HRESULT = -1072879786
NS_E_DRM_UNABLE_TO_CREATE_HEADER_OBJECT: win32more.Windows.Win32.Foundation.HRESULT = -1072879785
NS_E_DRM_UNABLE_TO_CREATE_KEYS_OBJECT: win32more.Windows.Win32.Foundation.HRESULT = -1072879784
NS_E_DRM_LICENSE_NOTACQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -1072879783
NS_E_DRM_UNABLE_TO_CREATE_CODING_OBJECT: win32more.Windows.Win32.Foundation.HRESULT = -1072879782
NS_E_DRM_UNABLE_TO_CREATE_STATE_DATA_OBJECT: win32more.Windows.Win32.Foundation.HRESULT = -1072879781
NS_E_DRM_BUFFER_TOO_SMALL: win32more.Windows.Win32.Foundation.HRESULT = -1072879780
NS_E_DRM_UNSUPPORTED_PROPERTY: win32more.Windows.Win32.Foundation.HRESULT = -1072879779
NS_E_DRM_ERROR_BAD_NET_RESP: win32more.Windows.Win32.Foundation.HRESULT = -1072879778
NS_E_DRM_STORE_NOTALLSTORED: win32more.Windows.Win32.Foundation.HRESULT = -1072879777
NS_E_DRM_SECURITY_COMPONENT_SIGNATURE_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -1072879776
NS_E_DRM_INVALID_DATA: win32more.Windows.Win32.Foundation.HRESULT = -1072879775
NS_E_DRM_POLICY_DISABLE_ONLINE: win32more.Windows.Win32.Foundation.HRESULT = -1072879774
NS_E_DRM_UNABLE_TO_CREATE_AUTHENTICATION_OBJECT: win32more.Windows.Win32.Foundation.HRESULT = -1072879773
NS_E_DRM_NOT_CONFIGURED: win32more.Windows.Win32.Foundation.HRESULT = -1072879772
NS_E_DRM_DEVICE_ACTIVATION_CANCELED: win32more.Windows.Win32.Foundation.HRESULT = -1072879771
NS_E_BACKUP_RESTORE_TOO_MANY_RESETS: win32more.Windows.Win32.Foundation.HRESULT = -1072879770
NS_E_DRM_DEBUGGING_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -1072879769
NS_E_DRM_OPERATION_CANCELED: win32more.Windows.Win32.Foundation.HRESULT = -1072879768
NS_E_DRM_RESTRICTIONS_NOT_RETRIEVED: win32more.Windows.Win32.Foundation.HRESULT = -1072879767
NS_E_DRM_UNABLE_TO_CREATE_PLAYLIST_OBJECT: win32more.Windows.Win32.Foundation.HRESULT = -1072879766
NS_E_DRM_UNABLE_TO_CREATE_PLAYLIST_BURN_OBJECT: win32more.Windows.Win32.Foundation.HRESULT = -1072879765
NS_E_DRM_UNABLE_TO_CREATE_DEVICE_REGISTRATION_OBJECT: win32more.Windows.Win32.Foundation.HRESULT = -1072879764
NS_E_DRM_UNABLE_TO_CREATE_METERING_OBJECT: win32more.Windows.Win32.Foundation.HRESULT = -1072879763
NS_S_DRM_BURNABLE_TRACK: win32more.Windows.Win32.Foundation.HRESULT = 862062
NS_S_DRM_BURNABLE_TRACK_WITH_PLAYLIST_RESTRICTION: win32more.Windows.Win32.Foundation.HRESULT = 862063
NS_E_DRM_TRACK_EXCEEDED_PLAYLIST_RESTICTION: win32more.Windows.Win32.Foundation.HRESULT = -1072879760
NS_E_DRM_TRACK_EXCEEDED_TRACKBURN_RESTRICTION: win32more.Windows.Win32.Foundation.HRESULT = -1072879759
NS_E_DRM_UNABLE_TO_GET_DEVICE_CERT: win32more.Windows.Win32.Foundation.HRESULT = -1072879758
NS_E_DRM_UNABLE_TO_GET_SECURE_CLOCK: win32more.Windows.Win32.Foundation.HRESULT = -1072879757
NS_E_DRM_UNABLE_TO_SET_SECURE_CLOCK: win32more.Windows.Win32.Foundation.HRESULT = -1072879756
NS_E_DRM_UNABLE_TO_GET_SECURE_CLOCK_FROM_SERVER: win32more.Windows.Win32.Foundation.HRESULT = -1072879755
NS_E_DRM_POLICY_METERING_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -1072879754
NS_E_DRM_TRANSFER_CHAINED_LICENSES_UNSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1072879753
NS_E_DRM_SDK_VERSIONMISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -1072879752
NS_E_DRM_LIC_NEEDS_DEVICE_CLOCK_SET: win32more.Windows.Win32.Foundation.HRESULT = -1072879751
NS_E_LICENSE_HEADER_MISSING_URL: win32more.Windows.Win32.Foundation.HRESULT = -1072879750
NS_E_DEVICE_NOT_WMDRM_DEVICE: win32more.Windows.Win32.Foundation.HRESULT = -1072879749
NS_E_DRM_INVALID_APPCERT: win32more.Windows.Win32.Foundation.HRESULT = -1072879748
NS_E_DRM_PROTOCOL_FORCEFUL_TERMINATION_ON_PETITION: win32more.Windows.Win32.Foundation.HRESULT = -1072879747
NS_E_DRM_PROTOCOL_FORCEFUL_TERMINATION_ON_CHALLENGE: win32more.Windows.Win32.Foundation.HRESULT = -1072879746
NS_E_DRM_CHECKPOINT_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -1072879745
NS_E_DRM_BB_UNABLE_TO_INITIALIZE: win32more.Windows.Win32.Foundation.HRESULT = -1072879744
NS_E_DRM_UNABLE_TO_LOAD_HARDWARE_ID: win32more.Windows.Win32.Foundation.HRESULT = -1072879743
NS_E_DRM_UNABLE_TO_OPEN_DATA_STORE: win32more.Windows.Win32.Foundation.HRESULT = -1072879742
NS_E_DRM_DATASTORE_CORRUPT: win32more.Windows.Win32.Foundation.HRESULT = -1072879741
NS_E_DRM_UNABLE_TO_CREATE_INMEMORYSTORE_OBJECT: win32more.Windows.Win32.Foundation.HRESULT = -1072879740
NS_E_DRM_STUBLIB_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -1072879739
NS_E_DRM_UNABLE_TO_CREATE_CERTIFICATE_OBJECT: win32more.Windows.Win32.Foundation.HRESULT = -1072879738
NS_E_DRM_MIGRATION_TARGET_NOT_ONLINE: win32more.Windows.Win32.Foundation.HRESULT = -1072879737
NS_E_DRM_INVALID_MIGRATION_IMAGE: win32more.Windows.Win32.Foundation.HRESULT = -1072879736
NS_E_DRM_MIGRATION_TARGET_STATES_CORRUPTED: win32more.Windows.Win32.Foundation.HRESULT = -1072879735
NS_E_DRM_MIGRATION_IMPORTER_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -1072879734
NS_DRM_E_MIGRATION_UPGRADE_WITH_DIFF_SID: win32more.Windows.Win32.Foundation.HRESULT = -1072879733
NS_DRM_E_MIGRATION_SOURCE_MACHINE_IN_USE: win32more.Windows.Win32.Foundation.HRESULT = -1072879732
NS_DRM_E_MIGRATION_TARGET_MACHINE_LESS_THAN_LH: win32more.Windows.Win32.Foundation.HRESULT = -1072879731
NS_DRM_E_MIGRATION_IMAGE_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = -1072879730
NS_E_DRM_HARDWAREID_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -1072879729
NS_E_INVALID_DRMV2CLT_STUBLIB: win32more.Windows.Win32.Foundation.HRESULT = -1072879728
NS_E_DRM_MIGRATION_INVALID_LEGACYV2_DATA: win32more.Windows.Win32.Foundation.HRESULT = -1072879727
NS_E_DRM_MIGRATION_LICENSE_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = -1072879726
NS_E_DRM_MIGRATION_INVALID_LEGACYV2_SST_PASSWORD: win32more.Windows.Win32.Foundation.HRESULT = -1072879725
NS_E_DRM_MIGRATION_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1072879724
NS_E_DRM_UNABLE_TO_CREATE_MIGRATION_IMPORTER_OBJECT: win32more.Windows.Win32.Foundation.HRESULT = -1072879723
NS_E_DRM_CHECKPOINT_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -1072879722
NS_E_DRM_CHECKPOINT_CORRUPT: win32more.Windows.Win32.Foundation.HRESULT = -1072879721
NS_E_REG_FLUSH_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -1072879720
NS_E_HDS_KEY_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -1072879719
NS_E_DRM_MIGRATION_OPERATION_CANCELLED: win32more.Windows.Win32.Foundation.HRESULT = -1072879718
NS_E_DRM_MIGRATION_OBJECT_IN_USE: win32more.Windows.Win32.Foundation.HRESULT = -1072879717
NS_E_DRM_MALFORMED_CONTENT_HEADER: win32more.Windows.Win32.Foundation.HRESULT = -1072879716
NS_E_DRM_LICENSE_EXPIRED: win32more.Windows.Win32.Foundation.HRESULT = -1072879656
NS_E_DRM_LICENSE_NOTENABLED: win32more.Windows.Win32.Foundation.HRESULT = -1072879655
NS_E_DRM_LICENSE_APPSECLOW: win32more.Windows.Win32.Foundation.HRESULT = -1072879654
NS_E_DRM_STORE_NEEDINDI: win32more.Windows.Win32.Foundation.HRESULT = -1072879653
NS_E_DRM_STORE_NOTALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -1072879652
NS_E_DRM_LICENSE_APP_NOTALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -1072879651
NS_S_DRM_NEEDS_INDIVIDUALIZATION: win32more.Windows.Win32.Foundation.HRESULT = 862174
NS_E_DRM_LICENSE_CERT_EXPIRED: win32more.Windows.Win32.Foundation.HRESULT = -1072879649
NS_E_DRM_LICENSE_SECLOW: win32more.Windows.Win32.Foundation.HRESULT = -1072879648
NS_E_DRM_LICENSE_CONTENT_REVOKED: win32more.Windows.Win32.Foundation.HRESULT = -1072879647
NS_E_DRM_DEVICE_NOT_REGISTERED: win32more.Windows.Win32.Foundation.HRESULT = -1072879646
NS_E_DRM_LICENSE_NOSAP: win32more.Windows.Win32.Foundation.HRESULT = -1072879606
NS_E_DRM_LICENSE_NOSVP: win32more.Windows.Win32.Foundation.HRESULT = -1072879605
NS_E_DRM_LICENSE_NOWDM: win32more.Windows.Win32.Foundation.HRESULT = -1072879604
NS_E_DRM_LICENSE_NOTRUSTEDCODEC: win32more.Windows.Win32.Foundation.HRESULT = -1072879603
NS_E_DRM_SOURCEID_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1072879602
NS_E_DRM_NEEDS_UPGRADE_TEMPFILE: win32more.Windows.Win32.Foundation.HRESULT = -1072879555
NS_E_DRM_NEED_UPGRADE_PD: win32more.Windows.Win32.Foundation.HRESULT = -1072879554
NS_E_DRM_SIGNATURE_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -1072879553
NS_E_DRM_LICENSE_SERVER_INFO_MISSING: win32more.Windows.Win32.Foundation.HRESULT = -1072879552
NS_E_DRM_BUSY: win32more.Windows.Win32.Foundation.HRESULT = -1072879551
NS_E_DRM_PD_TOO_MANY_DEVICES: win32more.Windows.Win32.Foundation.HRESULT = -1072879550
NS_E_DRM_INDIV_FRAUD: win32more.Windows.Win32.Foundation.HRESULT = -1072879549
NS_E_DRM_INDIV_NO_CABS: win32more.Windows.Win32.Foundation.HRESULT = -1072879548
NS_E_DRM_INDIV_SERVICE_UNAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -1072879547
NS_E_DRM_RESTORE_SERVICE_UNAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -1072879546
NS_E_DRM_CLIENT_CODE_EXPIRED: win32more.Windows.Win32.Foundation.HRESULT = -1072879545
NS_E_DRM_NO_UPLINK_LICENSE: win32more.Windows.Win32.Foundation.HRESULT = -1072879544
NS_E_DRM_INVALID_KID: win32more.Windows.Win32.Foundation.HRESULT = -1072879543
NS_E_DRM_LICENSE_INITIALIZATION_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072879542
NS_E_DRM_CHAIN_TOO_LONG: win32more.Windows.Win32.Foundation.HRESULT = -1072879540
NS_E_DRM_UNSUPPORTED_ALGORITHM: win32more.Windows.Win32.Foundation.HRESULT = -1072879539
NS_E_DRM_LICENSE_DELETION_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072879538
NS_E_DRM_INVALID_CERTIFICATE: win32more.Windows.Win32.Foundation.HRESULT = -1072879456
NS_E_DRM_CERTIFICATE_REVOKED: win32more.Windows.Win32.Foundation.HRESULT = -1072879455
NS_E_DRM_LICENSE_UNAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -1072879454
NS_E_DRM_DEVICE_LIMIT_REACHED: win32more.Windows.Win32.Foundation.HRESULT = -1072879453
NS_E_DRM_UNABLE_TO_VERIFY_PROXIMITY: win32more.Windows.Win32.Foundation.HRESULT = -1072879452
NS_E_DRM_MUST_REGISTER: win32more.Windows.Win32.Foundation.HRESULT = -1072879451
NS_E_DRM_MUST_APPROVE: win32more.Windows.Win32.Foundation.HRESULT = -1072879450
NS_E_DRM_MUST_REVALIDATE: win32more.Windows.Win32.Foundation.HRESULT = -1072879449
NS_E_DRM_INVALID_PROXIMITY_RESPONSE: win32more.Windows.Win32.Foundation.HRESULT = -1072879448
NS_E_DRM_INVALID_SESSION: win32more.Windows.Win32.Foundation.HRESULT = -1072879447
NS_E_DRM_DEVICE_NOT_OPEN: win32more.Windows.Win32.Foundation.HRESULT = -1072879446
NS_E_DRM_DEVICE_ALREADY_REGISTERED: win32more.Windows.Win32.Foundation.HRESULT = -1072879445
NS_E_DRM_UNSUPPORTED_PROTOCOL_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -1072879444
NS_E_DRM_UNSUPPORTED_ACTION: win32more.Windows.Win32.Foundation.HRESULT = -1072879443
NS_E_DRM_CERTIFICATE_SECURITY_LEVEL_INADEQUATE: win32more.Windows.Win32.Foundation.HRESULT = -1072879442
NS_E_DRM_UNABLE_TO_OPEN_PORT: win32more.Windows.Win32.Foundation.HRESULT = -1072879441
NS_E_DRM_BAD_REQUEST: win32more.Windows.Win32.Foundation.HRESULT = -1072879440
NS_E_DRM_INVALID_CRL: win32more.Windows.Win32.Foundation.HRESULT = -1072879439
NS_E_DRM_ATTRIBUTE_TOO_LONG: win32more.Windows.Win32.Foundation.HRESULT = -1072879438
NS_E_DRM_EXPIRED_LICENSEBLOB: win32more.Windows.Win32.Foundation.HRESULT = -1072879437
NS_E_DRM_INVALID_LICENSEBLOB: win32more.Windows.Win32.Foundation.HRESULT = -1072879436
NS_E_DRM_INCLUSION_LIST_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -1072879435
NS_E_DRM_DRMV2CLT_REVOKED: win32more.Windows.Win32.Foundation.HRESULT = -1072879434
NS_E_DRM_RIV_TOO_SMALL: win32more.Windows.Win32.Foundation.HRESULT = -1072879433
NS_E_OUTPUT_PROTECTION_LEVEL_UNSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1072879356
NS_E_COMPRESSED_DIGITAL_VIDEO_PROTECTION_LEVEL_UNSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1072879355
NS_E_UNCOMPRESSED_DIGITAL_VIDEO_PROTECTION_LEVEL_UNSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1072879354
NS_E_ANALOG_VIDEO_PROTECTION_LEVEL_UNSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1072879353
NS_E_COMPRESSED_DIGITAL_AUDIO_PROTECTION_LEVEL_UNSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1072879352
NS_E_UNCOMPRESSED_DIGITAL_AUDIO_PROTECTION_LEVEL_UNSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1072879351
NS_E_OUTPUT_PROTECTION_SCHEME_UNSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1072879350
NS_S_REBOOT_RECOMMENDED: win32more.Windows.Win32.Foundation.HRESULT = 862968
NS_S_REBOOT_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = 862969
NS_E_REBOOT_RECOMMENDED: win32more.Windows.Win32.Foundation.HRESULT = -1072878854
NS_E_REBOOT_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -1072878853
NS_E_SETUP_INCOMPLETE: win32more.Windows.Win32.Foundation.HRESULT = -1072878852
NS_E_SETUP_DRM_MIGRATION_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -1072878851
NS_E_SETUP_IGNORABLE_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -1072878850
NS_E_SETUP_DRM_MIGRATION_FAILED_AND_IGNORABLE_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -1072878849
NS_E_SETUP_BLOCKED: win32more.Windows.Win32.Foundation.HRESULT = -1072878848
NS_E_UNKNOWN_PROTOCOL: win32more.Windows.Win32.Foundation.HRESULT = -1072877856
NS_E_REDIRECT_TO_PROXY: win32more.Windows.Win32.Foundation.HRESULT = -1072877855
NS_E_INTERNAL_SERVER_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1072877854
NS_E_BAD_REQUEST: win32more.Windows.Win32.Foundation.HRESULT = -1072877853
NS_E_ERROR_FROM_PROXY: win32more.Windows.Win32.Foundation.HRESULT = -1072877852
NS_E_PROXY_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -1072877851
NS_E_SERVER_UNAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -1072877850
NS_E_REFUSED_BY_SERVER: win32more.Windows.Win32.Foundation.HRESULT = -1072877849
NS_E_INCOMPATIBLE_SERVER: win32more.Windows.Win32.Foundation.HRESULT = -1072877848
NS_E_MULTICAST_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -1072877847
NS_E_INVALID_REDIRECT: win32more.Windows.Win32.Foundation.HRESULT = -1072877846
NS_E_ALL_PROTOCOLS_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -1072877845
NS_E_MSBD_NO_LONGER_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1072877844
NS_E_PROXY_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1072877843
NS_E_CANNOT_CONNECT_TO_PROXY: win32more.Windows.Win32.Foundation.HRESULT = -1072877842
NS_E_SERVER_DNS_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -1072877841
NS_E_PROXY_DNS_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -1072877840
NS_E_CLOSED_ON_SUSPEND: win32more.Windows.Win32.Foundation.HRESULT = -1072877839
NS_E_CANNOT_READ_PLAYLIST_FROM_MEDIASERVER: win32more.Windows.Win32.Foundation.HRESULT = -1072877838
NS_E_SESSION_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1072877837
NS_E_REQUIRE_STREAMING_CLIENT: win32more.Windows.Win32.Foundation.HRESULT = -1072877836
NS_E_PLAYLIST_ENTRY_HAS_CHANGED: win32more.Windows.Win32.Foundation.HRESULT = -1072877835
NS_E_PROXY_ACCESSDENIED: win32more.Windows.Win32.Foundation.HRESULT = -1072877834
NS_E_PROXY_SOURCE_ACCESSDENIED: win32more.Windows.Win32.Foundation.HRESULT = -1072877833
NS_E_NETWORK_SINK_WRITE: win32more.Windows.Win32.Foundation.HRESULT = -1072877832
NS_E_FIREWALL: win32more.Windows.Win32.Foundation.HRESULT = -1072877831
NS_E_MMS_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1072877830
NS_E_SERVER_ACCESSDENIED: win32more.Windows.Win32.Foundation.HRESULT = -1072877829
NS_E_RESOURCE_GONE: win32more.Windows.Win32.Foundation.HRESULT = -1072877828
NS_E_NO_EXISTING_PACKETIZER: win32more.Windows.Win32.Foundation.HRESULT = -1072877827
NS_E_BAD_SYNTAX_IN_SERVER_RESPONSE: win32more.Windows.Win32.Foundation.HRESULT = -1072877826
NS_I_RECONNECTED: win32more.Windows.Win32.Foundation.HRESULT = 1074605823
NS_E_RESET_SOCKET_CONNECTION: win32more.Windows.Win32.Foundation.HRESULT = -1072877824
NS_I_NOLOG_STOP: win32more.Windows.Win32.Foundation.HRESULT = 1074605825
NS_E_TOO_MANY_HOPS: win32more.Windows.Win32.Foundation.HRESULT = -1072877822
NS_I_EXISTING_PACKETIZER: win32more.Windows.Win32.Foundation.HRESULT = 1074605827
NS_I_MANUAL_PROXY: win32more.Windows.Win32.Foundation.HRESULT = 1074605828
NS_E_TOO_MUCH_DATA_FROM_SERVER: win32more.Windows.Win32.Foundation.HRESULT = -1072877819
NS_E_CONNECT_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -1072877818
NS_E_PROXY_CONNECT_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -1072877817
NS_E_SESSION_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -1072877816
NS_S_EOSRECEDING: win32more.Windows.Win32.Foundation.HRESULT = 864009
NS_E_PACKETSINK_UNKNOWN_FEC_STREAM: win32more.Windows.Win32.Foundation.HRESULT = -1072877814
NS_E_PUSH_CANNOTCONNECT: win32more.Windows.Win32.Foundation.HRESULT = -1072877813
NS_E_INCOMPATIBLE_PUSH_SERVER: win32more.Windows.Win32.Foundation.HRESULT = -1072877812
NS_S_CHANGENOTICE: win32more.Windows.Win32.Foundation.HRESULT = 864013
NS_E_END_OF_PLAYLIST: win32more.Windows.Win32.Foundation.HRESULT = -1072876856
NS_E_USE_FILE_SOURCE: win32more.Windows.Win32.Foundation.HRESULT = -1072876855
NS_E_PROPERTY_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1072876854
NS_E_PROPERTY_READ_ONLY: win32more.Windows.Win32.Foundation.HRESULT = -1072876852
NS_E_TABLE_KEY_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1072876851
NS_E_INVALID_QUERY_OPERATOR: win32more.Windows.Win32.Foundation.HRESULT = -1072876849
NS_E_INVALID_QUERY_PROPERTY: win32more.Windows.Win32.Foundation.HRESULT = -1072876848
NS_E_PROPERTY_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1072876846
NS_E_SCHEMA_CLASSIFY_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -1072876844
NS_E_METADATA_FORMAT_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1072876843
NS_E_METADATA_NO_EDITING_CAPABILITY: win32more.Windows.Win32.Foundation.HRESULT = -1072876842
NS_E_METADATA_CANNOT_SET_LOCALE: win32more.Windows.Win32.Foundation.HRESULT = -1072876841
NS_E_METADATA_LANGUAGE_NOT_SUPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1072876840
NS_E_METADATA_NO_RFC1766_NAME_FOR_LOCALE: win32more.Windows.Win32.Foundation.HRESULT = -1072876839
NS_E_METADATA_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -1072876838
NS_E_METADATA_CACHE_DATA_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -1072876837
NS_E_METADATA_INVALID_DOCUMENT_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -1072876836
NS_E_METADATA_IDENTIFIER_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -1072876835
NS_E_METADATA_CANNOT_RETRIEVE_FROM_OFFLINE_CACHE: win32more.Windows.Win32.Foundation.HRESULT = -1072876834
VFW_HIDE_SETTINGS_PAGE: UInt32 = 1
VFW_HIDE_VIDEOSRC_PAGE: UInt32 = 2
VFW_HIDE_CAMERACONTROL_PAGE: UInt32 = 4
VFW_OEM_ADD_PAGE: UInt32 = 2147483648
VFW_USE_DEVICE_HANDLE: UInt32 = 1
VFW_USE_STREAM_HANDLE: UInt32 = 2
VFW_QUERY_DEV_CHANGED: UInt32 = 256
TARGET_DEVICE_FRIENDLY_NAME: String = 'TargetDeviceFriendlyName'
TARGET_DEVICE_OPEN_EXCLUSIVELY: String = 'TargetDeviceOpenExclusively'
MCIERR_INVALID_DEVICE_ID: UInt32 = 257
MCIERR_UNRECOGNIZED_KEYWORD: UInt32 = 259
MCIERR_UNRECOGNIZED_COMMAND: UInt32 = 261
MCIERR_HARDWARE: UInt32 = 262
MCIERR_INVALID_DEVICE_NAME: UInt32 = 263
MCIERR_OUT_OF_MEMORY: UInt32 = 264
MCIERR_DEVICE_OPEN: UInt32 = 265
MCIERR_CANNOT_LOAD_DRIVER: UInt32 = 266
MCIERR_MISSING_COMMAND_STRING: UInt32 = 267
MCIERR_PARAM_OVERFLOW: UInt32 = 268
MCIERR_MISSING_STRING_ARGUMENT: UInt32 = 269
MCIERR_BAD_INTEGER: UInt32 = 270
MCIERR_PARSER_INTERNAL: UInt32 = 271
MCIERR_DRIVER_INTERNAL: UInt32 = 272
MCIERR_MISSING_PARAMETER: UInt32 = 273
MCIERR_UNSUPPORTED_FUNCTION: UInt32 = 274
MCIERR_FILE_NOT_FOUND: UInt32 = 275
MCIERR_DEVICE_NOT_READY: UInt32 = 276
MCIERR_INTERNAL: UInt32 = 277
MCIERR_DRIVER: UInt32 = 278
MCIERR_CANNOT_USE_ALL: UInt32 = 279
MCIERR_MULTIPLE: UInt32 = 280
MCIERR_EXTENSION_NOT_FOUND: UInt32 = 281
MCIERR_OUTOFRANGE: UInt32 = 282
MCIERR_FLAGS_NOT_COMPATIBLE: UInt32 = 284
MCIERR_FILE_NOT_SAVED: UInt32 = 286
MCIERR_DEVICE_TYPE_REQUIRED: UInt32 = 287
MCIERR_DEVICE_LOCKED: UInt32 = 288
MCIERR_DUPLICATE_ALIAS: UInt32 = 289
MCIERR_BAD_CONSTANT: UInt32 = 290
MCIERR_MUST_USE_SHAREABLE: UInt32 = 291
MCIERR_MISSING_DEVICE_NAME: UInt32 = 292
MCIERR_BAD_TIME_FORMAT: UInt32 = 293
MCIERR_NO_CLOSING_QUOTE: UInt32 = 294
MCIERR_DUPLICATE_FLAGS: UInt32 = 295
MCIERR_INVALID_FILE: UInt32 = 296
MCIERR_NULL_PARAMETER_BLOCK: UInt32 = 297
MCIERR_UNNAMED_RESOURCE: UInt32 = 298
MCIERR_NEW_REQUIRES_ALIAS: UInt32 = 299
MCIERR_NOTIFY_ON_AUTO_OPEN: UInt32 = 300
MCIERR_NO_ELEMENT_ALLOWED: UInt32 = 301
MCIERR_NONAPPLICABLE_FUNCTION: UInt32 = 302
MCIERR_ILLEGAL_FOR_AUTO_OPEN: UInt32 = 303
MCIERR_FILENAME_REQUIRED: UInt32 = 304
MCIERR_EXTRA_CHARACTERS: UInt32 = 305
MCIERR_DEVICE_NOT_INSTALLED: UInt32 = 306
MCIERR_GET_CD: UInt32 = 307
MCIERR_SET_CD: UInt32 = 308
MCIERR_SET_DRIVE: UInt32 = 309
MCIERR_DEVICE_LENGTH: UInt32 = 310
MCIERR_DEVICE_ORD_LENGTH: UInt32 = 311
MCIERR_NO_INTEGER: UInt32 = 312
MCIERR_WAVE_OUTPUTSINUSE: UInt32 = 320
MCIERR_WAVE_SETOUTPUTINUSE: UInt32 = 321
MCIERR_WAVE_INPUTSINUSE: UInt32 = 322
MCIERR_WAVE_SETINPUTINUSE: UInt32 = 323
MCIERR_WAVE_OUTPUTUNSPECIFIED: UInt32 = 324
MCIERR_WAVE_INPUTUNSPECIFIED: UInt32 = 325
MCIERR_WAVE_OUTPUTSUNSUITABLE: UInt32 = 326
MCIERR_WAVE_SETOUTPUTUNSUITABLE: UInt32 = 327
MCIERR_WAVE_INPUTSUNSUITABLE: UInt32 = 328
MCIERR_WAVE_SETINPUTUNSUITABLE: UInt32 = 329
MCIERR_SEQ_DIV_INCOMPATIBLE: UInt32 = 336
MCIERR_SEQ_PORT_INUSE: UInt32 = 337
MCIERR_SEQ_PORT_NONEXISTENT: UInt32 = 338
MCIERR_SEQ_PORT_MAPNODEVICE: UInt32 = 339
MCIERR_SEQ_PORT_MISCERROR: UInt32 = 340
MCIERR_SEQ_TIMER: UInt32 = 341
MCIERR_SEQ_PORTUNSPECIFIED: UInt32 = 342
MCIERR_SEQ_NOMIDIPRESENT: UInt32 = 343
MCIERR_NO_WINDOW: UInt32 = 346
MCIERR_CREATEWINDOW: UInt32 = 347
MCIERR_FILE_READ: UInt32 = 348
MCIERR_FILE_WRITE: UInt32 = 349
MCIERR_NO_IDENTITY: UInt32 = 350
MCIERR_CUSTOM_DRIVER_BASE: UInt32 = 512
MCI_FIRST: UInt32 = 2048
MCI_ESCAPE: UInt32 = 2053
MCI_INFO: UInt32 = 2058
MCI_GETDEVCAPS: UInt32 = 2059
MCI_SPIN: UInt32 = 2060
MCI_SET: UInt32 = 2061
MCI_SYSINFO: UInt32 = 2064
MCI_BREAK: UInt32 = 2065
MCI_STATUS: UInt32 = 2068
MCI_CUE: UInt32 = 2096
MCI_REALIZE: UInt32 = 2112
MCI_WINDOW: UInt32 = 2113
MCI_PUT: UInt32 = 2114
MCI_WHERE: UInt32 = 2115
MCI_FREEZE: UInt32 = 2116
MCI_UNFREEZE: UInt32 = 2117
MCI_LOAD: UInt32 = 2128
MCI_UPDATE: UInt32 = 2132
MCI_USER_MESSAGES: UInt32 = 3072
MCI_LAST: UInt32 = 4095
MCI_DEVTYPE_VCR: UInt32 = 513
MCI_DEVTYPE_VIDEODISC: UInt32 = 514
MCI_DEVTYPE_OVERLAY: UInt32 = 515
MCI_DEVTYPE_CD_AUDIO: UInt32 = 516
MCI_DEVTYPE_DAT: UInt32 = 517
MCI_DEVTYPE_SCANNER: UInt32 = 518
MCI_DEVTYPE_ANIMATION: UInt32 = 519
MCI_DEVTYPE_DIGITAL_VIDEO: UInt32 = 520
MCI_DEVTYPE_OTHER: UInt32 = 521
MCI_DEVTYPE_WAVEFORM_AUDIO: UInt32 = 522
MCI_DEVTYPE_SEQUENCER: UInt32 = 523
MCI_DEVTYPE_FIRST: UInt32 = 513
MCI_DEVTYPE_LAST: UInt32 = 523
MCI_DEVTYPE_FIRST_USER: UInt32 = 4096
MCI_FORMAT_MILLISECONDS: UInt32 = 0
MCI_FORMAT_HMS: UInt32 = 1
MCI_FORMAT_MSF: UInt32 = 2
MCI_FORMAT_FRAMES: UInt32 = 3
MCI_FORMAT_SMPTE_24: UInt32 = 4
MCI_FORMAT_SMPTE_25: UInt32 = 5
MCI_FORMAT_SMPTE_30: UInt32 = 6
MCI_FORMAT_SMPTE_30DROP: UInt32 = 7
MCI_FORMAT_BYTES: UInt32 = 8
MCI_FORMAT_SAMPLES: UInt32 = 9
MCI_FORMAT_TMSF: UInt32 = 10
MCI_NOTIFY_SUCCESSFUL: UInt32 = 1
MCI_NOTIFY_SUPERSEDED: UInt32 = 2
MCI_NOTIFY_ABORTED: UInt32 = 4
MCI_NOTIFY_FAILURE: UInt32 = 8
MCI_NOTIFY: Int32 = 1
MCI_WAIT: Int32 = 2
MCI_FROM: Int32 = 4
MCI_TO: Int32 = 8
MCI_TRACK: Int32 = 16
MCI_OPEN_SHAREABLE: Int32 = 256
MCI_OPEN_ELEMENT: Int32 = 512
MCI_OPEN_ALIAS: Int32 = 1024
MCI_OPEN_ELEMENT_ID: Int32 = 2048
MCI_OPEN_TYPE_ID: Int32 = 4096
MCI_OPEN_TYPE: Int32 = 8192
MCI_SEEK_TO_START: Int32 = 256
MCI_SEEK_TO_END: Int32 = 512
MCI_STATUS_ITEM: Int32 = 256
MCI_STATUS_START: Int32 = 512
MCI_STATUS_LENGTH: Int32 = 1
MCI_STATUS_POSITION: Int32 = 2
MCI_STATUS_NUMBER_OF_TRACKS: Int32 = 3
MCI_STATUS_MODE: Int32 = 4
MCI_STATUS_MEDIA_PRESENT: Int32 = 5
MCI_STATUS_TIME_FORMAT: Int32 = 6
MCI_STATUS_READY: Int32 = 7
MCI_STATUS_CURRENT_TRACK: Int32 = 8
MCI_INFO_PRODUCT: Int32 = 256
MCI_INFO_FILE: Int32 = 512
MCI_INFO_MEDIA_UPC: Int32 = 1024
MCI_INFO_MEDIA_IDENTITY: Int32 = 2048
MCI_INFO_NAME: Int32 = 4096
MCI_INFO_COPYRIGHT: Int32 = 8192
MCI_GETDEVCAPS_ITEM: Int32 = 256
MCI_GETDEVCAPS_CAN_RECORD: Int32 = 1
MCI_GETDEVCAPS_HAS_AUDIO: Int32 = 2
MCI_GETDEVCAPS_HAS_VIDEO: Int32 = 3
MCI_GETDEVCAPS_DEVICE_TYPE: Int32 = 4
MCI_GETDEVCAPS_USES_FILES: Int32 = 5
MCI_GETDEVCAPS_COMPOUND_DEVICE: Int32 = 6
MCI_GETDEVCAPS_CAN_EJECT: Int32 = 7
MCI_GETDEVCAPS_CAN_PLAY: Int32 = 8
MCI_GETDEVCAPS_CAN_SAVE: Int32 = 9
MCI_SYSINFO_QUANTITY: Int32 = 256
MCI_SYSINFO_OPEN: Int32 = 512
MCI_SYSINFO_NAME: Int32 = 1024
MCI_SYSINFO_INSTALLNAME: Int32 = 2048
MCI_SET_DOOR_OPEN: Int32 = 256
MCI_SET_DOOR_CLOSED: Int32 = 512
MCI_SET_TIME_FORMAT: Int32 = 1024
MCI_SET_AUDIO: Int32 = 2048
MCI_SET_VIDEO: Int32 = 4096
MCI_SET_ON: Int32 = 8192
MCI_SET_OFF: Int32 = 16384
MCI_SET_AUDIO_ALL: Int32 = 0
MCI_SET_AUDIO_LEFT: Int32 = 1
MCI_SET_AUDIO_RIGHT: Int32 = 2
MCI_BREAK_KEY: Int32 = 256
MCI_BREAK_HWND: Int32 = 512
MCI_BREAK_OFF: Int32 = 1024
MCI_RECORD_INSERT: Int32 = 256
MCI_RECORD_OVERWRITE: Int32 = 512
MCI_SAVE_FILE: Int32 = 256
MCI_LOAD_FILE: Int32 = 256
MCI_VD_MODE_PARK: UInt32 = 1025
MCI_VD_MEDIA_CLV: UInt32 = 1026
MCI_VD_MEDIA_CAV: UInt32 = 1027
MCI_VD_MEDIA_OTHER: UInt32 = 1028
MCI_VD_FORMAT_TRACK: UInt32 = 16385
MCI_VD_PLAY_REVERSE: Int32 = 65536
MCI_VD_PLAY_FAST: Int32 = 131072
MCI_VD_PLAY_SPEED: Int32 = 262144
MCI_VD_PLAY_SCAN: Int32 = 524288
MCI_VD_PLAY_SLOW: Int32 = 1048576
MCI_VD_SEEK_REVERSE: Int32 = 65536
MCI_VD_STATUS_SPEED: Int32 = 16386
MCI_VD_STATUS_FORWARD: Int32 = 16387
MCI_VD_STATUS_MEDIA_TYPE: Int32 = 16388
MCI_VD_STATUS_SIDE: Int32 = 16389
MCI_VD_STATUS_DISC_SIZE: Int32 = 16390
MCI_VD_GETDEVCAPS_CLV: Int32 = 65536
MCI_VD_GETDEVCAPS_CAV: Int32 = 131072
MCI_VD_SPIN_UP: Int32 = 65536
MCI_VD_SPIN_DOWN: Int32 = 131072
MCI_VD_GETDEVCAPS_CAN_REVERSE: Int32 = 16386
MCI_VD_GETDEVCAPS_FAST_RATE: Int32 = 16387
MCI_VD_GETDEVCAPS_SLOW_RATE: Int32 = 16388
MCI_VD_GETDEVCAPS_NORMAL_RATE: Int32 = 16389
MCI_VD_STEP_FRAMES: Int32 = 65536
MCI_VD_STEP_REVERSE: Int32 = 131072
MCI_VD_ESCAPE_STRING: Int32 = 256
MCI_CDA_STATUS_TYPE_TRACK: Int32 = 16385
MCI_CDA_TRACK_AUDIO: UInt32 = 1088
MCI_CDA_TRACK_OTHER: UInt32 = 1089
MCI_WAVE_PCM: UInt32 = 1152
MCI_WAVE_MAPPER: UInt32 = 1153
MCI_WAVE_OPEN_BUFFER: Int32 = 65536
MCI_WAVE_SET_FORMATTAG: Int32 = 65536
MCI_WAVE_SET_CHANNELS: Int32 = 131072
MCI_WAVE_SET_SAMPLESPERSEC: Int32 = 262144
MCI_WAVE_SET_AVGBYTESPERSEC: Int32 = 524288
MCI_WAVE_SET_BLOCKALIGN: Int32 = 1048576
MCI_WAVE_SET_BITSPERSAMPLE: Int32 = 2097152
MCI_WAVE_INPUT: Int32 = 4194304
MCI_WAVE_OUTPUT: Int32 = 8388608
MCI_WAVE_STATUS_FORMATTAG: Int32 = 16385
MCI_WAVE_STATUS_CHANNELS: Int32 = 16386
MCI_WAVE_STATUS_SAMPLESPERSEC: Int32 = 16387
MCI_WAVE_STATUS_AVGBYTESPERSEC: Int32 = 16388
MCI_WAVE_STATUS_BLOCKALIGN: Int32 = 16389
MCI_WAVE_STATUS_BITSPERSAMPLE: Int32 = 16390
MCI_WAVE_STATUS_LEVEL: Int32 = 16391
MCI_WAVE_SET_ANYINPUT: Int32 = 67108864
MCI_WAVE_SET_ANYOUTPUT: Int32 = 134217728
MCI_WAVE_GETDEVCAPS_INPUTS: Int32 = 16385
MCI_WAVE_GETDEVCAPS_OUTPUTS: Int32 = 16386
MCI_SEQ_FORMAT_SONGPTR: UInt32 = 16385
MCI_SEQ_FILE: UInt32 = 16386
MCI_SEQ_MIDI: UInt32 = 16387
MCI_SEQ_SMPTE: UInt32 = 16388
MCI_SEQ_NONE: UInt32 = 65533
MCI_SEQ_MAPPER: UInt32 = 65535
MCI_SEQ_STATUS_TEMPO: Int32 = 16386
MCI_SEQ_STATUS_PORT: Int32 = 16387
MCI_SEQ_STATUS_SLAVE: Int32 = 16391
MCI_SEQ_STATUS_MASTER: Int32 = 16392
MCI_SEQ_STATUS_OFFSET: Int32 = 16393
MCI_SEQ_STATUS_DIVTYPE: Int32 = 16394
MCI_SEQ_STATUS_NAME: Int32 = 16395
MCI_SEQ_STATUS_COPYRIGHT: Int32 = 16396
MCI_SEQ_SET_TEMPO: Int32 = 65536
MCI_SEQ_SET_PORT: Int32 = 131072
MCI_SEQ_SET_SLAVE: Int32 = 262144
MCI_SEQ_SET_MASTER: Int32 = 524288
MCI_SEQ_SET_OFFSET: Int32 = 16777216
MCI_ANIM_OPEN_WS: Int32 = 65536
MCI_ANIM_OPEN_PARENT: Int32 = 131072
MCI_ANIM_OPEN_NOSTATIC: Int32 = 262144
MCI_ANIM_PLAY_SPEED: Int32 = 65536
MCI_ANIM_PLAY_REVERSE: Int32 = 131072
MCI_ANIM_PLAY_FAST: Int32 = 262144
MCI_ANIM_PLAY_SLOW: Int32 = 524288
MCI_ANIM_PLAY_SCAN: Int32 = 1048576
MCI_ANIM_STEP_REVERSE: Int32 = 65536
MCI_ANIM_STEP_FRAMES: Int32 = 131072
MCI_ANIM_STATUS_SPEED: Int32 = 16385
MCI_ANIM_STATUS_FORWARD: Int32 = 16386
MCI_ANIM_STATUS_HWND: Int32 = 16387
MCI_ANIM_STATUS_HPAL: Int32 = 16388
MCI_ANIM_STATUS_STRETCH: Int32 = 16389
MCI_ANIM_INFO_TEXT: Int32 = 65536
MCI_ANIM_GETDEVCAPS_CAN_REVERSE: Int32 = 16385
MCI_ANIM_GETDEVCAPS_FAST_RATE: Int32 = 16386
MCI_ANIM_GETDEVCAPS_SLOW_RATE: Int32 = 16387
MCI_ANIM_GETDEVCAPS_NORMAL_RATE: Int32 = 16388
MCI_ANIM_GETDEVCAPS_PALETTES: Int32 = 16390
MCI_ANIM_GETDEVCAPS_CAN_STRETCH: Int32 = 16391
MCI_ANIM_GETDEVCAPS_MAX_WINDOWS: Int32 = 16392
MCI_ANIM_REALIZE_NORM: Int32 = 65536
MCI_ANIM_REALIZE_BKGD: Int32 = 131072
MCI_ANIM_WINDOW_HWND: Int32 = 65536
MCI_ANIM_WINDOW_STATE: Int32 = 262144
MCI_ANIM_WINDOW_TEXT: Int32 = 524288
MCI_ANIM_WINDOW_ENABLE_STRETCH: Int32 = 1048576
MCI_ANIM_WINDOW_DISABLE_STRETCH: Int32 = 2097152
MCI_ANIM_WINDOW_DEFAULT: Int32 = 0
MCI_ANIM_RECT: Int32 = 65536
MCI_ANIM_PUT_SOURCE: Int32 = 131072
MCI_ANIM_PUT_DESTINATION: Int32 = 262144
MCI_ANIM_WHERE_SOURCE: Int32 = 131072
MCI_ANIM_WHERE_DESTINATION: Int32 = 262144
MCI_ANIM_UPDATE_HDC: Int32 = 131072
MCI_OVLY_OPEN_WS: Int32 = 65536
MCI_OVLY_OPEN_PARENT: Int32 = 131072
MCI_OVLY_STATUS_HWND: Int32 = 16385
MCI_OVLY_STATUS_STRETCH: Int32 = 16386
MCI_OVLY_INFO_TEXT: Int32 = 65536
MCI_OVLY_GETDEVCAPS_CAN_STRETCH: Int32 = 16385
MCI_OVLY_GETDEVCAPS_CAN_FREEZE: Int32 = 16386
MCI_OVLY_GETDEVCAPS_MAX_WINDOWS: Int32 = 16387
MCI_OVLY_WINDOW_HWND: Int32 = 65536
MCI_OVLY_WINDOW_STATE: Int32 = 262144
MCI_OVLY_WINDOW_TEXT: Int32 = 524288
MCI_OVLY_WINDOW_ENABLE_STRETCH: Int32 = 1048576
MCI_OVLY_WINDOW_DISABLE_STRETCH: Int32 = 2097152
MCI_OVLY_WINDOW_DEFAULT: Int32 = 0
MCI_OVLY_RECT: Int32 = 65536
MCI_OVLY_PUT_SOURCE: Int32 = 131072
MCI_OVLY_PUT_DESTINATION: Int32 = 262144
MCI_OVLY_PUT_FRAME: Int32 = 524288
MCI_OVLY_PUT_VIDEO: Int32 = 1048576
MCI_OVLY_WHERE_SOURCE: Int32 = 131072
MCI_OVLY_WHERE_DESTINATION: Int32 = 262144
MCI_OVLY_WHERE_FRAME: Int32 = 524288
MCI_OVLY_WHERE_VIDEO: Int32 = 1048576
@winfunctype('WINMM.dll')
def mciSendCommandA(mciId: UInt32, uMsg: UInt32, dwParam1: UIntPtr, dwParam2: UIntPtr) -> UInt32: ...
@winfunctype('WINMM.dll')
def mciSendCommandW(mciId: UInt32, uMsg: UInt32, dwParam1: UIntPtr, dwParam2: UIntPtr) -> UInt32: ...
mciSendCommand = UnicodeAlias('mciSendCommandW')
@winfunctype('WINMM.dll')
def mciSendStringA(lpstrCommand: win32more.Windows.Win32.Foundation.PSTR, lpstrReturnString: win32more.Windows.Win32.Foundation.PSTR, uReturnLength: UInt32, hwndCallback: win32more.Windows.Win32.Foundation.HWND) -> UInt32: ...
@winfunctype('WINMM.dll')
def mciSendStringW(lpstrCommand: win32more.Windows.Win32.Foundation.PWSTR, lpstrReturnString: win32more.Windows.Win32.Foundation.PWSTR, uReturnLength: UInt32, hwndCallback: win32more.Windows.Win32.Foundation.HWND) -> UInt32: ...
mciSendString = UnicodeAlias('mciSendStringW')
@winfunctype('WINMM.dll')
def mciGetDeviceIDA(pszDevice: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('WINMM.dll')
def mciGetDeviceIDW(pszDevice: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
mciGetDeviceID = UnicodeAlias('mciGetDeviceIDW')
@winfunctype('WINMM.dll')
def mciGetDeviceIDFromElementIDA(dwElementID: UInt32, lpstrType: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('WINMM.dll')
def mciGetDeviceIDFromElementIDW(dwElementID: UInt32, lpstrType: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
mciGetDeviceIDFromElementID = UnicodeAlias('mciGetDeviceIDFromElementIDW')
@winfunctype('WINMM.dll')
def mciGetErrorStringA(mcierr: UInt32, pszText: win32more.Windows.Win32.Foundation.PSTR, cchText: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WINMM.dll')
def mciGetErrorStringW(mcierr: UInt32, pszText: win32more.Windows.Win32.Foundation.PWSTR, cchText: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
mciGetErrorString = UnicodeAlias('mciGetErrorStringW')
@winfunctype('WINMM.dll')
def mciSetYieldProc(mciId: UInt32, fpYieldProc: win32more.Windows.Win32.Media.Multimedia.YIELDPROC, dwYieldData: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WINMM.dll')
def mciGetCreatorTask(mciId: UInt32) -> win32more.Windows.Win32.Media.HTASK: ...
@winfunctype('WINMM.dll')
def mciGetYieldProc(mciId: UInt32, pdwYieldData: POINTER(UInt32)) -> win32more.Windows.Win32.Media.Multimedia.YIELDPROC: ...
@winfunctype('WINMM.dll')
def mciGetDriverData(wDeviceID: UInt32) -> UIntPtr: ...
@winfunctype('WINMM.dll')
def mciLoadCommandResource(hInstance: win32more.Windows.Win32.Foundation.HANDLE, lpResName: win32more.Windows.Win32.Foundation.PWSTR, wType: UInt32) -> UInt32: ...
@winfunctype('WINMM.dll')
def mciSetDriverData(wDeviceID: UInt32, dwData: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WINMM.dll')
def mciDriverYield(wDeviceID: UInt32) -> UInt32: ...
@winfunctype('WINMM.dll')
def mciDriverNotify(hwndCallback: win32more.Windows.Win32.Foundation.HANDLE, wDeviceID: UInt32, uStatus: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WINMM.dll')
def mciFreeCommandResource(wTable: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WINMM.dll')
def CloseDriver(hDriver: win32more.Windows.Win32.Media.Multimedia.HDRVR, lParam1: win32more.Windows.Win32.Foundation.LPARAM, lParam2: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.LRESULT: ...
@winfunctype('WINMM.dll')
def OpenDriver(szDriverName: win32more.Windows.Win32.Foundation.PWSTR, szSectionName: win32more.Windows.Win32.Foundation.PWSTR, lParam2: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Media.Multimedia.HDRVR: ...
@winfunctype('WINMM.dll')
def SendDriverMessage(hDriver: win32more.Windows.Win32.Media.Multimedia.HDRVR, message: UInt32, lParam1: win32more.Windows.Win32.Foundation.LPARAM, lParam2: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.LRESULT: ...
@winfunctype('WINMM.dll')
def DrvGetModuleHandle(hDriver: win32more.Windows.Win32.Media.Multimedia.HDRVR) -> win32more.Windows.Win32.Foundation.HMODULE: ...
@winfunctype('WINMM.dll')
def GetDriverModuleHandle(hDriver: win32more.Windows.Win32.Media.Multimedia.HDRVR) -> win32more.Windows.Win32.Foundation.HMODULE: ...
@winfunctype('WINMM.dll')
def DefDriverProc(dwDriverIdentifier: UIntPtr, hdrvr: win32more.Windows.Win32.Media.Multimedia.HDRVR, uMsg: UInt32, lParam1: win32more.Windows.Win32.Foundation.LPARAM, lParam2: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.LRESULT: ...
@winfunctype('WINMM.dll')
def DriverCallback(dwCallback: UIntPtr, dwFlags: UInt32, hDevice: win32more.Windows.Win32.Media.Multimedia.HDRVR, dwMsg: UInt32, dwUser: UIntPtr, dwParam1: UIntPtr, dwParam2: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('api-ms-win-mm-misc-l1-1-1.dll')
def sndOpenSound(EventName: win32more.Windows.Win32.Foundation.PWSTR, AppName: win32more.Windows.Win32.Foundation.PWSTR, Flags: Int32, FileHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> Int32: ...
@winfunctype('WINMM.dll')
def mmDrvInstall(hDriver: win32more.Windows.Win32.Media.Multimedia.HDRVR, wszDrvEntry: win32more.Windows.Win32.Foundation.PWSTR, drvMessage: win32more.Windows.Win32.Media.Multimedia.DRIVERMSGPROC, wFlags: UInt32) -> UInt32: ...
@winfunctype('WINMM.dll')
def mmioStringToFOURCCA(sz: win32more.Windows.Win32.Foundation.PSTR, uFlags: UInt32) -> UInt32: ...
@winfunctype('WINMM.dll')
def mmioStringToFOURCCW(sz: win32more.Windows.Win32.Foundation.PWSTR, uFlags: UInt32) -> UInt32: ...
mmioStringToFOURCC = UnicodeAlias('mmioStringToFOURCCW')
@winfunctype('WINMM.dll')
def mmioInstallIOProcA(fccIOProc: UInt32, pIOProc: win32more.Windows.Win32.Media.Multimedia.LPMMIOPROC, dwFlags: UInt32) -> win32more.Windows.Win32.Media.Multimedia.LPMMIOPROC: ...
@winfunctype('WINMM.dll')
def mmioInstallIOProcW(fccIOProc: UInt32, pIOProc: win32more.Windows.Win32.Media.Multimedia.LPMMIOPROC, dwFlags: UInt32) -> win32more.Windows.Win32.Media.Multimedia.LPMMIOPROC: ...
mmioInstallIOProc = UnicodeAlias('mmioInstallIOProcW')
@winfunctype('WINMM.dll')
def mmioOpenA(pszFileName: win32more.Windows.Win32.Foundation.PSTR, pmmioinfo: POINTER(win32more.Windows.Win32.Media.Multimedia.MMIOINFO), fdwOpen: UInt32) -> win32more.Windows.Win32.Media.Multimedia.HMMIO: ...
@winfunctype('WINMM.dll')
def mmioOpenW(pszFileName: win32more.Windows.Win32.Foundation.PWSTR, pmmioinfo: POINTER(win32more.Windows.Win32.Media.Multimedia.MMIOINFO), fdwOpen: UInt32) -> win32more.Windows.Win32.Media.Multimedia.HMMIO: ...
mmioOpen = UnicodeAlias('mmioOpenW')
@winfunctype('WINMM.dll')
def mmioRenameA(pszFileName: win32more.Windows.Win32.Foundation.PSTR, pszNewFileName: win32more.Windows.Win32.Foundation.PSTR, pmmioinfo: POINTER(win32more.Windows.Win32.Media.Multimedia.MMIOINFO), fdwRename: UInt32) -> UInt32: ...
@winfunctype('WINMM.dll')
def mmioRenameW(pszFileName: win32more.Windows.Win32.Foundation.PWSTR, pszNewFileName: win32more.Windows.Win32.Foundation.PWSTR, pmmioinfo: POINTER(win32more.Windows.Win32.Media.Multimedia.MMIOINFO), fdwRename: UInt32) -> UInt32: ...
mmioRename = UnicodeAlias('mmioRenameW')
@winfunctype('WINMM.dll')
def mmioClose(hmmio: win32more.Windows.Win32.Media.Multimedia.HMMIO, fuClose: UInt32) -> UInt32: ...
@winfunctype('WINMM.dll')
def mmioRead(hmmio: win32more.Windows.Win32.Media.Multimedia.HMMIO, pch: POINTER(SByte), cch: Int32) -> Int32: ...
@winfunctype('WINMM.dll')
def mmioWrite(hmmio: win32more.Windows.Win32.Media.Multimedia.HMMIO, pch: win32more.Windows.Win32.Foundation.PSTR, cch: Int32) -> Int32: ...
@winfunctype('WINMM.dll')
def mmioSeek(hmmio: win32more.Windows.Win32.Media.Multimedia.HMMIO, lOffset: Int32, iOrigin: Int32) -> Int32: ...
@winfunctype('WINMM.dll')
def mmioGetInfo(hmmio: win32more.Windows.Win32.Media.Multimedia.HMMIO, pmmioinfo: POINTER(win32more.Windows.Win32.Media.Multimedia.MMIOINFO), fuInfo: UInt32) -> UInt32: ...
@winfunctype('WINMM.dll')
def mmioSetInfo(hmmio: win32more.Windows.Win32.Media.Multimedia.HMMIO, pmmioinfo: POINTER(win32more.Windows.Win32.Media.Multimedia.MMIOINFO), fuInfo: UInt32) -> UInt32: ...
@winfunctype('WINMM.dll')
def mmioSetBuffer(hmmio: win32more.Windows.Win32.Media.Multimedia.HMMIO, pchBuffer: win32more.Windows.Win32.Foundation.PSTR, cchBuffer: Int32, fuBuffer: UInt32) -> UInt32: ...
@winfunctype('WINMM.dll')
def mmioFlush(hmmio: win32more.Windows.Win32.Media.Multimedia.HMMIO, fuFlush: UInt32) -> UInt32: ...
@winfunctype('WINMM.dll')
def mmioAdvance(hmmio: win32more.Windows.Win32.Media.Multimedia.HMMIO, pmmioinfo: POINTER(win32more.Windows.Win32.Media.Multimedia.MMIOINFO), fuAdvance: UInt32) -> UInt32: ...
@winfunctype('WINMM.dll')
def mmioSendMessage(hmmio: win32more.Windows.Win32.Media.Multimedia.HMMIO, uMsg: UInt32, lParam1: win32more.Windows.Win32.Foundation.LPARAM, lParam2: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.LRESULT: ...
@winfunctype('WINMM.dll')
def mmioDescend(hmmio: win32more.Windows.Win32.Media.Multimedia.HMMIO, pmmcki: POINTER(win32more.Windows.Win32.Media.Multimedia.MMCKINFO), pmmckiParent: POINTER(win32more.Windows.Win32.Media.Multimedia.MMCKINFO), fuDescend: UInt32) -> UInt32: ...
@winfunctype('WINMM.dll')
def mmioAscend(hmmio: win32more.Windows.Win32.Media.Multimedia.HMMIO, pmmcki: POINTER(win32more.Windows.Win32.Media.Multimedia.MMCKINFO), fuAscend: UInt32) -> UInt32: ...
@winfunctype('WINMM.dll')
def mmioCreateChunk(hmmio: win32more.Windows.Win32.Media.Multimedia.HMMIO, pmmcki: POINTER(win32more.Windows.Win32.Media.Multimedia.MMCKINFO), fuCreate: UInt32) -> UInt32: ...
@winfunctype('WINMM.dll')
def joyGetPosEx(uJoyID: UInt32, pji: POINTER(win32more.Windows.Win32.Media.Multimedia.JOYINFOEX)) -> UInt32: ...
@winfunctype('WINMM.dll')
def joyGetNumDevs() -> UInt32: ...
@winfunctype('WINMM.dll')
def joyGetDevCapsA(uJoyID: UIntPtr, pjc: POINTER(win32more.Windows.Win32.Media.Multimedia.JOYCAPSA), cbjc: UInt32) -> UInt32: ...
@winfunctype('WINMM.dll')
def joyGetDevCapsW(uJoyID: UIntPtr, pjc: POINTER(win32more.Windows.Win32.Media.Multimedia.JOYCAPSW), cbjc: UInt32) -> UInt32: ...
joyGetDevCaps = UnicodeAlias('joyGetDevCapsW')
@winfunctype('WINMM.dll')
def joyGetPos(uJoyID: UInt32, pji: POINTER(win32more.Windows.Win32.Media.Multimedia.JOYINFO)) -> UInt32: ...
@winfunctype('WINMM.dll')
def joyGetThreshold(uJoyID: UInt32, puThreshold: POINTER(UInt32)) -> UInt32: ...
@winfunctype('WINMM.dll')
def joyReleaseCapture(uJoyID: UInt32) -> UInt32: ...
@winfunctype('WINMM.dll')
def joySetCapture(hwnd: win32more.Windows.Win32.Foundation.HWND, uJoyID: UInt32, uPeriod: UInt32, fChanged: win32more.Windows.Win32.Foundation.BOOL) -> UInt32: ...
@winfunctype('WINMM.dll')
def joySetThreshold(uJoyID: UInt32, uThreshold: UInt32) -> UInt32: ...
@winfunctype('MSVFW32.dll')
def VideoForWindowsVersion() -> UInt32: ...
@winfunctype('MSVFW32.dll')
def ICInfo(fccType: UInt32, fccHandler: UInt32, lpicinfo: POINTER(win32more.Windows.Win32.Media.Multimedia.ICINFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('MSVFW32.dll')
def ICInstall(fccType: UInt32, fccHandler: UInt32, lParam: win32more.Windows.Win32.Foundation.LPARAM, szDesc: win32more.Windows.Win32.Foundation.PSTR, wFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('MSVFW32.dll')
def ICRemove(fccType: UInt32, fccHandler: UInt32, wFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('MSVFW32.dll')
def ICGetInfo(hic: win32more.Windows.Win32.Media.Multimedia.HIC, picinfo: POINTER(win32more.Windows.Win32.Media.Multimedia.ICINFO), cb: UInt32) -> win32more.Windows.Win32.Foundation.LRESULT: ...
@winfunctype('MSVFW32.dll')
def ICOpen(fccType: UInt32, fccHandler: UInt32, wMode: UInt32) -> win32more.Windows.Win32.Media.Multimedia.HIC: ...
@winfunctype('MSVFW32.dll')
def ICOpenFunction(fccType: UInt32, fccHandler: UInt32, wMode: UInt32, lpfnHandler: win32more.Windows.Win32.Foundation.FARPROC) -> win32more.Windows.Win32.Media.Multimedia.HIC: ...
@winfunctype('MSVFW32.dll')
def ICClose(hic: win32more.Windows.Win32.Media.Multimedia.HIC) -> win32more.Windows.Win32.Foundation.LRESULT: ...
@winfunctype('MSVFW32.dll')
def ICSendMessage(hic: win32more.Windows.Win32.Media.Multimedia.HIC, msg: UInt32, dw1: UIntPtr, dw2: UIntPtr) -> win32more.Windows.Win32.Foundation.LRESULT: ...
@cfunctype('MSVFW32.dll')
def ICCompress(hic: win32more.Windows.Win32.Media.Multimedia.HIC, dwFlags: UInt32, lpbiOutput: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFOHEADER), lpData: VoidPtr, lpbiInput: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFOHEADER), lpBits: VoidPtr, lpckid: POINTER(UInt32), lpdwFlags: POINTER(UInt32), lFrameNum: Int32, dwFrameSize: UInt32, dwQuality: UInt32, lpbiPrev: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFOHEADER), lpPrev: VoidPtr) -> UInt32: ...
@cfunctype('MSVFW32.dll')
def ICDecompress(hic: win32more.Windows.Win32.Media.Multimedia.HIC, dwFlags: UInt32, lpbiFormat: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFOHEADER), lpData: VoidPtr, lpbi: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFOHEADER), lpBits: VoidPtr) -> UInt32: ...
@cfunctype('MSVFW32.dll')
def ICDrawBegin(hic: win32more.Windows.Win32.Media.Multimedia.HIC, dwFlags: UInt32, hpal: win32more.Windows.Win32.Graphics.Gdi.HPALETTE, hwnd: win32more.Windows.Win32.Foundation.HWND, hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, xDst: Int32, yDst: Int32, dxDst: Int32, dyDst: Int32, lpbi: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFOHEADER), xSrc: Int32, ySrc: Int32, dxSrc: Int32, dySrc: Int32, dwRate: UInt32, dwScale: UInt32) -> UInt32: ...
@cfunctype('MSVFW32.dll')
def ICDraw(hic: win32more.Windows.Win32.Media.Multimedia.HIC, dwFlags: UInt32, lpFormat: VoidPtr, lpData: VoidPtr, cbData: UInt32, lTime: Int32) -> UInt32: ...
@winfunctype('MSVFW32.dll')
def ICLocate(fccType: UInt32, fccHandler: UInt32, lpbiIn: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFOHEADER), lpbiOut: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFOHEADER), wFlags: UInt16) -> win32more.Windows.Win32.Media.Multimedia.HIC: ...
@winfunctype('MSVFW32.dll')
def ICGetDisplayFormat(hic: win32more.Windows.Win32.Media.Multimedia.HIC, lpbiIn: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFOHEADER), lpbiOut: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFOHEADER), BitDepth: Int32, dx: Int32, dy: Int32) -> win32more.Windows.Win32.Media.Multimedia.HIC: ...
@winfunctype('MSVFW32.dll')
def ICImageCompress(hic: win32more.Windows.Win32.Media.Multimedia.HIC, uiFlags: UInt32, lpbiIn: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFO), lpBits: VoidPtr, lpbiOut: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFO), lQuality: Int32, plSize: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('MSVFW32.dll')
def ICImageDecompress(hic: win32more.Windows.Win32.Media.Multimedia.HIC, uiFlags: UInt32, lpbiIn: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFO), lpBits: VoidPtr, lpbiOut: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFO)) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('MSVFW32.dll')
def ICCompressorChoose(hwnd: win32more.Windows.Win32.Foundation.HWND, uiFlags: UInt32, pvIn: VoidPtr, lpData: VoidPtr, pc: POINTER(win32more.Windows.Win32.Media.Multimedia.COMPVARS), lpszTitle: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('MSVFW32.dll')
def ICSeqCompressFrameStart(pc: POINTER(win32more.Windows.Win32.Media.Multimedia.COMPVARS), lpbiIn: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('MSVFW32.dll')
def ICSeqCompressFrameEnd(pc: POINTER(win32more.Windows.Win32.Media.Multimedia.COMPVARS)) -> Void: ...
@winfunctype('MSVFW32.dll')
def ICSeqCompressFrame(pc: POINTER(win32more.Windows.Win32.Media.Multimedia.COMPVARS), uiFlags: UInt32, lpBits: VoidPtr, pfKey: POINTER(win32more.Windows.Win32.Foundation.BOOL), plSize: POINTER(Int32)) -> VoidPtr: ...
@winfunctype('MSVFW32.dll')
def ICCompressorFree(pc: POINTER(win32more.Windows.Win32.Media.Multimedia.COMPVARS)) -> Void: ...
@winfunctype('MSVFW32.dll')
def DrawDibOpen() -> IntPtr: ...
@winfunctype('MSVFW32.dll')
def DrawDibClose(hdd: IntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('MSVFW32.dll')
def DrawDibGetBuffer(hdd: IntPtr, lpbi: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFOHEADER), dwSize: UInt32, dwFlags: UInt32) -> VoidPtr: ...
@winfunctype('MSVFW32.dll')
def DrawDibGetPalette(hdd: IntPtr) -> win32more.Windows.Win32.Graphics.Gdi.HPALETTE: ...
@winfunctype('MSVFW32.dll')
def DrawDibSetPalette(hdd: IntPtr, hpal: win32more.Windows.Win32.Graphics.Gdi.HPALETTE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('MSVFW32.dll')
def DrawDibChangePalette(hdd: IntPtr, iStart: Int32, iLen: Int32, lppe: POINTER(win32more.Windows.Win32.Graphics.Gdi.PALETTEENTRY)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('MSVFW32.dll')
def DrawDibRealize(hdd: IntPtr, hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, fBackground: win32more.Windows.Win32.Foundation.BOOL) -> UInt32: ...
@winfunctype('MSVFW32.dll')
def DrawDibStart(hdd: IntPtr, rate: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('MSVFW32.dll')
def DrawDibStop(hdd: IntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('MSVFW32.dll')
def DrawDibBegin(hdd: IntPtr, hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, dxDst: Int32, dyDst: Int32, lpbi: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFOHEADER), dxSrc: Int32, dySrc: Int32, wFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('MSVFW32.dll')
def DrawDibDraw(hdd: IntPtr, hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, xDst: Int32, yDst: Int32, dxDst: Int32, dyDst: Int32, lpbi: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFOHEADER), lpBits: VoidPtr, xSrc: Int32, ySrc: Int32, dxSrc: Int32, dySrc: Int32, wFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('MSVFW32.dll')
def DrawDibEnd(hdd: IntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('MSVFW32.dll')
def DrawDibTime(hdd: IntPtr, lpddtime: POINTER(win32more.Windows.Win32.Media.Multimedia.DRAWDIBTIME)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('MSVFW32.dll')
def DrawDibProfileDisplay(lpbi: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFOHEADER)) -> win32more.Windows.Win32.Foundation.LRESULT: ...
@winfunctype('AVIFIL32.dll')
def AVIFileInit() -> Void: ...
@winfunctype('AVIFIL32.dll')
def AVIFileExit() -> Void: ...
@winfunctype('AVIFIL32.dll')
def AVIFileAddRef(pfile: win32more.Windows.Win32.Media.Multimedia.IAVIFile) -> UInt32: ...
@winfunctype('AVIFIL32.dll')
def AVIFileRelease(pfile: win32more.Windows.Win32.Media.Multimedia.IAVIFile) -> UInt32: ...
@winfunctype('AVIFIL32.dll')
def AVIFileOpenA(ppfile: POINTER(win32more.Windows.Win32.Media.Multimedia.IAVIFile), szFile: win32more.Windows.Win32.Foundation.PSTR, uMode: UInt32, lpHandler: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('AVIFIL32.dll')
def AVIFileOpenW(ppfile: POINTER(win32more.Windows.Win32.Media.Multimedia.IAVIFile), szFile: win32more.Windows.Win32.Foundation.PWSTR, uMode: UInt32, lpHandler: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
AVIFileOpen = UnicodeAlias('AVIFileOpenW')
@winfunctype('AVIFIL32.dll')
def AVIFileInfoW(pfile: win32more.Windows.Win32.Media.Multimedia.IAVIFile, pfi: POINTER(win32more.Windows.Win32.Media.Multimedia.AVIFILEINFOW), lSize: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
AVIFileInfo = UnicodeAlias('AVIFileInfoW')
@winfunctype('AVIFIL32.dll')
def AVIFileInfoA(pfile: win32more.Windows.Win32.Media.Multimedia.IAVIFile, pfi: POINTER(win32more.Windows.Win32.Media.Multimedia.AVIFILEINFOA), lSize: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('AVIFIL32.dll')
def AVIFileGetStream(pfile: win32more.Windows.Win32.Media.Multimedia.IAVIFile, ppavi: POINTER(win32more.Windows.Win32.Media.Multimedia.IAVIStream), fccType: UInt32, lParam: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('AVIFIL32.dll')
def AVIFileCreateStreamW(pfile: win32more.Windows.Win32.Media.Multimedia.IAVIFile, ppavi: POINTER(win32more.Windows.Win32.Media.Multimedia.IAVIStream), psi: POINTER(win32more.Windows.Win32.Media.Multimedia.AVISTREAMINFOW)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
AVIFileCreateStream = UnicodeAlias('AVIFileCreateStreamW')
@winfunctype('AVIFIL32.dll')
def AVIFileCreateStreamA(pfile: win32more.Windows.Win32.Media.Multimedia.IAVIFile, ppavi: POINTER(win32more.Windows.Win32.Media.Multimedia.IAVIStream), psi: POINTER(win32more.Windows.Win32.Media.Multimedia.AVISTREAMINFOA)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('AVIFIL32.dll')
def AVIFileWriteData(pfile: win32more.Windows.Win32.Media.Multimedia.IAVIFile, ckid: UInt32, lpData: VoidPtr, cbData: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('AVIFIL32.dll')
def AVIFileReadData(pfile: win32more.Windows.Win32.Media.Multimedia.IAVIFile, ckid: UInt32, lpData: VoidPtr, lpcbData: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('AVIFIL32.dll')
def AVIFileEndRecord(pfile: win32more.Windows.Win32.Media.Multimedia.IAVIFile) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('AVIFIL32.dll')
def AVIStreamAddRef(pavi: win32more.Windows.Win32.Media.Multimedia.IAVIStream) -> UInt32: ...
@winfunctype('AVIFIL32.dll')
def AVIStreamRelease(pavi: win32more.Windows.Win32.Media.Multimedia.IAVIStream) -> UInt32: ...
@winfunctype('AVIFIL32.dll')
def AVIStreamInfoW(pavi: win32more.Windows.Win32.Media.Multimedia.IAVIStream, psi: POINTER(win32more.Windows.Win32.Media.Multimedia.AVISTREAMINFOW), lSize: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
AVIStreamInfo = UnicodeAlias('AVIStreamInfoW')
@winfunctype('AVIFIL32.dll')
def AVIStreamInfoA(pavi: win32more.Windows.Win32.Media.Multimedia.IAVIStream, psi: POINTER(win32more.Windows.Win32.Media.Multimedia.AVISTREAMINFOA), lSize: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('AVIFIL32.dll')
def AVIStreamFindSample(pavi: win32more.Windows.Win32.Media.Multimedia.IAVIStream, lPos: Int32, lFlags: Int32) -> Int32: ...
@winfunctype('AVIFIL32.dll')
def AVIStreamReadFormat(pavi: win32more.Windows.Win32.Media.Multimedia.IAVIStream, lPos: Int32, lpFormat: VoidPtr, lpcbFormat: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('AVIFIL32.dll')
def AVIStreamSetFormat(pavi: win32more.Windows.Win32.Media.Multimedia.IAVIStream, lPos: Int32, lpFormat: VoidPtr, cbFormat: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('AVIFIL32.dll')
def AVIStreamReadData(pavi: win32more.Windows.Win32.Media.Multimedia.IAVIStream, fcc: UInt32, lp: VoidPtr, lpcb: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('AVIFIL32.dll')
def AVIStreamWriteData(pavi: win32more.Windows.Win32.Media.Multimedia.IAVIStream, fcc: UInt32, lp: VoidPtr, cb: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('AVIFIL32.dll')
def AVIStreamRead(pavi: win32more.Windows.Win32.Media.Multimedia.IAVIStream, lStart: Int32, lSamples: Int32, lpBuffer: VoidPtr, cbBuffer: Int32, plBytes: POINTER(Int32), plSamples: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('AVIFIL32.dll')
def AVIStreamWrite(pavi: win32more.Windows.Win32.Media.Multimedia.IAVIStream, lStart: Int32, lSamples: Int32, lpBuffer: VoidPtr, cbBuffer: Int32, dwFlags: UInt32, plSampWritten: POINTER(Int32), plBytesWritten: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('AVIFIL32.dll')
def AVIStreamStart(pavi: win32more.Windows.Win32.Media.Multimedia.IAVIStream) -> Int32: ...
@winfunctype('AVIFIL32.dll')
def AVIStreamLength(pavi: win32more.Windows.Win32.Media.Multimedia.IAVIStream) -> Int32: ...
@winfunctype('AVIFIL32.dll')
def AVIStreamTimeToSample(pavi: win32more.Windows.Win32.Media.Multimedia.IAVIStream, lTime: Int32) -> Int32: ...
@winfunctype('AVIFIL32.dll')
def AVIStreamSampleToTime(pavi: win32more.Windows.Win32.Media.Multimedia.IAVIStream, lSample: Int32) -> Int32: ...
@winfunctype('AVIFIL32.dll')
def AVIStreamBeginStreaming(pavi: win32more.Windows.Win32.Media.Multimedia.IAVIStream, lStart: Int32, lEnd: Int32, lRate: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('AVIFIL32.dll')
def AVIStreamEndStreaming(pavi: win32more.Windows.Win32.Media.Multimedia.IAVIStream) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('AVIFIL32.dll')
def AVIStreamGetFrameOpen(pavi: win32more.Windows.Win32.Media.Multimedia.IAVIStream, lpbiWanted: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFOHEADER)) -> win32more.Windows.Win32.Media.Multimedia.IGetFrame: ...
@winfunctype('AVIFIL32.dll')
def AVIStreamGetFrame(pg: win32more.Windows.Win32.Media.Multimedia.IGetFrame, lPos: Int32) -> VoidPtr: ...
@winfunctype('AVIFIL32.dll')
def AVIStreamGetFrameClose(pg: win32more.Windows.Win32.Media.Multimedia.IGetFrame) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('AVIFIL32.dll')
def AVIStreamOpenFromFileA(ppavi: POINTER(win32more.Windows.Win32.Media.Multimedia.IAVIStream), szFile: win32more.Windows.Win32.Foundation.PSTR, fccType: UInt32, lParam: Int32, mode: UInt32, pclsidHandler: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('AVIFIL32.dll')
def AVIStreamOpenFromFileW(ppavi: POINTER(win32more.Windows.Win32.Media.Multimedia.IAVIStream), szFile: win32more.Windows.Win32.Foundation.PWSTR, fccType: UInt32, lParam: Int32, mode: UInt32, pclsidHandler: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
AVIStreamOpenFromFile = UnicodeAlias('AVIStreamOpenFromFileW')
@winfunctype('AVIFIL32.dll')
def AVIStreamCreate(ppavi: POINTER(win32more.Windows.Win32.Media.Multimedia.IAVIStream), lParam1: Int32, lParam2: Int32, pclsidHandler: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('AVIFIL32.dll')
def AVIMakeCompressedStream(ppsCompressed: POINTER(win32more.Windows.Win32.Media.Multimedia.IAVIStream), ppsSource: win32more.Windows.Win32.Media.Multimedia.IAVIStream, lpOptions: POINTER(win32more.Windows.Win32.Media.Multimedia.AVICOMPRESSOPTIONS), pclsidHandler: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@cfunctype('AVIFIL32.dll', variadic=True)
def AVISaveA(szFile: win32more.Windows.Win32.Foundation.PSTR, pclsidHandler: POINTER(Guid), lpfnCallback: win32more.Windows.Win32.Media.Multimedia.AVISAVECALLBACK, nStreams: Int32, pfile: win32more.Windows.Win32.Media.Multimedia.IAVIStream, lpOptions: POINTER(win32more.Windows.Win32.Media.Multimedia.AVICOMPRESSOPTIONS), *__arglist) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('AVIFIL32.dll')
def AVISaveVA(szFile: win32more.Windows.Win32.Foundation.PSTR, pclsidHandler: POINTER(Guid), lpfnCallback: win32more.Windows.Win32.Media.Multimedia.AVISAVECALLBACK, nStreams: Int32, ppavi: POINTER(win32more.Windows.Win32.Media.Multimedia.IAVIStream), plpOptions: POINTER(POINTER(win32more.Windows.Win32.Media.Multimedia.AVICOMPRESSOPTIONS))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@cfunctype('AVIFIL32.dll', variadic=True)
def AVISaveW(szFile: win32more.Windows.Win32.Foundation.PWSTR, pclsidHandler: POINTER(Guid), lpfnCallback: win32more.Windows.Win32.Media.Multimedia.AVISAVECALLBACK, nStreams: Int32, pfile: win32more.Windows.Win32.Media.Multimedia.IAVIStream, lpOptions: POINTER(win32more.Windows.Win32.Media.Multimedia.AVICOMPRESSOPTIONS), *__arglist) -> win32more.Windows.Win32.Foundation.HRESULT: ...
AVISave = UnicodeAlias('AVISaveW')
@winfunctype('AVIFIL32.dll')
def AVISaveVW(szFile: win32more.Windows.Win32.Foundation.PWSTR, pclsidHandler: POINTER(Guid), lpfnCallback: win32more.Windows.Win32.Media.Multimedia.AVISAVECALLBACK, nStreams: Int32, ppavi: POINTER(win32more.Windows.Win32.Media.Multimedia.IAVIStream), plpOptions: POINTER(POINTER(win32more.Windows.Win32.Media.Multimedia.AVICOMPRESSOPTIONS))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
AVISaveV = UnicodeAlias('AVISaveVW')
@winfunctype('AVIFIL32.dll')
def AVISaveOptions(hwnd: win32more.Windows.Win32.Foundation.HWND, uiFlags: UInt32, nStreams: Int32, ppavi: POINTER(win32more.Windows.Win32.Media.Multimedia.IAVIStream), plpOptions: POINTER(POINTER(win32more.Windows.Win32.Media.Multimedia.AVICOMPRESSOPTIONS))) -> IntPtr: ...
@winfunctype('AVIFIL32.dll')
def AVISaveOptionsFree(nStreams: Int32, plpOptions: POINTER(POINTER(win32more.Windows.Win32.Media.Multimedia.AVICOMPRESSOPTIONS))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('AVIFIL32.dll')
def AVIBuildFilterW(lpszFilter: win32more.Windows.Win32.Foundation.PWSTR, cbFilter: Int32, fSaving: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
AVIBuildFilter = UnicodeAlias('AVIBuildFilterW')
@winfunctype('AVIFIL32.dll')
def AVIBuildFilterA(lpszFilter: win32more.Windows.Win32.Foundation.PSTR, cbFilter: Int32, fSaving: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('AVIFIL32.dll')
def AVIMakeFileFromStreams(ppfile: POINTER(win32more.Windows.Win32.Media.Multimedia.IAVIFile), nStreams: Int32, papStreams: POINTER(win32more.Windows.Win32.Media.Multimedia.IAVIStream)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('AVIFIL32.dll')
def AVIMakeStreamFromClipboard(cfFormat: UInt32, hGlobal: win32more.Windows.Win32.Foundation.HANDLE, ppstream: POINTER(win32more.Windows.Win32.Media.Multimedia.IAVIStream)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('AVIFIL32.dll')
def AVIPutFileOnClipboard(pf: win32more.Windows.Win32.Media.Multimedia.IAVIFile) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('AVIFIL32.dll')
def AVIGetFromClipboard(lppf: POINTER(win32more.Windows.Win32.Media.Multimedia.IAVIFile)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('AVIFIL32.dll')
def AVIClearClipboard() -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('AVIFIL32.dll')
def CreateEditableStream(ppsEditable: POINTER(win32more.Windows.Win32.Media.Multimedia.IAVIStream), psSource: win32more.Windows.Win32.Media.Multimedia.IAVIStream) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('AVIFIL32.dll')
def EditStreamCut(pavi: win32more.Windows.Win32.Media.Multimedia.IAVIStream, plStart: POINTER(Int32), plLength: POINTER(Int32), ppResult: POINTER(win32more.Windows.Win32.Media.Multimedia.IAVIStream)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('AVIFIL32.dll')
def EditStreamCopy(pavi: win32more.Windows.Win32.Media.Multimedia.IAVIStream, plStart: POINTER(Int32), plLength: POINTER(Int32), ppResult: POINTER(win32more.Windows.Win32.Media.Multimedia.IAVIStream)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('AVIFIL32.dll')
def EditStreamPaste(pavi: win32more.Windows.Win32.Media.Multimedia.IAVIStream, plPos: POINTER(Int32), plLength: POINTER(Int32), pstream: win32more.Windows.Win32.Media.Multimedia.IAVIStream, lStart: Int32, lEnd: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('AVIFIL32.dll')
def EditStreamClone(pavi: win32more.Windows.Win32.Media.Multimedia.IAVIStream, ppResult: POINTER(win32more.Windows.Win32.Media.Multimedia.IAVIStream)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('AVIFIL32.dll')
def EditStreamSetNameA(pavi: win32more.Windows.Win32.Media.Multimedia.IAVIStream, lpszName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('AVIFIL32.dll')
def EditStreamSetNameW(pavi: win32more.Windows.Win32.Media.Multimedia.IAVIStream, lpszName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
EditStreamSetName = UnicodeAlias('EditStreamSetNameW')
@winfunctype('AVIFIL32.dll')
def EditStreamSetInfoW(pavi: win32more.Windows.Win32.Media.Multimedia.IAVIStream, lpInfo: POINTER(win32more.Windows.Win32.Media.Multimedia.AVISTREAMINFOW), cbInfo: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
EditStreamSetInfo = UnicodeAlias('EditStreamSetInfoW')
@winfunctype('AVIFIL32.dll')
def EditStreamSetInfoA(pavi: win32more.Windows.Win32.Media.Multimedia.IAVIStream, lpInfo: POINTER(win32more.Windows.Win32.Media.Multimedia.AVISTREAMINFOA), cbInfo: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@cfunctype('MSVFW32.dll')
def MCIWndCreateA(hwndParent: win32more.Windows.Win32.Foundation.HWND, hInstance: win32more.Windows.Win32.Foundation.HINSTANCE, dwStyle: UInt32, szFile: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HWND: ...
@cfunctype('MSVFW32.dll')
def MCIWndCreateW(hwndParent: win32more.Windows.Win32.Foundation.HWND, hInstance: win32more.Windows.Win32.Foundation.HINSTANCE, dwStyle: UInt32, szFile: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HWND: ...
MCIWndCreate = UnicodeAlias('MCIWndCreateW')
@cfunctype('MSVFW32.dll')
def MCIWndRegisterClass() -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('AVICAP32.dll')
def capCreateCaptureWindowA(lpszWindowName: win32more.Windows.Win32.Foundation.PSTR, dwStyle: UInt32, x: Int32, y: Int32, nWidth: Int32, nHeight: Int32, hwndParent: win32more.Windows.Win32.Foundation.HWND, nID: Int32) -> win32more.Windows.Win32.Foundation.HWND: ...
@winfunctype('AVICAP32.dll')
def capGetDriverDescriptionA(wDriverIndex: UInt32, lpszName: win32more.Windows.Win32.Foundation.PSTR, cbName: Int32, lpszVer: win32more.Windows.Win32.Foundation.PSTR, cbVer: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('AVICAP32.dll')
def capCreateCaptureWindowW(lpszWindowName: win32more.Windows.Win32.Foundation.PWSTR, dwStyle: UInt32, x: Int32, y: Int32, nWidth: Int32, nHeight: Int32, hwndParent: win32more.Windows.Win32.Foundation.HWND, nID: Int32) -> win32more.Windows.Win32.Foundation.HWND: ...
capCreateCaptureWindow = UnicodeAlias('capCreateCaptureWindowW')
@winfunctype('AVICAP32.dll')
def capGetDriverDescriptionW(wDriverIndex: UInt32, lpszName: win32more.Windows.Win32.Foundation.PWSTR, cbName: Int32, lpszVer: win32more.Windows.Win32.Foundation.PWSTR, cbVer: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
capGetDriverDescription = UnicodeAlias('capGetDriverDescriptionW')
@winfunctype('MSVFW32.dll')
def GetOpenFileNamePreviewA(lpofn: POINTER(win32more.Windows.Win32.UI.Controls.Dialogs.OPENFILENAMEA)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('MSVFW32.dll')
def GetSaveFileNamePreviewA(lpofn: POINTER(win32more.Windows.Win32.UI.Controls.Dialogs.OPENFILENAMEA)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('MSVFW32.dll')
def GetOpenFileNamePreviewW(lpofn: POINTER(win32more.Windows.Win32.UI.Controls.Dialogs.OPENFILENAMEW)) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetOpenFileNamePreview = UnicodeAlias('GetOpenFileNamePreviewW')
@winfunctype('MSVFW32.dll')
def GetSaveFileNamePreviewW(lpofn: POINTER(win32more.Windows.Win32.UI.Controls.Dialogs.OPENFILENAMEW)) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetSaveFileNamePreview = UnicodeAlias('GetSaveFileNamePreviewW')
@winfunctype('WINMM.dll')
def mmTaskCreate(lpfn: win32more.Windows.Win32.Media.Multimedia.LPTASKCALLBACK, lph: POINTER(win32more.Windows.Win32.Foundation.HANDLE), dwInst: UIntPtr) -> UInt32: ...
@winfunctype('WINMM.dll')
def mmTaskBlock(h: UInt32) -> Void: ...
@winfunctype('WINMM.dll')
def mmTaskSignal(h: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WINMM.dll')
def mmTaskYield() -> Void: ...
@winfunctype('WINMM.dll')
def mmGetCurrentTask() -> UInt32: ...
@winfunctype_pointer
def CAPCONTROLCALLBACK(hWnd: win32more.Windows.Win32.Foundation.HWND, nState: Int32) -> win32more.Windows.Win32.Foundation.LRESULT: ...
class CAPDRIVERCAPS(Structure):
    wDeviceIndex: UInt32
    fHasOverlay: win32more.Windows.Win32.Foundation.BOOL
    fHasDlgVideoSource: win32more.Windows.Win32.Foundation.BOOL
    fHasDlgVideoFormat: win32more.Windows.Win32.Foundation.BOOL
    fHasDlgVideoDisplay: win32more.Windows.Win32.Foundation.BOOL
    fCaptureInitialized: win32more.Windows.Win32.Foundation.BOOL
    fDriverSuppliesPalettes: win32more.Windows.Win32.Foundation.BOOL
    hVideoIn: win32more.Windows.Win32.Foundation.HANDLE
    hVideoOut: win32more.Windows.Win32.Foundation.HANDLE
    hVideoExtIn: win32more.Windows.Win32.Foundation.HANDLE
    hVideoExtOut: win32more.Windows.Win32.Foundation.HANDLE
@winfunctype_pointer
def CAPERRORCALLBACKA(hWnd: win32more.Windows.Win32.Foundation.HWND, nID: Int32, lpsz: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.LRESULT: ...
@winfunctype_pointer
def CAPERRORCALLBACKW(hWnd: win32more.Windows.Win32.Foundation.HWND, nID: Int32, lpsz: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.LRESULT: ...
CAPERRORCALLBACK = UnicodeAlias('CAPERRORCALLBACKW')
class CAPINFOCHUNK(Structure):
    fccInfoID: UInt32
    lpData: VoidPtr
    cbData: Int32
class CAPSTATUS(Structure):
    uiImageWidth: UInt32
    uiImageHeight: UInt32
    fLiveWindow: win32more.Windows.Win32.Foundation.BOOL
    fOverlayWindow: win32more.Windows.Win32.Foundation.BOOL
    fScale: win32more.Windows.Win32.Foundation.BOOL
    ptScroll: win32more.Windows.Win32.Foundation.POINT
    fUsingDefaultPalette: win32more.Windows.Win32.Foundation.BOOL
    fAudioHardware: win32more.Windows.Win32.Foundation.BOOL
    fCapFileExists: win32more.Windows.Win32.Foundation.BOOL
    dwCurrentVideoFrame: UInt32
    dwCurrentVideoFramesDropped: UInt32
    dwCurrentWaveSamples: UInt32
    dwCurrentTimeElapsedMS: UInt32
    hPalCurrent: win32more.Windows.Win32.Graphics.Gdi.HPALETTE
    fCapturingNow: win32more.Windows.Win32.Foundation.BOOL
    dwReturn: UInt32
    wNumVideoAllocated: UInt32
    wNumAudioAllocated: UInt32
@winfunctype_pointer
def CAPSTATUSCALLBACKA(hWnd: win32more.Windows.Win32.Foundation.HWND, nID: Int32, lpsz: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.LRESULT: ...
@winfunctype_pointer
def CAPSTATUSCALLBACKW(hWnd: win32more.Windows.Win32.Foundation.HWND, nID: Int32, lpsz: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.LRESULT: ...
CAPSTATUSCALLBACK = UnicodeAlias('CAPSTATUSCALLBACKW')
class CAPTUREPARMS(Structure):
    dwRequestMicroSecPerFrame: UInt32
    fMakeUserHitOKToCapture: win32more.Windows.Win32.Foundation.BOOL
    wPercentDropForError: UInt32
    fYield: win32more.Windows.Win32.Foundation.BOOL
    dwIndexSize: UInt32
    wChunkGranularity: UInt32
    fUsingDOSMemory: win32more.Windows.Win32.Foundation.BOOL
    wNumVideoRequested: UInt32
    fCaptureAudio: win32more.Windows.Win32.Foundation.BOOL
    wNumAudioRequested: UInt32
    vKeyAbort: UInt32
    fAbortLeftMouse: win32more.Windows.Win32.Foundation.BOOL
    fAbortRightMouse: win32more.Windows.Win32.Foundation.BOOL
    fLimitEnabled: win32more.Windows.Win32.Foundation.BOOL
    wTimeLimit: UInt32
    fMCIControl: win32more.Windows.Win32.Foundation.BOOL
    fStepMCIDevice: win32more.Windows.Win32.Foundation.BOOL
    dwMCIStartTime: UInt32
    dwMCIStopTime: UInt32
    fStepCaptureAt2x: win32more.Windows.Win32.Foundation.BOOL
    wStepCaptureAverageFrames: UInt32
    dwAudioBufferSize: UInt32
    fDisableWriteCache: win32more.Windows.Win32.Foundation.BOOL
    AVStreamMaster: UInt32
@winfunctype_pointer
def CAPVIDEOCALLBACK(hWnd: win32more.Windows.Win32.Foundation.HWND, lpVHdr: POINTER(win32more.Windows.Win32.Media.Multimedia.VIDEOHDR)) -> win32more.Windows.Win32.Foundation.LRESULT: ...
@winfunctype_pointer
def CAPWAVECALLBACK(hWnd: win32more.Windows.Win32.Foundation.HWND, lpWHdr: POINTER(win32more.Windows.Win32.Media.Audio.WAVEHDR)) -> win32more.Windows.Win32.Foundation.LRESULT: ...
@winfunctype_pointer
def CAPYIELDCALLBACK(hWnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.LRESULT: ...
class CHANNEL_CAPS(Structure):
    dwFlags: UInt32
    dwSrcRectXMod: UInt32
    dwSrcRectYMod: UInt32
    dwSrcRectWidthMod: UInt32
    dwSrcRectHeightMod: UInt32
    dwDstRectXMod: UInt32
    dwDstRectYMod: UInt32
    dwDstRectWidthMod: UInt32
    dwDstRectHeightMod: UInt32
class COMPVARS(Structure):
    cbSize: Int32
    dwFlags: UInt32
    hic: win32more.Windows.Win32.Media.Multimedia.HIC
    fccType: UInt32
    fccHandler: UInt32
    lpbiIn: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFO)
    lpbiOut: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFO)
    lpBitsOut: VoidPtr
    lpBitsPrev: VoidPtr
    lFrame: Int32
    lKey: Int32
    lDataRate: Int32
    lQ: Int32
    lKeyCount: Int32
    lpState: VoidPtr
    cbState: Int32
class CONTRESCR10WAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    wSamplesPerBlock: UInt16
    _pack_ = 1
class CONTRESVQLPCWAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    wSamplesPerBlock: UInt16
    _pack_ = 1
class CREATIVEADPCMWAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    wRevision: UInt16
    _pack_ = 1
class CREATIVEFASTSPEECH10WAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    wRevision: UInt16
    _pack_ = 1
class CREATIVEFASTSPEECH8WAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    wRevision: UInt16
    _pack_ = 1
class CSIMAADPCMWAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    _pack_ = 1
class DIALOGICOKIADPCMWAVEFORMAT(Structure):
    ewf: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    _pack_ = 1
class DIGIADPCMWAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    wSamplesPerBlock: UInt16
    _pack_ = 1
class DIGIFIXWAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    _pack_ = 1
class DIGIREALWAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    wSamplesPerBlock: UInt16
    _pack_ = 1
class DIGISTDWAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    _pack_ = 1
class DOLBYAC2WAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    nAuxBitsCode: UInt16
    _pack_ = 1
class DRAWDIBTIME(Structure):
    timeCount: Int32
    timeDraw: Int32
    timeDecompress: Int32
    timeDither: Int32
    timeStretch: Int32
    timeBlt: Int32
    timeSetDIBits: Int32
@winfunctype_pointer
def DRIVERMSGPROC(param0: UInt32, param1: UInt32, param2: UIntPtr, param3: UIntPtr, param4: UIntPtr) -> UInt32: ...
@winfunctype_pointer
def DRIVERPROC(param0: UIntPtr, param1: win32more.Windows.Win32.Media.Multimedia.HDRVR, param2: UInt32, param3: win32more.Windows.Win32.Foundation.LPARAM, param4: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.LRESULT: ...
class DRMWAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    wReserved: UInt16
    ulContentId: UInt32
    wfxSecure: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    _pack_ = 1
class DRVCONFIGINFO(Structure):
    dwDCISize: UInt32
    lpszDCISectionName: win32more.Windows.Win32.Foundation.PWSTR
    lpszDCIAliasName: win32more.Windows.Win32.Foundation.PWSTR
    _pack_ = 1
class DRVCONFIGINFOEX(Structure):
    dwDCISize: UInt32
    lpszDCISectionName: win32more.Windows.Win32.Foundation.PWSTR
    lpszDCIAliasName: win32more.Windows.Win32.Foundation.PWSTR
    dnDevNode: UInt32
    _pack_ = 1
class DRVM_IOCTL_DATA(Structure):
    dwSize: UInt32
    dwCmd: UInt32
    _pack_ = 1
class DVIADPCMWAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    wSamplesPerBlock: UInt16
    _pack_ = 1
class ECHOSC1WAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    _pack_ = 1
class EXBMINFOHEADER(Structure):
    bmi: win32more.Windows.Win32.Graphics.Gdi.BITMAPINFOHEADER
    biExtDataOffset: UInt32
    _pack_ = 1
class FMTOWNS_SND_WAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    wRevision: UInt16
    _pack_ = 1
class G721_ADPCMWAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    nAuxBlockSize: UInt16
    _pack_ = 1
class G723_ADPCMWAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    cbExtraSize: UInt16
    nAuxBlockSize: UInt16
    _pack_ = 1
class GSM610WAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    wSamplesPerBlock: UInt16
    _pack_ = 1
HDRVR = VoidPtr
HIC = VoidPtr
HMMIO = VoidPtr
HVIDEO = VoidPtr
class IAVIEditStream(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{00020024-0000-0000-c000-000000000046}')
    @commethod(3)
    def Cut(self, plStart: POINTER(Int32), plLength: POINTER(Int32), ppResult: POINTER(win32more.Windows.Win32.Media.Multimedia.IAVIStream)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Copy(self, plStart: POINTER(Int32), plLength: POINTER(Int32), ppResult: POINTER(win32more.Windows.Win32.Media.Multimedia.IAVIStream)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Paste(self, plPos: POINTER(Int32), plLength: POINTER(Int32), pstream: win32more.Windows.Win32.Media.Multimedia.IAVIStream, lStart: Int32, lEnd: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Clone(self, ppResult: POINTER(win32more.Windows.Win32.Media.Multimedia.IAVIStream)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetInfo(self, lpInfo: POINTER(win32more.Windows.Win32.Media.Multimedia.AVISTREAMINFOW), cbInfo: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IAVIFile(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{00020020-0000-0000-c000-000000000046}')
    @commethod(3)
    def Info(self, pfi: POINTER(win32more.Windows.Win32.Media.Multimedia.AVIFILEINFOW), lSize: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetStream(self, ppStream: POINTER(win32more.Windows.Win32.Media.Multimedia.IAVIStream), fccType: UInt32, lParam: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CreateStream(self, ppStream: POINTER(win32more.Windows.Win32.Media.Multimedia.IAVIStream), psi: POINTER(win32more.Windows.Win32.Media.Multimedia.AVISTREAMINFOW)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def WriteData(self, ckid: UInt32, lpData: VoidPtr, cbData: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def ReadData(self, ckid: UInt32, lpData: VoidPtr, lpcbData: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def EndRecord(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def DeleteStream(self, fccType: UInt32, lParam: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IAVIPersistFile(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IPersistFile
    _iid_ = Guid('{00020025-0000-0000-c000-000000000046}')
    @commethod(9)
    def Reserved1(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IAVIStream(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{00020021-0000-0000-c000-000000000046}')
    @commethod(3)
    def Create(self, lParam1: win32more.Windows.Win32.Foundation.LPARAM, lParam2: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Info(self, psi: POINTER(win32more.Windows.Win32.Media.Multimedia.AVISTREAMINFOW), lSize: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def FindSample(self, lPos: Int32, lFlags: Int32) -> Int32: ...
    @commethod(6)
    def ReadFormat(self, lPos: Int32, lpFormat: VoidPtr, lpcbFormat: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetFormat(self, lPos: Int32, lpFormat: VoidPtr, cbFormat: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Read(self, lStart: Int32, lSamples: Int32, lpBuffer: VoidPtr, cbBuffer: Int32, plBytes: POINTER(Int32), plSamples: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Write(self, lStart: Int32, lSamples: Int32, lpBuffer: VoidPtr, cbBuffer: Int32, dwFlags: UInt32, plSampWritten: POINTER(Int32), plBytesWritten: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def Delete(self, lStart: Int32, lSamples: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def ReadData(self, fcc: UInt32, lp: VoidPtr, lpcb: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def WriteData(self, fcc: UInt32, lp: VoidPtr, cb: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def SetInfo(self, lpInfo: POINTER(win32more.Windows.Win32.Media.Multimedia.AVISTREAMINFOW), cbInfo: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IAVIStreaming(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{00020022-0000-0000-c000-000000000046}')
    @commethod(3)
    def Begin(self, lStart: Int32, lEnd: Int32, lRate: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def End(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ICCOMPRESS(Structure):
    dwFlags: UInt32
    lpbiOutput: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFOHEADER)
    lpOutput: VoidPtr
    lpbiInput: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFOHEADER)
    lpInput: VoidPtr
    lpckid: POINTER(UInt32)
    lpdwFlags: POINTER(UInt32)
    lFrameNum: Int32
    dwFrameSize: UInt32
    dwQuality: UInt32
    lpbiPrev: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFOHEADER)
    lpPrev: VoidPtr
class ICCOMPRESSFRAMES(Structure):
    dwFlags: UInt32
    lpbiOutput: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFOHEADER)
    lOutput: win32more.Windows.Win32.Foundation.LPARAM
    lpbiInput: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFOHEADER)
    lInput: win32more.Windows.Win32.Foundation.LPARAM
    lStartFrame: Int32
    lFrameCount: Int32
    lQuality: Int32
    lDataRate: Int32
    lKeyRate: Int32
    dwRate: UInt32
    dwScale: UInt32
    dwOverheadPerFrame: UInt32
    dwReserved2: UInt32
    GetData: IntPtr
    PutData: IntPtr
class ICDECOMPRESS(Structure):
    dwFlags: UInt32
    lpbiInput: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFOHEADER)
    lpInput: VoidPtr
    lpbiOutput: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFOHEADER)
    lpOutput: VoidPtr
    ckid: UInt32
class ICDECOMPRESSEX(Structure):
    dwFlags: UInt32
    lpbiSrc: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFOHEADER)
    lpSrc: VoidPtr
    lpbiDst: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFOHEADER)
    lpDst: VoidPtr
    xDst: Int32
    yDst: Int32
    dxDst: Int32
    dyDst: Int32
    xSrc: Int32
    ySrc: Int32
    dxSrc: Int32
    dySrc: Int32
class ICDRAW(Structure):
    dwFlags: UInt32
    lpFormat: VoidPtr
    lpData: VoidPtr
    cbData: UInt32
    lTime: Int32
class ICDRAWBEGIN(Structure):
    dwFlags: UInt32
    hpal: win32more.Windows.Win32.Graphics.Gdi.HPALETTE
    hwnd: win32more.Windows.Win32.Foundation.HWND
    hdc: win32more.Windows.Win32.Graphics.Gdi.HDC
    xDst: Int32
    yDst: Int32
    dxDst: Int32
    dyDst: Int32
    lpbi: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFOHEADER)
    xSrc: Int32
    ySrc: Int32
    dxSrc: Int32
    dySrc: Int32
    dwRate: UInt32
    dwScale: UInt32
class ICDRAWSUGGEST(Structure):
    lpbiIn: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFOHEADER)
    lpbiSuggest: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFOHEADER)
    dxSrc: Int32
    dySrc: Int32
    dxDst: Int32
    dyDst: Int32
    hicDecompressor: win32more.Windows.Win32.Media.Multimedia.HIC
class ICINFO(Structure):
    dwSize: UInt32
    fccType: UInt32
    fccHandler: UInt32
    dwFlags: UInt32
    dwVersion: UInt32
    dwVersionICM: UInt32
    szName: Char * 16
    szDescription: Char * 128
    szDriver: Char * 128
class ICOPEN(Structure):
    dwSize: UInt32
    fccType: UInt32
    fccHandler: UInt32
    dwVersion: UInt32
    dwFlags: UInt32
    dwError: win32more.Windows.Win32.Foundation.LRESULT
    pV1Reserved: VoidPtr
    pV2Reserved: VoidPtr
    dnDevNode: UInt32
class ICPALETTE(Structure):
    dwFlags: UInt32
    iStart: Int32
    iLen: Int32
    lppe: POINTER(win32more.Windows.Win32.Graphics.Gdi.PALETTEENTRY)
class ICSETSTATUSPROC(Structure):
    dwFlags: UInt32
    lParam: win32more.Windows.Win32.Foundation.LPARAM
    Status: IntPtr
class IGetFrame(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{00020023-0000-0000-c000-000000000046}')
    @commethod(3)
    def GetFrame(self, lPos: Int32) -> VoidPtr: ...
    @commethod(4)
    def Begin(self, lStart: Int32, lEnd: Int32, lRate: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def End(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetFormat(self, lpbi: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFOHEADER), lpBits: VoidPtr, x: Int32, y: Int32, dx: Int32, dy: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMAADPCMWAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    wSamplesPerBlock: UInt16
    _pack_ = 1
class JOYCAPS2A(Structure):
    wMid: UInt16
    wPid: UInt16
    szPname: win32more.Windows.Win32.Foundation.CHAR * 32
    wXmin: UInt32
    wXmax: UInt32
    wYmin: UInt32
    wYmax: UInt32
    wZmin: UInt32
    wZmax: UInt32
    wNumButtons: UInt32
    wPeriodMin: UInt32
    wPeriodMax: UInt32
    wRmin: UInt32
    wRmax: UInt32
    wUmin: UInt32
    wUmax: UInt32
    wVmin: UInt32
    wVmax: UInt32
    wCaps: UInt32
    wMaxAxes: UInt32
    wNumAxes: UInt32
    wMaxButtons: UInt32
    szRegKey: win32more.Windows.Win32.Foundation.CHAR * 32
    szOEMVxD: win32more.Windows.Win32.Foundation.CHAR * 260
    ManufacturerGuid: Guid
    ProductGuid: Guid
    NameGuid: Guid
    _pack_ = 1
class JOYCAPS2W(Structure):
    wMid: UInt16
    wPid: UInt16
    szPname: Char * 32
    wXmin: UInt32
    wXmax: UInt32
    wYmin: UInt32
    wYmax: UInt32
    wZmin: UInt32
    wZmax: UInt32
    wNumButtons: UInt32
    wPeriodMin: UInt32
    wPeriodMax: UInt32
    wRmin: UInt32
    wRmax: UInt32
    wUmin: UInt32
    wUmax: UInt32
    wVmin: UInt32
    wVmax: UInt32
    wCaps: UInt32
    wMaxAxes: UInt32
    wNumAxes: UInt32
    wMaxButtons: UInt32
    szRegKey: Char * 32
    szOEMVxD: Char * 260
    ManufacturerGuid: Guid
    ProductGuid: Guid
    NameGuid: Guid
    _pack_ = 1
JOYCAPS2 = UnicodeAlias('JOYCAPS2W')
class JOYCAPSA(Structure):
    wMid: UInt16
    wPid: UInt16
    szPname: win32more.Windows.Win32.Foundation.CHAR * 32
    wXmin: UInt32
    wXmax: UInt32
    wYmin: UInt32
    wYmax: UInt32
    wZmin: UInt32
    wZmax: UInt32
    wNumButtons: UInt32
    wPeriodMin: UInt32
    wPeriodMax: UInt32
    wRmin: UInt32
    wRmax: UInt32
    wUmin: UInt32
    wUmax: UInt32
    wVmin: UInt32
    wVmax: UInt32
    wCaps: UInt32
    wMaxAxes: UInt32
    wNumAxes: UInt32
    wMaxButtons: UInt32
    szRegKey: win32more.Windows.Win32.Foundation.CHAR * 32
    szOEMVxD: win32more.Windows.Win32.Foundation.CHAR * 260
    _pack_ = 1
class JOYCAPSW(Structure):
    wMid: UInt16
    wPid: UInt16
    szPname: Char * 32
    wXmin: UInt32
    wXmax: UInt32
    wYmin: UInt32
    wYmax: UInt32
    wZmin: UInt32
    wZmax: UInt32
    wNumButtons: UInt32
    wPeriodMin: UInt32
    wPeriodMax: UInt32
    wRmin: UInt32
    wRmax: UInt32
    wUmin: UInt32
    wUmax: UInt32
    wVmin: UInt32
    wVmax: UInt32
    wCaps: UInt32
    wMaxAxes: UInt32
    wNumAxes: UInt32
    wMaxButtons: UInt32
    szRegKey: Char * 32
    szOEMVxD: Char * 260
    _pack_ = 1
JOYCAPS = UnicodeAlias('JOYCAPSW')
class JOYINFO(Structure):
    wXpos: UInt32
    wYpos: UInt32
    wZpos: UInt32
    wButtons: UInt32
    _pack_ = 1
class JOYINFOEX(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    dwXpos: UInt32
    dwYpos: UInt32
    dwZpos: UInt32
    dwRpos: UInt32
    dwUpos: UInt32
    dwVpos: UInt32
    dwButtons: UInt32
    dwButtonNumber: UInt32
    dwPOV: UInt32
    dwReserved1: UInt32
    dwReserved2: UInt32
    _pack_ = 1
class JPEGINFOHEADER(Structure):
    JPEGSize: UInt32
    JPEGProcess: UInt32
    JPEGColorSpaceID: UInt32
    JPEGBitsPerSample: UInt32
    JPEGHSubSampling: UInt32
    JPEGVSubSampling: UInt32
    _pack_ = 1
KSDATAFORMAT_SUBTYPE_IEEE_FLOAT = Guid('{00000003-0000-0010-8000-00aa00389b71}')
@winfunctype_pointer
def LPFNEXTDEVIO(lParam: win32more.Windows.Win32.Foundation.LPARAM, dwFlags: UInt32, dwIoControlCode: UInt32, lpInBuffer: VoidPtr, nInBufferSize: UInt32, lpOutBuffer: VoidPtr, nOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32), lpOverlapped: POINTER(win32more.Windows.Win32.System.IO.OVERLAPPED)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def LPMMIOPROC(lpmmioinfo: win32more.Windows.Win32.Foundation.PSTR, uMsg: UInt32, lParam1: win32more.Windows.Win32.Foundation.LPARAM, lParam2: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.LRESULT: ...
@winfunctype_pointer
def LPTASKCALLBACK(dwInst: UIntPtr) -> Void: ...
class MCI_ANIM_OPEN_PARMSA(Structure):
    dwCallback: UIntPtr
    wDeviceID: UInt32
    lpstrDeviceType: win32more.Windows.Win32.Foundation.PSTR
    lpstrElementName: win32more.Windows.Win32.Foundation.PSTR
    lpstrAlias: win32more.Windows.Win32.Foundation.PSTR
    dwStyle: UInt32
    hWndParent: win32more.Windows.Win32.Foundation.HWND
    _pack_ = 1
class MCI_ANIM_OPEN_PARMSW(Structure):
    dwCallback: UIntPtr
    wDeviceID: UInt32
    lpstrDeviceType: win32more.Windows.Win32.Foundation.PWSTR
    lpstrElementName: win32more.Windows.Win32.Foundation.PWSTR
    lpstrAlias: win32more.Windows.Win32.Foundation.PWSTR
    dwStyle: UInt32
    hWndParent: win32more.Windows.Win32.Foundation.HWND
    _pack_ = 1
MCI_ANIM_OPEN_PARMS = UnicodeAlias('MCI_ANIM_OPEN_PARMSW')
class MCI_ANIM_PLAY_PARMS(Structure):
    dwCallback: UIntPtr
    dwFrom: UInt32
    dwTo: UInt32
    dwSpeed: UInt32
    _pack_ = 1
class MCI_ANIM_RECT_PARMS(Structure):
    dwCallback: UIntPtr
    rc: win32more.Windows.Win32.Foundation.RECT
    _pack_ = 1
class MCI_ANIM_STEP_PARMS(Structure):
    dwCallback: UIntPtr
    dwFrames: UInt32
    _pack_ = 1
class MCI_ANIM_UPDATE_PARMS(Structure):
    dwCallback: UIntPtr
    rc: win32more.Windows.Win32.Foundation.RECT
    hDC: win32more.Windows.Win32.Graphics.Gdi.HDC
    _pack_ = 1
class MCI_ANIM_WINDOW_PARMSA(Structure):
    dwCallback: UIntPtr
    hWnd: win32more.Windows.Win32.Foundation.HWND
    nCmdShow: UInt32
    lpstrText: win32more.Windows.Win32.Foundation.PSTR
    _pack_ = 1
class MCI_ANIM_WINDOW_PARMSW(Structure):
    dwCallback: UIntPtr
    hWnd: win32more.Windows.Win32.Foundation.HWND
    nCmdShow: UInt32
    lpstrText: win32more.Windows.Win32.Foundation.PWSTR
    _pack_ = 1
MCI_ANIM_WINDOW_PARMS = UnicodeAlias('MCI_ANIM_WINDOW_PARMSW')
class MCI_BREAK_PARMS(Structure):
    dwCallback: UIntPtr
    nVirtKey: Int32
    hwndBreak: win32more.Windows.Win32.Foundation.HWND
    _pack_ = 1
class MCI_DGV_CAPTURE_PARMSA(Structure):
    dwCallback: UIntPtr
    lpstrFileName: win32more.Windows.Win32.Foundation.PSTR
    rc: win32more.Windows.Win32.Foundation.RECT
    _pack_ = 1
class MCI_DGV_CAPTURE_PARMSW(Structure):
    dwCallback: UIntPtr
    lpstrFileName: win32more.Windows.Win32.Foundation.PWSTR
    rc: win32more.Windows.Win32.Foundation.RECT
    _pack_ = 1
MCI_DGV_CAPTURE_PARMS = UnicodeAlias('MCI_DGV_CAPTURE_PARMSW')
class MCI_DGV_COPY_PARMS(Structure):
    dwCallback: UIntPtr
    dwFrom: UInt32
    dwTo: UInt32
    rc: win32more.Windows.Win32.Foundation.RECT
    dwAudioStream: UInt32
    dwVideoStream: UInt32
    _pack_ = 1
class MCI_DGV_CUE_PARMS(Structure):
    dwCallback: UIntPtr
    dwTo: UInt32
    _pack_ = 1
class MCI_DGV_CUT_PARMS(Structure):
    dwCallback: UIntPtr
    dwFrom: UInt32
    dwTo: UInt32
    rc: win32more.Windows.Win32.Foundation.RECT
    dwAudioStream: UInt32
    dwVideoStream: UInt32
    _pack_ = 1
class MCI_DGV_DELETE_PARMS(Structure):
    dwCallback: UIntPtr
    dwFrom: UInt32
    dwTo: UInt32
    rc: win32more.Windows.Win32.Foundation.RECT
    dwAudioStream: UInt32
    dwVideoStream: UInt32
    _pack_ = 1
class MCI_DGV_INFO_PARMSA(Structure):
    dwCallback: UIntPtr
    lpstrReturn: win32more.Windows.Win32.Foundation.PSTR
    dwRetSize: UInt32
    dwItem: UInt32
    _pack_ = 1
class MCI_DGV_INFO_PARMSW(Structure):
    dwCallback: UIntPtr
    lpstrReturn: win32more.Windows.Win32.Foundation.PWSTR
    dwRetSize: UInt32
    dwItem: UInt32
    _pack_ = 1
MCI_DGV_INFO_PARMS = UnicodeAlias('MCI_DGV_INFO_PARMSW')
class MCI_DGV_LIST_PARMSA(Structure):
    dwCallback: UIntPtr
    lpstrReturn: win32more.Windows.Win32.Foundation.PSTR
    dwLength: UInt32
    dwNumber: UInt32
    dwItem: UInt32
    lpstrAlgorithm: win32more.Windows.Win32.Foundation.PSTR
    _pack_ = 1
class MCI_DGV_LIST_PARMSW(Structure):
    dwCallback: UIntPtr
    lpstrReturn: win32more.Windows.Win32.Foundation.PWSTR
    dwLength: UInt32
    dwNumber: UInt32
    dwItem: UInt32
    lpstrAlgorithm: win32more.Windows.Win32.Foundation.PWSTR
    _pack_ = 1
MCI_DGV_LIST_PARMS = UnicodeAlias('MCI_DGV_LIST_PARMSW')
class MCI_DGV_MONITOR_PARMS(Structure):
    dwCallback: UIntPtr
    dwSource: UInt32
    dwMethod: UInt32
    _pack_ = 1
class MCI_DGV_OPEN_PARMSA(Structure):
    dwCallback: UIntPtr
    wDeviceID: UInt32
    lpstrDeviceType: win32more.Windows.Win32.Foundation.PSTR
    lpstrElementName: win32more.Windows.Win32.Foundation.PSTR
    lpstrAlias: win32more.Windows.Win32.Foundation.PSTR
    dwStyle: UInt32
    hWndParent: win32more.Windows.Win32.Foundation.HWND
    _pack_ = 1
class MCI_DGV_OPEN_PARMSW(Structure):
    dwCallback: UIntPtr
    wDeviceID: UInt32
    lpstrDeviceType: win32more.Windows.Win32.Foundation.PWSTR
    lpstrElementName: win32more.Windows.Win32.Foundation.PWSTR
    lpstrAlias: win32more.Windows.Win32.Foundation.PWSTR
    dwStyle: UInt32
    hWndParent: win32more.Windows.Win32.Foundation.HWND
    _pack_ = 1
MCI_DGV_OPEN_PARMS = UnicodeAlias('MCI_DGV_OPEN_PARMSW')
class MCI_DGV_PASTE_PARMS(Structure):
    dwCallback: UIntPtr
    dwTo: UInt32
    rc: win32more.Windows.Win32.Foundation.RECT
    dwAudioStream: UInt32
    dwVideoStream: UInt32
    _pack_ = 1
class MCI_DGV_QUALITY_PARMSA(Structure):
    dwCallback: UIntPtr
    dwItem: UInt32
    lpstrName: win32more.Windows.Win32.Foundation.PSTR
    lpstrAlgorithm: UInt32
    dwHandle: UInt32
    _pack_ = 1
class MCI_DGV_QUALITY_PARMSW(Structure):
    dwCallback: UIntPtr
    dwItem: UInt32
    lpstrName: win32more.Windows.Win32.Foundation.PWSTR
    lpstrAlgorithm: UInt32
    dwHandle: UInt32
    _pack_ = 1
MCI_DGV_QUALITY_PARMS = UnicodeAlias('MCI_DGV_QUALITY_PARMSW')
class MCI_DGV_RECORD_PARMS(Structure):
    dwCallback: UIntPtr
    dwFrom: UInt32
    dwTo: UInt32
    rc: win32more.Windows.Win32.Foundation.RECT
    dwAudioStream: UInt32
    dwVideoStream: UInt32
    _pack_ = 1
class MCI_DGV_RECT_PARMS(Structure):
    dwCallback: UIntPtr
    rc: win32more.Windows.Win32.Foundation.RECT
    _pack_ = 1
class MCI_DGV_RESERVE_PARMSA(Structure):
    dwCallback: UIntPtr
    lpstrPath: win32more.Windows.Win32.Foundation.PSTR
    dwSize: UInt32
    _pack_ = 1
class MCI_DGV_RESERVE_PARMSW(Structure):
    dwCallback: UIntPtr
    lpstrPath: win32more.Windows.Win32.Foundation.PWSTR
    dwSize: UInt32
    _pack_ = 1
MCI_DGV_RESERVE_PARMS = UnicodeAlias('MCI_DGV_RESERVE_PARMSW')
class MCI_DGV_RESTORE_PARMSA(Structure):
    dwCallback: UIntPtr
    lpstrFileName: win32more.Windows.Win32.Foundation.PSTR
    rc: win32more.Windows.Win32.Foundation.RECT
    _pack_ = 1
class MCI_DGV_RESTORE_PARMSW(Structure):
    dwCallback: UIntPtr
    lpstrFileName: win32more.Windows.Win32.Foundation.PWSTR
    rc: win32more.Windows.Win32.Foundation.RECT
    _pack_ = 1
MCI_DGV_RESTORE_PARMS = UnicodeAlias('MCI_DGV_RESTORE_PARMSW')
class MCI_DGV_SAVE_PARMSA(Structure):
    dwCallback: UIntPtr
    lpstrFileName: win32more.Windows.Win32.Foundation.PSTR
    rc: win32more.Windows.Win32.Foundation.RECT
    _pack_ = 1
class MCI_DGV_SAVE_PARMSW(Structure):
    dwCallback: UIntPtr
    lpstrFileName: win32more.Windows.Win32.Foundation.PWSTR
    rc: win32more.Windows.Win32.Foundation.RECT
    _pack_ = 1
MCI_DGV_SAVE_PARMS = UnicodeAlias('MCI_DGV_SAVE_PARMSW')
class MCI_DGV_SETAUDIO_PARMSA(Structure):
    dwCallback: UIntPtr
    dwItem: UInt32
    dwValue: UInt32
    dwOver: UInt32
    lpstrAlgorithm: win32more.Windows.Win32.Foundation.PSTR
    lpstrQuality: win32more.Windows.Win32.Foundation.PSTR
    _pack_ = 1
class MCI_DGV_SETAUDIO_PARMSW(Structure):
    dwCallback: UIntPtr
    dwItem: UInt32
    dwValue: UInt32
    dwOver: UInt32
    lpstrAlgorithm: win32more.Windows.Win32.Foundation.PWSTR
    lpstrQuality: win32more.Windows.Win32.Foundation.PWSTR
    _pack_ = 1
MCI_DGV_SETAUDIO_PARMS = UnicodeAlias('MCI_DGV_SETAUDIO_PARMSW')
class MCI_DGV_SETVIDEO_PARMSA(Structure):
    dwCallback: UIntPtr
    dwItem: UInt32
    dwValue: UInt32
    dwOver: UInt32
    lpstrAlgorithm: win32more.Windows.Win32.Foundation.PSTR
    lpstrQuality: win32more.Windows.Win32.Foundation.PSTR
    dwSourceNumber: UInt32
    _pack_ = 1
class MCI_DGV_SETVIDEO_PARMSW(Structure):
    dwCallback: UIntPtr
    dwItem: UInt32
    dwValue: UInt32
    dwOver: UInt32
    lpstrAlgorithm: win32more.Windows.Win32.Foundation.PWSTR
    lpstrQuality: win32more.Windows.Win32.Foundation.PWSTR
    dwSourceNumber: UInt32
    _pack_ = 1
MCI_DGV_SETVIDEO_PARMS = UnicodeAlias('MCI_DGV_SETVIDEO_PARMSW')
class MCI_DGV_SET_PARMS(Structure):
    dwCallback: UIntPtr
    dwTimeFormat: UInt32
    dwAudio: UInt32
    dwFileFormat: UInt32
    dwSpeed: UInt32
    _pack_ = 1
class MCI_DGV_SIGNAL_PARMS(Structure):
    dwCallback: UIntPtr
    dwPosition: UInt32
    dwPeriod: UInt32
    dwUserParm: UInt32
    _pack_ = 1
class MCI_DGV_STATUS_PARMSA(Structure):
    dwCallback: UIntPtr
    dwReturn: UIntPtr
    dwItem: UInt32
    dwTrack: UInt32
    lpstrDrive: win32more.Windows.Win32.Foundation.PSTR
    dwReference: UInt32
    _pack_ = 1
class MCI_DGV_STATUS_PARMSW(Structure):
    dwCallback: UIntPtr
    dwReturn: UIntPtr
    dwItem: UInt32
    dwTrack: UInt32
    lpstrDrive: win32more.Windows.Win32.Foundation.PWSTR
    dwReference: UInt32
    _pack_ = 1
MCI_DGV_STATUS_PARMS = UnicodeAlias('MCI_DGV_STATUS_PARMSW')
class MCI_DGV_STEP_PARMS(Structure):
    dwCallback: UIntPtr
    dwFrames: UInt32
    _pack_ = 1
class MCI_DGV_UPDATE_PARMS(Structure):
    dwCallback: UIntPtr
    rc: win32more.Windows.Win32.Foundation.RECT
    hDC: win32more.Windows.Win32.Graphics.Gdi.HDC
    _pack_ = 1
class MCI_DGV_WINDOW_PARMSA(Structure):
    dwCallback: UIntPtr
    hWnd: win32more.Windows.Win32.Foundation.HWND
    nCmdShow: UInt32
    lpstrText: win32more.Windows.Win32.Foundation.PSTR
    _pack_ = 1
class MCI_DGV_WINDOW_PARMSW(Structure):
    dwCallback: UIntPtr
    hWnd: win32more.Windows.Win32.Foundation.HWND
    nCmdShow: UInt32
    lpstrText: win32more.Windows.Win32.Foundation.PWSTR
    _pack_ = 1
MCI_DGV_WINDOW_PARMS = UnicodeAlias('MCI_DGV_WINDOW_PARMSW')
class MCI_GENERIC_PARMS(Structure):
    dwCallback: UIntPtr
    _pack_ = 1
class MCI_GETDEVCAPS_PARMS(Structure):
    dwCallback: UIntPtr
    dwReturn: UInt32
    dwItem: UInt32
    _pack_ = 1
class MCI_INFO_PARMSA(Structure):
    dwCallback: UIntPtr
    lpstrReturn: win32more.Windows.Win32.Foundation.PSTR
    dwRetSize: UInt32
    _pack_ = 1
class MCI_INFO_PARMSW(Structure):
    dwCallback: UIntPtr
    lpstrReturn: win32more.Windows.Win32.Foundation.PWSTR
    dwRetSize: UInt32
    _pack_ = 1
MCI_INFO_PARMS = UnicodeAlias('MCI_INFO_PARMSW')
class MCI_LOAD_PARMSA(Structure):
    dwCallback: UIntPtr
    lpfilename: win32more.Windows.Win32.Foundation.PSTR
    _pack_ = 1
class MCI_LOAD_PARMSW(Structure):
    dwCallback: UIntPtr
    lpfilename: win32more.Windows.Win32.Foundation.PWSTR
    _pack_ = 1
MCI_LOAD_PARMS = UnicodeAlias('MCI_LOAD_PARMSW')
class MCI_OPEN_DRIVER_PARMS(Structure):
    wDeviceID: UInt32
    lpstrParams: win32more.Windows.Win32.Foundation.PWSTR
    wCustomCommandTable: UInt32
    wType: UInt32
    _pack_ = 1
class MCI_OPEN_PARMSA(Structure):
    dwCallback: UIntPtr
    wDeviceID: UInt32
    lpstrDeviceType: win32more.Windows.Win32.Foundation.PSTR
    lpstrElementName: win32more.Windows.Win32.Foundation.PSTR
    lpstrAlias: win32more.Windows.Win32.Foundation.PSTR
    _pack_ = 1
class MCI_OPEN_PARMSW(Structure):
    dwCallback: UIntPtr
    wDeviceID: UInt32
    lpstrDeviceType: win32more.Windows.Win32.Foundation.PWSTR
    lpstrElementName: win32more.Windows.Win32.Foundation.PWSTR
    lpstrAlias: win32more.Windows.Win32.Foundation.PWSTR
    _pack_ = 1
MCI_OPEN_PARMS = UnicodeAlias('MCI_OPEN_PARMSW')
class MCI_OVLY_LOAD_PARMSA(Structure):
    dwCallback: UIntPtr
    lpfilename: win32more.Windows.Win32.Foundation.PSTR
    rc: win32more.Windows.Win32.Foundation.RECT
    _pack_ = 1
class MCI_OVLY_LOAD_PARMSW(Structure):
    dwCallback: UIntPtr
    lpfilename: win32more.Windows.Win32.Foundation.PWSTR
    rc: win32more.Windows.Win32.Foundation.RECT
    _pack_ = 1
MCI_OVLY_LOAD_PARMS = UnicodeAlias('MCI_OVLY_LOAD_PARMSW')
class MCI_OVLY_OPEN_PARMSA(Structure):
    dwCallback: UIntPtr
    wDeviceID: UInt32
    lpstrDeviceType: win32more.Windows.Win32.Foundation.PSTR
    lpstrElementName: win32more.Windows.Win32.Foundation.PSTR
    lpstrAlias: win32more.Windows.Win32.Foundation.PSTR
    dwStyle: UInt32
    hWndParent: win32more.Windows.Win32.Foundation.HWND
    _pack_ = 1
class MCI_OVLY_OPEN_PARMSW(Structure):
    dwCallback: UIntPtr
    wDeviceID: UInt32
    lpstrDeviceType: win32more.Windows.Win32.Foundation.PWSTR
    lpstrElementName: win32more.Windows.Win32.Foundation.PWSTR
    lpstrAlias: win32more.Windows.Win32.Foundation.PWSTR
    dwStyle: UInt32
    hWndParent: win32more.Windows.Win32.Foundation.HWND
    _pack_ = 1
MCI_OVLY_OPEN_PARMS = UnicodeAlias('MCI_OVLY_OPEN_PARMSW')
class MCI_OVLY_RECT_PARMS(Structure):
    dwCallback: UIntPtr
    rc: win32more.Windows.Win32.Foundation.RECT
    _pack_ = 1
class MCI_OVLY_SAVE_PARMSA(Structure):
    dwCallback: UIntPtr
    lpfilename: win32more.Windows.Win32.Foundation.PSTR
    rc: win32more.Windows.Win32.Foundation.RECT
    _pack_ = 1
class MCI_OVLY_SAVE_PARMSW(Structure):
    dwCallback: UIntPtr
    lpfilename: win32more.Windows.Win32.Foundation.PWSTR
    rc: win32more.Windows.Win32.Foundation.RECT
    _pack_ = 1
MCI_OVLY_SAVE_PARMS = UnicodeAlias('MCI_OVLY_SAVE_PARMSW')
class MCI_OVLY_WINDOW_PARMSA(Structure):
    dwCallback: UIntPtr
    hWnd: win32more.Windows.Win32.Foundation.HWND
    nCmdShow: UInt32
    lpstrText: win32more.Windows.Win32.Foundation.PSTR
    _pack_ = 1
class MCI_OVLY_WINDOW_PARMSW(Structure):
    dwCallback: UIntPtr
    hWnd: win32more.Windows.Win32.Foundation.HWND
    nCmdShow: UInt32
    lpstrText: win32more.Windows.Win32.Foundation.PWSTR
    _pack_ = 1
MCI_OVLY_WINDOW_PARMS = UnicodeAlias('MCI_OVLY_WINDOW_PARMSW')
class MCI_PLAY_PARMS(Structure):
    dwCallback: UIntPtr
    dwFrom: UInt32
    dwTo: UInt32
    _pack_ = 1
class MCI_RECORD_PARMS(Structure):
    dwCallback: UIntPtr
    dwFrom: UInt32
    dwTo: UInt32
    _pack_ = 1
class MCI_SAVE_PARMSA(Structure):
    dwCallback: UIntPtr
    lpfilename: win32more.Windows.Win32.Foundation.PSTR
    _pack_ = 1
class MCI_SAVE_PARMSW(Structure):
    dwCallback: UIntPtr
    lpfilename: win32more.Windows.Win32.Foundation.PWSTR
    _pack_ = 1
MCI_SAVE_PARMS = UnicodeAlias('MCI_SAVE_PARMSW')
class MCI_SEEK_PARMS(Structure):
    dwCallback: UIntPtr
    dwTo: UInt32
    _pack_ = 1
class MCI_SEQ_SET_PARMS(Structure):
    dwCallback: UIntPtr
    dwTimeFormat: UInt32
    dwAudio: UInt32
    dwTempo: UInt32
    dwPort: UInt32
    dwSlave: UInt32
    dwMaster: UInt32
    dwOffset: UInt32
    _pack_ = 1
class MCI_SET_PARMS(Structure):
    dwCallback: UIntPtr
    dwTimeFormat: UInt32
    dwAudio: UInt32
    _pack_ = 1
class MCI_STATUS_PARMS(Structure):
    dwCallback: UIntPtr
    dwReturn: UIntPtr
    dwItem: UInt32
    dwTrack: UInt32
    _pack_ = 1
class MCI_SYSINFO_PARMSA(Structure):
    dwCallback: UIntPtr
    lpstrReturn: win32more.Windows.Win32.Foundation.PSTR
    dwRetSize: UInt32
    dwNumber: UInt32
    wDeviceType: UInt32
    _pack_ = 1
class MCI_SYSINFO_PARMSW(Structure):
    dwCallback: UIntPtr
    lpstrReturn: win32more.Windows.Win32.Foundation.PWSTR
    dwRetSize: UInt32
    dwNumber: UInt32
    wDeviceType: UInt32
    _pack_ = 1
MCI_SYSINFO_PARMS = UnicodeAlias('MCI_SYSINFO_PARMSW')
class MCI_VD_ESCAPE_PARMSA(Structure):
    dwCallback: UIntPtr
    lpstrCommand: win32more.Windows.Win32.Foundation.PSTR
    _pack_ = 1
class MCI_VD_ESCAPE_PARMSW(Structure):
    dwCallback: UIntPtr
    lpstrCommand: win32more.Windows.Win32.Foundation.PWSTR
    _pack_ = 1
MCI_VD_ESCAPE_PARMS = UnicodeAlias('MCI_VD_ESCAPE_PARMSW')
class MCI_VD_PLAY_PARMS(Structure):
    dwCallback: UIntPtr
    dwFrom: UInt32
    dwTo: UInt32
    dwSpeed: UInt32
    _pack_ = 1
class MCI_VD_STEP_PARMS(Structure):
    dwCallback: UIntPtr
    dwFrames: UInt32
    _pack_ = 1
class MCI_WAVE_DELETE_PARMS(Structure):
    dwCallback: UIntPtr
    dwFrom: UInt32
    dwTo: UInt32
    _pack_ = 1
class MCI_WAVE_OPEN_PARMSA(Structure):
    dwCallback: UIntPtr
    wDeviceID: UInt32
    lpstrDeviceType: win32more.Windows.Win32.Foundation.PSTR
    lpstrElementName: win32more.Windows.Win32.Foundation.PSTR
    lpstrAlias: win32more.Windows.Win32.Foundation.PSTR
    dwBufferSeconds: UInt32
    _pack_ = 1
class MCI_WAVE_OPEN_PARMSW(Structure):
    dwCallback: UIntPtr
    wDeviceID: UInt32
    lpstrDeviceType: win32more.Windows.Win32.Foundation.PWSTR
    lpstrElementName: win32more.Windows.Win32.Foundation.PWSTR
    lpstrAlias: win32more.Windows.Win32.Foundation.PWSTR
    dwBufferSeconds: UInt32
    _pack_ = 1
MCI_WAVE_OPEN_PARMS = UnicodeAlias('MCI_WAVE_OPEN_PARMSW')
class MCI_WAVE_SET_PARMS(Structure):
    dwCallback: UIntPtr
    dwTimeFormat: UInt32
    dwAudio: UInt32
    wInput: UInt32
    wOutput: UInt32
    wFormatTag: UInt16
    wReserved2: UInt16
    nChannels: UInt16
    wReserved3: UInt16
    nSamplesPerSec: UInt32
    nAvgBytesPerSec: UInt32
    nBlockAlign: UInt16
    wReserved4: UInt16
    wBitsPerSample: UInt16
    wReserved5: UInt16
    _pack_ = 1
class MEDIASPACEADPCMWAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    wRevision: UInt16
    _pack_ = 1
class MIDIOPENSTRMID(Structure):
    dwStreamID: UInt32
    uDeviceID: UInt32
    _pack_ = 1
class MIXEROPENDESC(Structure):
    hmx: win32more.Windows.Win32.Media.Audio.HMIXER
    pReserved0: VoidPtr
    dwCallback: UIntPtr
    dwInstance: UIntPtr
    dnDevNode: UIntPtr
    _pack_ = 1
class MMCKINFO(Structure):
    ckid: UInt32
    cksize: UInt32
    fccType: UInt32
    dwDataOffset: UInt32
    dwFlags: UInt32
    _pack_ = 1
class MMIOINFO(Structure):
    dwFlags: UInt32
    fccIOProc: UInt32
    pIOProc: win32more.Windows.Win32.Media.Multimedia.LPMMIOPROC
    wErrorRet: UInt32
    htask: win32more.Windows.Win32.Media.HTASK
    cchBuffer: Int32
    pchBuffer: POINTER(SByte)
    pchNext: POINTER(SByte)
    pchEndRead: POINTER(SByte)
    pchEndWrite: POINTER(SByte)
    lBufOffset: Int32
    lDiskOffset: Int32
    adwInfo: UInt32 * 3
    dwReserved1: UInt32
    dwReserved2: UInt32
    hmmio: win32more.Windows.Win32.Media.Multimedia.HMMIO
    _pack_ = 1
class MSAUDIO1WAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    wSamplesPerBlock: UInt16
    wEncodeOptions: UInt16
    _pack_ = 1
class NMS_VBXADPCMWAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    wSamplesPerBlock: UInt16
    _pack_ = 1
class OLIADPCMWAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    _pack_ = 1
class OLICELPWAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    _pack_ = 1
class OLIGSMWAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    _pack_ = 1
class OLIOPRWAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    _pack_ = 1
class OLISBCWAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    _pack_ = 1
class SIERRAADPCMWAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    wRevision: UInt16
    _pack_ = 1
class SONARCWAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    wCompType: UInt16
    _pack_ = 1
class TIMEREVENT(Structure):
    wDelay: UInt16
    wResolution: UInt16
    lpFunction: win32more.Windows.Win32.Media.LPTIMECALLBACK
    dwUser: UInt32
    wFlags: UInt16
    wReserved1: UInt16
    _pack_ = 1
class TRUESPEECHWAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    wRevision: UInt16
    nSamplesPerBlock: UInt16
    abReserved: Byte * 28
    _pack_ = 1
@winfunctype_pointer
def VFWWDMExtensionProc(pfnDeviceIoControl: VoidPtr, pfnAddPropertyPage: win32more.Windows.Win32.UI.Controls.LPFNSVADDPROPSHEETPAGE, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> UInt32: ...
class VIDEOHDR(Structure):
    lpData: POINTER(Byte)
    dwBufferLength: UInt32
    dwBytesUsed: UInt32
    dwTimeCaptured: UInt32
    dwUser: UIntPtr
    dwFlags: UInt32
    dwReserved: UIntPtr * 4
class WAVEOPENDESC(Structure):
    hWave: win32more.Windows.Win32.Media.Audio.HWAVE
    lpFormat: POINTER(win32more.Windows.Win32.Media.Audio.WAVEFORMAT)
    dwCallback: UIntPtr
    dwInstance: UIntPtr
    uMappedDeviceID: UInt32
    dnDevNode: UIntPtr
    _pack_ = 1
class WMAUDIO2WAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    dwSamplesPerBlock: UInt32
    wEncodeOptions: UInt16
    dwSuperBlockAlign: UInt32
    _pack_ = 1
class WMAUDIO3WAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    wValidBitsPerSample: UInt16
    dwChannelMask: UInt32
    dwReserved1: UInt32
    dwReserved2: UInt32
    wEncodeOptions: UInt16
    wReserved3: UInt16
    _pack_ = 1
class YAMAHA_ADPCMWAVEFORMAT(Structure):
    wfx: win32more.Windows.Win32.Media.Audio.WAVEFORMATEX
    _pack_ = 1
@winfunctype_pointer
def YIELDPROC(mciId: UInt32, dwYieldData: UInt32) -> UInt32: ...
class s_RIFFWAVE_inst(Structure):
    bUnshiftedNote: Byte
    chFineTune: win32more.Windows.Win32.Foundation.CHAR
    chGain: win32more.Windows.Win32.Foundation.CHAR
    bLowNote: Byte
    bHighNote: Byte
    bLowVelocity: Byte
    bHighVelocity: Byte


make_ready(__name__)
