from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform
import win32more.Windows.Win32.Security
import win32more.Windows.Win32.System.Rpc
FWPM_NET_EVENT_KEYWORD_INBOUND_MCAST: UInt32 = 1
FWPM_NET_EVENT_KEYWORD_INBOUND_BCAST: UInt32 = 2
FWPM_NET_EVENT_KEYWORD_CAPABILITY_DROP: UInt32 = 4
FWPM_NET_EVENT_KEYWORD_CAPABILITY_ALLOW: UInt32 = 8
FWPM_NET_EVENT_KEYWORD_CLASSIFY_ALLOW: UInt32 = 16
FWPM_NET_EVENT_KEYWORD_PORT_SCANNING_DROP: UInt32 = 32
FWPM_ENGINE_OPTION_PACKET_QUEUE_NONE: UInt32 = 0
FWPM_ENGINE_OPTION_PACKET_QUEUE_INBOUND: UInt32 = 1
FWPM_ENGINE_OPTION_PACKET_QUEUE_FORWARD: UInt32 = 2
FWPM_ENGINE_OPTION_PACKET_BATCH_INBOUND: UInt32 = 4
FWPM_SESSION_FLAG_DYNAMIC: UInt32 = 1
FWPM_SESSION_FLAG_RESERVED: UInt32 = 268435456
FWPM_PROVIDER_FLAG_PERSISTENT: UInt32 = 1
FWPM_PROVIDER_FLAG_DISABLED: UInt32 = 16
FWPM_PROVIDER_CONTEXT_FLAG_PERSISTENT: UInt32 = 1
FWPM_PROVIDER_CONTEXT_FLAG_DOWNLEVEL: UInt32 = 2
FWPM_SUBLAYER_FLAG_PERSISTENT: UInt32 = 1
FWPM_LAYER_FLAG_KERNEL: UInt32 = 1
FWPM_LAYER_FLAG_BUILTIN: UInt32 = 2
FWPM_LAYER_FLAG_CLASSIFY_MOSTLY: UInt32 = 4
FWPM_LAYER_FLAG_BUFFERED: UInt32 = 8
FWPM_CALLOUT_FLAG_PERSISTENT: UInt32 = 65536
FWPM_CALLOUT_FLAG_USES_PROVIDER_CONTEXT: UInt32 = 131072
FWPM_CALLOUT_FLAG_REGISTERED: UInt32 = 262144
FWPM_FILTER_FLAG_HAS_SECURITY_REALM_PROVIDER_CONTEXT: UInt32 = 128
FWPM_FILTER_FLAG_SYSTEMOS_ONLY: UInt32 = 256
FWPM_FILTER_FLAG_GAMEOS_ONLY: UInt32 = 512
FWPM_FILTER_FLAG_SILENT_MODE: UInt32 = 1024
FWPM_FILTER_FLAG_IPSEC_NO_ACQUIRE_INITIATE: UInt32 = 2048
FWPM_FILTER_FLAG_RESERVED0: UInt32 = 4096
FWPM_FILTER_FLAG_RESERVED1: UInt32 = 8192
FWPM_NET_EVENT_FLAG_IP_PROTOCOL_SET: UInt32 = 1
FWPM_NET_EVENT_FLAG_LOCAL_ADDR_SET: UInt32 = 2
FWPM_NET_EVENT_FLAG_REMOTE_ADDR_SET: UInt32 = 4
FWPM_NET_EVENT_FLAG_LOCAL_PORT_SET: UInt32 = 8
FWPM_NET_EVENT_FLAG_REMOTE_PORT_SET: UInt32 = 16
FWPM_NET_EVENT_FLAG_APP_ID_SET: UInt32 = 32
FWPM_NET_EVENT_FLAG_USER_ID_SET: UInt32 = 64
FWPM_NET_EVENT_FLAG_SCOPE_ID_SET: UInt32 = 128
FWPM_NET_EVENT_FLAG_IP_VERSION_SET: UInt32 = 256
FWPM_NET_EVENT_FLAG_REAUTH_REASON_SET: UInt32 = 512
FWPM_NET_EVENT_FLAG_PACKAGE_ID_SET: UInt32 = 1024
FWPM_NET_EVENT_FLAG_ENTERPRISE_ID_SET: UInt32 = 2048
FWPM_NET_EVENT_FLAG_POLICY_FLAGS_SET: UInt32 = 4096
FWPM_NET_EVENT_FLAG_EFFECTIVE_NAME_SET: UInt32 = 8192
IKEEXT_CERT_HASH_LEN: UInt32 = 20
FWPM_NET_EVENT_IKEEXT_MM_FAILURE_FLAG_BENIGN: UInt32 = 1
FWPM_NET_EVENT_IKEEXT_MM_FAILURE_FLAG_MULTIPLE: UInt32 = 2
FWPM_NET_EVENT_IKEEXT_EM_FAILURE_FLAG_MULTIPLE: UInt32 = 1
FWPM_NET_EVENT_IKEEXT_EM_FAILURE_FLAG_BENIGN: UInt32 = 2
FWPM_CONNECTION_ENUM_FLAG_QUERY_BYTES_TRANSFERRED: UInt32 = 1
FWPS_FILTER_FLAG_CLEAR_ACTION_RIGHT: UInt32 = 1
FWPS_FILTER_FLAG_PERMIT_IF_CALLOUT_UNREGISTERED: UInt32 = 2
FWPS_FILTER_FLAG_OR_CONDITIONS: UInt32 = 4
FWPS_FILTER_FLAG_HAS_SECURITY_REALM_PROVIDER_CONTEXT: UInt32 = 8
FWPS_FILTER_FLAG_SILENT_MODE: UInt32 = 16
FWPS_FILTER_FLAG_IPSEC_NO_ACQUIRE_INITIATE: UInt32 = 32
FWPS_FILTER_FLAG_RESERVED0: UInt32 = 64
FWPS_FILTER_FLAG_RESERVED1: UInt32 = 128
FWPS_INCOMING_FLAG_CACHE_SAFE: UInt32 = 1
FWPS_INCOMING_FLAG_ENFORCE_QUERY: UInt32 = 2
FWPS_INCOMING_FLAG_ABSORB: UInt32 = 4
FWPS_INCOMING_FLAG_CONNECTION_FAILING_INDICATION: UInt32 = 8
FWPS_INCOMING_FLAG_MID_STREAM_INSPECTION: UInt32 = 16
FWPS_INCOMING_FLAG_RECLASSIFY: UInt32 = 32
FWPS_INCOMING_FLAG_IS_LOOSE_SOURCE_FLOW: UInt32 = 64
FWPS_INCOMING_FLAG_IS_LOCAL_ONLY_FLOW: UInt32 = 128
FWPS_L2_INCOMING_FLAG_IS_RAW_IPV4_FRAMING: UInt32 = 1
FWPS_L2_INCOMING_FLAG_IS_RAW_IPV6_FRAMING: UInt32 = 2
FWPS_L2_INCOMING_FLAG_RECLASSIFY_MULTI_DESTINATION: UInt32 = 8
FWPS_INCOMING_FLAG_RESERVED0: UInt32 = 256
FWPS_RIGHT_ACTION_WRITE: UInt32 = 1
FWPS_CLASSIFY_OUT_FLAG_ABSORB: UInt32 = 1
FWPS_CLASSIFY_OUT_FLAG_BUFFER_LIMIT_REACHED: UInt32 = 2
FWPS_CLASSIFY_OUT_FLAG_NO_MORE_DATA: UInt32 = 4
FWPS_CLASSIFY_OUT_FLAG_ALE_FAST_CACHE_CHECK: UInt32 = 8
FWPS_CLASSIFY_OUT_FLAG_ALE_FAST_CACHE_POSSIBLE: UInt32 = 16
FWPS_ALE_ENDPOINT_FLAG_IPSEC_SECURED: UInt32 = 1
FWP_BYTEMAP_ARRAY64_SIZE: UInt32 = 8
FWP_BYTE_ARRAY6_SIZE: UInt32 = 6
FWP_V6_ADDR_SIZE: UInt32 = 16
FWP_ACTRL_MATCH_FILTER: UInt32 = 1
FWP_OPTION_VALUE_ALLOW_MULTICAST_STATE: UInt32 = 0
FWP_OPTION_VALUE_DENY_MULTICAST_STATE: UInt32 = 1
FWP_OPTION_VALUE_ALLOW_GLOBAL_MULTICAST_STATE: UInt32 = 2
FWP_OPTION_VALUE_DISABLE_LOOSE_SOURCE: UInt32 = 0
FWP_OPTION_VALUE_ENABLE_LOOSE_SOURCE: UInt32 = 1
FWP_OPTION_VALUE_DISABLE_LOCAL_ONLY_MAPPING: UInt32 = 0
FWP_OPTION_VALUE_ENABLE_LOCAL_ONLY_MAPPING: UInt32 = 1
FWP_ACTION_FLAG_TERMINATING: UInt32 = 4096
FWP_ACTION_FLAG_NON_TERMINATING: UInt32 = 8192
FWP_ACTION_FLAG_CALLOUT: UInt32 = 16384
FWP_CONDITION_FLAG_IS_LOOPBACK: UInt32 = 1
FWP_CONDITION_FLAG_IS_IPSEC_SECURED: UInt32 = 2
FWP_CONDITION_FLAG_IS_REAUTHORIZE: UInt32 = 4
FWP_CONDITION_FLAG_IS_WILDCARD_BIND: UInt32 = 8
FWP_CONDITION_FLAG_IS_RAW_ENDPOINT: UInt32 = 16
FWP_CONDITION_FLAG_IS_FRAGMENT: UInt32 = 32
FWP_CONDITION_FLAG_IS_FRAGMENT_GROUP: UInt32 = 64
FWP_CONDITION_FLAG_IS_IPSEC_NATT_RECLASSIFY: UInt32 = 128
FWP_CONDITION_FLAG_REQUIRES_ALE_CLASSIFY: UInt32 = 256
FWP_CONDITION_FLAG_IS_IMPLICIT_BIND: UInt32 = 512
FWP_CONDITION_FLAG_IS_REASSEMBLED: UInt32 = 1024
FWP_CONDITION_FLAG_IS_NAME_APP_SPECIFIED: UInt32 = 16384
FWP_CONDITION_FLAG_IS_PROMISCUOUS: UInt32 = 32768
FWP_CONDITION_FLAG_IS_AUTH_FW: UInt32 = 65536
FWP_CONDITION_FLAG_IS_RECLASSIFY: UInt32 = 131072
FWP_CONDITION_FLAG_IS_OUTBOUND_PASS_THRU: UInt32 = 262144
FWP_CONDITION_FLAG_IS_INBOUND_PASS_THRU: UInt32 = 524288
FWP_CONDITION_FLAG_IS_CONNECTION_REDIRECTED: UInt32 = 1048576
FWP_CONDITION_FLAG_IS_PROXY_CONNECTION: UInt32 = 2097152
FWP_CONDITION_FLAG_IS_APPCONTAINER_LOOPBACK: UInt32 = 4194304
FWP_CONDITION_FLAG_IS_NON_APPCONTAINER_LOOPBACK: UInt32 = 8388608
FWP_CONDITION_FLAG_IS_RESERVED: UInt32 = 16777216
FWP_CONDITION_FLAG_IS_HONORING_POLICY_AUTHORIZE: UInt32 = 33554432
FWP_CONDITION_REAUTHORIZE_REASON_POLICY_CHANGE: UInt32 = 1
FWP_CONDITION_REAUTHORIZE_REASON_NEW_ARRIVAL_INTERFACE: UInt32 = 2
FWP_CONDITION_REAUTHORIZE_REASON_NEW_NEXTHOP_INTERFACE: UInt32 = 4
FWP_CONDITION_REAUTHORIZE_REASON_PROFILE_CROSSING: UInt32 = 8
FWP_CONDITION_REAUTHORIZE_REASON_CLASSIFY_COMPLETION: UInt32 = 16
FWP_CONDITION_REAUTHORIZE_REASON_IPSEC_PROPERTIES_CHANGED: UInt32 = 32
FWP_CONDITION_REAUTHORIZE_REASON_MID_STREAM_INSPECTION: UInt32 = 64
FWP_CONDITION_REAUTHORIZE_REASON_SOCKET_PROPERTY_CHANGED: UInt32 = 128
FWP_CONDITION_REAUTHORIZE_REASON_NEW_INBOUND_MCAST_BCAST_PACKET: UInt32 = 256
FWP_CONDITION_REAUTHORIZE_REASON_EDP_POLICY_CHANGED: UInt32 = 512
FWP_CONDITION_REAUTHORIZE_REASON_PROXY_HANDLE_CHANGED: UInt32 = 16384
FWP_CONDITION_REAUTHORIZE_REASON_CHECK_OFFLOAD: UInt32 = 65536
FWP_CONDITION_SOCKET_PROPERTY_FLAG_IS_SYSTEM_PORT_RPC: UInt32 = 1
FWP_CONDITION_SOCKET_PROPERTY_FLAG_ALLOW_EDGE_TRAFFIC: UInt32 = 2
FWP_CONDITION_SOCKET_PROPERTY_FLAG_DENY_EDGE_TRAFFIC: UInt32 = 4
FWP_CONDITION_L2_IS_NATIVE_ETHERNET: UInt32 = 1
FWP_CONDITION_L2_IS_WIFI: UInt32 = 2
FWP_CONDITION_L2_IS_MOBILE_BROADBAND: UInt32 = 4
FWP_CONDITION_L2_IS_WIFI_DIRECT_DATA: UInt32 = 8
FWP_CONDITION_L2_IS_VM2VM: UInt32 = 16
FWP_CONDITION_L2_IS_MALFORMED_PACKET: UInt32 = 32
FWP_CONDITION_L2_IS_IP_FRAGMENT_GROUP: UInt32 = 64
FWP_CONDITION_L2_IF_CONNECTOR_PRESENT: UInt32 = 128
FWP_FILTER_ENUM_FLAG_BEST_TERMINATING_MATCH: UInt32 = 1
FWP_FILTER_ENUM_FLAG_SORTED: UInt32 = 2
FWP_FILTER_ENUM_FLAG_BOOTTIME_ONLY: UInt32 = 4
FWP_FILTER_ENUM_FLAG_INCLUDE_BOOTTIME: UInt32 = 8
FWP_FILTER_ENUM_FLAG_INCLUDE_DISABLED: UInt32 = 16
FWP_FILTER_ENUM_FLAG_RESERVED1: UInt32 = 32
FWP_CALLOUT_FLAG_CONDITIONAL_ON_FLOW: UInt32 = 1
FWP_CALLOUT_FLAG_ALLOW_OFFLOAD: UInt32 = 2
FWP_CALLOUT_FLAG_ENABLE_COMMIT_ADD_NOTIFY: UInt32 = 4
FWP_CALLOUT_FLAG_ALLOW_MID_STREAM_INSPECTION: UInt32 = 8
FWP_CALLOUT_FLAG_ALLOW_RECLASSIFY: UInt32 = 16
FWP_CALLOUT_FLAG_RESERVED1: UInt32 = 32
FWP_CALLOUT_FLAG_ALLOW_RSC: UInt32 = 64
FWP_CALLOUT_FLAG_ALLOW_L2_BATCH_CLASSIFY: UInt32 = 128
FWP_CALLOUT_FLAG_ALLOW_USO: UInt32 = 256
FWP_CALLOUT_FLAG_ALLOW_URO: UInt32 = 512
FWP_CALLOUT_FLAG_RESERVED2: UInt32 = 1024
IKEEXT_CERT_AUTH_FLAG_DISABLE_CRL_CHECK: UInt32 = 2
IKEEXT_CERT_AUTH_FLAG_DISABLE_REQUEST_PAYLOAD: UInt32 = 64
IKEEXT_KERB_AUTH_FORCE_PROXY_ON_INITIATOR: UInt32 = 4
IKEEXT_NTLM_V2_AUTH_DONT_ACCEPT_EXPLICIT_CREDENTIALS: UInt32 = 1
IKEEXT_POLICY_FLAG_MOBIKE_NOT_SUPPORTED: UInt32 = 16
IKEEXT_POLICY_FLAG_SITE_TO_SITE: UInt32 = 32
IKEEXT_POLICY_FLAG_IMS_VPN: UInt32 = 64
IKEEXT_POLICY_ENABLE_IKEV2_FRAGMENTATION: UInt32 = 128
IKEEXT_POLICY_SUPPORT_LOW_POWER_MODE: UInt32 = 256
IKEEXT_CERT_CREDENTIAL_FLAG_NAP_CERT: UInt32 = 1
IPSEC_AUTH_CONFIG_HMAC_MD5_96: UInt32 = 0
IPSEC_AUTH_CONFIG_HMAC_SHA_1_96: UInt32 = 1
IPSEC_AUTH_CONFIG_HMAC_SHA_256_128: UInt32 = 2
IPSEC_AUTH_CONFIG_GCM_AES_128: UInt32 = 3
IPSEC_AUTH_CONFIG_GCM_AES_192: UInt32 = 4
IPSEC_AUTH_CONFIG_GCM_AES_256: UInt32 = 5
IPSEC_AUTH_CONFIG_MAX: UInt32 = 6
IPSEC_CIPHER_CONFIG_CBC_DES: UInt32 = 1
IPSEC_CIPHER_CONFIG_CBC_3DES: UInt32 = 2
IPSEC_CIPHER_CONFIG_CBC_AES_128: UInt32 = 3
IPSEC_CIPHER_CONFIG_CBC_AES_192: UInt32 = 4
IPSEC_CIPHER_CONFIG_CBC_AES_256: UInt32 = 5
IPSEC_CIPHER_CONFIG_GCM_AES_128: UInt32 = 6
IPSEC_CIPHER_CONFIG_GCM_AES_192: UInt32 = 7
IPSEC_CIPHER_CONFIG_GCM_AES_256: UInt32 = 8
IPSEC_CIPHER_CONFIG_MAX: UInt32 = 9
IPSEC_POLICY_FLAG_KEY_MANAGER_ALLOW_NOTIFY_KEY: UInt32 = 16384
IPSEC_POLICY_FLAG_RESERVED1: UInt32 = 32768
IPSEC_POLICY_FLAG_SITE_TO_SITE_TUNNEL: UInt32 = 65536
IPSEC_POLICY_FLAG_BANDWIDTH1: UInt32 = 268435456
IPSEC_POLICY_FLAG_BANDWIDTH2: UInt32 = 536870912
IPSEC_POLICY_FLAG_BANDWIDTH3: UInt32 = 1073741824
IPSEC_POLICY_FLAG_BANDWIDTH4: UInt32 = 2147483648
IPSEC_KEYING_POLICY_FLAG_TERMINATING_MATCH: UInt32 = 1
IPSEC_SA_BUNDLE_FLAG_NLB: UInt32 = 16
IPSEC_SA_BUNDLE_FLAG_NO_MACHINE_LUID_VERIFY: UInt32 = 32
IPSEC_SA_BUNDLE_FLAG_NO_IMPERSONATION_LUID_VERIFY: UInt32 = 64
IPSEC_SA_BUNDLE_FLAG_NO_EXPLICIT_CRED_MATCH: UInt32 = 128
IPSEC_SA_BUNDLE_FLAG_FORCE_INBOUND_CONNECTIONS: UInt32 = 32768
IPSEC_SA_BUNDLE_FLAG_FORCE_OUTBOUND_CONNECTIONS: UInt32 = 65536
IPSEC_SA_BUNDLE_FLAG_FORWARD_PATH_INITIATOR: UInt32 = 131072
IPSEC_SA_BUNDLE_FLAG_ENABLE_OPTIONAL_ASYMMETRIC_IDLE: UInt32 = 262144
IPSEC_SA_BUNDLE_FLAG_USING_DICTATED_KEYS: UInt32 = 524288
IPSEC_SA_BUNDLE_FLAG_LOCALLY_DICTATED_KEYS: UInt32 = 1048576
IPSEC_SA_BUNDLE_FLAG_SA_OFFLOADED: UInt32 = 2097152
IPSEC_SA_BUNDLE_FLAG_IP_IN_IP_PKT: UInt32 = 4194304
IPSEC_SA_BUNDLE_FLAG_LOW_POWER_MODE_SUPPORT: UInt32 = 8388608
IPSEC_SA_BUNDLE_FLAG_TUNNEL_BANDWIDTH1: UInt32 = 268435456
IPSEC_SA_BUNDLE_FLAG_TUNNEL_BANDWIDTH2: UInt32 = 536870912
IPSEC_SA_BUNDLE_FLAG_TUNNEL_BANDWIDTH3: UInt32 = 1073741824
IPSEC_SA_BUNDLE_FLAG_TUNNEL_BANDWIDTH4: UInt32 = 2147483648
IPSEC_DOSP_DSCP_DISABLE_VALUE: UInt32 = 255
IPSEC_DOSP_RATE_LIMIT_DISABLE_VALUE: UInt32 = 0
IPSEC_KEY_MANAGER_FLAG_DICTATE_KEY: UInt32 = 1
FWPM_LAYER_INBOUND_IPPACKET_V4: Guid = Guid('{c86fd1bf-21cd-497e-a0bb-17425c885c58}')
FWPM_LAYER_INBOUND_IPPACKET_V4_DISCARD: Guid = Guid('{b5a230d0-a8c0-44f2-916e-991b53ded1f7}')
FWPM_LAYER_INBOUND_IPPACKET_V6: Guid = Guid('{f52032cb-991c-46e7-971d-2601459a91ca}')
FWPM_LAYER_INBOUND_IPPACKET_V6_DISCARD: Guid = Guid('{bb24c279-93b4-47a2-83ad-ae1698b50885}')
FWPM_LAYER_OUTBOUND_IPPACKET_V4: Guid = Guid('{1e5c9fae-8a84-4135-a331-950b54229ecd}')
FWPM_LAYER_OUTBOUND_IPPACKET_V4_DISCARD: Guid = Guid('{08e4bcb5-b647-48f3-953c-e5ddbd03937e}')
FWPM_LAYER_OUTBOUND_IPPACKET_V6: Guid = Guid('{a3b3ab6b-3564-488c-9117-f34e82142763}')
FWPM_LAYER_OUTBOUND_IPPACKET_V6_DISCARD: Guid = Guid('{9513d7c4-a934-49dc-91a7-6ccb80cc02e3}')
FWPM_LAYER_IPFORWARD_V4: Guid = Guid('{a82acc24-4ee1-4ee1-b465-fd1d25cb10a4}')
FWPM_LAYER_IPFORWARD_V4_DISCARD: Guid = Guid('{9e9ea773-2fae-4210-8f17-34129ef369eb}')
FWPM_LAYER_IPFORWARD_V6: Guid = Guid('{7b964818-19c7-493a-b71f-832c3684d28c}')
FWPM_LAYER_IPFORWARD_V6_DISCARD: Guid = Guid('{31524a5d-1dfe-472f-bb93-518ee945d8a2}')
FWPM_LAYER_INBOUND_TRANSPORT_V4: Guid = Guid('{5926dfc8-e3cf-4426-a283-dc393f5d0f9d}')
FWPM_LAYER_INBOUND_TRANSPORT_V4_DISCARD: Guid = Guid('{ac4a9833-f69d-4648-b261-6dc84835ef39}')
FWPM_LAYER_INBOUND_TRANSPORT_V6: Guid = Guid('{634a869f-fc23-4b90-b0c1-bf620a36ae6f}')
FWPM_LAYER_INBOUND_TRANSPORT_V6_DISCARD: Guid = Guid('{2a6ff955-3b2b-49d2-9848-ad9d72dcaab7}')
FWPM_LAYER_OUTBOUND_TRANSPORT_V4: Guid = Guid('{09e61aea-d214-46e2-9b21-b26b0b2f28c8}')
FWPM_LAYER_OUTBOUND_TRANSPORT_V4_DISCARD: Guid = Guid('{c5f10551-bdb0-43d7-a313-50e211f4d68a}')
FWPM_LAYER_OUTBOUND_TRANSPORT_V6: Guid = Guid('{e1735bde-013f-4655-b351-a49e15762df0}')
FWPM_LAYER_OUTBOUND_TRANSPORT_V6_DISCARD: Guid = Guid('{f433df69-ccbd-482e-b9b2-57165658c3b3}')
FWPM_LAYER_STREAM_V4: Guid = Guid('{3b89653c-c170-49e4-b1cd-e0eeeee19a3e}')
FWPM_LAYER_STREAM_V4_DISCARD: Guid = Guid('{25c4c2c2-25ff-4352-82f9-c54a4a4726dc}')
FWPM_LAYER_STREAM_V6: Guid = Guid('{47c9137a-7ec4-46b3-b6e4-48e926b1eda4}')
FWPM_LAYER_STREAM_V6_DISCARD: Guid = Guid('{10a59fc7-b628-4c41-9eb8-cf37d55103cf}')
FWPM_LAYER_DATAGRAM_DATA_V4: Guid = Guid('{3d08bf4e-45f6-4930-a922-417098e20027}')
FWPM_LAYER_DATAGRAM_DATA_V4_DISCARD: Guid = Guid('{18e330c6-7248-4e52-aaab-472ed67704fd}')
FWPM_LAYER_DATAGRAM_DATA_V6: Guid = Guid('{fa45fe2f-3cba-4427-87fc-57b9a4b10d00}')
FWPM_LAYER_DATAGRAM_DATA_V6_DISCARD: Guid = Guid('{09d1dfe1-9b86-4a42-be9d-8c315b92a5d0}')
FWPM_LAYER_INBOUND_ICMP_ERROR_V4: Guid = Guid('{61499990-3cb6-4e84-b950-53b94b6964f3}')
FWPM_LAYER_INBOUND_ICMP_ERROR_V4_DISCARD: Guid = Guid('{a6b17075-ebaf-4053-a4e7-213c8121ede5}')
FWPM_LAYER_INBOUND_ICMP_ERROR_V6: Guid = Guid('{65f9bdff-3b2d-4e5d-b8c6-c720651fe898}')
FWPM_LAYER_INBOUND_ICMP_ERROR_V6_DISCARD: Guid = Guid('{a6e7ccc0-08fb-468d-a472-9771d5595e09}')
FWPM_LAYER_OUTBOUND_ICMP_ERROR_V4: Guid = Guid('{41390100-564c-4b32-bc1d-718048354d7c}')
FWPM_LAYER_OUTBOUND_ICMP_ERROR_V4_DISCARD: Guid = Guid('{b3598d36-0561-4588-a6bf-e955e3f6264b}')
FWPM_LAYER_OUTBOUND_ICMP_ERROR_V6: Guid = Guid('{7fb03b60-7b8d-4dfa-badd-980176fc4e12}')
FWPM_LAYER_OUTBOUND_ICMP_ERROR_V6_DISCARD: Guid = Guid('{65f2e647-8d0c-4f47-b19b-33a4d3f1357c}')
FWPM_LAYER_ALE_RESOURCE_ASSIGNMENT_V4: Guid = Guid('{1247d66d-0b60-4a15-8d44-7155d0f53a0c}')
FWPM_LAYER_ALE_RESOURCE_ASSIGNMENT_V4_DISCARD: Guid = Guid('{0b5812a2-c3ff-4eca-b88d-c79e20ac6322}')
FWPM_LAYER_ALE_RESOURCE_ASSIGNMENT_V6: Guid = Guid('{55a650e1-5f0a-4eca-a653-88f53b26aa8c}')
FWPM_LAYER_ALE_RESOURCE_ASSIGNMENT_V6_DISCARD: Guid = Guid('{cbc998bb-c51f-4c1a-bb4f-9775fcacab2f}')
FWPM_LAYER_ALE_AUTH_LISTEN_V4: Guid = Guid('{88bb5dad-76d7-4227-9c71-df0a3ed7be7e}')
FWPM_LAYER_ALE_AUTH_LISTEN_V4_DISCARD: Guid = Guid('{371dfada-9f26-45fd-b4eb-c29eb212893f}')
FWPM_LAYER_ALE_AUTH_LISTEN_V6: Guid = Guid('{7ac9de24-17dd-4814-b4bd-a9fbc95a321b}')
FWPM_LAYER_ALE_AUTH_LISTEN_V6_DISCARD: Guid = Guid('{60703b07-63c8-48e9-ada3-12b1af40a617}')
FWPM_LAYER_ALE_AUTH_RECV_ACCEPT_V4: Guid = Guid('{e1cd9fe7-f4b5-4273-96c0-592e487b8650}')
FWPM_LAYER_ALE_AUTH_RECV_ACCEPT_V4_DISCARD: Guid = Guid('{9eeaa99b-bd22-4227-919f-0073c63357b1}')
FWPM_LAYER_ALE_AUTH_RECV_ACCEPT_V6: Guid = Guid('{a3b42c97-9f04-4672-b87e-cee9c483257f}')
FWPM_LAYER_ALE_AUTH_RECV_ACCEPT_V6_DISCARD: Guid = Guid('{89455b97-dbe1-453f-a224-13da895af396}')
FWPM_LAYER_ALE_AUTH_CONNECT_V4: Guid = Guid('{c38d57d1-05a7-4c33-904f-7fbceee60e82}')
FWPM_LAYER_ALE_AUTH_CONNECT_V4_DISCARD: Guid = Guid('{d632a801-f5ba-4ad6-96e3-607017d9836a}')
FWPM_LAYER_ALE_AUTH_CONNECT_V6: Guid = Guid('{4a72393b-319f-44bc-84c3-ba54dcb3b6b4}')
FWPM_LAYER_ALE_AUTH_CONNECT_V6_DISCARD: Guid = Guid('{c97bc3b8-c9a3-4e33-8695-8e17aad4de09}')
FWPM_LAYER_ALE_FLOW_ESTABLISHED_V4: Guid = Guid('{af80470a-5596-4c13-9992-539e6fe57967}')
FWPM_LAYER_ALE_FLOW_ESTABLISHED_V4_DISCARD: Guid = Guid('{146ae4a9-a1d2-4d43-a31a-4c42682b8e4f}')
FWPM_LAYER_ALE_FLOW_ESTABLISHED_V6: Guid = Guid('{7021d2b3-dfa4-406e-afeb-6afaf7e70efd}')
FWPM_LAYER_ALE_FLOW_ESTABLISHED_V6_DISCARD: Guid = Guid('{46928636-bbca-4b76-941d-0fa7f5d7d372}')
FWPM_LAYER_INBOUND_MAC_FRAME_ETHERNET: Guid = Guid('{effb7edb-0055-4f9a-a231-4ff8131ad191}')
FWPM_LAYER_OUTBOUND_MAC_FRAME_ETHERNET: Guid = Guid('{694673bc-d6db-4870-adee-0acdbdb7f4b2}')
FWPM_LAYER_INBOUND_MAC_FRAME_NATIVE: Guid = Guid('{d4220bd3-62ce-4f08-ae88-b56e8526df50}')
FWPM_LAYER_OUTBOUND_MAC_FRAME_NATIVE: Guid = Guid('{94c44912-9d6f-4ebf-b995-05ab8a088d1b}')
FWPM_LAYER_INGRESS_VSWITCH_ETHERNET: Guid = Guid('{7d98577a-9a87-41ec-9718-7cf589c9f32d}')
FWPM_LAYER_EGRESS_VSWITCH_ETHERNET: Guid = Guid('{86c872b0-76fa-4b79-93a4-0750530ae292}')
FWPM_LAYER_INGRESS_VSWITCH_TRANSPORT_V4: Guid = Guid('{b2696ff6-774f-4554-9f7d-3da3945f8e85}')
FWPM_LAYER_INGRESS_VSWITCH_TRANSPORT_V6: Guid = Guid('{5ee314fc-7d8a-47f4-b7e3-291a36da4e12}')
FWPM_LAYER_EGRESS_VSWITCH_TRANSPORT_V4: Guid = Guid('{b92350b6-91f0-46b6-bdc4-871dfd4a7c98}')
FWPM_LAYER_EGRESS_VSWITCH_TRANSPORT_V6: Guid = Guid('{1b2def23-1881-40bd-82f4-4254e63141cb}')
FWPM_LAYER_INBOUND_TRANSPORT_FAST: Guid = Guid('{e41d2719-05c7-40f0-8983-ea8d17bbc2f6}')
FWPM_LAYER_OUTBOUND_TRANSPORT_FAST: Guid = Guid('{13ed4388-a070-4815-9935-7a9be6408b78}')
FWPM_LAYER_INBOUND_MAC_FRAME_NATIVE_FAST: Guid = Guid('{853aaa8e-2b78-4d24-a804-36db08b29711}')
FWPM_LAYER_OUTBOUND_MAC_FRAME_NATIVE_FAST: Guid = Guid('{470df946-c962-486f-9446-8293cbc75eb8}')
FWPM_LAYER_IPSEC_KM_DEMUX_V4: Guid = Guid('{f02b1526-a459-4a51-b9e3-759de52b9d2c}')
FWPM_LAYER_IPSEC_KM_DEMUX_V6: Guid = Guid('{2f755cf6-2fd4-4e88-b3e4-a91bca495235}')
FWPM_LAYER_IPSEC_V4: Guid = Guid('{eda65c74-610d-4bc5-948f-3c4f89556867}')
FWPM_LAYER_IPSEC_V6: Guid = Guid('{13c48442-8d87-4261-9a29-59d2abc348b4}')
FWPM_LAYER_IKEEXT_V4: Guid = Guid('{b14b7bdb-dbbd-473e-bed4-8b4708d4f270}')
FWPM_LAYER_IKEEXT_V6: Guid = Guid('{b64786b3-f687-4eb9-89d2-8ef32acdabe2}')
FWPM_LAYER_RPC_UM: Guid = Guid('{75a89dda-95e4-40f3-adc7-7688a9c847e1}')
FWPM_LAYER_RPC_EPMAP: Guid = Guid('{9247bc61-eb07-47ee-872c-bfd78bfd1616}')
FWPM_LAYER_RPC_EP_ADD: Guid = Guid('{618dffc7-c450-4943-95db-99b4c16a55d4}')
FWPM_LAYER_RPC_PROXY_CONN: Guid = Guid('{94a4b50b-ba5c-4f27-907a-229fac0c2a7a}')
FWPM_LAYER_RPC_PROXY_IF: Guid = Guid('{f8a38615-e12c-41ac-98df-121ad981aade}')
FWPM_LAYER_KM_AUTHORIZATION: Guid = Guid('{4aa226e9-9020-45fb-956a-c0249d841195}')
FWPM_LAYER_NAME_RESOLUTION_CACHE_V4: Guid = Guid('{0c2aa681-905b-4ccd-a467-4dd811d07b7b}')
FWPM_LAYER_NAME_RESOLUTION_CACHE_V6: Guid = Guid('{92d592fa-6b01-434a-9dea-d1e96ea97da9}')
FWPM_LAYER_ALE_RESOURCE_RELEASE_V4: Guid = Guid('{74365cce-ccb0-401a-bfc1-b89934ad7e15}')
FWPM_LAYER_ALE_RESOURCE_RELEASE_V6: Guid = Guid('{f4e5ce80-edcc-4e13-8a2f-b91454bb057b}')
FWPM_LAYER_ALE_ENDPOINT_CLOSURE_V4: Guid = Guid('{b4766427-e2a2-467a-bd7e-dbcd1bd85a09}')
FWPM_LAYER_ALE_ENDPOINT_CLOSURE_V6: Guid = Guid('{bb536ccd-4755-4ba9-9ff7-f9edf8699c7b}')
FWPM_LAYER_ALE_CONNECT_REDIRECT_V4: Guid = Guid('{c6e63c8c-b784-4562-aa7d-0a67cfcaf9a3}')
FWPM_LAYER_ALE_CONNECT_REDIRECT_V6: Guid = Guid('{587e54a7-8046-42ba-a0aa-b716250fc7fd}')
FWPM_LAYER_ALE_BIND_REDIRECT_V4: Guid = Guid('{66978cad-c704-42ac-86ac-7c1a231bd253}')
FWPM_LAYER_ALE_BIND_REDIRECT_V6: Guid = Guid('{bef02c9c-606b-4536-8c26-1c2fc7b631d4}')
FWPM_LAYER_STREAM_PACKET_V4: Guid = Guid('{af52d8ec-cb2d-44e5-ad92-f8dc38d2eb29}')
FWPM_LAYER_STREAM_PACKET_V6: Guid = Guid('{779a8ca3-f099-468f-b5d4-83535c461c02}')
FWPM_LAYER_INBOUND_RESERVED2: Guid = Guid('{f4fb8d55-c076-46d8-a2c7-6a4c722ca4ed}')
FWPM_LAYER_OUTBOUND_NETWORK_CONNECTION_POLICY_V4: Guid = Guid('{037f317a-d696-494a-bba5-bffc265e6052}')
FWPM_LAYER_OUTBOUND_NETWORK_CONNECTION_POLICY_V6: Guid = Guid('{22a4fdb1-6d7e-48ae-ae77-3742525c3119}')
FWPM_SUBLAYER_RPC_AUDIT: Guid = Guid('{758c84f4-fb48-4de9-9aeb-3ed9551ab1fd}')
FWPM_SUBLAYER_IPSEC_TUNNEL: Guid = Guid('{83f299ed-9ff4-4967-aff4-c309f4dab827}')
FWPM_SUBLAYER_UNIVERSAL: Guid = Guid('{eebecc03-ced4-4380-819a-2734397b2b74}')
FWPM_SUBLAYER_LIPS: Guid = Guid('{1b75c0ce-ff60-4711-a70f-b4958cc3b2d0}')
FWPM_SUBLAYER_SECURE_SOCKET: Guid = Guid('{15a66e17-3f3c-4f7b-aa6c-812aa613dd82}')
FWPM_SUBLAYER_TCP_CHIMNEY_OFFLOAD: Guid = Guid('{337608b9-b7d5-4d5f-82f9-3618618bc058}')
FWPM_SUBLAYER_INSPECTION: Guid = Guid('{877519e1-e6a9-41a5-81b4-8c4f118e4a60}')
FWPM_SUBLAYER_TEREDO: Guid = Guid('{ba69dc66-5176-4979-9c89-26a7b46a8327}')
FWPM_SUBLAYER_IPSEC_FORWARD_OUTBOUND_TUNNEL: Guid = Guid('{a5082e73-8f71-4559-8a9a-101cea04ef87}')
FWPM_SUBLAYER_IPSEC_DOSP: Guid = Guid('{e076d572-5d3d-48ef-802b-909eddb098bd}')
FWPM_SUBLAYER_TCP_TEMPLATES: Guid = Guid('{24421dcf-0ac5-4caa-9e14-50f6e3636af0}')
FWPM_SUBLAYER_IPSEC_SECURITY_REALM: Guid = Guid('{37a57701-5884-4964-92b8-3e704688b0ad}')
FWPM_SUBLAYER_MPSSVC_WSH: Guid = Guid('{b3cdd441-af90-41ba-a745-7c6008ff2300}')
FWPM_SUBLAYER_MPSSVC_WF: Guid = Guid('{b3cdd441-af90-41ba-a745-7c6008ff2301}')
FWPM_SUBLAYER_MPSSVC_QUARANTINE: Guid = Guid('{b3cdd441-af90-41ba-a745-7c6008ff2302}')
FWPM_SUBLAYER_MPSSVC_EDP: Guid = Guid('{09a47e38-fa97-471b-b123-18bcd7e65071}')
FWPM_SUBLAYER_MPSSVC_TENANT_RESTRICTIONS: Guid = Guid('{1ec6c7e1-fdd9-478a-b55f-ff8ba1d2c17d}')
FWPM_SUBLAYER_MPSSVC_APP_ISOLATION: Guid = Guid('{ffe221c3-92a8-4564-a59f-dafb70756020}')
FWPM_CONDITION_INTERFACE_MAC_ADDRESS: Guid = Guid('{f6e63dce-1f4b-4c6b-b6ef-1165e71f8ee7}')
FWPM_CONDITION_MAC_LOCAL_ADDRESS: Guid = Guid('{d999e981-7948-4c83-b742-c84e3b678f8f}')
FWPM_CONDITION_MAC_REMOTE_ADDRESS: Guid = Guid('{408f2ed4-3a70-4b4d-92a6-415ac20e2f12}')
FWPM_CONDITION_ETHER_TYPE: Guid = Guid('{fd08948d-a219-4d52-bb98-1a5540ee7b4e}')
FWPM_CONDITION_VLAN_ID: Guid = Guid('{938eab21-3618-4e64-9ca5-2141ebda1ca2}')
FWPM_CONDITION_VSWITCH_TENANT_NETWORK_ID: Guid = Guid('{dc04843c-79e6-4e44-a025-65b9bb0f9f94}')
FWPM_CONDITION_NDIS_PORT: Guid = Guid('{db7bb42b-2dac-4cd4-a59a-e0bdce1e6834}')
FWPM_CONDITION_NDIS_MEDIA_TYPE: Guid = Guid('{cb31cef1-791d-473b-89d1-61c5984304a0}')
FWPM_CONDITION_NDIS_PHYSICAL_MEDIA_TYPE: Guid = Guid('{34c79823-c229-44f2-b83c-74020882ae77}')
FWPM_CONDITION_L2_FLAGS: Guid = Guid('{7bc43cbf-37ba-45f1-b74a-82ff518eeb10}')
FWPM_CONDITION_MAC_LOCAL_ADDRESS_TYPE: Guid = Guid('{cc31355c-3073-4ffb-a14f-79415cb1ead1}')
FWPM_CONDITION_MAC_REMOTE_ADDRESS_TYPE: Guid = Guid('{027fedb4-f1c1-4030-b564-ee777fd867ea}')
FWPM_CONDITION_ALE_PACKAGE_ID: Guid = Guid('{71bc78fa-f17c-4997-a602-6abb261f351c}')
FWPM_CONDITION_MAC_SOURCE_ADDRESS: Guid = Guid('{7b795451-f1f6-4d05-b7cb-21779d802336}')
FWPM_CONDITION_MAC_DESTINATION_ADDRESS: Guid = Guid('{04ea2a93-858c-4027-b613-b43180c7859e}')
FWPM_CONDITION_MAC_SOURCE_ADDRESS_TYPE: Guid = Guid('{5c1b72e4-299e-4437-a298-bc3f014b3dc2}')
FWPM_CONDITION_MAC_DESTINATION_ADDRESS_TYPE: Guid = Guid('{ae052932-ef42-4e99-b129-f3b3139e34f7}')
FWPM_CONDITION_IP_SOURCE_PORT: Guid = Guid('{a6afef91-3df4-4730-a214-f5426aebf821}')
FWPM_CONDITION_IP_DESTINATION_PORT: Guid = Guid('{ce6def45-60fb-4a7b-a304-af30a117000e}')
FWPM_CONDITION_VSWITCH_ID: Guid = Guid('{c4a414ba-437b-4de6-9946-d99c1b95b312}')
FWPM_CONDITION_VSWITCH_NETWORK_TYPE: Guid = Guid('{11d48b4b-e77a-40b4-9155-392c906c2608}')
FWPM_CONDITION_VSWITCH_SOURCE_INTERFACE_ID: Guid = Guid('{7f4ef24b-b2c1-4938-ba33-a1ecbed512ba}')
FWPM_CONDITION_VSWITCH_DESTINATION_INTERFACE_ID: Guid = Guid('{8ed48be4-c926-49f6-a4f6-ef3030e3fc16}')
FWPM_CONDITION_VSWITCH_SOURCE_VM_ID: Guid = Guid('{9c2a9ec2-9fc6-42bc-bdd8-406d4da0be64}')
FWPM_CONDITION_VSWITCH_DESTINATION_VM_ID: Guid = Guid('{6106aace-4de1-4c84-9671-3637f8bcf731}')
FWPM_CONDITION_VSWITCH_SOURCE_INTERFACE_TYPE: Guid = Guid('{e6b040a2-edaf-4c36-908b-f2f58ae43807}')
FWPM_CONDITION_VSWITCH_DESTINATION_INTERFACE_TYPE: Guid = Guid('{fa9b3f06-2f1a-4c57-9e68-a7098b28dbfe}')
FWPM_CONDITION_ALE_SECURITY_ATTRIBUTE_FQBN_VALUE: Guid = Guid('{37a57699-5883-4963-92b8-3e704688b0ad}')
FWPM_CONDITION_IPSEC_SECURITY_REALM_ID: Guid = Guid('{37a57700-5884-4964-92b8-3e704688b0ad}')
FWPM_CONDITION_ALE_EFFECTIVE_NAME: Guid = Guid('{b1277b9a-b781-40fc-9671-e5f1b989f34e}')
FWPM_CONDITION_IP_LOCAL_ADDRESS: Guid = Guid('{d9ee00de-c1ef-4617-bfe3-ffd8f5a08957}')
FWPM_CONDITION_IP_REMOTE_ADDRESS: Guid = Guid('{b235ae9a-1d64-49b8-a44c-5ff3d9095045}')
FWPM_CONDITION_IP_SOURCE_ADDRESS: Guid = Guid('{ae96897e-2e94-4bc9-b313-b27ee80e574d}')
FWPM_CONDITION_IP_DESTINATION_ADDRESS: Guid = Guid('{2d79133b-b390-45c6-8699-acaceaafed33}')
FWPM_CONDITION_IP_LOCAL_ADDRESS_TYPE: Guid = Guid('{6ec7f6c4-376b-45d7-9e9c-d337cedcd237}')
FWPM_CONDITION_IP_DESTINATION_ADDRESS_TYPE: Guid = Guid('{1ec1b7c9-4eea-4f5e-b9ef-76beaaaf17ee}')
FWPM_CONDITION_IP_NEXTHOP_ADDRESS: Guid = Guid('{eabe448a-a711-4d64-85b7-3f76b65299c7}')
FWPM_CONDITION_IP_LOCAL_INTERFACE: Guid = Guid('{4cd62a49-59c3-4969-b7f3-bda5d32890a4}')
FWPM_CONDITION_IP_ARRIVAL_INTERFACE: Guid = Guid('{618a9b6d-386b-4136-ad6e-b51587cfb1cd}')
FWPM_CONDITION_ARRIVAL_INTERFACE_TYPE: Guid = Guid('{89f990de-e798-4e6d-ab76-7c9558292e6f}')
FWPM_CONDITION_ARRIVAL_TUNNEL_TYPE: Guid = Guid('{511166dc-7a8c-4aa7-b533-95ab59fb0340}')
FWPM_CONDITION_ARRIVAL_INTERFACE_INDEX: Guid = Guid('{cc088db3-1792-4a71-b0f9-037d21cd828b}')
FWPM_CONDITION_NEXTHOP_SUB_INTERFACE_INDEX: Guid = Guid('{ef8a6122-0577-45a7-9aaf-825fbeb4fb95}')
FWPM_CONDITION_IP_NEXTHOP_INTERFACE: Guid = Guid('{93ae8f5b-7f6f-4719-98c8-14e97429ef04}')
FWPM_CONDITION_NEXTHOP_INTERFACE_TYPE: Guid = Guid('{97537c6c-d9a3-4767-a381-e942675cd920}')
FWPM_CONDITION_NEXTHOP_TUNNEL_TYPE: Guid = Guid('{72b1a111-987b-4720-99dd-c7c576fa2d4c}')
FWPM_CONDITION_NEXTHOP_INTERFACE_INDEX: Guid = Guid('{138e6888-7ab8-4d65-9ee8-0591bcf6a494}')
FWPM_CONDITION_ORIGINAL_PROFILE_ID: Guid = Guid('{46ea1551-2255-492b-8019-aabeee349f40}')
FWPM_CONDITION_CURRENT_PROFILE_ID: Guid = Guid('{ab3033c9-c0e3-4759-937d-5758c65d4ae3}')
FWPM_CONDITION_LOCAL_INTERFACE_PROFILE_ID: Guid = Guid('{4ebf7562-9f18-4d06-9941-a7a625744d71}')
FWPM_CONDITION_ARRIVAL_INTERFACE_PROFILE_ID: Guid = Guid('{cdfe6aab-c083-4142-8679-c08f95329c61}')
FWPM_CONDITION_NEXTHOP_INTERFACE_PROFILE_ID: Guid = Guid('{d7ff9a56-cdaa-472b-84db-d23963c1d1bf}')
FWPM_CONDITION_REAUTHORIZE_REASON: Guid = Guid('{11205e8c-11ae-457a-8a44-477026dd764a}')
FWPM_CONDITION_ORIGINAL_ICMP_TYPE: Guid = Guid('{076dfdbe-c56c-4f72-ae8a-2cfe7e5c8286}')
FWPM_CONDITION_IP_PHYSICAL_ARRIVAL_INTERFACE: Guid = Guid('{da50d5c8-fa0d-4c89-b032-6e62136d1e96}')
FWPM_CONDITION_IP_PHYSICAL_NEXTHOP_INTERFACE: Guid = Guid('{f09bd5ce-5150-48be-b098-c25152fb1f92}')
FWPM_CONDITION_INTERFACE_QUARANTINE_EPOCH: Guid = Guid('{cce68d5e-053b-43a8-9a6f-33384c28e4f6}')
FWPM_CONDITION_INTERFACE_TYPE: Guid = Guid('{daf8cd14-e09e-4c93-a5ae-c5c13b73ffca}')
FWPM_CONDITION_TUNNEL_TYPE: Guid = Guid('{77a40437-8779-4868-a261-f5a902f1c0cd}')
FWPM_CONDITION_IP_FORWARD_INTERFACE: Guid = Guid('{1076b8a5-6323-4c5e-9810-e8d3fc9e6136}')
FWPM_CONDITION_IP_PROTOCOL: Guid = Guid('{3971ef2b-623e-4f9a-8cb1-6e79b806b9a7}')
FWPM_CONDITION_IP_LOCAL_PORT: Guid = Guid('{0c1ba1af-5765-453f-af22-a8f791ac775b}')
FWPM_CONDITION_IP_REMOTE_PORT: Guid = Guid('{c35a604d-d22b-4e1a-91b4-68f674ee674b}')
FWPM_CONDITION_EMBEDDED_LOCAL_ADDRESS_TYPE: Guid = Guid('{4672a468-8a0a-4202-abb4-849e92e66809}')
FWPM_CONDITION_EMBEDDED_REMOTE_ADDRESS: Guid = Guid('{77ee4b39-3273-4671-b63b-ab6feb66eeb6}')
FWPM_CONDITION_EMBEDDED_PROTOCOL: Guid = Guid('{07784107-a29e-4c7b-9ec7-29c44afafdbc}')
FWPM_CONDITION_EMBEDDED_LOCAL_PORT: Guid = Guid('{bfca394d-acdb-484e-b8e6-2aff79757345}')
FWPM_CONDITION_EMBEDDED_REMOTE_PORT: Guid = Guid('{cae4d6a1-2968-40ed-a4ce-547160dda88d}')
FWPM_CONDITION_FLAGS: Guid = Guid('{632ce23b-5167-435c-86d7-e903684aa80c}')
FWPM_CONDITION_DIRECTION: Guid = Guid('{8784c146-ca97-44d6-9fd1-19fb1840cbf7}')
FWPM_CONDITION_INTERFACE_INDEX: Guid = Guid('{667fd755-d695-434a-8af5-d3835a1259bc}')
FWPM_CONDITION_SUB_INTERFACE_INDEX: Guid = Guid('{0cd42473-d621-4be3-ae8c-72a348d283e1}')
FWPM_CONDITION_SOURCE_INTERFACE_INDEX: Guid = Guid('{2311334d-c92d-45bf-9496-edf447820e2d}')
FWPM_CONDITION_SOURCE_SUB_INTERFACE_INDEX: Guid = Guid('{055edd9d-acd2-4361-8dab-f9525d97662f}')
FWPM_CONDITION_DESTINATION_INTERFACE_INDEX: Guid = Guid('{35cf6522-4139-45ee-a0d5-67b80949d879}')
FWPM_CONDITION_DESTINATION_SUB_INTERFACE_INDEX: Guid = Guid('{2b7d4399-d4c7-4738-a2f5-e994b43da388}')
FWPM_CONDITION_ALE_APP_ID: Guid = Guid('{d78e1e87-8644-4ea5-9437-d809ecefc971}')
FWPM_CONDITION_ALE_ORIGINAL_APP_ID: Guid = Guid('{0e6cd086-e1fb-4212-842f-8a9f993fb3f6}')
FWPM_CONDITION_ALE_USER_ID: Guid = Guid('{af043a0a-b34d-4f86-979c-c90371af6e66}')
FWPM_CONDITION_ALE_REMOTE_USER_ID: Guid = Guid('{f63073b7-0189-4ab0-95a4-6123cbfab862}')
FWPM_CONDITION_ALE_REMOTE_MACHINE_ID: Guid = Guid('{1aa47f51-7f93-4508-a271-81abb00c9cab}')
FWPM_CONDITION_ALE_PROMISCUOUS_MODE: Guid = Guid('{1c974776-7182-46e9-afd3-b02910e30334}')
FWPM_CONDITION_ALE_SIO_FIREWALL_SYSTEM_PORT: Guid = Guid('{b9f4e088-cb98-4efb-a2c7-ad07332643db}')
FWPM_CONDITION_ALE_REAUTH_REASON: Guid = Guid('{b482d227-1979-4a98-8044-18bbe6237542}')
FWPM_CONDITION_ALE_NAP_CONTEXT: Guid = Guid('{46275a9d-c03f-4d77-b784-1c57f4d02753}')
FWPM_CONDITION_KM_AUTH_NAP_CONTEXT: Guid = Guid('{35d0ea0e-15ca-492b-900e-97fd46352cce}')
FWPM_CONDITION_REMOTE_USER_TOKEN: Guid = Guid('{9bf0ee66-06c9-41b9-84da-288cb43af51f}')
FWPM_CONDITION_RPC_IF_UUID: Guid = Guid('{7c9c7d9f-0075-4d35-a0d1-8311c4cf6af1}')
FWPM_CONDITION_RPC_IF_VERSION: Guid = Guid('{eabfd9b7-1262-4a2e-adaa-5f96f6fe326d}')
FWPM_CONDITION_RPC_IF_FLAG: Guid = Guid('{238a8a32-3199-467d-871c-272621ab3896}')
FWPM_CONDITION_DCOM_APP_ID: Guid = Guid('{ff2e7b4d-3112-4770-b636-4d24ae3a6af2}')
FWPM_CONDITION_IMAGE_NAME: Guid = Guid('{d024de4d-deaa-4317-9c85-e40ef6e140c3}')
FWPM_CONDITION_RPC_PROTOCOL: Guid = Guid('{2717bc74-3a35-4ce7-b7ef-c838fabdec45}')
FWPM_CONDITION_RPC_AUTH_TYPE: Guid = Guid('{daba74ab-0d67-43e7-986e-75b84f82f594}')
FWPM_CONDITION_RPC_AUTH_LEVEL: Guid = Guid('{e5a0aed5-59ac-46ea-be05-a5f05ecf446e}')
FWPM_CONDITION_SEC_ENCRYPT_ALGORITHM: Guid = Guid('{0d306ef0-e974-4f74-b5c7-591b0da7d562}')
FWPM_CONDITION_SEC_KEY_SIZE: Guid = Guid('{4772183b-ccf8-4aeb-bce1-c6c6161c8fe4}')
FWPM_CONDITION_IP_LOCAL_ADDRESS_V4: Guid = Guid('{03a629cb-6e52-49f8-9c41-5709633c09cf}')
FWPM_CONDITION_IP_LOCAL_ADDRESS_V6: Guid = Guid('{2381be84-7524-45b3-a05b-1e637d9c7a6a}')
FWPM_CONDITION_PIPE: Guid = Guid('{1bd0741d-e3df-4e24-8634-762046eef6eb}')
FWPM_CONDITION_IP_REMOTE_ADDRESS_V4: Guid = Guid('{1febb610-3bcc-45e1-bc36-2e067e2cb186}')
FWPM_CONDITION_IP_REMOTE_ADDRESS_V6: Guid = Guid('{246e1d8c-8bee-4018-9b98-31d4582f3361}')
FWPM_CONDITION_PROCESS_WITH_RPC_IF_UUID: Guid = Guid('{e31180a8-bbbd-4d14-a65e-7157b06233bb}')
FWPM_CONDITION_RPC_EP_VALUE: Guid = Guid('{dccea0b9-0886-4360-9c6a-ab043a24fba9}')
FWPM_CONDITION_RPC_EP_FLAGS: Guid = Guid('{218b814a-0a39-49b8-8e71-c20c39c7dd2e}')
FWPM_CONDITION_CLIENT_TOKEN: Guid = Guid('{c228fc1e-403a-4478-be05-c9baa4c05ace}')
FWPM_CONDITION_RPC_SERVER_NAME: Guid = Guid('{b605a225-c3b3-48c7-9833-7aefa9527546}')
FWPM_CONDITION_RPC_SERVER_PORT: Guid = Guid('{8090f645-9ad5-4e3b-9f9f-8023ca097909}')
FWPM_CONDITION_RPC_PROXY_AUTH_TYPE: Guid = Guid('{40953fe2-8565-4759-8488-1771b4b4b5db}')
FWPM_CONDITION_CLIENT_CERT_KEY_LENGTH: Guid = Guid('{a3ec00c7-05f4-4df7-91f2-5f60d91ff443}')
FWPM_CONDITION_CLIENT_CERT_OID: Guid = Guid('{c491ad5e-f882-4283-b916-436b103ff4ad}')
FWPM_CONDITION_NET_EVENT_TYPE: Guid = Guid('{206e9996-490e-40cf-b831-b38641eb6fcb}')
FWPM_CONDITION_PEER_NAME: Guid = Guid('{9b539082-eb90-4186-a6cc-de5b63235016}')
FWPM_CONDITION_REMOTE_ID: Guid = Guid('{f68166fd-0682-4c89-b8f5-86436c7ef9b7}')
FWPM_CONDITION_AUTHENTICATION_TYPE: Guid = Guid('{eb458cd5-da7b-4ef9-8d43-7b0a840332f2}')
FWPM_CONDITION_KM_TYPE: Guid = Guid('{ff0f5f49-0ceb-481b-8638-1479791f3f2c}')
FWPM_CONDITION_KM_MODE: Guid = Guid('{feef4582-ef8f-4f7b-858b-9077d122de47}')
FWPM_CONDITION_IPSEC_POLICY_KEY: Guid = Guid('{ad37dee3-722f-45cc-a4e3-068048124452}')
FWPM_CONDITION_QM_MODE: Guid = Guid('{f64fc6d1-f9cb-43d2-8a5f-e13bc894f265}')
FWPM_CONDITION_COMPARTMENT_ID: Guid = Guid('{35a791ab-04ac-4ff2-a6bb-da6cfac71806}')
FWPM_CONDITION_RESERVED0: Guid = Guid('{678f4deb-45af-4882-93fe-19d4729d9834}')
FWPM_CONDITION_RESERVED1: Guid = Guid('{d818f827-5c69-48eb-bf80-d86b17755f97}')
FWPM_CONDITION_RESERVED2: Guid = Guid('{53d4123d-e15b-4e84-b7a8-dce16f7b62d9}')
FWPM_CONDITION_RESERVED3: Guid = Guid('{7f6e8ca3-6606-4932-97c7-e1f20710af3b}')
FWPM_CONDITION_RESERVED4: Guid = Guid('{5f58e642-b937-495e-a94b-f6b051a49250}')
FWPM_CONDITION_RESERVED5: Guid = Guid('{9ba8f6cd-f77c-43e6-8847-11939dc5db5a}')
FWPM_CONDITION_RESERVED6: Guid = Guid('{f13d84bd-59d5-44c4-8817-5ecdae1805bd}')
FWPM_CONDITION_RESERVED7: Guid = Guid('{65a0f930-45dd-4983-aa33-efc7b611af08}')
FWPM_CONDITION_RESERVED8: Guid = Guid('{4f424974-0c12-4816-9b47-9a547db39a32}')
FWPM_CONDITION_RESERVED9: Guid = Guid('{ce78e10f-13ff-4c70-8643-36ad1879afa3}')
FWPM_CONDITION_RESERVED10: Guid = Guid('{b979e282-d621-4c8c-b184-b105a61c36ce}')
FWPM_CONDITION_RESERVED11: Guid = Guid('{2d62ee4d-023d-411f-9582-43acbb795975}')
FWPM_CONDITION_RESERVED12: Guid = Guid('{a3677c32-7e35-4ddc-93da-e8c33fc923c7}')
FWPM_CONDITION_RESERVED13: Guid = Guid('{335a3e90-84aa-42f5-9e6f-59309536a44c}')
FWPM_CONDITION_RESERVED14: Guid = Guid('{30e44da2-2f1a-4116-a559-f907de83604a}')
FWPM_CONDITION_RESERVED15: Guid = Guid('{bab8340f-afe0-43d1-80d8-5ca456962de3}')
FWPM_PROVIDER_IKEEXT: Guid = Guid('{10ad9216-ccde-456c-8b16-e9f04e60a90b}')
FWPM_PROVIDER_IPSEC_DOSP_CONFIG: Guid = Guid('{3c6c05a9-c05c-4bb9-8338-2327814ce8bf}')
FWPM_PROVIDER_TCP_CHIMNEY_OFFLOAD: Guid = Guid('{896aa19e-9a34-4bcb-ae79-beb9127c84b9}')
FWPM_PROVIDER_TCP_TEMPLATES: Guid = Guid('{76cfcd30-3394-432d-bed3-441ae50e63c3}')
FWPM_PROVIDER_MPSSVC_WSH: Guid = Guid('{4b153735-1049-4480-aab4-d1b9bdc03710}')
FWPM_PROVIDER_MPSSVC_WF: Guid = Guid('{decc16ca-3f33-4346-be1e-8fb4ae0f3d62}')
FWPM_PROVIDER_MPSSVC_EDP: Guid = Guid('{a90296f7-46b8-4457-8f84-b05e05d3c622}')
FWPM_PROVIDER_MPSSVC_TENANT_RESTRICTIONS: Guid = Guid('{d0718ff9-44da-4f50-9dc2-c963a4247613}')
FWPM_PROVIDER_MPSSVC_APP_ISOLATION: Guid = Guid('{3cc2631f-2d5d-43a0-b174-614837d863a1}')
FWPM_CALLOUT_IPSEC_INBOUND_TRANSPORT_V4: Guid = Guid('{5132900d-5e84-4b5f-80e4-01741e81ff10}')
FWPM_CALLOUT_IPSEC_INBOUND_TRANSPORT_V6: Guid = Guid('{49d3ac92-2a6c-4dcf-955f-1c3be009dd99}')
FWPM_CALLOUT_IPSEC_OUTBOUND_TRANSPORT_V4: Guid = Guid('{4b46bf0a-4523-4e57-aa38-a87987c910d9}')
FWPM_CALLOUT_IPSEC_OUTBOUND_TRANSPORT_V6: Guid = Guid('{38d87722-ad83-4f11-a91f-df0fb077225b}')
FWPM_CALLOUT_IPSEC_INBOUND_TUNNEL_V4: Guid = Guid('{191a8a46-0bf8-46cf-b045-4b45dfa6a324}')
FWPM_CALLOUT_IPSEC_INBOUND_TUNNEL_V6: Guid = Guid('{80c342e3-1e53-4d6f-9b44-03df5aeee154}')
FWPM_CALLOUT_IPSEC_OUTBOUND_TUNNEL_V4: Guid = Guid('{70a4196c-835b-4fb0-98e8-075f4d977d46}')
FWPM_CALLOUT_IPSEC_OUTBOUND_TUNNEL_V6: Guid = Guid('{f1835363-a6a5-4e62-b180-23db789d8da6}')
FWPM_CALLOUT_IPSEC_FORWARD_INBOUND_TUNNEL_V4: Guid = Guid('{28829633-c4f0-4e66-873f-844db2a899c7}')
FWPM_CALLOUT_IPSEC_FORWARD_INBOUND_TUNNEL_V6: Guid = Guid('{af50bec2-c686-429a-884d-b74443e7b0b4}')
FWPM_CALLOUT_IPSEC_FORWARD_OUTBOUND_TUNNEL_V4: Guid = Guid('{fb532136-15cb-440b-937c-1717ca320c40}')
FWPM_CALLOUT_IPSEC_FORWARD_OUTBOUND_TUNNEL_V6: Guid = Guid('{dae640cc-e021-4bee-9eb6-a48b275c8c1d}')
FWPM_CALLOUT_IPSEC_INBOUND_INITIATE_SECURE_V4: Guid = Guid('{7dff309b-ba7d-4aba-91aa-ae5c6640c944}')
FWPM_CALLOUT_IPSEC_INBOUND_INITIATE_SECURE_V6: Guid = Guid('{a9a0d6d9-c58c-474e-8aeb-3cfe99d6d53d}')
FWPM_CALLOUT_IPSEC_INBOUND_TUNNEL_ALE_ACCEPT_V4: Guid = Guid('{3df6e7de-fd20-48f2-9f26-f854444cba79}')
FWPM_CALLOUT_IPSEC_INBOUND_TUNNEL_ALE_ACCEPT_V6: Guid = Guid('{a1e392d3-72ac-47bb-87a7-0122c69434ab}')
FWPM_CALLOUT_IPSEC_ALE_CONNECT_V4: Guid = Guid('{6ac141fc-f75d-4203-b9c8-48e6149c2712}')
FWPM_CALLOUT_IPSEC_ALE_CONNECT_V6: Guid = Guid('{4c0dda05-e31f-4666-90b0-b3dfad34129a}')
FWPM_CALLOUT_IPSEC_DOSP_FORWARD_V6: Guid = Guid('{6d08a342-db9e-4fbe-9ed2-57374ce89f79}')
FWPM_CALLOUT_IPSEC_DOSP_FORWARD_V4: Guid = Guid('{2fcb56ec-cd37-4b4f-b108-62c2b1850a0c}')
FWPM_CALLOUT_WFP_TRANSPORT_LAYER_V4_SILENT_DROP: Guid = Guid('{eda08606-2494-4d78-89bc-67837c03b969}')
FWPM_CALLOUT_WFP_TRANSPORT_LAYER_V6_SILENT_DROP: Guid = Guid('{8693cc74-a075-4156-b476-9286eece814e}')
FWPM_CALLOUT_TCP_CHIMNEY_CONNECT_LAYER_V4: Guid = Guid('{f3e10ab3-2c25-4279-ac36-c30fc181bec4}')
FWPM_CALLOUT_TCP_CHIMNEY_CONNECT_LAYER_V6: Guid = Guid('{39e22085-a341-42fc-a279-aec94e689c56}')
FWPM_CALLOUT_TCP_CHIMNEY_ACCEPT_LAYER_V4: Guid = Guid('{e183ecb2-3a7f-4b54-8ad9-76050ed880ca}')
FWPM_CALLOUT_TCP_CHIMNEY_ACCEPT_LAYER_V6: Guid = Guid('{0378cf41-bf98-4603-81f2-7f12586079f6}')
FWPM_CALLOUT_SET_OPTIONS_AUTH_CONNECT_LAYER_V4: Guid = Guid('{bc582280-1677-41e9-94ab-c2fcb15c2eeb}')
FWPM_CALLOUT_SET_OPTIONS_AUTH_CONNECT_LAYER_V6: Guid = Guid('{98e5373c-b884-490f-b65f-2f6a4a575195}')
FWPM_CALLOUT_SET_OPTIONS_AUTH_RECV_ACCEPT_LAYER_V4: Guid = Guid('{2d55f008-0c01-4f92-b26e-a08a94569b8d}')
FWPM_CALLOUT_SET_OPTIONS_AUTH_RECV_ACCEPT_LAYER_V6: Guid = Guid('{63018537-f281-4dc4-83d3-8dec18b7ade2}')
FWPM_CALLOUT_RESERVED_AUTH_CONNECT_LAYER_V4: Guid = Guid('{288b524d-0566-4e19-b612-8f441a2e5949}')
FWPM_CALLOUT_RESERVED_AUTH_CONNECT_LAYER_V6: Guid = Guid('{00b84b92-2b5e-4b71-ab0e-aaca43e387e6}')
FWPM_CALLOUT_TEREDO_ALE_RESOURCE_ASSIGNMENT_V6: Guid = Guid('{31b95392-066e-42a2-b7db-92f8acdd56f9}')
FWPM_CALLOUT_EDGE_TRAVERSAL_ALE_RESOURCE_ASSIGNMENT_V4: Guid = Guid('{079b1010-f1c5-4fcd-ae05-da41107abd0b}')
FWPM_CALLOUT_TEREDO_ALE_LISTEN_V6: Guid = Guid('{81a434e7-f60c-4378-bab8-c625a30f0197}')
FWPM_CALLOUT_EDGE_TRAVERSAL_ALE_LISTEN_V4: Guid = Guid('{33486ab5-6d5e-4e65-a00b-a7afed0ba9a1}')
FWPM_CALLOUT_TCP_TEMPLATES_CONNECT_LAYER_V4: Guid = Guid('{215a0b39-4b7e-4eda-8ce4-179679df6224}')
FWPM_CALLOUT_TCP_TEMPLATES_CONNECT_LAYER_V6: Guid = Guid('{838b37a1-5c12-4d34-8b38-078728b2d25c}')
FWPM_CALLOUT_TCP_TEMPLATES_ACCEPT_LAYER_V4: Guid = Guid('{2f23f5d0-40c4-4c41-a254-46d8dba8957c}')
FWPM_CALLOUT_TCP_TEMPLATES_ACCEPT_LAYER_V6: Guid = Guid('{b25152f0-991c-4f53-bbe7-d24b45fe632c}')
FWPM_CALLOUT_POLICY_SILENT_MODE_AUTH_CONNECT_LAYER_V4: Guid = Guid('{5fbfc31d-a51c-44dc-acb6-0624a030a700}')
FWPM_CALLOUT_POLICY_SILENT_MODE_AUTH_CONNECT_LAYER_V6: Guid = Guid('{5fbfc31d-a51c-44dc-acb6-0624a030a701}')
FWPM_CALLOUT_POLICY_SILENT_MODE_AUTH_RECV_ACCEPT_LAYER_V4: Guid = Guid('{5fbfc31d-a51c-44dc-acb6-0624a030a702}')
FWPM_CALLOUT_POLICY_SILENT_MODE_AUTH_RECV_ACCEPT_LAYER_V6: Guid = Guid('{5fbfc31d-a51c-44dc-acb6-0624a030a703}')
FWPM_CALLOUT_HTTP_TEMPLATE_SSL_HANDSHAKE: Guid = Guid('{b3423249-8d09-4858-9210-95c7fda8e30f}')
FWPM_CALLOUT_OUTBOUND_NETWORK_CONNECTION_POLICY_LAYER_V4: Guid = Guid('{103090d4-8e28-4fd6-9894-d1d67d6b10c9}')
FWPM_CALLOUT_OUTBOUND_NETWORK_CONNECTION_POLICY_LAYER_V6: Guid = Guid('{4ed3446d-8dc7-459b-b09f-c1cb7a8f8689}')
FWPM_CALLOUT_BUILT_IN_RESERVED_1: Guid = Guid('{779719a4-e695-47b6-a199-7999fec9163b}')
FWPM_CALLOUT_BUILT_IN_RESERVED_2: Guid = Guid('{ef9661b6-7c5e-48fd-a130-96678ceacc41}')
FWPM_CALLOUT_BUILT_IN_RESERVED_3: Guid = Guid('{18729c7a-2f62-4be0-966f-974b21b86df1}')
FWPM_CALLOUT_BUILT_IN_RESERVED_4: Guid = Guid('{6c3fb801-daff-40e9-91e6-f7ff7e52f7d9}')
FWPM_PROVIDER_CONTEXT_SECURE_SOCKET_AUTHIP: Guid = Guid('{b25ea800-0d02-46ed-92bd-7fa84bb73e9d}')
FWPM_PROVIDER_CONTEXT_SECURE_SOCKET_IPSEC: Guid = Guid('{8c2d4144-f8e0-42c0-94ce-7ccfc63b2f9b}')
FWPM_KEYING_MODULE_IKE: Guid = Guid('{a9bbf787-82a8-45bb-a400-5d7e5952c7a9}')
FWPM_KEYING_MODULE_AUTHIP: Guid = Guid('{11e3dae0-dd26-4590-857d-ab4b28d1a095}')
FWPM_KEYING_MODULE_IKEV2: Guid = Guid('{041792cc-8f07-419d-a394-716968cb1647}')
FWPM_AUTO_WEIGHT_BITS: UInt32 = 60
FWPM_WEIGHT_RANGE_IPSEC: UInt32 = 0
FWPM_WEIGHT_RANGE_IKE_EXEMPTIONS: UInt32 = 12
FWPM_ACTRL_ADD: UInt32 = 1
FWPM_ACTRL_ADD_LINK: UInt32 = 2
FWPM_ACTRL_BEGIN_READ_TXN: UInt32 = 4
FWPM_ACTRL_BEGIN_WRITE_TXN: UInt32 = 8
FWPM_ACTRL_CLASSIFY: UInt32 = 16
FWPM_ACTRL_ENUM: UInt32 = 32
FWPM_ACTRL_OPEN: UInt32 = 64
FWPM_ACTRL_READ: UInt32 = 128
FWPM_ACTRL_READ_STATS: UInt32 = 256
FWPM_ACTRL_SUBSCRIBE: UInt32 = 512
FWPM_ACTRL_WRITE: UInt32 = 1024
FWPM_TXN_READ_ONLY: UInt32 = 1
FWPM_TUNNEL_FLAG_POINT_TO_POINT: UInt32 = 1
FWPM_TUNNEL_FLAG_ENABLE_VIRTUAL_IF_TUNNELING: UInt32 = 2
FWPM_TUNNEL_FLAG_RESERVED0: UInt32 = 4
FWPS_METADATA_FIELD_DISCARD_REASON: UInt32 = 1
FWPS_METADATA_FIELD_FLOW_HANDLE: UInt32 = 2
FWPS_METADATA_FIELD_IP_HEADER_SIZE: UInt32 = 4
FWPS_METADATA_FIELD_PROCESS_PATH: UInt32 = 8
FWPS_METADATA_FIELD_TOKEN: UInt32 = 16
FWPS_METADATA_FIELD_PROCESS_ID: UInt32 = 32
FWPS_METADATA_FIELD_SYSTEM_FLAGS: UInt32 = 64
FWPS_METADATA_FIELD_RESERVED: UInt32 = 128
FWPS_METADATA_FIELD_SOURCE_INTERFACE_INDEX: UInt32 = 256
FWPS_METADATA_FIELD_DESTINATION_INTERFACE_INDEX: UInt32 = 512
FWPS_METADATA_FIELD_TRANSPORT_HEADER_SIZE: UInt32 = 1024
FWPS_METADATA_FIELD_COMPARTMENT_ID: UInt32 = 2048
FWPS_METADATA_FIELD_FRAGMENT_DATA: UInt32 = 4096
FWPS_METADATA_FIELD_PATH_MTU: UInt32 = 8192
FWPS_METADATA_FIELD_COMPLETION_HANDLE: UInt32 = 16384
FWPS_METADATA_FIELD_TRANSPORT_ENDPOINT_HANDLE: UInt32 = 32768
FWPS_METADATA_FIELD_TRANSPORT_CONTROL_DATA: UInt32 = 65536
FWPS_METADATA_FIELD_REMOTE_SCOPE_ID: UInt32 = 131072
FWPS_METADATA_FIELD_PACKET_DIRECTION: UInt32 = 262144
FWPS_METADATA_FIELD_PACKET_SYSTEM_CRITICAL: UInt32 = 524288
FWPS_METADATA_FIELD_FORWARD_LAYER_OUTBOUND_PASS_THRU: UInt32 = 1048576
FWPS_METADATA_FIELD_FORWARD_LAYER_INBOUND_PASS_THRU: UInt32 = 2097152
FWPS_METADATA_FIELD_ALE_CLASSIFY_REQUIRED: UInt32 = 4194304
FWPS_METADATA_FIELD_TRANSPORT_HEADER_INCLUDE_HEADER: UInt32 = 8388608
FWPS_METADATA_FIELD_DESTINATION_PREFIX: UInt32 = 16777216
FWPS_METADATA_FIELD_ETHER_FRAME_LENGTH: UInt32 = 33554432
FWPS_METADATA_FIELD_PARENT_ENDPOINT_HANDLE: UInt32 = 67108864
FWPS_METADATA_FIELD_ICMP_ID_AND_SEQUENCE: UInt32 = 134217728
FWPS_METADATA_FIELD_LOCAL_REDIRECT_TARGET_PID: UInt32 = 268435456
FWPS_METADATA_FIELD_ORIGINAL_DESTINATION: UInt32 = 536870912
FWPS_METADATA_FIELD_REDIRECT_RECORD_HANDLE: UInt32 = 1073741824
FWPS_METADATA_FIELD_SUB_PROCESS_TAG: UInt32 = 2147483648
FWPS_L2_METADATA_FIELD_ETHERNET_MAC_HEADER_SIZE: UInt32 = 1
FWPS_L2_METADATA_FIELD_WIFI_OPERATION_MODE: UInt32 = 2
FWPS_L2_METADATA_FIELD_VSWITCH_SOURCE_PORT_ID: UInt32 = 4
FWPS_L2_METADATA_FIELD_VSWITCH_SOURCE_NIC_INDEX: UInt32 = 8
FWPS_L2_METADATA_FIELD_VSWITCH_PACKET_CONTEXT: UInt32 = 16
FWPS_L2_METADATA_FIELD_VSWITCH_DESTINATION_PORT_ID: UInt32 = 32
FWPS_L2_METADATA_FIELD_RESERVED: UInt32 = 2147483648
@winfunctype('fwpuclnt.dll')
def FwpmFreeMemory0(p: POINTER(VoidPtr)) -> Void: ...
@winfunctype('fwpuclnt.dll')
def FwpmEngineOpen0(serverName: win32more.Windows.Win32.Foundation.PWSTR, authnService: UInt32, authIdentity: POINTER(win32more.Windows.Win32.System.Rpc.SEC_WINNT_AUTH_IDENTITY_W), session: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_SESSION0), engineHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmEngineClose0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmEngineGetOption0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, option: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_ENGINE_OPTION, value: POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_VALUE0))) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmEngineSetOption0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, option: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_ENGINE_OPTION, newValue: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_VALUE0)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmEngineGetSecurityInfo0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, securityInfo: UInt32, sidOwner: POINTER(win32more.Windows.Win32.Security.PSID), sidGroup: POINTER(win32more.Windows.Win32.Security.PSID), dacl: POINTER(POINTER(win32more.Windows.Win32.Security.ACL)), sacl: POINTER(POINTER(win32more.Windows.Win32.Security.ACL)), securityDescriptor: POINTER(win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmEngineSetSecurityInfo0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, securityInfo: UInt32, sidOwner: POINTER(win32more.Windows.Win32.Security.SID), sidGroup: POINTER(win32more.Windows.Win32.Security.SID), dacl: POINTER(win32more.Windows.Win32.Security.ACL), sacl: POINTER(win32more.Windows.Win32.Security.ACL)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmSessionCreateEnumHandle0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumTemplate: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_SESSION_ENUM_TEMPLATE0), enumHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmSessionEnum0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE, numEntriesRequested: UInt32, entries: POINTER(POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_SESSION0))), numEntriesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmSessionDestroyEnumHandle0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmTransactionBegin0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, flags: UInt32) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmTransactionCommit0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmTransactionAbort0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmProviderAdd0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, provider: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER0), sd: win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmProviderDeleteByKey0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, key: POINTER(Guid)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmProviderGetByKey0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, key: POINTER(Guid), provider: POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER0))) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmProviderCreateEnumHandle0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumTemplate: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_ENUM_TEMPLATE0), enumHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmProviderEnum0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE, numEntriesRequested: UInt32, entries: POINTER(POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER0))), numEntriesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmProviderDestroyEnumHandle0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmProviderGetSecurityInfoByKey0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, key: POINTER(Guid), securityInfo: UInt32, sidOwner: POINTER(win32more.Windows.Win32.Security.PSID), sidGroup: POINTER(win32more.Windows.Win32.Security.PSID), dacl: POINTER(POINTER(win32more.Windows.Win32.Security.ACL)), sacl: POINTER(POINTER(win32more.Windows.Win32.Security.ACL)), securityDescriptor: POINTER(win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmProviderSetSecurityInfoByKey0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, key: POINTER(Guid), securityInfo: UInt32, sidOwner: POINTER(win32more.Windows.Win32.Security.SID), sidGroup: POINTER(win32more.Windows.Win32.Security.SID), dacl: POINTER(win32more.Windows.Win32.Security.ACL), sacl: POINTER(win32more.Windows.Win32.Security.ACL)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmProviderSubscribeChanges0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, subscription: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_SUBSCRIPTION0), callback: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CHANGE_CALLBACK0, context: VoidPtr, changeHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmProviderUnsubscribeChanges0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, changeHandle: win32more.Windows.Win32.Foundation.HANDLE) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmProviderSubscriptionsGet0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, entries: POINTER(POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_SUBSCRIPTION0))), numEntries: POINTER(UInt32)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmProviderContextAdd0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, providerContext: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT0), sd: win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR, id: POINTER(UInt64)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmProviderContextAdd1(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, providerContext: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT1), sd: win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR, id: POINTER(UInt64)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmProviderContextAdd2(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, providerContext: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT2), sd: win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR, id: POINTER(UInt64)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmProviderContextAdd3(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, providerContext: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT3), sd: win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR, id: POINTER(UInt64)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmProviderContextDeleteById0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, id: UInt64) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmProviderContextDeleteByKey0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, key: POINTER(Guid)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmProviderContextGetById0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, id: UInt64, providerContext: POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT0))) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmProviderContextGetById1(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, id: UInt64, providerContext: POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT1))) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmProviderContextGetById2(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, id: UInt64, providerContext: POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT2))) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmProviderContextGetById3(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, id: UInt64, providerContext: POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT3))) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmProviderContextGetByKey0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, key: POINTER(Guid), providerContext: POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT0))) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmProviderContextGetByKey1(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, key: POINTER(Guid), providerContext: POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT1))) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmProviderContextGetByKey2(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, key: POINTER(Guid), providerContext: POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT2))) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmProviderContextGetByKey3(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, key: POINTER(Guid), providerContext: POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT3))) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmProviderContextCreateEnumHandle0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumTemplate: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT_ENUM_TEMPLATE0), enumHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmProviderContextEnum0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE, numEntriesRequested: UInt32, entries: POINTER(POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT0))), numEntriesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmProviderContextEnum1(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE, numEntriesRequested: UInt32, entries: POINTER(POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT1))), numEntriesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmProviderContextEnum2(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE, numEntriesRequested: UInt32, entries: POINTER(POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT2))), numEntriesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmProviderContextEnum3(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE, numEntriesRequested: UInt32, entries: POINTER(POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT3))), numEntriesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmProviderContextDestroyEnumHandle0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmProviderContextGetSecurityInfoByKey0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, key: POINTER(Guid), securityInfo: UInt32, sidOwner: POINTER(win32more.Windows.Win32.Security.PSID), sidGroup: POINTER(win32more.Windows.Win32.Security.PSID), dacl: POINTER(POINTER(win32more.Windows.Win32.Security.ACL)), sacl: POINTER(POINTER(win32more.Windows.Win32.Security.ACL)), securityDescriptor: POINTER(win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmProviderContextSetSecurityInfoByKey0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, key: POINTER(Guid), securityInfo: UInt32, sidOwner: POINTER(win32more.Windows.Win32.Security.SID), sidGroup: POINTER(win32more.Windows.Win32.Security.SID), dacl: POINTER(win32more.Windows.Win32.Security.ACL), sacl: POINTER(win32more.Windows.Win32.Security.ACL)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmProviderContextSubscribeChanges0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, subscription: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT_SUBSCRIPTION0), callback: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT_CHANGE_CALLBACK0, context: VoidPtr, changeHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmProviderContextUnsubscribeChanges0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, changeHandle: win32more.Windows.Win32.Foundation.HANDLE) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmProviderContextSubscriptionsGet0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, entries: POINTER(POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT_SUBSCRIPTION0))), numEntries: POINTER(UInt32)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmSubLayerAdd0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, subLayer: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_SUBLAYER0), sd: win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmSubLayerDeleteByKey0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, key: POINTER(Guid)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmSubLayerGetByKey0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, key: POINTER(Guid), subLayer: POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_SUBLAYER0))) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmSubLayerCreateEnumHandle0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumTemplate: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_SUBLAYER_ENUM_TEMPLATE0), enumHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmSubLayerEnum0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE, numEntriesRequested: UInt32, entries: POINTER(POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_SUBLAYER0))), numEntriesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmSubLayerDestroyEnumHandle0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmSubLayerGetSecurityInfoByKey0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, key: POINTER(Guid), securityInfo: UInt32, sidOwner: POINTER(win32more.Windows.Win32.Security.PSID), sidGroup: POINTER(win32more.Windows.Win32.Security.PSID), dacl: POINTER(POINTER(win32more.Windows.Win32.Security.ACL)), sacl: POINTER(POINTER(win32more.Windows.Win32.Security.ACL)), securityDescriptor: POINTER(win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmSubLayerSetSecurityInfoByKey0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, key: POINTER(Guid), securityInfo: UInt32, sidOwner: POINTER(win32more.Windows.Win32.Security.SID), sidGroup: POINTER(win32more.Windows.Win32.Security.SID), dacl: POINTER(win32more.Windows.Win32.Security.ACL), sacl: POINTER(win32more.Windows.Win32.Security.ACL)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmSubLayerSubscribeChanges0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, subscription: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_SUBLAYER_SUBSCRIPTION0), callback: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_SUBLAYER_CHANGE_CALLBACK0, context: VoidPtr, changeHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmSubLayerUnsubscribeChanges0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, changeHandle: win32more.Windows.Win32.Foundation.HANDLE) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmSubLayerSubscriptionsGet0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, entries: POINTER(POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_SUBLAYER_SUBSCRIPTION0))), numEntries: POINTER(UInt32)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmLayerGetById0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, id: UInt16, layer: POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_LAYER0))) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmLayerGetByKey0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, key: POINTER(Guid), layer: POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_LAYER0))) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmLayerCreateEnumHandle0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumTemplate: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_LAYER_ENUM_TEMPLATE0), enumHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmLayerEnum0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE, numEntriesRequested: UInt32, entries: POINTER(POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_LAYER0))), numEntriesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmLayerDestroyEnumHandle0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmLayerGetSecurityInfoByKey0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, key: POINTER(Guid), securityInfo: UInt32, sidOwner: POINTER(win32more.Windows.Win32.Security.PSID), sidGroup: POINTER(win32more.Windows.Win32.Security.PSID), dacl: POINTER(POINTER(win32more.Windows.Win32.Security.ACL)), sacl: POINTER(POINTER(win32more.Windows.Win32.Security.ACL)), securityDescriptor: POINTER(win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmLayerSetSecurityInfoByKey0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, key: POINTER(Guid), securityInfo: UInt32, sidOwner: POINTER(win32more.Windows.Win32.Security.SID), sidGroup: POINTER(win32more.Windows.Win32.Security.SID), dacl: POINTER(win32more.Windows.Win32.Security.ACL), sacl: POINTER(win32more.Windows.Win32.Security.ACL)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmCalloutAdd0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, callout: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_CALLOUT0), sd: win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR, id: POINTER(UInt32)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmCalloutDeleteById0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, id: UInt32) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmCalloutDeleteByKey0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, key: POINTER(Guid)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmCalloutGetById0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, id: UInt32, callout: POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_CALLOUT0))) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmCalloutGetByKey0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, key: POINTER(Guid), callout: POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_CALLOUT0))) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmCalloutCreateEnumHandle0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumTemplate: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_CALLOUT_ENUM_TEMPLATE0), enumHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmCalloutEnum0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE, numEntriesRequested: UInt32, entries: POINTER(POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_CALLOUT0))), numEntriesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmCalloutDestroyEnumHandle0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmCalloutGetSecurityInfoByKey0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, key: POINTER(Guid), securityInfo: UInt32, sidOwner: POINTER(win32more.Windows.Win32.Security.PSID), sidGroup: POINTER(win32more.Windows.Win32.Security.PSID), dacl: POINTER(POINTER(win32more.Windows.Win32.Security.ACL)), sacl: POINTER(POINTER(win32more.Windows.Win32.Security.ACL)), securityDescriptor: POINTER(win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmCalloutSetSecurityInfoByKey0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, key: POINTER(Guid), securityInfo: UInt32, sidOwner: POINTER(win32more.Windows.Win32.Security.SID), sidGroup: POINTER(win32more.Windows.Win32.Security.SID), dacl: POINTER(win32more.Windows.Win32.Security.ACL), sacl: POINTER(win32more.Windows.Win32.Security.ACL)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmCalloutSubscribeChanges0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, subscription: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_CALLOUT_SUBSCRIPTION0), callback: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_CALLOUT_CHANGE_CALLBACK0, context: VoidPtr, changeHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmCalloutUnsubscribeChanges0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, changeHandle: win32more.Windows.Win32.Foundation.HANDLE) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmCalloutSubscriptionsGet0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, entries: POINTER(POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_CALLOUT_SUBSCRIPTION0))), numEntries: POINTER(UInt32)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmFilterAdd0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, filter: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_FILTER0), sd: win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR, id: POINTER(UInt64)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmFilterDeleteById0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, id: UInt64) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmFilterDeleteByKey0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, key: POINTER(Guid)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmFilterGetById0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, id: UInt64, filter: POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_FILTER0))) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmFilterGetByKey0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, key: POINTER(Guid), filter: POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_FILTER0))) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmFilterCreateEnumHandle0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumTemplate: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_FILTER_ENUM_TEMPLATE0), enumHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmFilterEnum0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE, numEntriesRequested: UInt32, entries: POINTER(POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_FILTER0))), numEntriesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmFilterDestroyEnumHandle0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmFilterGetSecurityInfoByKey0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, key: POINTER(Guid), securityInfo: UInt32, sidOwner: POINTER(win32more.Windows.Win32.Security.PSID), sidGroup: POINTER(win32more.Windows.Win32.Security.PSID), dacl: POINTER(POINTER(win32more.Windows.Win32.Security.ACL)), sacl: POINTER(POINTER(win32more.Windows.Win32.Security.ACL)), securityDescriptor: POINTER(win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmFilterSetSecurityInfoByKey0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, key: POINTER(Guid), securityInfo: UInt32, sidOwner: POINTER(win32more.Windows.Win32.Security.SID), sidGroup: POINTER(win32more.Windows.Win32.Security.SID), dacl: POINTER(win32more.Windows.Win32.Security.ACL), sacl: POINTER(win32more.Windows.Win32.Security.ACL)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmFilterSubscribeChanges0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, subscription: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_FILTER_SUBSCRIPTION0), callback: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_FILTER_CHANGE_CALLBACK0, context: VoidPtr, changeHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmFilterUnsubscribeChanges0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, changeHandle: win32more.Windows.Win32.Foundation.HANDLE) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmFilterSubscriptionsGet0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, entries: POINTER(POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_FILTER_SUBSCRIPTION0))), numEntries: POINTER(UInt32)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmGetAppIdFromFileName0(fileName: win32more.Windows.Win32.Foundation.PWSTR, appId: POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB))) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmIPsecTunnelAdd0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, flags: UInt32, mainModePolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT0), tunnelPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT0), numFilterConditions: UInt32, filterConditions: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_FILTER_CONDITION0), sd: win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmIPsecTunnelAdd1(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, flags: UInt32, mainModePolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT1), tunnelPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT1), numFilterConditions: UInt32, filterConditions: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_FILTER_CONDITION0), keyModKey: POINTER(Guid), sd: win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmIPsecTunnelAdd2(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, flags: UInt32, mainModePolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT2), tunnelPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT2), numFilterConditions: UInt32, filterConditions: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_FILTER_CONDITION0), keyModKey: POINTER(Guid), sd: win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmIPsecTunnelAdd3(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, flags: UInt32, mainModePolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT3), tunnelPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT3), numFilterConditions: UInt32, filterConditions: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_FILTER_CONDITION0), keyModKey: POINTER(Guid), sd: win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmIPsecTunnelDeleteByKey0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, key: POINTER(Guid)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecGetStatistics0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, ipsecStatistics: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_STATISTICS0)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecGetStatistics1(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, ipsecStatistics: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_STATISTICS1)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecSaContextCreate0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, outboundTraffic: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRAFFIC0), inboundFilterId: POINTER(UInt64), id: POINTER(UInt64)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecSaContextCreate1(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, outboundTraffic: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRAFFIC1), virtualIfTunnelInfo: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_VIRTUAL_IF_TUNNEL_INFO0), inboundFilterId: POINTER(UInt64), id: POINTER(UInt64)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecSaContextDeleteById0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, id: UInt64) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecSaContextGetById0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, id: UInt64, saContext: POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_CONTEXT0))) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecSaContextGetById1(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, id: UInt64, saContext: POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_CONTEXT1))) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecSaContextGetSpi0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, id: UInt64, getSpi: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_GETSPI0), inboundSpi: POINTER(UInt32)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecSaContextGetSpi1(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, id: UInt64, getSpi: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_GETSPI1), inboundSpi: POINTER(UInt32)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecSaContextSetSpi0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, id: UInt64, getSpi: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_GETSPI1), inboundSpi: UInt32) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecSaContextAddInbound0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, id: UInt64, inboundBundle: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_BUNDLE0)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecSaContextAddOutbound0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, id: UInt64, outboundBundle: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_BUNDLE0)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecSaContextAddInbound1(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, id: UInt64, inboundBundle: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_BUNDLE1)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecSaContextAddOutbound1(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, id: UInt64, outboundBundle: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_BUNDLE1)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecSaContextExpire0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, id: UInt64) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecSaContextUpdate0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, flags: UInt64, newValues: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_CONTEXT1)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecSaContextCreateEnumHandle0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumTemplate: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_CONTEXT_ENUM_TEMPLATE0), enumHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecSaContextEnum0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE, numEntriesRequested: UInt32, entries: POINTER(POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_CONTEXT0))), numEntriesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecSaContextEnum1(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE, numEntriesRequested: UInt32, entries: POINTER(POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_CONTEXT1))), numEntriesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecSaContextDestroyEnumHandle0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecSaContextSubscribe0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, subscription: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_CONTEXT_SUBSCRIPTION0), callback: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_CONTEXT_CALLBACK0, context: VoidPtr, eventsHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecSaContextUnsubscribe0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, eventsHandle: win32more.Windows.Win32.Foundation.HANDLE) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecSaContextSubscriptionsGet0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, entries: POINTER(POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_CONTEXT_SUBSCRIPTION0))), numEntries: POINTER(UInt32)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecSaCreateEnumHandle0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumTemplate: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_ENUM_TEMPLATE0), enumHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecSaEnum0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE, numEntriesRequested: UInt32, entries: POINTER(POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_DETAILS0))), numEntriesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecSaEnum1(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE, numEntriesRequested: UInt32, entries: POINTER(POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_DETAILS1))), numEntriesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecSaDestroyEnumHandle0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecSaDbGetSecurityInfo0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, securityInfo: UInt32, sidOwner: POINTER(win32more.Windows.Win32.Security.PSID), sidGroup: POINTER(win32more.Windows.Win32.Security.PSID), dacl: POINTER(POINTER(win32more.Windows.Win32.Security.ACL)), sacl: POINTER(POINTER(win32more.Windows.Win32.Security.ACL)), securityDescriptor: POINTER(win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecSaDbSetSecurityInfo0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, securityInfo: UInt32, sidOwner: POINTER(win32more.Windows.Win32.Security.SID), sidGroup: POINTER(win32more.Windows.Win32.Security.SID), dacl: POINTER(win32more.Windows.Win32.Security.ACL), sacl: POINTER(win32more.Windows.Win32.Security.ACL)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecDospGetStatistics0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, idpStatistics: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_DOSP_STATISTICS0)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecDospStateCreateEnumHandle0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumTemplate: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_DOSP_STATE_ENUM_TEMPLATE0), enumHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecDospStateEnum0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE, numEntriesRequested: UInt32, entries: POINTER(POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_DOSP_STATE0))), numEntries: POINTER(UInt32)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecDospStateDestroyEnumHandle0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecDospGetSecurityInfo0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, securityInfo: UInt32, sidOwner: POINTER(win32more.Windows.Win32.Security.PSID), sidGroup: POINTER(win32more.Windows.Win32.Security.PSID), dacl: POINTER(POINTER(win32more.Windows.Win32.Security.ACL)), sacl: POINTER(POINTER(win32more.Windows.Win32.Security.ACL)), securityDescriptor: POINTER(win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecDospSetSecurityInfo0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, securityInfo: UInt32, sidOwner: POINTER(win32more.Windows.Win32.Security.SID), sidGroup: POINTER(win32more.Windows.Win32.Security.SID), dacl: POINTER(win32more.Windows.Win32.Security.ACL), sacl: POINTER(win32more.Windows.Win32.Security.ACL)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecKeyManagerAddAndRegister0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, keyManager: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_KEY_MANAGER0), keyManagerCallbacks: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_KEY_MANAGER_CALLBACKS0), keyMgmtHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecKeyManagerUnregisterAndDelete0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, keyMgmtHandle: win32more.Windows.Win32.Foundation.HANDLE) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecKeyManagersGet0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, entries: POINTER(POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_KEY_MANAGER0))), numEntries: POINTER(UInt32)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecKeyManagerGetSecurityInfoByKey0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, reserved: VoidPtr, securityInfo: UInt32, sidOwner: POINTER(win32more.Windows.Win32.Security.PSID), sidGroup: POINTER(win32more.Windows.Win32.Security.PSID), dacl: POINTER(POINTER(win32more.Windows.Win32.Security.ACL)), sacl: POINTER(POINTER(win32more.Windows.Win32.Security.ACL)), securityDescriptor: POINTER(win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IPsecKeyManagerSetSecurityInfoByKey0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, reserved: VoidPtr, securityInfo: UInt32, sidOwner: POINTER(win32more.Windows.Win32.Security.SID), sidGroup: POINTER(win32more.Windows.Win32.Security.SID), dacl: POINTER(win32more.Windows.Win32.Security.ACL), sacl: POINTER(win32more.Windows.Win32.Security.ACL)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IkeextGetStatistics0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, ikeextStatistics: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_STATISTICS0)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IkeextGetStatistics1(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, ikeextStatistics: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_STATISTICS1)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IkeextSaDeleteById0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, id: UInt64) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IkeextSaGetById0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, id: UInt64, sa: POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_SA_DETAILS0))) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IkeextSaGetById1(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, id: UInt64, saLookupContext: POINTER(Guid), sa: POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_SA_DETAILS1))) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IkeextSaGetById2(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, id: UInt64, saLookupContext: POINTER(Guid), sa: POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_SA_DETAILS2))) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IkeextSaCreateEnumHandle0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumTemplate: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_SA_ENUM_TEMPLATE0), enumHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IkeextSaEnum0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE, numEntriesRequested: UInt32, entries: POINTER(POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_SA_DETAILS0))), numEntriesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IkeextSaEnum1(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE, numEntriesRequested: UInt32, entries: POINTER(POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_SA_DETAILS1))), numEntriesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IkeextSaEnum2(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE, numEntriesRequested: UInt32, entries: POINTER(POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_SA_DETAILS2))), numEntriesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IkeextSaDestroyEnumHandle0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IkeextSaDbGetSecurityInfo0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, securityInfo: UInt32, sidOwner: POINTER(win32more.Windows.Win32.Security.PSID), sidGroup: POINTER(win32more.Windows.Win32.Security.PSID), dacl: POINTER(POINTER(win32more.Windows.Win32.Security.ACL)), sacl: POINTER(POINTER(win32more.Windows.Win32.Security.ACL)), securityDescriptor: POINTER(win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def IkeextSaDbSetSecurityInfo0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, securityInfo: UInt32, sidOwner: POINTER(win32more.Windows.Win32.Security.SID), sidGroup: POINTER(win32more.Windows.Win32.Security.SID), dacl: POINTER(win32more.Windows.Win32.Security.ACL), sacl: POINTER(win32more.Windows.Win32.Security.ACL)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmNetEventCreateEnumHandle0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumTemplate: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_ENUM_TEMPLATE0), enumHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmNetEventEnum0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE, numEntriesRequested: UInt32, entries: POINTER(POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT0))), numEntriesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmNetEventEnum1(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE, numEntriesRequested: UInt32, entries: POINTER(POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT1))), numEntriesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmNetEventEnum2(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE, numEntriesRequested: UInt32, entries: POINTER(POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT2))), numEntriesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmNetEventEnum3(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE, numEntriesRequested: UInt32, entries: POINTER(POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT3))), numEntriesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmNetEventEnum4(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE, numEntriesRequested: UInt32, entries: POINTER(POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT4))), numEntriesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmNetEventEnum5(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE, numEntriesRequested: UInt32, entries: POINTER(POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT5))), numEntriesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmNetEventDestroyEnumHandle0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmNetEventsGetSecurityInfo0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, securityInfo: UInt32, sidOwner: POINTER(win32more.Windows.Win32.Security.PSID), sidGroup: POINTER(win32more.Windows.Win32.Security.PSID), dacl: POINTER(POINTER(win32more.Windows.Win32.Security.ACL)), sacl: POINTER(POINTER(win32more.Windows.Win32.Security.ACL)), securityDescriptor: POINTER(win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmNetEventsSetSecurityInfo0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, securityInfo: UInt32, sidOwner: POINTER(win32more.Windows.Win32.Security.SID), sidGroup: POINTER(win32more.Windows.Win32.Security.SID), dacl: POINTER(win32more.Windows.Win32.Security.ACL), sacl: POINTER(win32more.Windows.Win32.Security.ACL)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmNetEventSubscribe0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, subscription: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_SUBSCRIPTION0), callback: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_CALLBACK0, context: VoidPtr, eventsHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmNetEventUnsubscribe0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, eventsHandle: win32more.Windows.Win32.Foundation.HANDLE) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmNetEventSubscriptionsGet0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, entries: POINTER(POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_SUBSCRIPTION0))), numEntries: POINTER(UInt32)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmNetEventSubscribe1(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, subscription: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_SUBSCRIPTION0), callback: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_CALLBACK1, context: VoidPtr, eventsHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmNetEventSubscribe2(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, subscription: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_SUBSCRIPTION0), callback: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_CALLBACK2, context: VoidPtr, eventsHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmNetEventSubscribe3(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, subscription: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_SUBSCRIPTION0), callback: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_CALLBACK3, context: VoidPtr, eventsHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmNetEventSubscribe4(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, subscription: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_SUBSCRIPTION0), callback: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_CALLBACK4, context: VoidPtr, eventsHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmDynamicKeywordSubscribe0(flags: UInt32, callback: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_DYNAMIC_KEYWORD_CALLBACK0, context: VoidPtr, subscriptionHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmDynamicKeywordUnsubscribe0(subscriptionHandle: win32more.Windows.Win32.Foundation.HANDLE) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmSystemPortsGet0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, sysPorts: POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_SYSTEM_PORTS0))) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmSystemPortsSubscribe0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, reserved: VoidPtr, callback: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_SYSTEM_PORTS_CALLBACK0, context: VoidPtr, sysPortsHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmSystemPortsUnsubscribe0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, sysPortsHandle: win32more.Windows.Win32.Foundation.HANDLE) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmConnectionGetById0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, id: UInt64, connection: POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_CONNECTION0))) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmConnectionEnum0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE, numEntriesRequested: UInt32, entries: POINTER(POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_CONNECTION0))), numEntriesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmConnectionCreateEnumHandle0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumTemplate: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_CONNECTION_ENUM_TEMPLATE0), enumHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmConnectionDestroyEnumHandle0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, enumHandle: win32more.Windows.Win32.Foundation.HANDLE) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmConnectionGetSecurityInfo0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, securityInfo: UInt32, sidOwner: POINTER(win32more.Windows.Win32.Security.PSID), sidGroup: POINTER(win32more.Windows.Win32.Security.PSID), dacl: POINTER(POINTER(win32more.Windows.Win32.Security.ACL)), sacl: POINTER(POINTER(win32more.Windows.Win32.Security.ACL)), securityDescriptor: POINTER(win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmConnectionSetSecurityInfo0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, securityInfo: UInt32, sidOwner: POINTER(win32more.Windows.Win32.Security.SID), sidGroup: POINTER(win32more.Windows.Win32.Security.SID), dacl: POINTER(win32more.Windows.Win32.Security.ACL), sacl: POINTER(win32more.Windows.Win32.Security.ACL)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmConnectionSubscribe0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, subscription: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_CONNECTION_SUBSCRIPTION0), callback: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_CONNECTION_CALLBACK0, context: VoidPtr, eventsHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmConnectionUnsubscribe0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, eventsHandle: win32more.Windows.Win32.Foundation.HANDLE) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmvSwitchEventSubscribe0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, subscription: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_VSWITCH_EVENT_SUBSCRIPTION0), callback: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_VSWITCH_EVENT_CALLBACK0, context: VoidPtr, subscriptionHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmvSwitchEventUnsubscribe0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, subscriptionHandle: win32more.Windows.Win32.Foundation.HANDLE) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmvSwitchEventsGetSecurityInfo0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, securityInfo: UInt32, sidOwner: POINTER(win32more.Windows.Win32.Security.PSID), sidGroup: POINTER(win32more.Windows.Win32.Security.PSID), dacl: POINTER(POINTER(win32more.Windows.Win32.Security.ACL)), sacl: POINTER(POINTER(win32more.Windows.Win32.Security.ACL)), securityDescriptor: POINTER(win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR)) -> UInt32: ...
@winfunctype('fwpuclnt.dll')
def FwpmvSwitchEventsSetSecurityInfo0(engineHandle: win32more.Windows.Win32.Foundation.HANDLE, securityInfo: UInt32, sidOwner: POINTER(win32more.Windows.Win32.Security.SID), sidGroup: POINTER(win32more.Windows.Win32.Security.SID), dacl: POINTER(win32more.Windows.Win32.Security.ACL), sacl: POINTER(win32more.Windows.Win32.Security.ACL)) -> UInt32: ...
DL_ADDRESS_TYPE = Int32
DlUnicast: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.DL_ADDRESS_TYPE = 0
DlMulticast: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.DL_ADDRESS_TYPE = 1
DlBroadcast: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.DL_ADDRESS_TYPE = 2
class FWPM_ACTION0(Structure):
    type: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_ACTION_TYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        filterType: Guid
        calloutKey: Guid
FWPM_APPC_NETWORK_CAPABILITY_TYPE = Int32
FWPM_APPC_NETWORK_CAPABILITY_INTERNET_CLIENT: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_APPC_NETWORK_CAPABILITY_TYPE = 0
FWPM_APPC_NETWORK_CAPABILITY_INTERNET_CLIENT_SERVER: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_APPC_NETWORK_CAPABILITY_TYPE = 1
FWPM_APPC_NETWORK_CAPABILITY_INTERNET_PRIVATE_NETWORK: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_APPC_NETWORK_CAPABILITY_TYPE = 2
class FWPM_CALLOUT0(Structure):
    calloutKey: Guid
    displayData: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_DISPLAY_DATA0
    flags: UInt32
    providerKey: POINTER(Guid)
    providerData: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB
    applicableLayer: Guid
    calloutId: UInt32
class FWPM_CALLOUT_CHANGE0(Structure):
    changeType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_CHANGE_TYPE
    calloutKey: Guid
    calloutId: UInt32
@winfunctype_pointer
def FWPM_CALLOUT_CHANGE_CALLBACK0(context: VoidPtr, change: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_CALLOUT_CHANGE0)) -> Void: ...
class FWPM_CALLOUT_ENUM_TEMPLATE0(Structure):
    providerKey: POINTER(Guid)
    layerKey: Guid
class FWPM_CALLOUT_SUBSCRIPTION0(Structure):
    enumTemplate: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_CALLOUT_ENUM_TEMPLATE0)
    flags: UInt32
    sessionKey: Guid
FWPM_CHANGE_TYPE = Int32
FWPM_CHANGE_ADD: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_CHANGE_TYPE = 1
FWPM_CHANGE_DELETE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_CHANGE_TYPE = 2
FWPM_CHANGE_TYPE_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_CHANGE_TYPE = 3
class FWPM_CLASSIFY_OPTION0(Structure):
    type: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_CLASSIFY_OPTION_TYPE
    value: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_VALUE0
class FWPM_CLASSIFY_OPTIONS0(Structure):
    numOptions: UInt32
    options: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_CLASSIFY_OPTION0)
class FWPM_CONNECTION0(Structure):
    connectionId: UInt64
    ipVersion: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_IP_VERSION
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    providerKey: POINTER(Guid)
    ipsecTrafficModeType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRAFFIC_TYPE
    keyModuleType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_KEY_MODULE_TYPE
    mmCrypto: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_PROPOSAL0
    mmPeer: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CREDENTIAL2
    emPeer: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CREDENTIAL2
    bytesTransferredIn: UInt64
    bytesTransferredOut: UInt64
    bytesTransferredTotal: UInt64
    startSysTime: win32more.Windows.Win32.Foundation.FILETIME
    class _Anonymous1_e__Union(Union):
        localV4Address: UInt32
        localV6Address: Byte * 16
    class _Anonymous2_e__Union(Union):
        remoteV4Address: UInt32
        remoteV6Address: Byte * 16
@winfunctype_pointer
def FWPM_CONNECTION_CALLBACK0(context: VoidPtr, eventType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_CONNECTION_EVENT_TYPE, connection: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_CONNECTION0)) -> Void: ...
class FWPM_CONNECTION_ENUM_TEMPLATE0(Structure):
    connectionId: UInt64
    flags: UInt32
FWPM_CONNECTION_EVENT_TYPE = Int32
FWPM_CONNECTION_EVENT_ADD: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_CONNECTION_EVENT_TYPE = 0
FWPM_CONNECTION_EVENT_DELETE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_CONNECTION_EVENT_TYPE = 1
FWPM_CONNECTION_EVENT_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_CONNECTION_EVENT_TYPE = 2
class FWPM_CONNECTION_SUBSCRIPTION0(Structure):
    enumTemplate: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_CONNECTION_ENUM_TEMPLATE0)
    flags: UInt32
    sessionKey: Guid
class FWPM_DISPLAY_DATA0(Structure):
    name: win32more.Windows.Win32.Foundation.PWSTR
    description: win32more.Windows.Win32.Foundation.PWSTR
@winfunctype_pointer
def FWPM_DYNAMIC_KEYWORD_CALLBACK0(notification: VoidPtr, context: VoidPtr) -> Void: ...
FWPM_ENGINE_OPTION = Int32
FWPM_ENGINE_COLLECT_NET_EVENTS: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_ENGINE_OPTION = 0
FWPM_ENGINE_NET_EVENT_MATCH_ANY_KEYWORDS: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_ENGINE_OPTION = 1
FWPM_ENGINE_NAME_CACHE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_ENGINE_OPTION = 2
FWPM_ENGINE_MONITOR_IPSEC_CONNECTIONS: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_ENGINE_OPTION = 3
FWPM_ENGINE_PACKET_QUEUING: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_ENGINE_OPTION = 4
FWPM_ENGINE_TXN_WATCHDOG_TIMEOUT_IN_MSEC: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_ENGINE_OPTION = 5
FWPM_ENGINE_OPTION_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_ENGINE_OPTION = 6
class FWPM_FIELD0(Structure):
    fieldKey: POINTER(Guid)
    type: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_FIELD_TYPE
    dataType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_DATA_TYPE
FWPM_FIELD_TYPE = Int32
FWPM_FIELD_RAW_DATA: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_FIELD_TYPE = 0
FWPM_FIELD_IP_ADDRESS: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_FIELD_TYPE = 1
FWPM_FIELD_FLAGS: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_FIELD_TYPE = 2
FWPM_FIELD_TYPE_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_FIELD_TYPE = 3
class FWPM_FILTER0(Structure):
    filterKey: Guid
    displayData: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_DISPLAY_DATA0
    flags: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_FILTER_FLAGS
    providerKey: POINTER(Guid)
    providerData: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB
    layerKey: Guid
    subLayerKey: Guid
    weight: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_VALUE0
    numFilterConditions: UInt32
    filterCondition: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_FILTER_CONDITION0)
    action: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_ACTION0
    Anonymous: _Anonymous_e__Union
    reserved: POINTER(Guid)
    filterId: UInt64
    effectiveWeight: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_VALUE0
    class _Anonymous_e__Union(Union):
        rawContext: UInt64
        providerContextKey: Guid
class FWPM_FILTER_CHANGE0(Structure):
    changeType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_CHANGE_TYPE
    filterKey: Guid
    filterId: UInt64
@winfunctype_pointer
def FWPM_FILTER_CHANGE_CALLBACK0(context: VoidPtr, change: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_FILTER_CHANGE0)) -> Void: ...
class FWPM_FILTER_CONDITION0(Structure):
    fieldKey: Guid
    matchType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_MATCH_TYPE
    conditionValue: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_CONDITION_VALUE0
class FWPM_FILTER_ENUM_TEMPLATE0(Structure):
    providerKey: POINTER(Guid)
    layerKey: Guid
    enumType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_FILTER_ENUM_TYPE
    flags: UInt32
    providerContextTemplate: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT_ENUM_TEMPLATE0)
    numFilterConditions: UInt32
    filterCondition: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_FILTER_CONDITION0)
    actionMask: UInt32
    calloutKey: POINTER(Guid)
FWPM_FILTER_FLAGS = UInt32
FWPM_FILTER_FLAG_NONE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_FILTER_FLAGS = 0
FWPM_FILTER_FLAG_PERSISTENT: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_FILTER_FLAGS = 1
FWPM_FILTER_FLAG_BOOTTIME: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_FILTER_FLAGS = 2
FWPM_FILTER_FLAG_HAS_PROVIDER_CONTEXT: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_FILTER_FLAGS = 4
FWPM_FILTER_FLAG_CLEAR_ACTION_RIGHT: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_FILTER_FLAGS = 8
FWPM_FILTER_FLAG_PERMIT_IF_CALLOUT_UNREGISTERED: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_FILTER_FLAGS = 16
FWPM_FILTER_FLAG_DISABLED: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_FILTER_FLAGS = 32
FWPM_FILTER_FLAG_INDEXED: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_FILTER_FLAGS = 64
class FWPM_FILTER_SUBSCRIPTION0(Structure):
    enumTemplate: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_FILTER_ENUM_TEMPLATE0)
    flags: UInt32
    sessionKey: Guid
class FWPM_LAYER0(Structure):
    layerKey: Guid
    displayData: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_DISPLAY_DATA0
    flags: UInt32
    numFields: UInt32
    field: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_FIELD0)
    defaultSubLayerKey: Guid
    layerId: UInt16
class FWPM_LAYER_ENUM_TEMPLATE0(Structure):
    reserved: UInt64
class FWPM_LAYER_STATISTICS0(Structure):
    layerId: Guid
    classifyPermitCount: UInt32
    classifyBlockCount: UInt32
    classifyVetoCount: UInt32
    numCacheEntries: UInt32
class FWPM_NETWORK_CONNECTION_POLICY_SETTING0(Structure):
    type: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_NETWORK_CONNECTION_POLICY_SETTING_TYPE
    value: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_VALUE0
class FWPM_NETWORK_CONNECTION_POLICY_SETTINGS0(Structure):
    numSettings: UInt32
    settings: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NETWORK_CONNECTION_POLICY_SETTING0)
class FWPM_NET_EVENT0(Structure):
    header: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_HEADER0
    type: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_TYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        ikeMmFailure: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_IKEEXT_MM_FAILURE0)
        ikeQmFailure: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_IKEEXT_QM_FAILURE0)
        ikeEmFailure: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_IKEEXT_EM_FAILURE0)
        classifyDrop: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_CLASSIFY_DROP0)
        ipsecDrop: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_IPSEC_KERNEL_DROP0)
        idpDrop: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_IPSEC_DOSP_DROP0)
class FWPM_NET_EVENT1(Structure):
    header: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_HEADER1
    type: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_TYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        ikeMmFailure: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_IKEEXT_MM_FAILURE1)
        ikeQmFailure: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_IKEEXT_QM_FAILURE0)
        ikeEmFailure: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_IKEEXT_EM_FAILURE1)
        classifyDrop: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_CLASSIFY_DROP1)
        ipsecDrop: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_IPSEC_KERNEL_DROP0)
        idpDrop: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_IPSEC_DOSP_DROP0)
class FWPM_NET_EVENT2(Structure):
    header: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_HEADER2
    type: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_TYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        ikeMmFailure: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_IKEEXT_MM_FAILURE1)
        ikeQmFailure: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_IKEEXT_QM_FAILURE0)
        ikeEmFailure: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_IKEEXT_EM_FAILURE1)
        classifyDrop: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_CLASSIFY_DROP2)
        ipsecDrop: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_IPSEC_KERNEL_DROP0)
        idpDrop: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_IPSEC_DOSP_DROP0)
        classifyAllow: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_CLASSIFY_ALLOW0)
        capabilityDrop: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_CAPABILITY_DROP0)
        capabilityAllow: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_CAPABILITY_ALLOW0)
        classifyDropMac: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_CLASSIFY_DROP_MAC0)
class FWPM_NET_EVENT3(Structure):
    header: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_HEADER3
    type: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_TYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        ikeMmFailure: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_IKEEXT_MM_FAILURE1)
        ikeQmFailure: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_IKEEXT_QM_FAILURE0)
        ikeEmFailure: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_IKEEXT_EM_FAILURE1)
        classifyDrop: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_CLASSIFY_DROP2)
        ipsecDrop: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_IPSEC_KERNEL_DROP0)
        idpDrop: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_IPSEC_DOSP_DROP0)
        classifyAllow: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_CLASSIFY_ALLOW0)
        capabilityDrop: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_CAPABILITY_DROP0)
        capabilityAllow: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_CAPABILITY_ALLOW0)
        classifyDropMac: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_CLASSIFY_DROP_MAC0)
class FWPM_NET_EVENT4(Structure):
    header: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_HEADER3
    type: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_TYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        ikeMmFailure: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_IKEEXT_MM_FAILURE2)
        ikeQmFailure: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_IKEEXT_QM_FAILURE1)
        ikeEmFailure: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_IKEEXT_EM_FAILURE1)
        classifyDrop: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_CLASSIFY_DROP2)
        ipsecDrop: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_IPSEC_KERNEL_DROP0)
        idpDrop: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_IPSEC_DOSP_DROP0)
        classifyAllow: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_CLASSIFY_ALLOW0)
        capabilityDrop: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_CAPABILITY_DROP0)
        capabilityAllow: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_CAPABILITY_ALLOW0)
        classifyDropMac: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_CLASSIFY_DROP_MAC0)
class FWPM_NET_EVENT5(Structure):
    header: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_HEADER3
    type: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_TYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        ikeMmFailure: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_IKEEXT_MM_FAILURE2)
        ikeQmFailure: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_IKEEXT_QM_FAILURE1)
        ikeEmFailure: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_IKEEXT_EM_FAILURE1)
        classifyDrop: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_CLASSIFY_DROP2)
        ipsecDrop: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_IPSEC_KERNEL_DROP0)
        idpDrop: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_IPSEC_DOSP_DROP0)
        classifyAllow: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_CLASSIFY_ALLOW0)
        capabilityDrop: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_CAPABILITY_DROP0)
        capabilityAllow: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_CAPABILITY_ALLOW0)
        classifyDropMac: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_CLASSIFY_DROP_MAC0)
        lpmPacketArrival: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_LPM_PACKET_ARRIVAL0)
@winfunctype_pointer
def FWPM_NET_EVENT_CALLBACK0(context: VoidPtr, event: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT1)) -> Void: ...
@winfunctype_pointer
def FWPM_NET_EVENT_CALLBACK1(context: VoidPtr, event: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT2)) -> Void: ...
@winfunctype_pointer
def FWPM_NET_EVENT_CALLBACK2(context: VoidPtr, event: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT3)) -> Void: ...
@winfunctype_pointer
def FWPM_NET_EVENT_CALLBACK3(context: VoidPtr, event: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT4)) -> Void: ...
@winfunctype_pointer
def FWPM_NET_EVENT_CALLBACK4(context: VoidPtr, event: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT5)) -> Void: ...
class FWPM_NET_EVENT_CAPABILITY_ALLOW0(Structure):
    networkCapabilityId: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_APPC_NETWORK_CAPABILITY_TYPE
    filterId: UInt64
    isLoopback: win32more.Windows.Win32.Foundation.BOOL
class FWPM_NET_EVENT_CAPABILITY_DROP0(Structure):
    networkCapabilityId: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_APPC_NETWORK_CAPABILITY_TYPE
    filterId: UInt64
    isLoopback: win32more.Windows.Win32.Foundation.BOOL
class FWPM_NET_EVENT_CLASSIFY_ALLOW0(Structure):
    filterId: UInt64
    layerId: UInt16
    reauthReason: UInt32
    originalProfile: UInt32
    currentProfile: UInt32
    msFwpDirection: UInt32
    isLoopback: win32more.Windows.Win32.Foundation.BOOL
class FWPM_NET_EVENT_CLASSIFY_DROP0(Structure):
    filterId: UInt64
    layerId: UInt16
class FWPM_NET_EVENT_CLASSIFY_DROP1(Structure):
    filterId: UInt64
    layerId: UInt16
    reauthReason: UInt32
    originalProfile: UInt32
    currentProfile: UInt32
    msFwpDirection: UInt32
    isLoopback: win32more.Windows.Win32.Foundation.BOOL
class FWPM_NET_EVENT_CLASSIFY_DROP2(Structure):
    filterId: UInt64
    layerId: UInt16
    reauthReason: UInt32
    originalProfile: UInt32
    currentProfile: UInt32
    msFwpDirection: UInt32
    isLoopback: win32more.Windows.Win32.Foundation.BOOL
    vSwitchId: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB
    vSwitchSourcePort: UInt32
    vSwitchDestinationPort: UInt32
class FWPM_NET_EVENT_CLASSIFY_DROP_MAC0(Structure):
    localMacAddr: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_ARRAY6
    remoteMacAddr: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_ARRAY6
    mediaType: UInt32
    ifType: UInt32
    etherType: UInt16
    ndisPortNumber: UInt32
    reserved: UInt32
    vlanTag: UInt16
    ifLuid: UInt64
    filterId: UInt64
    layerId: UInt16
    reauthReason: UInt32
    originalProfile: UInt32
    currentProfile: UInt32
    msFwpDirection: UInt32
    isLoopback: win32more.Windows.Win32.Foundation.BOOL
    vSwitchId: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB
    vSwitchSourcePort: UInt32
    vSwitchDestinationPort: UInt32
class FWPM_NET_EVENT_ENUM_TEMPLATE0(Structure):
    startTime: win32more.Windows.Win32.Foundation.FILETIME
    endTime: win32more.Windows.Win32.Foundation.FILETIME
    numFilterConditions: UInt32
    filterCondition: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_FILTER_CONDITION0)
class FWPM_NET_EVENT_HEADER0(Structure):
    timeStamp: win32more.Windows.Win32.Foundation.FILETIME
    flags: UInt32
    ipVersion: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_IP_VERSION
    ipProtocol: Byte
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    localPort: UInt16
    remotePort: UInt16
    scopeId: UInt32
    appId: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB
    userId: POINTER(win32more.Windows.Win32.Security.SID)
    class _Anonymous1_e__Union(Union):
        localAddrV4: UInt32
        localAddrV6: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_ARRAY16
    class _Anonymous2_e__Union(Union):
        remoteAddrV4: UInt32
        remoteAddrV6: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_ARRAY16
class FWPM_NET_EVENT_HEADER1(Structure):
    timeStamp: win32more.Windows.Win32.Foundation.FILETIME
    flags: UInt32
    ipVersion: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_IP_VERSION
    ipProtocol: Byte
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    localPort: UInt16
    remotePort: UInt16
    scopeId: UInt32
    appId: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB
    userId: POINTER(win32more.Windows.Win32.Security.SID)
    Anonymous3: _Anonymous3_e__Union
    class _Anonymous1_e__Union(Union):
        localAddrV4: UInt32
        localAddrV6: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_ARRAY16
    class _Anonymous2_e__Union(Union):
        remoteAddrV4: UInt32
        remoteAddrV6: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_ARRAY16
    class _Anonymous3_e__Union(Union):
        Anonymous: _Anonymous_e__Struct
        class _Anonymous_e__Struct(Structure):
            reserved1: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_AF
            Anonymous: _Anonymous_e__Union
            class _Anonymous_e__Union(Union):
                Anonymous: _Anonymous_e__Struct
                class _Anonymous_e__Struct(Structure):
                    reserved2: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_ARRAY6
                    reserved3: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_ARRAY6
                    reserved4: UInt32
                    reserved5: UInt32
                    reserved6: UInt16
                    reserved7: UInt32
                    reserved8: UInt32
                    reserved9: UInt16
                    reserved10: UInt64
class FWPM_NET_EVENT_HEADER2(Structure):
    timeStamp: win32more.Windows.Win32.Foundation.FILETIME
    flags: UInt32
    ipVersion: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_IP_VERSION
    ipProtocol: Byte
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    localPort: UInt16
    remotePort: UInt16
    scopeId: UInt32
    appId: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB
    userId: POINTER(win32more.Windows.Win32.Security.SID)
    addressFamily: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_AF
    packageSid: POINTER(win32more.Windows.Win32.Security.SID)
    class _Anonymous1_e__Union(Union):
        localAddrV4: UInt32
        localAddrV6: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_ARRAY16
    class _Anonymous2_e__Union(Union):
        remoteAddrV4: UInt32
        remoteAddrV6: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_ARRAY16
class FWPM_NET_EVENT_HEADER3(Structure):
    timeStamp: win32more.Windows.Win32.Foundation.FILETIME
    flags: UInt32
    ipVersion: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_IP_VERSION
    ipProtocol: Byte
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    localPort: UInt16
    remotePort: UInt16
    scopeId: UInt32
    appId: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB
    userId: POINTER(win32more.Windows.Win32.Security.SID)
    addressFamily: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_AF
    packageSid: POINTER(win32more.Windows.Win32.Security.SID)
    enterpriseId: win32more.Windows.Win32.Foundation.PWSTR
    policyFlags: UInt64
    effectiveName: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB
    class _Anonymous1_e__Union(Union):
        localAddrV4: UInt32
        localAddrV6: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_ARRAY16
    class _Anonymous2_e__Union(Union):
        remoteAddrV4: UInt32
        remoteAddrV6: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_ARRAY16
class FWPM_NET_EVENT_IKEEXT_EM_FAILURE0(Structure):
    failureErrorCode: UInt32
    failurePoint: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_FAILURE_POINT
    flags: UInt32
    emState: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_EM_SA_STATE
    saRole: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_SA_ROLE
    emAuthMethod: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_METHOD_TYPE
    endCertHash: Byte * 20
    mmId: UInt64
    qmFilterId: UInt64
class FWPM_NET_EVENT_IKEEXT_EM_FAILURE1(Structure):
    failureErrorCode: UInt32
    failurePoint: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_FAILURE_POINT
    flags: UInt32
    emState: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_EM_SA_STATE
    saRole: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_SA_ROLE
    emAuthMethod: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_METHOD_TYPE
    endCertHash: Byte * 20
    mmId: UInt64
    qmFilterId: UInt64
    localPrincipalNameForAuth: win32more.Windows.Win32.Foundation.PWSTR
    remotePrincipalNameForAuth: win32more.Windows.Win32.Foundation.PWSTR
    numLocalPrincipalGroupSids: UInt32
    localPrincipalGroupSids: POINTER(win32more.Windows.Win32.Foundation.PWSTR)
    numRemotePrincipalGroupSids: UInt32
    remotePrincipalGroupSids: POINTER(win32more.Windows.Win32.Foundation.PWSTR)
    saTrafficType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRAFFIC_TYPE
class FWPM_NET_EVENT_IKEEXT_MM_FAILURE0(Structure):
    failureErrorCode: UInt32
    failurePoint: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_FAILURE_POINT
    flags: UInt32
    keyingModuleType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_KEY_MODULE_TYPE
    mmState: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_MM_SA_STATE
    saRole: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_SA_ROLE
    mmAuthMethod: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_METHOD_TYPE
    endCertHash: Byte * 20
    mmId: UInt64
    mmFilterId: UInt64
class FWPM_NET_EVENT_IKEEXT_MM_FAILURE1(Structure):
    failureErrorCode: UInt32
    failurePoint: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_FAILURE_POINT
    flags: UInt32
    keyingModuleType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_KEY_MODULE_TYPE
    mmState: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_MM_SA_STATE
    saRole: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_SA_ROLE
    mmAuthMethod: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_METHOD_TYPE
    endCertHash: Byte * 20
    mmId: UInt64
    mmFilterId: UInt64
    localPrincipalNameForAuth: win32more.Windows.Win32.Foundation.PWSTR
    remotePrincipalNameForAuth: win32more.Windows.Win32.Foundation.PWSTR
    numLocalPrincipalGroupSids: UInt32
    localPrincipalGroupSids: POINTER(win32more.Windows.Win32.Foundation.PWSTR)
    numRemotePrincipalGroupSids: UInt32
    remotePrincipalGroupSids: POINTER(win32more.Windows.Win32.Foundation.PWSTR)
class FWPM_NET_EVENT_IKEEXT_MM_FAILURE2(Structure):
    failureErrorCode: UInt32
    failurePoint: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_FAILURE_POINT
    flags: UInt32
    keyingModuleType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_KEY_MODULE_TYPE
    mmState: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_MM_SA_STATE
    saRole: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_SA_ROLE
    mmAuthMethod: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_METHOD_TYPE
    endCertHash: Byte * 20
    mmId: UInt64
    mmFilterId: UInt64
    localPrincipalNameForAuth: win32more.Windows.Win32.Foundation.PWSTR
    remotePrincipalNameForAuth: win32more.Windows.Win32.Foundation.PWSTR
    numLocalPrincipalGroupSids: UInt32
    localPrincipalGroupSids: POINTER(win32more.Windows.Win32.Foundation.PWSTR)
    numRemotePrincipalGroupSids: UInt32
    remotePrincipalGroupSids: POINTER(win32more.Windows.Win32.Foundation.PWSTR)
    providerContextKey: POINTER(Guid)
class FWPM_NET_EVENT_IKEEXT_QM_FAILURE0(Structure):
    failureErrorCode: UInt32
    failurePoint: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_FAILURE_POINT
    keyingModuleType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_KEY_MODULE_TYPE
    qmState: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_QM_SA_STATE
    saRole: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_SA_ROLE
    saTrafficType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRAFFIC_TYPE
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    qmFilterId: UInt64
    class _Anonymous1_e__Union(Union):
        localSubNet: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_CONDITION_VALUE0
    class _Anonymous2_e__Union(Union):
        remoteSubNet: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_CONDITION_VALUE0
class FWPM_NET_EVENT_IKEEXT_QM_FAILURE1(Structure):
    failureErrorCode: UInt32
    failurePoint: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_FAILURE_POINT
    keyingModuleType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_KEY_MODULE_TYPE
    qmState: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_QM_SA_STATE
    saRole: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_SA_ROLE
    saTrafficType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRAFFIC_TYPE
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    qmFilterId: UInt64
    mmSaLuid: UInt64
    mmProviderContextKey: Guid
    class _Anonymous1_e__Union(Union):
        localSubNet: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_CONDITION_VALUE0
    class _Anonymous2_e__Union(Union):
        remoteSubNet: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_CONDITION_VALUE0
class FWPM_NET_EVENT_IPSEC_DOSP_DROP0(Structure):
    ipVersion: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_IP_VERSION
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    failureStatus: Int32
    direction: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_DIRECTION
    class _Anonymous1_e__Union(Union):
        publicHostV4Addr: UInt32
        publicHostV6Addr: Byte * 16
    class _Anonymous2_e__Union(Union):
        internalHostV4Addr: UInt32
        internalHostV6Addr: Byte * 16
class FWPM_NET_EVENT_IPSEC_KERNEL_DROP0(Structure):
    failureStatus: Int32
    direction: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_DIRECTION
    spi: UInt32
    filterId: UInt64
    layerId: UInt16
class FWPM_NET_EVENT_LPM_PACKET_ARRIVAL0(Structure):
    spi: UInt32
class FWPM_NET_EVENT_SUBSCRIPTION0(Structure):
    enumTemplate: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_ENUM_TEMPLATE0)
    flags: UInt32
    sessionKey: Guid
FWPM_NET_EVENT_TYPE = Int32
FWPM_NET_EVENT_TYPE_IKEEXT_MM_FAILURE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_TYPE = 0
FWPM_NET_EVENT_TYPE_IKEEXT_QM_FAILURE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_TYPE = 1
FWPM_NET_EVENT_TYPE_IKEEXT_EM_FAILURE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_TYPE = 2
FWPM_NET_EVENT_TYPE_CLASSIFY_DROP: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_TYPE = 3
FWPM_NET_EVENT_TYPE_IPSEC_KERNEL_DROP: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_TYPE = 4
FWPM_NET_EVENT_TYPE_IPSEC_DOSP_DROP: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_TYPE = 5
FWPM_NET_EVENT_TYPE_CLASSIFY_ALLOW: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_TYPE = 6
FWPM_NET_EVENT_TYPE_CAPABILITY_DROP: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_TYPE = 7
FWPM_NET_EVENT_TYPE_CAPABILITY_ALLOW: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_TYPE = 8
FWPM_NET_EVENT_TYPE_CLASSIFY_DROP_MAC: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_TYPE = 9
FWPM_NET_EVENT_TYPE_LPM_PACKET_ARRIVAL: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_TYPE = 10
FWPM_NET_EVENT_TYPE_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NET_EVENT_TYPE = 11
class FWPM_PROVIDER0(Structure):
    providerKey: Guid
    displayData: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_DISPLAY_DATA0
    flags: UInt32
    providerData: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB
    serviceName: win32more.Windows.Win32.Foundation.PWSTR
class FWPM_PROVIDER_CHANGE0(Structure):
    changeType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_CHANGE_TYPE
    providerKey: Guid
@winfunctype_pointer
def FWPM_PROVIDER_CHANGE_CALLBACK0(context: VoidPtr, change: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CHANGE0)) -> Void: ...
class FWPM_PROVIDER_CONTEXT0(Structure):
    providerContextKey: Guid
    displayData: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_DISPLAY_DATA0
    flags: UInt32
    providerKey: POINTER(Guid)
    providerData: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB
    type: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT_TYPE
    Anonymous: _Anonymous_e__Union
    providerContextId: UInt64
    class _Anonymous_e__Union(Union):
        keyingPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_KEYING_POLICY0)
        ikeQmTransportPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRANSPORT_POLICY0)
        ikeQmTunnelPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TUNNEL_POLICY0)
        authipQmTransportPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRANSPORT_POLICY0)
        authipQmTunnelPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TUNNEL_POLICY0)
        ikeMmPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_POLICY0)
        authIpMmPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_POLICY0)
        dataBuffer: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB)
        classifyOptions: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_CLASSIFY_OPTIONS0)
class FWPM_PROVIDER_CONTEXT1(Structure):
    providerContextKey: Guid
    displayData: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_DISPLAY_DATA0
    flags: UInt32
    providerKey: POINTER(Guid)
    providerData: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB
    type: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT_TYPE
    Anonymous: _Anonymous_e__Union
    providerContextId: UInt64
    class _Anonymous_e__Union(Union):
        keyingPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_KEYING_POLICY0)
        ikeQmTransportPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRANSPORT_POLICY1)
        ikeQmTunnelPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TUNNEL_POLICY1)
        authipQmTransportPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRANSPORT_POLICY1)
        authipQmTunnelPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TUNNEL_POLICY1)
        ikeMmPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_POLICY1)
        authIpMmPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_POLICY1)
        dataBuffer: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB)
        classifyOptions: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_CLASSIFY_OPTIONS0)
        ikeV2QmTunnelPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TUNNEL_POLICY1)
        ikeV2MmPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_POLICY1)
        idpOptions: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_DOSP_OPTIONS0)
class FWPM_PROVIDER_CONTEXT2(Structure):
    providerContextKey: Guid
    displayData: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_DISPLAY_DATA0
    flags: UInt32
    providerKey: POINTER(Guid)
    providerData: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB
    type: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT_TYPE
    Anonymous: _Anonymous_e__Union
    providerContextId: UInt64
    class _Anonymous_e__Union(Union):
        keyingPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_KEYING_POLICY1)
        ikeQmTransportPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRANSPORT_POLICY2)
        ikeQmTunnelPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TUNNEL_POLICY2)
        authipQmTransportPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRANSPORT_POLICY2)
        authipQmTunnelPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TUNNEL_POLICY2)
        ikeMmPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_POLICY2)
        authIpMmPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_POLICY2)
        dataBuffer: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB)
        classifyOptions: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_CLASSIFY_OPTIONS0)
        ikeV2QmTunnelPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TUNNEL_POLICY2)
        ikeV2QmTransportPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRANSPORT_POLICY2)
        ikeV2MmPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_POLICY2)
        idpOptions: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_DOSP_OPTIONS0)
class FWPM_PROVIDER_CONTEXT3(Structure):
    providerContextKey: Guid
    displayData: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_DISPLAY_DATA0
    flags: UInt32
    providerKey: POINTER(Guid)
    providerData: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB
    type: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT_TYPE
    Anonymous: _Anonymous_e__Union
    providerContextId: UInt64
    class _Anonymous_e__Union(Union):
        keyingPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_KEYING_POLICY1)
        ikeQmTransportPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRANSPORT_POLICY2)
        ikeQmTunnelPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TUNNEL_POLICY3)
        authipQmTransportPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRANSPORT_POLICY2)
        authipQmTunnelPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TUNNEL_POLICY3)
        ikeMmPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_POLICY2)
        authIpMmPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_POLICY2)
        dataBuffer: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB)
        classifyOptions: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_CLASSIFY_OPTIONS0)
        ikeV2QmTunnelPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TUNNEL_POLICY3)
        ikeV2QmTransportPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRANSPORT_POLICY2)
        ikeV2MmPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_POLICY2)
        idpOptions: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_DOSP_OPTIONS0)
        networkConnectionPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_NETWORK_CONNECTION_POLICY_SETTINGS0)
class FWPM_PROVIDER_CONTEXT_CHANGE0(Structure):
    changeType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_CHANGE_TYPE
    providerContextKey: Guid
    providerContextId: UInt64
@winfunctype_pointer
def FWPM_PROVIDER_CONTEXT_CHANGE_CALLBACK0(context: VoidPtr, change: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT_CHANGE0)) -> Void: ...
class FWPM_PROVIDER_CONTEXT_ENUM_TEMPLATE0(Structure):
    providerKey: POINTER(Guid)
    providerContextType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT_TYPE
class FWPM_PROVIDER_CONTEXT_SUBSCRIPTION0(Structure):
    enumTemplate: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT_ENUM_TEMPLATE0)
    flags: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_SUBSCRIPTION_FLAGS
    sessionKey: Guid
FWPM_PROVIDER_CONTEXT_TYPE = Int32
FWPM_IPSEC_KEYING_CONTEXT: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT_TYPE = 0
FWPM_IPSEC_IKE_QM_TRANSPORT_CONTEXT: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT_TYPE = 1
FWPM_IPSEC_IKE_QM_TUNNEL_CONTEXT: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT_TYPE = 2
FWPM_IPSEC_AUTHIP_QM_TRANSPORT_CONTEXT: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT_TYPE = 3
FWPM_IPSEC_AUTHIP_QM_TUNNEL_CONTEXT: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT_TYPE = 4
FWPM_IPSEC_IKE_MM_CONTEXT: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT_TYPE = 5
FWPM_IPSEC_AUTHIP_MM_CONTEXT: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT_TYPE = 6
FWPM_CLASSIFY_OPTIONS_CONTEXT: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT_TYPE = 7
FWPM_GENERAL_CONTEXT: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT_TYPE = 8
FWPM_IPSEC_IKEV2_QM_TUNNEL_CONTEXT: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT_TYPE = 9
FWPM_IPSEC_IKEV2_MM_CONTEXT: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT_TYPE = 10
FWPM_IPSEC_DOSP_CONTEXT: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT_TYPE = 11
FWPM_IPSEC_IKEV2_QM_TRANSPORT_CONTEXT: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT_TYPE = 12
FWPM_NETWORK_CONNECTION_POLICY_CONTEXT: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT_TYPE = 13
FWPM_PROVIDER_CONTEXT_TYPE_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_CONTEXT_TYPE = 14
class FWPM_PROVIDER_ENUM_TEMPLATE0(Structure):
    reserved: UInt64
class FWPM_PROVIDER_SUBSCRIPTION0(Structure):
    enumTemplate: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_PROVIDER_ENUM_TEMPLATE0)
    flags: UInt32
    sessionKey: Guid
FWPM_SERVICE_STATE = Int32
FWPM_SERVICE_STOPPED: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_SERVICE_STATE = 0
FWPM_SERVICE_START_PENDING: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_SERVICE_STATE = 1
FWPM_SERVICE_STOP_PENDING: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_SERVICE_STATE = 2
FWPM_SERVICE_RUNNING: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_SERVICE_STATE = 3
FWPM_SERVICE_STATE_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_SERVICE_STATE = 4
class FWPM_SESSION0(Structure):
    sessionKey: Guid
    displayData: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_DISPLAY_DATA0
    flags: UInt32
    txnWaitTimeoutInMSec: UInt32
    processId: UInt32
    sid: POINTER(win32more.Windows.Win32.Security.SID)
    username: win32more.Windows.Win32.Foundation.PWSTR
    kernelMode: win32more.Windows.Win32.Foundation.BOOL
class FWPM_SESSION_ENUM_TEMPLATE0(Structure):
    reserved: UInt64
class FWPM_STATISTICS0(Structure):
    numLayerStatistics: UInt32
    layerStatistics: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_LAYER_STATISTICS0)
    inboundAllowedConnectionsV4: UInt32
    inboundBlockedConnectionsV4: UInt32
    outboundAllowedConnectionsV4: UInt32
    outboundBlockedConnectionsV4: UInt32
    inboundAllowedConnectionsV6: UInt32
    inboundBlockedConnectionsV6: UInt32
    outboundAllowedConnectionsV6: UInt32
    outboundBlockedConnectionsV6: UInt32
    inboundActiveConnectionsV4: UInt32
    outboundActiveConnectionsV4: UInt32
    inboundActiveConnectionsV6: UInt32
    outboundActiveConnectionsV6: UInt32
    reauthDirInbound: UInt64
    reauthDirOutbound: UInt64
    reauthFamilyV4: UInt64
    reauthFamilyV6: UInt64
    reauthProtoOther: UInt64
    reauthProtoIPv4: UInt64
    reauthProtoIPv6: UInt64
    reauthProtoICMP: UInt64
    reauthProtoICMP6: UInt64
    reauthProtoUDP: UInt64
    reauthProtoTCP: UInt64
    reauthReasonPolicyChange: UInt64
    reauthReasonNewArrivalInterface: UInt64
    reauthReasonNewNextHopInterface: UInt64
    reauthReasonProfileCrossing: UInt64
    reauthReasonClassifyCompletion: UInt64
    reauthReasonIPSecPropertiesChanged: UInt64
    reauthReasonMidStreamInspection: UInt64
    reauthReasonSocketPropertyChanged: UInt64
    reauthReasonNewInboundMCastBCastPacket: UInt64
    reauthReasonEDPPolicyChanged: UInt64
    reauthReasonProxyHandleChanged: UInt64
class FWPM_SUBLAYER0(Structure):
    subLayerKey: Guid
    displayData: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_DISPLAY_DATA0
    flags: UInt32
    providerKey: POINTER(Guid)
    providerData: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB
    weight: UInt16
class FWPM_SUBLAYER_CHANGE0(Structure):
    changeType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_CHANGE_TYPE
    subLayerKey: Guid
@winfunctype_pointer
def FWPM_SUBLAYER_CHANGE_CALLBACK0(context: VoidPtr, change: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_SUBLAYER_CHANGE0)) -> Void: ...
class FWPM_SUBLAYER_ENUM_TEMPLATE0(Structure):
    providerKey: POINTER(Guid)
class FWPM_SUBLAYER_SUBSCRIPTION0(Structure):
    enumTemplate: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_SUBLAYER_ENUM_TEMPLATE0)
    flags: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_SUBSCRIPTION_FLAGS
    sessionKey: Guid
FWPM_SUBSCRIPTION_FLAGS = UInt32
FWPM_SUBSCRIPTION_FLAG_NOTIFY_ON_ADD: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_SUBSCRIPTION_FLAGS = 1
FWPM_SUBSCRIPTION_FLAG_NOTIFY_ON_DELETE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_SUBSCRIPTION_FLAGS = 2
class FWPM_SYSTEM_PORTS0(Structure):
    numTypes: UInt32
    types: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_SYSTEM_PORTS_BY_TYPE0)
class FWPM_SYSTEM_PORTS_BY_TYPE0(Structure):
    type: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_SYSTEM_PORT_TYPE
    numPorts: UInt32
    ports: POINTER(UInt16)
@winfunctype_pointer
def FWPM_SYSTEM_PORTS_CALLBACK0(context: VoidPtr, sysPorts: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_SYSTEM_PORTS0)) -> Void: ...
FWPM_SYSTEM_PORT_TYPE = Int32
FWPM_SYSTEM_PORT_RPC_EPMAP: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_SYSTEM_PORT_TYPE = 0
FWPM_SYSTEM_PORT_TEREDO: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_SYSTEM_PORT_TYPE = 1
FWPM_SYSTEM_PORT_IPHTTPS_IN: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_SYSTEM_PORT_TYPE = 2
FWPM_SYSTEM_PORT_IPHTTPS_OUT: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_SYSTEM_PORT_TYPE = 3
FWPM_SYSTEM_PORT_TYPE_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_SYSTEM_PORT_TYPE = 4
class FWPM_VSWITCH_EVENT0(Structure):
    eventType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_VSWITCH_EVENT_TYPE
    vSwitchId: win32more.Windows.Win32.Foundation.PWSTR
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        positionInfo: _positionInfo_e__Struct
        reorderInfo: _reorderInfo_e__Struct
        class _positionInfo_e__Struct(Structure):
            numvSwitchFilterExtensions: UInt32
            vSwitchFilterExtensions: POINTER(win32more.Windows.Win32.Foundation.PWSTR)
        class _reorderInfo_e__Struct(Structure):
            inRequiredPosition: win32more.Windows.Win32.Foundation.BOOL
            numvSwitchFilterExtensions: UInt32
            vSwitchFilterExtensions: POINTER(win32more.Windows.Win32.Foundation.PWSTR)
@winfunctype_pointer
def FWPM_VSWITCH_EVENT_CALLBACK0(context: VoidPtr, vSwitchEvent: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_VSWITCH_EVENT0)) -> UInt32: ...
class FWPM_VSWITCH_EVENT_SUBSCRIPTION0(Structure):
    flags: UInt32
    sessionKey: Guid
FWPM_VSWITCH_EVENT_TYPE = Int32
FWPM_VSWITCH_EVENT_FILTER_ADD_TO_INCOMPLETE_LAYER: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_VSWITCH_EVENT_TYPE = 0
FWPM_VSWITCH_EVENT_FILTER_ENGINE_NOT_IN_REQUIRED_POSITION: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_VSWITCH_EVENT_TYPE = 1
FWPM_VSWITCH_EVENT_ENABLED_FOR_INSPECTION: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_VSWITCH_EVENT_TYPE = 2
FWPM_VSWITCH_EVENT_DISABLED_FOR_INSPECTION: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_VSWITCH_EVENT_TYPE = 3
FWPM_VSWITCH_EVENT_FILTER_ENGINE_REORDER: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_VSWITCH_EVENT_TYPE = 4
FWPM_VSWITCH_EVENT_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_VSWITCH_EVENT_TYPE = 5
FWP_ACTION_TYPE = UInt32
FWP_ACTION_BLOCK: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_ACTION_TYPE = 4097
FWP_ACTION_PERMIT: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_ACTION_TYPE = 4098
FWP_ACTION_CALLOUT_TERMINATING: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_ACTION_TYPE = 20483
FWP_ACTION_CALLOUT_INSPECTION: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_ACTION_TYPE = 24580
FWP_ACTION_CALLOUT_UNKNOWN: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_ACTION_TYPE = 16389
FWP_ACTION_CONTINUE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_ACTION_TYPE = 8198
FWP_ACTION_NONE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_ACTION_TYPE = 7
FWP_ACTION_NONE_NO_MATCH: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_ACTION_TYPE = 8
FWP_AF = Int32
FWP_AF_INET: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_AF = 0
FWP_AF_INET6: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_AF = 1
FWP_AF_ETHER: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_AF = 2
FWP_AF_NONE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_AF = 3
class FWP_BYTE_ARRAY16(Structure):
    byteArray16: Byte * 16
class FWP_BYTE_ARRAY6(Structure):
    byteArray6: Byte * 6
class FWP_BYTE_BLOB(Structure):
    size: UInt32
    data: POINTER(Byte)
FWP_CLASSIFY_OPTION_TYPE = Int32
FWP_CLASSIFY_OPTION_MULTICAST_STATE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_CLASSIFY_OPTION_TYPE = 0
FWP_CLASSIFY_OPTION_LOOSE_SOURCE_MAPPING: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_CLASSIFY_OPTION_TYPE = 1
FWP_CLASSIFY_OPTION_UNICAST_LIFETIME: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_CLASSIFY_OPTION_TYPE = 2
FWP_CLASSIFY_OPTION_MCAST_BCAST_LIFETIME: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_CLASSIFY_OPTION_TYPE = 3
FWP_CLASSIFY_OPTION_SECURE_SOCKET_SECURITY_FLAGS: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_CLASSIFY_OPTION_TYPE = 4
FWP_CLASSIFY_OPTION_SECURE_SOCKET_AUTHIP_MM_POLICY_KEY: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_CLASSIFY_OPTION_TYPE = 5
FWP_CLASSIFY_OPTION_SECURE_SOCKET_AUTHIP_QM_POLICY_KEY: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_CLASSIFY_OPTION_TYPE = 6
FWP_CLASSIFY_OPTION_LOCAL_ONLY_MAPPING: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_CLASSIFY_OPTION_TYPE = 7
FWP_CLASSIFY_OPTION_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_CLASSIFY_OPTION_TYPE = 8
class FWP_CONDITION_VALUE0(Structure):
    type: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_DATA_TYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        uint8: Byte
        uint16: UInt16
        uint32: UInt32
        uint64: POINTER(UInt64)
        int8: SByte
        int16: Int16
        int32: Int32
        int64: POINTER(Int64)
        float32: Single
        double64: POINTER(Double)
        byteArray16: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_ARRAY16)
        byteBlob: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB)
        sid: POINTER(win32more.Windows.Win32.Security.SID)
        sd: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB)
        tokenInformation: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_TOKEN_INFORMATION)
        tokenAccessInformation: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB)
        unicodeString: win32more.Windows.Win32.Foundation.PWSTR
        byteArray6: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_ARRAY6)
        v4AddrMask: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_V4_ADDR_AND_MASK)
        v6AddrMask: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_V6_ADDR_AND_MASK)
        rangeValue: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_RANGE0)
FWP_DATA_TYPE = Int32
FWP_EMPTY: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_DATA_TYPE = 0
FWP_UINT8: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_DATA_TYPE = 1
FWP_UINT16: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_DATA_TYPE = 2
FWP_UINT32: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_DATA_TYPE = 3
FWP_UINT64: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_DATA_TYPE = 4
FWP_INT8: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_DATA_TYPE = 5
FWP_INT16: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_DATA_TYPE = 6
FWP_INT32: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_DATA_TYPE = 7
FWP_INT64: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_DATA_TYPE = 8
FWP_FLOAT: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_DATA_TYPE = 9
FWP_DOUBLE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_DATA_TYPE = 10
FWP_BYTE_ARRAY16_TYPE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_DATA_TYPE = 11
FWP_BYTE_BLOB_TYPE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_DATA_TYPE = 12
FWP_SID: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_DATA_TYPE = 13
FWP_SECURITY_DESCRIPTOR_TYPE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_DATA_TYPE = 14
FWP_TOKEN_INFORMATION_TYPE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_DATA_TYPE = 15
FWP_TOKEN_ACCESS_INFORMATION_TYPE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_DATA_TYPE = 16
FWP_UNICODE_STRING_TYPE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_DATA_TYPE = 17
FWP_BYTE_ARRAY6_TYPE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_DATA_TYPE = 18
FWP_SINGLE_DATA_TYPE_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_DATA_TYPE = 255
FWP_V4_ADDR_MASK: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_DATA_TYPE = 256
FWP_V6_ADDR_MASK: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_DATA_TYPE = 257
FWP_RANGE_TYPE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_DATA_TYPE = 258
FWP_DATA_TYPE_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_DATA_TYPE = 259
FWP_DIRECTION = Int32
FWP_DIRECTION_OUTBOUND: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_DIRECTION = 0
FWP_DIRECTION_INBOUND: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_DIRECTION = 1
FWP_DIRECTION_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_DIRECTION = 2
FWP_ETHER_ENCAP_METHOD = Int32
FWP_ETHER_ENCAP_METHOD_ETHER_V2: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_ETHER_ENCAP_METHOD = 0
FWP_ETHER_ENCAP_METHOD_SNAP: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_ETHER_ENCAP_METHOD = 1
FWP_ETHER_ENCAP_METHOD_SNAP_W_OUI_ZERO: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_ETHER_ENCAP_METHOD = 3
FWP_FILTER_ENUM_TYPE = Int32
FWP_FILTER_ENUM_FULLY_CONTAINED: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_FILTER_ENUM_TYPE = 0
FWP_FILTER_ENUM_OVERLAPPING: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_FILTER_ENUM_TYPE = 1
FWP_FILTER_ENUM_TYPE_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_FILTER_ENUM_TYPE = 2
FWP_IP_VERSION = Int32
FWP_IP_VERSION_V4: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_IP_VERSION = 0
FWP_IP_VERSION_V6: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_IP_VERSION = 1
FWP_IP_VERSION_NONE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_IP_VERSION = 2
FWP_IP_VERSION_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_IP_VERSION = 3
FWP_MATCH_TYPE = Int32
FWP_MATCH_EQUAL: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_MATCH_TYPE = 0
FWP_MATCH_GREATER: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_MATCH_TYPE = 1
FWP_MATCH_LESS: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_MATCH_TYPE = 2
FWP_MATCH_GREATER_OR_EQUAL: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_MATCH_TYPE = 3
FWP_MATCH_LESS_OR_EQUAL: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_MATCH_TYPE = 4
FWP_MATCH_RANGE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_MATCH_TYPE = 5
FWP_MATCH_FLAGS_ALL_SET: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_MATCH_TYPE = 6
FWP_MATCH_FLAGS_ANY_SET: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_MATCH_TYPE = 7
FWP_MATCH_FLAGS_NONE_SET: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_MATCH_TYPE = 8
FWP_MATCH_EQUAL_CASE_INSENSITIVE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_MATCH_TYPE = 9
FWP_MATCH_NOT_EQUAL: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_MATCH_TYPE = 10
FWP_MATCH_PREFIX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_MATCH_TYPE = 11
FWP_MATCH_NOT_PREFIX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_MATCH_TYPE = 12
FWP_MATCH_TYPE_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_MATCH_TYPE = 13
FWP_NETWORK_CONNECTION_POLICY_SETTING_TYPE = Int32
FWP_NETWORK_CONNECTION_POLICY_SOURCE_ADDRESS: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_NETWORK_CONNECTION_POLICY_SETTING_TYPE = 0
FWP_NETWORK_CONNECTION_POLICY_NEXT_HOP_INTERFACE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_NETWORK_CONNECTION_POLICY_SETTING_TYPE = 1
FWP_NETWORK_CONNECTION_POLICY_NEXT_HOP: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_NETWORK_CONNECTION_POLICY_SETTING_TYPE = 2
FWP_NETWORK_CONNECTION_POLICY_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_NETWORK_CONNECTION_POLICY_SETTING_TYPE = 3
class FWP_RANGE0(Structure):
    valueLow: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_VALUE0
    valueHigh: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_VALUE0
class FWP_TOKEN_INFORMATION(Structure):
    sidCount: UInt32
    sids: POINTER(win32more.Windows.Win32.Security.SID_AND_ATTRIBUTES)
    restrictedSidCount: UInt32
    restrictedSids: POINTER(win32more.Windows.Win32.Security.SID_AND_ATTRIBUTES)
class FWP_V4_ADDR_AND_MASK(Structure):
    addr: UInt32
    mask: UInt32
class FWP_V6_ADDR_AND_MASK(Structure):
    addr: Byte * 16
    prefixLength: Byte
class FWP_VALUE0(Structure):
    type: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_DATA_TYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        uint8: Byte
        uint16: UInt16
        uint32: UInt32
        uint64: POINTER(UInt64)
        int8: SByte
        int16: Int16
        int32: Int32
        int64: POINTER(Int64)
        float32: Single
        double64: POINTER(Double)
        byteArray16: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_ARRAY16)
        byteBlob: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB)
        sid: POINTER(win32more.Windows.Win32.Security.SID)
        sd: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB)
        tokenInformation: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_TOKEN_INFORMATION)
        tokenAccessInformation: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB)
        unicodeString: win32more.Windows.Win32.Foundation.PWSTR
        byteArray6: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_ARRAY6)
FWP_VSWITCH_NETWORK_TYPE = Int32
FWP_VSWITCH_NETWORK_TYPE_UNKNOWN: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_VSWITCH_NETWORK_TYPE = 0
FWP_VSWITCH_NETWORK_TYPE_PRIVATE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_VSWITCH_NETWORK_TYPE = 1
FWP_VSWITCH_NETWORK_TYPE_INTERNAL: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_VSWITCH_NETWORK_TYPE = 2
FWP_VSWITCH_NETWORK_TYPE_EXTERNAL: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_VSWITCH_NETWORK_TYPE = 3
IKEEXT_AUTHENTICATION_IMPERSONATION_TYPE = Int32
IKEEXT_IMPERSONATION_NONE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_IMPERSONATION_TYPE = 0
IKEEXT_IMPERSONATION_SOCKET_PRINCIPAL: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_IMPERSONATION_TYPE = 1
IKEEXT_IMPERSONATION_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_IMPERSONATION_TYPE = 2
class IKEEXT_AUTHENTICATION_METHOD0(Structure):
    authenticationMethodType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_METHOD_TYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        presharedKeyAuthentication: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_PRESHARED_KEY_AUTHENTICATION0
        certificateAuthentication: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERTIFICATE_AUTHENTICATION0
        kerberosAuthentication: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_KERBEROS_AUTHENTICATION0
        ntlmV2Authentication: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_NTLM_V2_AUTHENTICATION0
        sslAuthentication: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERTIFICATE_AUTHENTICATION0
        cgaAuthentication: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_IPV6_CGA_AUTHENTICATION0
class IKEEXT_AUTHENTICATION_METHOD1(Structure):
    authenticationMethodType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_METHOD_TYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        presharedKeyAuthentication: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_PRESHARED_KEY_AUTHENTICATION1
        certificateAuthentication: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERTIFICATE_AUTHENTICATION1
        kerberosAuthentication: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_KERBEROS_AUTHENTICATION0
        ntlmV2Authentication: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_NTLM_V2_AUTHENTICATION0
        sslAuthentication: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERTIFICATE_AUTHENTICATION1
        cgaAuthentication: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_IPV6_CGA_AUTHENTICATION0
        eapAuthentication: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_EAP_AUTHENTICATION0
class IKEEXT_AUTHENTICATION_METHOD2(Structure):
    authenticationMethodType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_METHOD_TYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        presharedKeyAuthentication: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_PRESHARED_KEY_AUTHENTICATION1
        certificateAuthentication: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERTIFICATE_AUTHENTICATION2
        kerberosAuthentication: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_KERBEROS_AUTHENTICATION1
        reservedAuthentication: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_RESERVED_AUTHENTICATION0
        ntlmV2Authentication: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_NTLM_V2_AUTHENTICATION0
        sslAuthentication: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERTIFICATE_AUTHENTICATION2
        cgaAuthentication: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_IPV6_CGA_AUTHENTICATION0
        eapAuthentication: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_EAP_AUTHENTICATION0
IKEEXT_AUTHENTICATION_METHOD_TYPE = Int32
IKEEXT_PRESHARED_KEY: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_METHOD_TYPE = 0
IKEEXT_CERTIFICATE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_METHOD_TYPE = 1
IKEEXT_KERBEROS: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_METHOD_TYPE = 2
IKEEXT_ANONYMOUS: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_METHOD_TYPE = 3
IKEEXT_SSL: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_METHOD_TYPE = 4
IKEEXT_NTLM_V2: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_METHOD_TYPE = 5
IKEEXT_IPV6_CGA: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_METHOD_TYPE = 6
IKEEXT_CERTIFICATE_ECDSA_P256: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_METHOD_TYPE = 7
IKEEXT_CERTIFICATE_ECDSA_P384: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_METHOD_TYPE = 8
IKEEXT_SSL_ECDSA_P256: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_METHOD_TYPE = 9
IKEEXT_SSL_ECDSA_P384: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_METHOD_TYPE = 10
IKEEXT_EAP: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_METHOD_TYPE = 11
IKEEXT_RESERVED: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_METHOD_TYPE = 12
IKEEXT_AUTHENTICATION_METHOD_TYPE_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_METHOD_TYPE = 13
class IKEEXT_CERTIFICATE_AUTHENTICATION0(Structure):
    inboundConfigType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_CONFIG_TYPE
    Anonymous1: _Anonymous1_e__Union
    outboundConfigType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_CONFIG_TYPE
    Anonymous2: _Anonymous2_e__Union
    flags: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_AUTH
    class _Anonymous1_e__Union(Union):
        Anonymous: _Anonymous_e__Struct
        inboundEnterpriseStoreConfig: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_ROOT_CONFIG0)
        inboundTrustedRootStoreConfig: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_ROOT_CONFIG0)
        class _Anonymous_e__Struct(Structure):
            inboundRootArraySize: UInt32
            inboundRootArray: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_ROOT_CONFIG0)
    class _Anonymous2_e__Union(Union):
        Anonymous: _Anonymous_e__Struct
        outboundEnterpriseStoreConfig: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_ROOT_CONFIG0)
        outboundTrustedRootStoreConfig: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_ROOT_CONFIG0)
        class _Anonymous_e__Struct(Structure):
            outboundRootArraySize: UInt32
            outboundRootArray: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_ROOT_CONFIG0)
class IKEEXT_CERTIFICATE_AUTHENTICATION1(Structure):
    inboundConfigType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_CONFIG_TYPE
    Anonymous1: _Anonymous1_e__Union
    outboundConfigType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_CONFIG_TYPE
    Anonymous2: _Anonymous2_e__Union
    flags: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_AUTH
    localCertLocationUrl: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB
    class _Anonymous1_e__Union(Union):
        Anonymous: _Anonymous_e__Struct
        inboundEnterpriseStoreConfig: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_ROOT_CONFIG0)
        inboundTrustedRootStoreConfig: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_ROOT_CONFIG0)
        class _Anonymous_e__Struct(Structure):
            inboundRootArraySize: UInt32
            inboundRootArray: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_ROOT_CONFIG0)
    class _Anonymous2_e__Union(Union):
        Anonymous: _Anonymous_e__Struct
        outboundEnterpriseStoreConfig: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_ROOT_CONFIG0)
        outboundTrustedRootStoreConfig: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_ROOT_CONFIG0)
        class _Anonymous_e__Struct(Structure):
            outboundRootArraySize: UInt32
            outboundRootArray: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_ROOT_CONFIG0)
class IKEEXT_CERTIFICATE_AUTHENTICATION2(Structure):
    inboundConfigType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_CONFIG_TYPE
    Anonymous1: _Anonymous1_e__Union
    outboundConfigType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_CONFIG_TYPE
    Anonymous2: _Anonymous2_e__Union
    flags: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_AUTH
    localCertLocationUrl: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB
    class _Anonymous1_e__Union(Union):
        Anonymous1: _Anonymous1_e__Struct
        Anonymous2: _Anonymous2_e__Struct
        Anonymous3: _Anonymous3_e__Struct
        class _Anonymous1_e__Struct(Structure):
            inboundRootArraySize: UInt32
            inboundRootCriteria: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERTIFICATE_CRITERIA0)
        class _Anonymous2_e__Struct(Structure):
            inboundEnterpriseStoreArraySize: UInt32
            inboundEnterpriseStoreCriteria: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERTIFICATE_CRITERIA0)
        class _Anonymous3_e__Struct(Structure):
            inboundRootStoreArraySize: UInt32
            inboundTrustedRootStoreCriteria: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERTIFICATE_CRITERIA0)
    class _Anonymous2_e__Union(Union):
        Anonymous1: _Anonymous1_e__Struct
        Anonymous2: _Anonymous2_e__Struct
        Anonymous3: _Anonymous3_e__Struct
        class _Anonymous1_e__Struct(Structure):
            outboundRootArraySize: UInt32
            outboundRootCriteria: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERTIFICATE_CRITERIA0)
        class _Anonymous2_e__Struct(Structure):
            outboundEnterpriseStoreArraySize: UInt32
            outboundEnterpriseStoreCriteria: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERTIFICATE_CRITERIA0)
        class _Anonymous3_e__Struct(Structure):
            outboundRootStoreArraySize: UInt32
            outboundTrustedRootStoreCriteria: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERTIFICATE_CRITERIA0)
class IKEEXT_CERTIFICATE_CREDENTIAL0(Structure):
    subjectName: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB
    certHash: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB
    flags: UInt32
class IKEEXT_CERTIFICATE_CREDENTIAL1(Structure):
    subjectName: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB
    certHash: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB
    flags: UInt32
    certificate: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB
class IKEEXT_CERTIFICATE_CRITERIA0(Structure):
    certData: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB
    certHash: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB
    eku: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_EKUS0)
    name: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_NAME0)
    flags: UInt32
IKEEXT_CERT_AUTH = UInt32
IKEEXT_CERT_AUTH_FLAG_SSL_ONE_WAY: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_AUTH = 1
IKEEXT_CERT_AUTH_ENABLE_CRL_CHECK_STRONG: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_AUTH = 4
IKEEXT_CERT_AUTH_DISABLE_SSL_CERT_VALIDATION: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_AUTH = 8
IKEEXT_CERT_AUTH_ALLOW_HTTP_CERT_LOOKUP: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_AUTH = 16
IKEEXT_CERT_AUTH_URL_CONTAINS_BUNDLE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_AUTH = 32
IKEEXT_CERT_CONFIG_TYPE = Int32
IKEEXT_CERT_CONFIG_EXPLICIT_TRUST_LIST: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_CONFIG_TYPE = 0
IKEEXT_CERT_CONFIG_ENTERPRISE_STORE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_CONFIG_TYPE = 1
IKEEXT_CERT_CONFIG_TRUSTED_ROOT_STORE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_CONFIG_TYPE = 2
IKEEXT_CERT_CONFIG_UNSPECIFIED: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_CONFIG_TYPE = 3
IKEEXT_CERT_CONFIG_TYPE_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_CONFIG_TYPE = 4
IKEEXT_CERT_CRITERIA_NAME_TYPE = Int32
IKEEXT_CERT_CRITERIA_DNS: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_CRITERIA_NAME_TYPE = 0
IKEEXT_CERT_CRITERIA_UPN: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_CRITERIA_NAME_TYPE = 1
IKEEXT_CERT_CRITERIA_RFC822: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_CRITERIA_NAME_TYPE = 2
IKEEXT_CERT_CRITERIA_CN: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_CRITERIA_NAME_TYPE = 3
IKEEXT_CERT_CRITERIA_OU: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_CRITERIA_NAME_TYPE = 4
IKEEXT_CERT_CRITERIA_O: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_CRITERIA_NAME_TYPE = 5
IKEEXT_CERT_CRITERIA_DC: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_CRITERIA_NAME_TYPE = 6
IKEEXT_CERT_CRITERIA_NAME_TYPE_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_CRITERIA_NAME_TYPE = 7
class IKEEXT_CERT_EKUS0(Structure):
    numEku: UInt32
    eku: POINTER(win32more.Windows.Win32.Foundation.PSTR)
IKEEXT_CERT_FLAGS = UInt32
IKEEXT_CERT_FLAG_ENABLE_ACCOUNT_MAPPING: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_FLAGS = 1
IKEEXT_CERT_FLAG_DISABLE_REQUEST_PAYLOAD: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_FLAGS = 2
IKEEXT_CERT_FLAG_USE_NAP_CERTIFICATE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_FLAGS = 4
IKEEXT_CERT_FLAG_INTERMEDIATE_CA: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_FLAGS = 8
IKEEXT_CERT_FLAG_IGNORE_INIT_CERT_MAP_FAILURE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_FLAGS = 16
IKEEXT_CERT_FLAG_PREFER_NAP_CERTIFICATE_OUTBOUND: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_FLAGS = 32
IKEEXT_CERT_FLAG_SELECT_NAP_CERTIFICATE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_FLAGS = 64
IKEEXT_CERT_FLAG_VERIFY_NAP_CERTIFICATE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_FLAGS = 128
IKEEXT_CERT_FLAG_FOLLOW_RENEWAL_CERTIFICATE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_FLAGS = 256
class IKEEXT_CERT_NAME0(Structure):
    nameType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_CRITERIA_NAME_TYPE
    certName: win32more.Windows.Win32.Foundation.PWSTR
class IKEEXT_CERT_ROOT_CONFIG0(Structure):
    certData: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB
    flags: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERT_FLAGS
class IKEEXT_CIPHER_ALGORITHM0(Structure):
    algoIdentifier: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CIPHER_TYPE
    keyLen: UInt32
    rounds: UInt32
IKEEXT_CIPHER_TYPE = Int32
IKEEXT_CIPHER_DES: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CIPHER_TYPE = 0
IKEEXT_CIPHER_3DES: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CIPHER_TYPE = 1
IKEEXT_CIPHER_AES_128: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CIPHER_TYPE = 2
IKEEXT_CIPHER_AES_192: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CIPHER_TYPE = 3
IKEEXT_CIPHER_AES_256: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CIPHER_TYPE = 4
IKEEXT_CIPHER_AES_GCM_128_16ICV: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CIPHER_TYPE = 5
IKEEXT_CIPHER_AES_GCM_256_16ICV: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CIPHER_TYPE = 6
IKEEXT_CIPHER_TYPE_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CIPHER_TYPE = 7
class IKEEXT_COMMON_STATISTICS0(Structure):
    v4Statistics: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_IP_VERSION_SPECIFIC_COMMON_STATISTICS0
    v6Statistics: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_IP_VERSION_SPECIFIC_COMMON_STATISTICS0
    totalPacketsReceived: UInt32
    totalInvalidPacketsReceived: UInt32
    currentQueuedWorkitems: UInt32
class IKEEXT_COMMON_STATISTICS1(Structure):
    v4Statistics: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_IP_VERSION_SPECIFIC_COMMON_STATISTICS1
    v6Statistics: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_IP_VERSION_SPECIFIC_COMMON_STATISTICS1
    totalPacketsReceived: UInt32
    totalInvalidPacketsReceived: UInt32
    currentQueuedWorkitems: UInt32
class IKEEXT_COOKIE_PAIR0(Structure):
    initiator: UInt64
    responder: UInt64
class IKEEXT_CREDENTIAL0(Structure):
    authenticationMethodType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_METHOD_TYPE
    impersonationType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_IMPERSONATION_TYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        presharedKey: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_PRESHARED_KEY_AUTHENTICATION0)
        certificate: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERTIFICATE_CREDENTIAL0)
        name: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_NAME_CREDENTIAL0)
class IKEEXT_CREDENTIAL1(Structure):
    authenticationMethodType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_METHOD_TYPE
    impersonationType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_IMPERSONATION_TYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        presharedKey: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_PRESHARED_KEY_AUTHENTICATION1)
        certificate: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERTIFICATE_CREDENTIAL1)
        name: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_NAME_CREDENTIAL0)
class IKEEXT_CREDENTIAL2(Structure):
    authenticationMethodType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_METHOD_TYPE
    impersonationType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_IMPERSONATION_TYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        presharedKey: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_PRESHARED_KEY_AUTHENTICATION1)
        certificate: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CERTIFICATE_CREDENTIAL1)
        name: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_NAME_CREDENTIAL0)
class IKEEXT_CREDENTIALS0(Structure):
    numCredentials: UInt32
    credentials: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CREDENTIAL_PAIR0)
class IKEEXT_CREDENTIALS1(Structure):
    numCredentials: UInt32
    credentials: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CREDENTIAL_PAIR1)
class IKEEXT_CREDENTIALS2(Structure):
    numCredentials: UInt32
    credentials: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CREDENTIAL_PAIR2)
class IKEEXT_CREDENTIAL_PAIR0(Structure):
    localCredentials: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CREDENTIAL0
    peerCredentials: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CREDENTIAL0
class IKEEXT_CREDENTIAL_PAIR1(Structure):
    localCredentials: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CREDENTIAL1
    peerCredentials: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CREDENTIAL1
class IKEEXT_CREDENTIAL_PAIR2(Structure):
    localCredentials: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CREDENTIAL2
    peerCredentials: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CREDENTIAL2
IKEEXT_DH_GROUP = Int32
IKEEXT_DH_GROUP_NONE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_DH_GROUP = 0
IKEEXT_DH_GROUP_1: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_DH_GROUP = 1
IKEEXT_DH_GROUP_2: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_DH_GROUP = 2
IKEEXT_DH_GROUP_14: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_DH_GROUP = 3
IKEEXT_DH_GROUP_2048: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_DH_GROUP = 3
IKEEXT_DH_ECP_256: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_DH_GROUP = 4
IKEEXT_DH_ECP_384: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_DH_GROUP = 5
IKEEXT_DH_GROUP_24: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_DH_GROUP = 6
IKEEXT_DH_GROUP_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_DH_GROUP = 7
class IKEEXT_EAP_AUTHENTICATION0(Structure):
    flags: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_EAP_AUTHENTICATION_FLAGS
IKEEXT_EAP_AUTHENTICATION_FLAGS = UInt32
IKEEXT_EAP_FLAG_LOCAL_AUTH_ONLY: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_EAP_AUTHENTICATION_FLAGS = 1
IKEEXT_EAP_FLAG_REMOTE_AUTH_ONLY: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_EAP_AUTHENTICATION_FLAGS = 2
class IKEEXT_EM_POLICY0(Structure):
    numAuthenticationMethods: UInt32
    authenticationMethods: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_METHOD0)
    initiatorImpersonationType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_IMPERSONATION_TYPE
class IKEEXT_EM_POLICY1(Structure):
    numAuthenticationMethods: UInt32
    authenticationMethods: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_METHOD1)
    initiatorImpersonationType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_IMPERSONATION_TYPE
class IKEEXT_EM_POLICY2(Structure):
    numAuthenticationMethods: UInt32
    authenticationMethods: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_METHOD2)
    initiatorImpersonationType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_IMPERSONATION_TYPE
IKEEXT_EM_SA_STATE = Int32
IKEEXT_EM_SA_STATE_NONE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_EM_SA_STATE = 0
IKEEXT_EM_SA_STATE_SENT_ATTS: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_EM_SA_STATE = 1
IKEEXT_EM_SA_STATE_SSPI_SENT: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_EM_SA_STATE = 2
IKEEXT_EM_SA_STATE_AUTH_COMPLETE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_EM_SA_STATE = 3
IKEEXT_EM_SA_STATE_FINAL: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_EM_SA_STATE = 4
IKEEXT_EM_SA_STATE_COMPLETE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_EM_SA_STATE = 5
IKEEXT_EM_SA_STATE_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_EM_SA_STATE = 6
class IKEEXT_INTEGRITY_ALGORITHM0(Structure):
    algoIdentifier: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_INTEGRITY_TYPE
IKEEXT_INTEGRITY_TYPE = Int32
IKEEXT_INTEGRITY_MD5: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_INTEGRITY_TYPE = 0
IKEEXT_INTEGRITY_SHA1: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_INTEGRITY_TYPE = 1
IKEEXT_INTEGRITY_SHA_256: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_INTEGRITY_TYPE = 2
IKEEXT_INTEGRITY_SHA_384: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_INTEGRITY_TYPE = 3
IKEEXT_INTEGRITY_TYPE_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_INTEGRITY_TYPE = 4
class IKEEXT_IPV6_CGA_AUTHENTICATION0(Structure):
    keyContainerName: win32more.Windows.Win32.Foundation.PWSTR
    cspName: win32more.Windows.Win32.Foundation.PWSTR
    cspType: UInt32
    cgaModifier: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_ARRAY16
    cgaCollisionCount: Byte
class IKEEXT_IP_VERSION_SPECIFIC_COMMON_STATISTICS0(Structure):
    totalSocketReceiveFailures: UInt32
    totalSocketSendFailures: UInt32
class IKEEXT_IP_VERSION_SPECIFIC_COMMON_STATISTICS1(Structure):
    totalSocketReceiveFailures: UInt32
    totalSocketSendFailures: UInt32
class IKEEXT_IP_VERSION_SPECIFIC_KEYMODULE_STATISTICS0(Structure):
    currentActiveMainModes: UInt32
    totalMainModesStarted: UInt32
    totalSuccessfulMainModes: UInt32
    totalFailedMainModes: UInt32
    totalResponderMainModes: UInt32
    currentNewResponderMainModes: UInt32
    currentActiveQuickModes: UInt32
    totalQuickModesStarted: UInt32
    totalSuccessfulQuickModes: UInt32
    totalFailedQuickModes: UInt32
    totalAcquires: UInt32
    totalReinitAcquires: UInt32
    currentActiveExtendedModes: UInt32
    totalExtendedModesStarted: UInt32
    totalSuccessfulExtendedModes: UInt32
    totalFailedExtendedModes: UInt32
    totalImpersonationExtendedModes: UInt32
    totalImpersonationMainModes: UInt32
class IKEEXT_IP_VERSION_SPECIFIC_KEYMODULE_STATISTICS1(Structure):
    currentActiveMainModes: UInt32
    totalMainModesStarted: UInt32
    totalSuccessfulMainModes: UInt32
    totalFailedMainModes: UInt32
    totalResponderMainModes: UInt32
    currentNewResponderMainModes: UInt32
    currentActiveQuickModes: UInt32
    totalQuickModesStarted: UInt32
    totalSuccessfulQuickModes: UInt32
    totalFailedQuickModes: UInt32
    totalAcquires: UInt32
    totalReinitAcquires: UInt32
    currentActiveExtendedModes: UInt32
    totalExtendedModesStarted: UInt32
    totalSuccessfulExtendedModes: UInt32
    totalFailedExtendedModes: UInt32
    totalImpersonationExtendedModes: UInt32
    totalImpersonationMainModes: UInt32
class IKEEXT_KERBEROS_AUTHENTICATION0(Structure):
    flags: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_KERBEROS_AUTHENTICATION_FLAGS
class IKEEXT_KERBEROS_AUTHENTICATION1(Structure):
    flags: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_KERBEROS_AUTHENTICATION_FLAGS
    proxyServer: win32more.Windows.Win32.Foundation.PWSTR
IKEEXT_KERBEROS_AUTHENTICATION_FLAGS = UInt32
IKEEXT_KERB_AUTH_DISABLE_INITIATOR_TOKEN_GENERATION: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_KERBEROS_AUTHENTICATION_FLAGS = 1
IKEEXT_KERB_AUTH_DONT_ACCEPT_EXPLICIT_CREDENTIALS: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_KERBEROS_AUTHENTICATION_FLAGS = 2
class IKEEXT_KEYMODULE_STATISTICS0(Structure):
    v4Statistics: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_IP_VERSION_SPECIFIC_KEYMODULE_STATISTICS0
    v6Statistics: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_IP_VERSION_SPECIFIC_KEYMODULE_STATISTICS0
    errorFrequencyTable: UInt32 * 97
    mainModeNegotiationTime: UInt32
    quickModeNegotiationTime: UInt32
    extendedModeNegotiationTime: UInt32
class IKEEXT_KEYMODULE_STATISTICS1(Structure):
    v4Statistics: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_IP_VERSION_SPECIFIC_KEYMODULE_STATISTICS1
    v6Statistics: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_IP_VERSION_SPECIFIC_KEYMODULE_STATISTICS1
    errorFrequencyTable: UInt32 * 97
    mainModeNegotiationTime: UInt32
    quickModeNegotiationTime: UInt32
    extendedModeNegotiationTime: UInt32
IKEEXT_KEY_MODULE_TYPE = Int32
IKEEXT_KEY_MODULE_IKE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_KEY_MODULE_TYPE = 0
IKEEXT_KEY_MODULE_AUTHIP: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_KEY_MODULE_TYPE = 1
IKEEXT_KEY_MODULE_IKEV2: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_KEY_MODULE_TYPE = 2
IKEEXT_KEY_MODULE_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_KEY_MODULE_TYPE = 3
IKEEXT_MM_SA_STATE = Int32
IKEEXT_MM_SA_STATE_NONE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_MM_SA_STATE = 0
IKEEXT_MM_SA_STATE_SA_SENT: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_MM_SA_STATE = 1
IKEEXT_MM_SA_STATE_SSPI_SENT: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_MM_SA_STATE = 2
IKEEXT_MM_SA_STATE_FINAL: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_MM_SA_STATE = 3
IKEEXT_MM_SA_STATE_FINAL_SENT: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_MM_SA_STATE = 4
IKEEXT_MM_SA_STATE_COMPLETE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_MM_SA_STATE = 5
IKEEXT_MM_SA_STATE_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_MM_SA_STATE = 6
class IKEEXT_NAME_CREDENTIAL0(Structure):
    principalName: win32more.Windows.Win32.Foundation.PWSTR
class IKEEXT_NTLM_V2_AUTHENTICATION0(Structure):
    flags: UInt32
class IKEEXT_POLICY0(Structure):
    softExpirationTime: UInt32
    numAuthenticationMethods: UInt32
    authenticationMethods: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_METHOD0)
    initiatorImpersonationType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_IMPERSONATION_TYPE
    numIkeProposals: UInt32
    ikeProposals: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_PROPOSAL0)
    flags: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_POLICY_FLAG
    maxDynamicFilters: UInt32
class IKEEXT_POLICY1(Structure):
    softExpirationTime: UInt32
    numAuthenticationMethods: UInt32
    authenticationMethods: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_METHOD1)
    initiatorImpersonationType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_IMPERSONATION_TYPE
    numIkeProposals: UInt32
    ikeProposals: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_PROPOSAL0)
    flags: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_POLICY_FLAG
    maxDynamicFilters: UInt32
    retransmitDurationSecs: UInt32
class IKEEXT_POLICY2(Structure):
    softExpirationTime: UInt32
    numAuthenticationMethods: UInt32
    authenticationMethods: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_METHOD2)
    initiatorImpersonationType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_AUTHENTICATION_IMPERSONATION_TYPE
    numIkeProposals: UInt32
    ikeProposals: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_PROPOSAL0)
    flags: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_POLICY_FLAG
    maxDynamicFilters: UInt32
    retransmitDurationSecs: UInt32
IKEEXT_POLICY_FLAG = UInt32
IKEEXT_POLICY_FLAG_DISABLE_DIAGNOSTICS: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_POLICY_FLAG = 1
IKEEXT_POLICY_FLAG_NO_MACHINE_LUID_VERIFY: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_POLICY_FLAG = 2
IKEEXT_POLICY_FLAG_NO_IMPERSONATION_LUID_VERIFY: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_POLICY_FLAG = 4
IKEEXT_POLICY_FLAG_ENABLE_OPTIONAL_DH: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_POLICY_FLAG = 8
class IKEEXT_PRESHARED_KEY_AUTHENTICATION0(Structure):
    presharedKey: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB
class IKEEXT_PRESHARED_KEY_AUTHENTICATION1(Structure):
    presharedKey: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB
    flags: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_PRESHARED_KEY_AUTHENTICATION_FLAGS
IKEEXT_PRESHARED_KEY_AUTHENTICATION_FLAGS = UInt32
IKEEXT_PSK_FLAG_LOCAL_AUTH_ONLY: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_PRESHARED_KEY_AUTHENTICATION_FLAGS = 1
IKEEXT_PSK_FLAG_REMOTE_AUTH_ONLY: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_PRESHARED_KEY_AUTHENTICATION_FLAGS = 2
class IKEEXT_PROPOSAL0(Structure):
    cipherAlgorithm: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CIPHER_ALGORITHM0
    integrityAlgorithm: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_INTEGRITY_ALGORITHM0
    maxLifetimeSeconds: UInt32
    dhGroup: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_DH_GROUP
    quickModeLimit: UInt32
IKEEXT_QM_SA_STATE = Int32
IKEEXT_QM_SA_STATE_NONE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_QM_SA_STATE = 0
IKEEXT_QM_SA_STATE_INITIAL: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_QM_SA_STATE = 1
IKEEXT_QM_SA_STATE_FINAL: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_QM_SA_STATE = 2
IKEEXT_QM_SA_STATE_COMPLETE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_QM_SA_STATE = 3
IKEEXT_QM_SA_STATE_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_QM_SA_STATE = 4
class IKEEXT_RESERVED_AUTHENTICATION0(Structure):
    flags: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_RESERVED_AUTHENTICATION_FLAGS
IKEEXT_RESERVED_AUTHENTICATION_FLAGS = UInt32
IKEEXT_RESERVED_AUTH_DISABLE_INITIATOR_TOKEN_GENERATION: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_RESERVED_AUTHENTICATION_FLAGS = 1
class IKEEXT_SA_DETAILS0(Structure):
    saId: UInt64
    keyModuleType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_KEY_MODULE_TYPE
    ipVersion: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_IP_VERSION
    Anonymous: _Anonymous_e__Union
    ikeTraffic: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_TRAFFIC0
    ikeProposal: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_PROPOSAL0
    cookiePair: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_COOKIE_PAIR0
    ikeCredentials: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CREDENTIALS0
    ikePolicyKey: Guid
    virtualIfTunnelId: UInt64
    class _Anonymous_e__Union(Union):
        v4UdpEncapsulation: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_V4_UDP_ENCAPSULATION0)
class IKEEXT_SA_DETAILS1(Structure):
    saId: UInt64
    keyModuleType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_KEY_MODULE_TYPE
    ipVersion: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_IP_VERSION
    Anonymous: _Anonymous_e__Union
    ikeTraffic: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_TRAFFIC0
    ikeProposal: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_PROPOSAL0
    cookiePair: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_COOKIE_PAIR0
    ikeCredentials: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CREDENTIALS1
    ikePolicyKey: Guid
    virtualIfTunnelId: UInt64
    correlationKey: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB
    class _Anonymous_e__Union(Union):
        v4UdpEncapsulation: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_V4_UDP_ENCAPSULATION0)
class IKEEXT_SA_DETAILS2(Structure):
    saId: UInt64
    keyModuleType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_KEY_MODULE_TYPE
    ipVersion: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_IP_VERSION
    Anonymous: _Anonymous_e__Union
    ikeTraffic: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_TRAFFIC0
    ikeProposal: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_PROPOSAL0
    cookiePair: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_COOKIE_PAIR0
    ikeCredentials: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_CREDENTIALS2
    ikePolicyKey: Guid
    virtualIfTunnelId: UInt64
    correlationKey: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB
    class _Anonymous_e__Union(Union):
        v4UdpEncapsulation: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_V4_UDP_ENCAPSULATION0)
class IKEEXT_SA_ENUM_TEMPLATE0(Structure):
    localSubNet: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_CONDITION_VALUE0
    remoteSubNet: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_CONDITION_VALUE0
    localMainModeCertHash: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB
IKEEXT_SA_ROLE = Int32
IKEEXT_SA_ROLE_INITIATOR: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_SA_ROLE = 0
IKEEXT_SA_ROLE_RESPONDER: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_SA_ROLE = 1
IKEEXT_SA_ROLE_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_SA_ROLE = 2
class IKEEXT_STATISTICS0(Structure):
    ikeStatistics: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_KEYMODULE_STATISTICS0
    authipStatistics: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_KEYMODULE_STATISTICS0
    commonStatistics: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_COMMON_STATISTICS0
class IKEEXT_STATISTICS1(Structure):
    ikeStatistics: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_KEYMODULE_STATISTICS1
    authipStatistics: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_KEYMODULE_STATISTICS1
    ikeV2Statistics: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_KEYMODULE_STATISTICS1
    commonStatistics: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_COMMON_STATISTICS1
class IKEEXT_TRAFFIC0(Structure):
    ipVersion: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_IP_VERSION
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    authIpFilterId: UInt64
    class _Anonymous1_e__Union(Union):
        localV4Address: UInt32
        localV6Address: Byte * 16
    class _Anonymous2_e__Union(Union):
        remoteV4Address: UInt32
        remoteV6Address: Byte * 16
class IPSEC_ADDRESS_INFO0(Structure):
    numV4Addresses: UInt32
    v4Addresses: POINTER(UInt32)
    numV6Addresses: UInt32
    v6Addresses: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_ARRAY16)
class IPSEC_AGGREGATE_DROP_PACKET_STATISTICS0(Structure):
    invalidSpisOnInbound: UInt32
    decryptionFailuresOnInbound: UInt32
    authenticationFailuresOnInbound: UInt32
    udpEspValidationFailuresOnInbound: UInt32
    replayCheckFailuresOnInbound: UInt32
    invalidClearTextInbound: UInt32
    saNotInitializedOnInbound: UInt32
    receiveOverIncorrectSaInbound: UInt32
    secureReceivesNotMatchingFilters: UInt32
class IPSEC_AGGREGATE_DROP_PACKET_STATISTICS1(Structure):
    invalidSpisOnInbound: UInt32
    decryptionFailuresOnInbound: UInt32
    authenticationFailuresOnInbound: UInt32
    udpEspValidationFailuresOnInbound: UInt32
    replayCheckFailuresOnInbound: UInt32
    invalidClearTextInbound: UInt32
    saNotInitializedOnInbound: UInt32
    receiveOverIncorrectSaInbound: UInt32
    secureReceivesNotMatchingFilters: UInt32
    totalDropPacketsInbound: UInt32
class IPSEC_AGGREGATE_SA_STATISTICS0(Structure):
    activeSas: UInt32
    pendingSaNegotiations: UInt32
    totalSasAdded: UInt32
    totalSasDeleted: UInt32
    successfulRekeys: UInt32
    activeTunnels: UInt32
    offloadedSas: UInt32
class IPSEC_AH_DROP_PACKET_STATISTICS0(Structure):
    invalidSpisOnInbound: UInt32
    authenticationFailuresOnInbound: UInt32
    replayCheckFailuresOnInbound: UInt32
    saNotInitializedOnInbound: UInt32
class IPSEC_AUTH_AND_CIPHER_TRANSFORM0(Structure):
    authTransform: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_AUTH_TRANSFORM0
    cipherTransform: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_CIPHER_TRANSFORM0
class IPSEC_AUTH_TRANSFORM0(Structure):
    authTransformId: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_AUTH_TRANSFORM_ID0
    cryptoModuleId: POINTER(Guid)
class IPSEC_AUTH_TRANSFORM_ID0(Structure):
    authType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_AUTH_TYPE
    authConfig: Byte
IPSEC_AUTH_TYPE = Int32
IPSEC_AUTH_MD5: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_AUTH_TYPE = 0
IPSEC_AUTH_SHA_1: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_AUTH_TYPE = 1
IPSEC_AUTH_SHA_256: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_AUTH_TYPE = 2
IPSEC_AUTH_AES_128: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_AUTH_TYPE = 3
IPSEC_AUTH_AES_192: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_AUTH_TYPE = 4
IPSEC_AUTH_AES_256: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_AUTH_TYPE = 5
IPSEC_AUTH_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_AUTH_TYPE = 6
class IPSEC_CIPHER_TRANSFORM0(Structure):
    cipherTransformId: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_CIPHER_TRANSFORM_ID0
    cryptoModuleId: POINTER(Guid)
class IPSEC_CIPHER_TRANSFORM_ID0(Structure):
    cipherType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_CIPHER_TYPE
    cipherConfig: Byte
IPSEC_CIPHER_TYPE = Int32
IPSEC_CIPHER_TYPE_DES: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_CIPHER_TYPE = 1
IPSEC_CIPHER_TYPE_3DES: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_CIPHER_TYPE = 2
IPSEC_CIPHER_TYPE_AES_128: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_CIPHER_TYPE = 3
IPSEC_CIPHER_TYPE_AES_192: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_CIPHER_TYPE = 4
IPSEC_CIPHER_TYPE_AES_256: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_CIPHER_TYPE = 5
IPSEC_CIPHER_TYPE_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_CIPHER_TYPE = 6
IPSEC_DOSP_FLAGS = UInt32
IPSEC_DOSP_FLAG_ENABLE_IKEV1: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_DOSP_FLAGS = 1
IPSEC_DOSP_FLAG_ENABLE_IKEV2: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_DOSP_FLAGS = 2
IPSEC_DOSP_FLAG_DISABLE_AUTHIP: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_DOSP_FLAGS = 4
IPSEC_DOSP_FLAG_DISABLE_DEFAULT_BLOCK: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_DOSP_FLAGS = 8
IPSEC_DOSP_FLAG_FILTER_BLOCK: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_DOSP_FLAGS = 16
IPSEC_DOSP_FLAG_FILTER_EXEMPT: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_DOSP_FLAGS = 32
class IPSEC_DOSP_OPTIONS0(Structure):
    stateIdleTimeoutSeconds: UInt32
    perIPRateLimitQueueIdleTimeoutSeconds: UInt32
    ipV6IPsecUnauthDscp: Byte
    ipV6IPsecUnauthRateLimitBytesPerSec: UInt32
    ipV6IPsecUnauthPerIPRateLimitBytesPerSec: UInt32
    ipV6IPsecAuthDscp: Byte
    ipV6IPsecAuthRateLimitBytesPerSec: UInt32
    icmpV6Dscp: Byte
    icmpV6RateLimitBytesPerSec: UInt32
    ipV6FilterExemptDscp: Byte
    ipV6FilterExemptRateLimitBytesPerSec: UInt32
    defBlockExemptDscp: Byte
    defBlockExemptRateLimitBytesPerSec: UInt32
    maxStateEntries: UInt32
    maxPerIPRateLimitQueues: UInt32
    flags: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_DOSP_FLAGS
    numPublicIFLuids: UInt32
    publicIFLuids: POINTER(UInt64)
    numInternalIFLuids: UInt32
    internalIFLuids: POINTER(UInt64)
    publicV6AddrMask: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_V6_ADDR_AND_MASK
    internalV6AddrMask: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_V6_ADDR_AND_MASK
class IPSEC_DOSP_STATE0(Structure):
    publicHostV6Addr: Byte * 16
    internalHostV6Addr: Byte * 16
    totalInboundIPv6IPsecAuthPackets: UInt64
    totalOutboundIPv6IPsecAuthPackets: UInt64
    durationSecs: UInt32
class IPSEC_DOSP_STATE_ENUM_TEMPLATE0(Structure):
    publicV6AddrMask: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_V6_ADDR_AND_MASK
    internalV6AddrMask: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_V6_ADDR_AND_MASK
class IPSEC_DOSP_STATISTICS0(Structure):
    totalStateEntriesCreated: UInt64
    currentStateEntries: UInt64
    totalInboundAllowedIPv6IPsecUnauthPkts: UInt64
    totalInboundRatelimitDiscardedIPv6IPsecUnauthPkts: UInt64
    totalInboundPerIPRatelimitDiscardedIPv6IPsecUnauthPkts: UInt64
    totalInboundOtherDiscardedIPv6IPsecUnauthPkts: UInt64
    totalInboundAllowedIPv6IPsecAuthPkts: UInt64
    totalInboundRatelimitDiscardedIPv6IPsecAuthPkts: UInt64
    totalInboundOtherDiscardedIPv6IPsecAuthPkts: UInt64
    totalInboundAllowedICMPv6Pkts: UInt64
    totalInboundRatelimitDiscardedICMPv6Pkts: UInt64
    totalInboundAllowedIPv6FilterExemptPkts: UInt64
    totalInboundRatelimitDiscardedIPv6FilterExemptPkts: UInt64
    totalInboundDiscardedIPv6FilterBlockPkts: UInt64
    totalInboundAllowedDefBlockExemptPkts: UInt64
    totalInboundRatelimitDiscardedDefBlockExemptPkts: UInt64
    totalInboundDiscardedDefBlockPkts: UInt64
    currentInboundIPv6IPsecUnauthPerIPRateLimitQueues: UInt64
class IPSEC_ESP_DROP_PACKET_STATISTICS0(Structure):
    invalidSpisOnInbound: UInt32
    decryptionFailuresOnInbound: UInt32
    authenticationFailuresOnInbound: UInt32
    replayCheckFailuresOnInbound: UInt32
    saNotInitializedOnInbound: UInt32
IPSEC_FAILURE_POINT = Int32
IPSEC_FAILURE_NONE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_FAILURE_POINT = 0
IPSEC_FAILURE_ME: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_FAILURE_POINT = 1
IPSEC_FAILURE_PEER: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_FAILURE_POINT = 2
IPSEC_FAILURE_POINT_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_FAILURE_POINT = 3
class IPSEC_GETSPI0(Structure):
    inboundIpsecTraffic: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRAFFIC0
    ipVersion: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_IP_VERSION
    Anonymous: _Anonymous_e__Union
    rngCryptoModuleID: POINTER(Guid)
    class _Anonymous_e__Union(Union):
        inboundUdpEncapsulation: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_V4_UDP_ENCAPSULATION0)
class IPSEC_GETSPI1(Structure):
    inboundIpsecTraffic: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRAFFIC1
    ipVersion: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_IP_VERSION
    Anonymous: _Anonymous_e__Union
    rngCryptoModuleID: POINTER(Guid)
    class _Anonymous_e__Union(Union):
        inboundUdpEncapsulation: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_V4_UDP_ENCAPSULATION0)
class IPSEC_ID0(Structure):
    mmTargetName: win32more.Windows.Win32.Foundation.PWSTR
    emTargetName: win32more.Windows.Win32.Foundation.PWSTR
    numTokens: UInt32
    tokens: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TOKEN0)
    explicitCredentials: UInt64
    logonId: UInt64
class IPSEC_KEYING_POLICY0(Structure):
    numKeyMods: UInt32
    keyModKeys: POINTER(Guid)
class IPSEC_KEYING_POLICY1(Structure):
    numKeyMods: UInt32
    keyModKeys: POINTER(Guid)
    flags: UInt32
class IPSEC_KEYMODULE_STATE0(Structure):
    keyModuleKey: Guid
    stateBlob: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB
class IPSEC_KEY_MANAGER0(Structure):
    keyManagerKey: Guid
    displayData: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_DISPLAY_DATA0
    flags: UInt32
    keyDictationTimeoutHint: Byte
class IPSEC_KEY_MANAGER_CALLBACKS0(Structure):
    reserved: Guid
    flags: UInt32
    keyDictationCheck: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_KEY_MANAGER_KEY_DICTATION_CHECK0
    keyDictation: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_KEY_MANAGER_DICTATE_KEY0
    keyNotify: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_KEY_MANAGER_NOTIFY_KEY0
@winfunctype_pointer
def IPSEC_KEY_MANAGER_DICTATE_KEY0(inboundSaDetails: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_DETAILS1), outboundSaDetails: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_DETAILS1), keyingModuleGenKey: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> UInt32: ...
@winfunctype_pointer
def IPSEC_KEY_MANAGER_KEY_DICTATION_CHECK0(ikeTraffic: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_TRAFFIC0), willDictateKey: POINTER(win32more.Windows.Win32.Foundation.BOOL), weight: POINTER(UInt32)) -> Void: ...
@winfunctype_pointer
def IPSEC_KEY_MANAGER_NOTIFY_KEY0(inboundSa: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_DETAILS1), outboundSa: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_DETAILS1)) -> Void: ...
IPSEC_PFS_GROUP = Int32
IPSEC_PFS_NONE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_PFS_GROUP = 0
IPSEC_PFS_1: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_PFS_GROUP = 1
IPSEC_PFS_2: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_PFS_GROUP = 2
IPSEC_PFS_2048: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_PFS_GROUP = 3
IPSEC_PFS_14: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_PFS_GROUP = 3
IPSEC_PFS_ECP_256: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_PFS_GROUP = 4
IPSEC_PFS_ECP_384: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_PFS_GROUP = 5
IPSEC_PFS_MM: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_PFS_GROUP = 6
IPSEC_PFS_24: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_PFS_GROUP = 7
IPSEC_PFS_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_PFS_GROUP = 8
IPSEC_POLICY_FLAG = UInt32
IPSEC_POLICY_FLAG_ND_SECURE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_POLICY_FLAG = 2
IPSEC_POLICY_FLAG_ND_BOUNDARY: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_POLICY_FLAG = 4
IPSEC_POLICY_FLAG_NAT_ENCAP_ALLOW_PEER_BEHIND_NAT: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_POLICY_FLAG = 16
IPSEC_POLICY_FLAG_NAT_ENCAP_ALLOW_GENERAL_NAT_TRAVERSAL: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_POLICY_FLAG = 32
IPSEC_POLICY_FLAG_DONT_NEGOTIATE_SECOND_LIFETIME: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_POLICY_FLAG = 64
IPSEC_POLICY_FLAG_DONT_NEGOTIATE_BYTE_LIFETIME: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_POLICY_FLAG = 128
IPSEC_POLICY_FLAG_CLEAR_DF_ON_TUNNEL: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_POLICY_FLAG = 8
IPSEC_POLICY_FLAG_ENABLE_V6_IN_V4_TUNNELING: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_POLICY_FLAG = 256
IPSEC_POLICY_FLAG_ENABLE_SERVER_ADDR_ASSIGNMENT: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_POLICY_FLAG = 512
IPSEC_POLICY_FLAG_TUNNEL_ALLOW_OUTBOUND_CLEAR_CONNECTION: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_POLICY_FLAG = 1024
IPSEC_POLICY_FLAG_TUNNEL_BYPASS_ALREADY_SECURE_CONNECTION: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_POLICY_FLAG = 2048
IPSEC_POLICY_FLAG_TUNNEL_BYPASS_ICMPV6: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_POLICY_FLAG = 4096
IPSEC_POLICY_FLAG_KEY_MANAGER_ALLOW_DICTATE_KEY: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_POLICY_FLAG = 8192
class IPSEC_PROPOSAL0(Structure):
    lifetime: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_LIFETIME0
    numSaTransforms: UInt32
    saTransforms: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_TRANSFORM0)
    pfsGroup: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_PFS_GROUP
class IPSEC_SA0(Structure):
    spi: UInt32
    saTransformType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRANSFORM_TYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        ahInformation: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_AUTH_INFORMATION0)
        espAuthInformation: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_AUTH_INFORMATION0)
        espCipherInformation: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_CIPHER_INFORMATION0)
        espAuthAndCipherInformation: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_AUTH_AND_CIPHER_INFORMATION0)
        espAuthFwInformation: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_AUTH_INFORMATION0)
class IPSEC_SA_AUTH_AND_CIPHER_INFORMATION0(Structure):
    saCipherInformation: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_CIPHER_INFORMATION0
    saAuthInformation: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_AUTH_INFORMATION0
class IPSEC_SA_AUTH_INFORMATION0(Structure):
    authTransform: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_AUTH_TRANSFORM0
    authKey: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB
class IPSEC_SA_BUNDLE0(Structure):
    flags: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_BUNDLE_FLAGS
    lifetime: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_LIFETIME0
    idleTimeoutSeconds: UInt32
    ndAllowClearTimeoutSeconds: UInt32
    ipsecId: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_ID0)
    napContext: UInt32
    qmSaId: UInt32
    numSAs: UInt32
    saList: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA0)
    keyModuleState: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_KEYMODULE_STATE0)
    ipVersion: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_IP_VERSION
    Anonymous: _Anonymous_e__Union
    mmSaId: UInt64
    pfsGroup: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_PFS_GROUP
    class _Anonymous_e__Union(Union):
        peerV4PrivateAddress: UInt32
class IPSEC_SA_BUNDLE1(Structure):
    flags: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_BUNDLE_FLAGS
    lifetime: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_LIFETIME0
    idleTimeoutSeconds: UInt32
    ndAllowClearTimeoutSeconds: UInt32
    ipsecId: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_ID0)
    napContext: UInt32
    qmSaId: UInt32
    numSAs: UInt32
    saList: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA0)
    keyModuleState: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_KEYMODULE_STATE0)
    ipVersion: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_IP_VERSION
    Anonymous: _Anonymous_e__Union
    mmSaId: UInt64
    pfsGroup: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_PFS_GROUP
    saLookupContext: Guid
    qmFilterId: UInt64
    class _Anonymous_e__Union(Union):
        peerV4PrivateAddress: UInt32
IPSEC_SA_BUNDLE_FLAGS = UInt32
IPSEC_SA_BUNDLE_FLAG_ND_SECURE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_BUNDLE_FLAGS = 1
IPSEC_SA_BUNDLE_FLAG_ND_BOUNDARY: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_BUNDLE_FLAGS = 2
IPSEC_SA_BUNDLE_FLAG_ND_PEER_NAT_BOUNDARY: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_BUNDLE_FLAGS = 4
IPSEC_SA_BUNDLE_FLAG_GUARANTEE_ENCRYPTION: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_BUNDLE_FLAGS = 8
IPSEC_SA_BUNDLE_FLAG_ALLOW_NULL_TARGET_NAME_MATCH: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_BUNDLE_FLAGS = 512
IPSEC_SA_BUNDLE_FLAG_CLEAR_DF_ON_TUNNEL: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_BUNDLE_FLAGS = 1024
IPSEC_SA_BUNDLE_FLAG_ASSUME_UDP_CONTEXT_OUTBOUND: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_BUNDLE_FLAGS = 2048
IPSEC_SA_BUNDLE_FLAG_ND_PEER_BOUNDARY: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_BUNDLE_FLAGS = 4096
IPSEC_SA_BUNDLE_FLAG_SUPPRESS_DUPLICATE_DELETION: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_BUNDLE_FLAGS = 8192
IPSEC_SA_BUNDLE_FLAG_PEER_SUPPORTS_GUARANTEE_ENCRYPTION: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_BUNDLE_FLAGS = 16384
class IPSEC_SA_CIPHER_INFORMATION0(Structure):
    cipherTransform: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_CIPHER_TRANSFORM0
    cipherKey: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_BYTE_BLOB
class IPSEC_SA_CONTEXT0(Structure):
    saContextId: UInt64
    inboundSa: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_DETAILS0)
    outboundSa: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_DETAILS0)
class IPSEC_SA_CONTEXT1(Structure):
    saContextId: UInt64
    inboundSa: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_DETAILS1)
    outboundSa: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_DETAILS1)
@winfunctype_pointer
def IPSEC_SA_CONTEXT_CALLBACK0(context: VoidPtr, change: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_CONTEXT_CHANGE0)) -> Void: ...
class IPSEC_SA_CONTEXT_CHANGE0(Structure):
    changeType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_CONTEXT_EVENT_TYPE0
    saContextId: UInt64
class IPSEC_SA_CONTEXT_ENUM_TEMPLATE0(Structure):
    localSubNet: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_CONDITION_VALUE0
    remoteSubNet: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_CONDITION_VALUE0
IPSEC_SA_CONTEXT_EVENT_TYPE0 = Int32
IPSEC_SA_CONTEXT_EVENT_ADD: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_CONTEXT_EVENT_TYPE0 = 1
IPSEC_SA_CONTEXT_EVENT_DELETE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_CONTEXT_EVENT_TYPE0 = 2
IPSEC_SA_CONTEXT_EVENT_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_CONTEXT_EVENT_TYPE0 = 3
class IPSEC_SA_CONTEXT_SUBSCRIPTION0(Structure):
    enumTemplate: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_CONTEXT_ENUM_TEMPLATE0)
    flags: UInt32
    sessionKey: Guid
class IPSEC_SA_DETAILS0(Structure):
    ipVersion: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_IP_VERSION
    saDirection: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_DIRECTION
    traffic: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRAFFIC0
    saBundle: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_BUNDLE0
    Anonymous: _Anonymous_e__Union
    transportFilter: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_FILTER0)
    class _Anonymous_e__Union(Union):
        udpEncapsulation: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_V4_UDP_ENCAPSULATION0)
class IPSEC_SA_DETAILS1(Structure):
    ipVersion: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_IP_VERSION
    saDirection: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_DIRECTION
    traffic: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRAFFIC1
    saBundle: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_BUNDLE1
    Anonymous: _Anonymous_e__Union
    transportFilter: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWPM_FILTER0)
    virtualIfTunnelInfo: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_VIRTUAL_IF_TUNNEL_INFO0
    class _Anonymous_e__Union(Union):
        udpEncapsulation: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_V4_UDP_ENCAPSULATION0)
class IPSEC_SA_ENUM_TEMPLATE0(Structure):
    saDirection: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_DIRECTION
class IPSEC_SA_IDLE_TIMEOUT0(Structure):
    idleTimeoutSeconds: UInt32
    idleTimeoutSecondsFailOver: UInt32
class IPSEC_SA_LIFETIME0(Structure):
    lifetimeSeconds: UInt32
    lifetimeKilobytes: UInt32
    lifetimePackets: UInt32
class IPSEC_SA_TRANSFORM0(Structure):
    ipsecTransformType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRANSFORM_TYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        ahTransform: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_AUTH_TRANSFORM0)
        espAuthTransform: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_AUTH_TRANSFORM0)
        espCipherTransform: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_CIPHER_TRANSFORM0)
        espAuthAndCipherTransform: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_AUTH_AND_CIPHER_TRANSFORM0)
        espAuthFwTransform: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_AUTH_TRANSFORM0)
class IPSEC_STATISTICS0(Structure):
    aggregateSaStatistics: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_AGGREGATE_SA_STATISTICS0
    espDropPacketStatistics: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_ESP_DROP_PACKET_STATISTICS0
    ahDropPacketStatistics: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_AH_DROP_PACKET_STATISTICS0
    aggregateDropPacketStatistics: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_AGGREGATE_DROP_PACKET_STATISTICS0
    inboundTrafficStatistics: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRAFFIC_STATISTICS0
    outboundTrafficStatistics: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRAFFIC_STATISTICS0
class IPSEC_STATISTICS1(Structure):
    aggregateSaStatistics: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_AGGREGATE_SA_STATISTICS0
    espDropPacketStatistics: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_ESP_DROP_PACKET_STATISTICS0
    ahDropPacketStatistics: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_AH_DROP_PACKET_STATISTICS0
    aggregateDropPacketStatistics: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_AGGREGATE_DROP_PACKET_STATISTICS1
    inboundTrafficStatistics: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRAFFIC_STATISTICS1
    outboundTrafficStatistics: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRAFFIC_STATISTICS1
class IPSEC_TOKEN0(Structure):
    type: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TOKEN_TYPE
    principal: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TOKEN_PRINCIPAL
    mode: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TOKEN_MODE
    token: UInt64
IPSEC_TOKEN_MODE = Int32
IPSEC_TOKEN_MODE_MAIN: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TOKEN_MODE = 0
IPSEC_TOKEN_MODE_EXTENDED: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TOKEN_MODE = 1
IPSEC_TOKEN_MODE_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TOKEN_MODE = 2
IPSEC_TOKEN_PRINCIPAL = Int32
IPSEC_TOKEN_PRINCIPAL_LOCAL: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TOKEN_PRINCIPAL = 0
IPSEC_TOKEN_PRINCIPAL_PEER: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TOKEN_PRINCIPAL = 1
IPSEC_TOKEN_PRINCIPAL_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TOKEN_PRINCIPAL = 2
IPSEC_TOKEN_TYPE = Int32
IPSEC_TOKEN_TYPE_MACHINE: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TOKEN_TYPE = 0
IPSEC_TOKEN_TYPE_IMPERSONATION: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TOKEN_TYPE = 1
IPSEC_TOKEN_TYPE_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TOKEN_TYPE = 2
class IPSEC_TRAFFIC0(Structure):
    ipVersion: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_IP_VERSION
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    trafficType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRAFFIC_TYPE
    Anonymous3: _Anonymous3_e__Union
    remotePort: UInt16
    class _Anonymous1_e__Union(Union):
        localV4Address: UInt32
        localV6Address: Byte * 16
    class _Anonymous2_e__Union(Union):
        remoteV4Address: UInt32
        remoteV6Address: Byte * 16
    class _Anonymous3_e__Union(Union):
        ipsecFilterId: UInt64
        tunnelPolicyId: UInt64
class IPSEC_TRAFFIC1(Structure):
    ipVersion: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_IP_VERSION
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    trafficType: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRAFFIC_TYPE
    Anonymous3: _Anonymous3_e__Union
    remotePort: UInt16
    localPort: UInt16
    ipProtocol: Byte
    localIfLuid: UInt64
    realIfProfileId: UInt32
    class _Anonymous1_e__Union(Union):
        localV4Address: UInt32
        localV6Address: Byte * 16
    class _Anonymous2_e__Union(Union):
        remoteV4Address: UInt32
        remoteV6Address: Byte * 16
    class _Anonymous3_e__Union(Union):
        ipsecFilterId: UInt64
        tunnelPolicyId: UInt64
class IPSEC_TRAFFIC_SELECTOR0(Structure):
    protocolId: Byte
    portStart: UInt16
    portEnd: UInt16
    ipVersion: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_IP_VERSION
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    class _Anonymous1_e__Union(Union):
        startV4Address: UInt32
        startV6Address: Byte * 16
    class _Anonymous2_e__Union(Union):
        endV4Address: UInt32
        endV6Address: Byte * 16
class IPSEC_TRAFFIC_SELECTOR_POLICY0(Structure):
    flags: UInt32
    numLocalTrafficSelectors: UInt32
    localTrafficSelectors: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRAFFIC_SELECTOR0)
    numRemoteTrafficSelectors: UInt32
    remoteTrafficSelectors: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRAFFIC_SELECTOR0)
class IPSEC_TRAFFIC_STATISTICS0(Structure):
    encryptedByteCount: UInt64
    authenticatedAHByteCount: UInt64
    authenticatedESPByteCount: UInt64
    transportByteCount: UInt64
    tunnelByteCount: UInt64
    offloadByteCount: UInt64
class IPSEC_TRAFFIC_STATISTICS1(Structure):
    encryptedByteCount: UInt64
    authenticatedAHByteCount: UInt64
    authenticatedESPByteCount: UInt64
    transportByteCount: UInt64
    tunnelByteCount: UInt64
    offloadByteCount: UInt64
    totalSuccessfulPackets: UInt64
IPSEC_TRAFFIC_TYPE = Int32
IPSEC_TRAFFIC_TYPE_TRANSPORT: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRAFFIC_TYPE = 0
IPSEC_TRAFFIC_TYPE_TUNNEL: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRAFFIC_TYPE = 1
IPSEC_TRAFFIC_TYPE_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRAFFIC_TYPE = 2
IPSEC_TRANSFORM_TYPE = Int32
IPSEC_TRANSFORM_AH: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRANSFORM_TYPE = 1
IPSEC_TRANSFORM_ESP_AUTH: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRANSFORM_TYPE = 2
IPSEC_TRANSFORM_ESP_CIPHER: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRANSFORM_TYPE = 3
IPSEC_TRANSFORM_ESP_AUTH_AND_CIPHER: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRANSFORM_TYPE = 4
IPSEC_TRANSFORM_ESP_AUTH_FW: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRANSFORM_TYPE = 5
IPSEC_TRANSFORM_TYPE_MAX: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRANSFORM_TYPE = 6
class IPSEC_TRANSPORT_POLICY0(Structure):
    numIpsecProposals: UInt32
    ipsecProposals: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_PROPOSAL0)
    flags: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_POLICY_FLAG
    ndAllowClearTimeoutSeconds: UInt32
    saIdleTimeout: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_IDLE_TIMEOUT0
    emPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_EM_POLICY0)
class IPSEC_TRANSPORT_POLICY1(Structure):
    numIpsecProposals: UInt32
    ipsecProposals: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_PROPOSAL0)
    flags: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_POLICY_FLAG
    ndAllowClearTimeoutSeconds: UInt32
    saIdleTimeout: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_IDLE_TIMEOUT0
    emPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_EM_POLICY1)
class IPSEC_TRANSPORT_POLICY2(Structure):
    numIpsecProposals: UInt32
    ipsecProposals: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_PROPOSAL0)
    flags: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_POLICY_FLAG
    ndAllowClearTimeoutSeconds: UInt32
    saIdleTimeout: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_IDLE_TIMEOUT0
    emPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_EM_POLICY2)
class IPSEC_TUNNEL_ENDPOINT0(Structure):
    ipVersion: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_IP_VERSION
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        v4Address: UInt32
        v6Address: Byte * 16
class IPSEC_TUNNEL_ENDPOINTS0(Structure):
    ipVersion: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_IP_VERSION
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    class _Anonymous1_e__Union(Union):
        localV4Address: UInt32
        localV6Address: Byte * 16
    class _Anonymous2_e__Union(Union):
        remoteV4Address: UInt32
        remoteV6Address: Byte * 16
class IPSEC_TUNNEL_ENDPOINTS1(Structure):
    ipVersion: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_IP_VERSION
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    localIfLuid: UInt64
    class _Anonymous1_e__Union(Union):
        localV4Address: UInt32
        localV6Address: Byte * 16
    class _Anonymous2_e__Union(Union):
        remoteV4Address: UInt32
        remoteV6Address: Byte * 16
class IPSEC_TUNNEL_ENDPOINTS2(Structure):
    ipVersion: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.FWP_IP_VERSION
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    localIfLuid: UInt64
    remoteFqdn: win32more.Windows.Win32.Foundation.PWSTR
    numAddresses: UInt32
    remoteAddresses: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TUNNEL_ENDPOINT0)
    class _Anonymous1_e__Union(Union):
        localV4Address: UInt32
        localV6Address: Byte * 16
    class _Anonymous2_e__Union(Union):
        remoteV4Address: UInt32
        remoteV6Address: Byte * 16
class IPSEC_TUNNEL_POLICY0(Structure):
    flags: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_POLICY_FLAG
    numIpsecProposals: UInt32
    ipsecProposals: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_PROPOSAL0)
    tunnelEndpoints: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TUNNEL_ENDPOINTS0
    saIdleTimeout: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_IDLE_TIMEOUT0
    emPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_EM_POLICY0)
class IPSEC_TUNNEL_POLICY1(Structure):
    flags: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_POLICY_FLAG
    numIpsecProposals: UInt32
    ipsecProposals: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_PROPOSAL0)
    tunnelEndpoints: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TUNNEL_ENDPOINTS1
    saIdleTimeout: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_IDLE_TIMEOUT0
    emPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_EM_POLICY1)
class IPSEC_TUNNEL_POLICY2(Structure):
    flags: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_POLICY_FLAG
    numIpsecProposals: UInt32
    ipsecProposals: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_PROPOSAL0)
    tunnelEndpoints: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TUNNEL_ENDPOINTS2
    saIdleTimeout: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_IDLE_TIMEOUT0
    emPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_EM_POLICY2)
    fwdPathSaLifetime: UInt32
class IPSEC_TUNNEL_POLICY3(Structure):
    flags: UInt32
    numIpsecProposals: UInt32
    ipsecProposals: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_PROPOSAL0)
    tunnelEndpoints: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TUNNEL_ENDPOINTS2
    saIdleTimeout: win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_SA_IDLE_TIMEOUT0
    emPolicy: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IKEEXT_EM_POLICY2)
    fwdPathSaLifetime: UInt32
    compartmentId: UInt32
    numTrafficSelectorPolicy: UInt32
    trafficSelectorPolicies: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsFilteringPlatform.IPSEC_TRAFFIC_SELECTOR_POLICY0)
class IPSEC_V4_UDP_ENCAPSULATION0(Structure):
    localUdpEncapPort: UInt16
    remoteUdpEncapPort: UInt16
class IPSEC_VIRTUAL_IF_TUNNEL_INFO0(Structure):
    virtualIfTunnelId: UInt64
    trafficSelectorId: UInt64


make_ready(__name__)
